@@ -132,6 +132,12 @@ export const TOGGLE_CANARY = {
   defaultKeys: ['g x'], // eslint-disable-line @gitlab/require-i18n-strings
 };
 
+export const DUO_CHAT = {
+  id: 'globalShortcuts.duoChat',
+  description: __('Open GitLab Duo Chat'),
+  defaultKeys: ['d'],
+};
+
 export const BOLD_TEXT = {
   id: 'editing.boldText',
   description: __('Bold text'),
@@ -190,7 +196,10 @@ export const TOGGLE_MARKDOWN_PREVIEW = {
   // However, this particular shortcut has been in place since before the `mod` key was available.
   // We've chosen to leave this implemented as-is for the time being to avoid breaking people's workflows.
   // See discussion in https://gitlab.com/gitlab-org/gitlab/-/merge_requests/45308#note_527490548.
-  defaultKeys: ['ctrl+shift+p', 'command+shift+p'],
+  // Update 2025-07-17: Adding `alt` version to fix an issue in Windows
+  // This new combination is compatible across Mac, Linux and Windows.
+  // See https://gitlab.com/gitlab-org/gitlab/-/issues/17600#note_2633177789
+  defaultKeys: ['ctrl+shift+p', 'command+shift+p', 'alt+shift+p'],
 };
 
 /**
@@ -386,14 +395,13 @@ export const PROJECT_FILES_GO_BACK = {
   id: 'projectFiles.goBack',
   description: __('Go back (while searching for files)'),
   defaultKeys: ['esc'],
+  // ESC is OK to have multiple actions
+  overrideGlobalHotkey: true,
 };
 
-const { blobOverflowMenu } = gon.features ?? {};
-export const PROJECT_FILES_GO_TO_PERMALINK = {
-  id: 'projectFiles.goToFilePermalink',
-  description: blobOverflowMenu
-    ? __('Copy file permalink')
-    : __('Go to file permalink (while viewing a file)'),
+export const PROJECT_FILES_COPY_FILE_PERMALINK = {
+  id: 'projectFiles.copyFilePermalink',
+  description: __('Copy file permalink'),
   defaultKeys: ['y'],
 };
 
@@ -403,6 +411,13 @@ export const PROJECT_FILES_GO_TO_COMPARE = {
   defaultKeys: ['shift+c'],
 };
 
+export const FOCUS_FILE_TREE_BROWSER_FILTER_BAR = {
+  id: 'projectFiles.focusFTBFilterBar',
+  description: __('Focus file tree browser filter bar'),
+  defaultKeys: ['f'],
+  overrideGlobalHotkey: true,
+};
+
 export const ISSUABLE_COMMENT_OR_REPLY = {
   id: 'issuables.commentReply',
   description: __('Comment/Reply (quoting selected text)'),
@@ -458,10 +473,19 @@ export const MR_GO_TO_FILE = {
   customizable: false,
 };
 
+export const MR_FOCUS_FILE_BROWSER = {
+  id: 'mergeRequests.focusFileBrowser',
+  description: __('Focus file browser'),
+  defaultKeys: ['f'],
+  customizable: false,
+  // there's no filtered search on the page, instead we focus the file browser search manually
+  overrideGlobalHotkey: true,
+};
+
 export const MR_TOGGLE_FILE_BROWSER = {
   id: 'mergeRequests.toggleFileBrowser',
   description: __('Toggle file browser'),
-  defaultKeys: ['f'],
+  defaultKeys: ['shift+f'],
   customizable: false,
 };
 
@@ -479,15 +503,22 @@ export const MR_ADD_COMMENT_NOW = {
   customizable: false,
 };
 
+export const MR_TOGGLE_REVIEW = {
+  id: 'mergeRequests.toggleReview',
+  description: s__('MergeRequest|Viewed by me'),
+  defaultKeys: ['v'],
+  customizable: false,
+};
+
 export const MR_NEXT_UNRESOLVED_DISCUSSION = {
   id: 'mergeRequests.nextUnresolvedDiscussion',
-  description: __('Next unresolved thread'),
+  description: __('Next open thread'),
   defaultKeys: ['n'],
 };
 
 export const MR_PREVIOUS_UNRESOLVED_DISCUSSION = {
   id: 'mergeRequests.previousUnresolvedDiscussion',
-  description: __('Previous unresolved thread'),
+  description: __('Previous open thread'),
   defaultKeys: ['p'],
 };
 
@@ -538,12 +569,24 @@ export const ISSUE_CLOSE_DESIGN = {
   id: 'issues.closeDesign',
   description: __('Close design'),
   defaultKeys: ['esc'],
+  // ESC is OK to have multiple actions
+  overrideGlobalHotkey: true,
 };
 
 export const SIDEBAR_CLOSE_WIDGET = {
   id: 'sidebar.closeWidget',
   description: __('Close sidebar widget'),
   defaultKeys: ['esc'],
+  // ESC is OK to have multiple actions
+  overrideGlobalHotkey: true,
+};
+
+export const WORK_ITEM_TOGGLE_SIDEBAR = {
+  id: 'workitems.toggleSidebar',
+  description: __('Show or hide sidebar'),
+  defaultKeys: ['mod+/', 'shift+mod+7'], // eslint-disable-line @gitlab/require-i18n-strings
+  // Shift+7 is equivalent to forward-slash on some keyboards without a dedicated key
+  customizable: false,
 };
 
 /**
@@ -587,6 +630,7 @@ const GLOBAL_SHORTCUTS_GROUP = {
     TOGGLE_PERFORMANCE_BAR,
     HIDE_APPEARING_CONTENT,
     TOGGLE_SUPER_SIDEBAR,
+    DUO_CHAT,
   ],
 };
 
@@ -658,7 +702,7 @@ const PROJECT_FILES_SHORTCUTS_GROUP = {
     PROJECT_FILES_MOVE_SELECTION_DOWN,
     PROJECT_FILES_OPEN_SELECTION,
     PROJECT_FILES_GO_BACK,
-    PROJECT_FILES_GO_TO_PERMALINK,
+    PROJECT_FILES_COPY_FILE_PERMALINK,
     PROJECT_FILES_GO_TO_COMPARE,
   ],
 };
@@ -690,9 +734,11 @@ const MR_SHORTCUTS_GROUP = {
     MR_NEXT_UNRESOLVED_DISCUSSION,
     MR_PREVIOUS_UNRESOLVED_DISCUSSION,
     MR_COPY_SOURCE_BRANCH_NAME,
+    MR_FOCUS_FILE_BROWSER,
     MR_TOGGLE_FILE_BROWSER,
     MR_ADD_TO_REVIEW,
     MR_ADD_COMMENT_NOW,
+    MR_TOGGLE_REVIEW,
   ],
 };
 
