@@ -59,6 +59,7 @@ import {
   EVT_MR_PREPARED,
   FILE_DIFF_POSITION_TYPE,
   EVT_DISCUSSIONS_ASSIGNED,
+  OLD_LINE_TYPE,
 } from '../../constants';
 import {
   DISCUSSION_SINGLE_DIFF_FAILED,
@@ -449,6 +450,8 @@ export function assignDiscussionsToDiff(discussions) {
   Vue.nextTick(() => {
     eventHub.$emit(EVT_DISCUSSIONS_ASSIGNED);
   });
+
+  return Promise.resolve();
 }
 
 export function removeDiscussionsFromDiff(removeDiscussion) {
@@ -660,6 +663,48 @@ export async function saveDiffDiscussion({ note, formData }) {
     });
 }
 
+export function getLinesForDiscussion({ discussion }) {
+  const lines = [];
+
+  if (!discussion?.diff_file || !discussion?.position) {
+    return lines;
+  }
+
+  const diffFile = this.diffFiles.find((file) => file.file_hash === discussion.diff_file.file_hash);
+
+  if (!diffFile) {
+    return lines;
+  }
+
+  const diffLines = diffFile[INLINE_DIFF_LINES_KEY];
+  let isAdding = false;
+  const { start, end } = discussion.position?.line_range || {};
+
+  if (!start || !end) {
+    return lines;
+  }
+
+  for (let i = 0, diffLinesLength = diffLines.length - 1; i <= diffLinesLength; i += 1) {
+    const line = diffLines[i];
+
+    if (start.line_code === line.line_code) {
+      isAdding = true;
+    }
+
+    if (isAdding) {
+      if (line.type !== OLD_LINE_TYPE) {
+        lines.push(line);
+      }
+
+      if (end.line_code === line.line_code) {
+        break;
+      }
+    }
+  }
+
+  return lines;
+}
+
 export function toggleTreeOpen(path) {
   this[types.TOGGLE_FOLDER_OPEN](path);
 }
@@ -669,6 +714,8 @@ export function setTreeOpen({ path, opened }) {
 }
 
 export function setCurrentFileHash(hash) {
+  if (hash.startsWith('note_')) return;
+
   this[types.SET_CURRENT_DIFF_FILE](hash);
 }
 
@@ -992,13 +1039,15 @@ export function rereadNoteHash() {
 export function setCurrentDiffFileIdFromNote(noteId) {
   const note = useNotes().notesById[noteId];
 
-  if (!note) return;
+  if (!note) return Promise.resolve();
 
   const fileHash = useNotes().getDiscussion(note.discussion_id).diff_file?.file_hash;
 
   if (fileHash && this.flatBlobsList.some((f) => f.fileHash === fileHash)) {
     this[types.SET_CURRENT_DIFF_FILE](fileHash);
   }
+
+  return Promise.resolve();
 }
 
 export function navigateToDiffFileIndex(index) {
@@ -1126,6 +1175,7 @@ export function fetchLinkedExpandedLine({ fileHash, oldLine, newLine }) {
   const matchLine = findClosestMatchLine(lines, newLine);
   const { new_pos: matchNewPosition, old_pos: matchOldPosition } = matchLine.meta_data;
   const matchLineIndex = lines.indexOf(matchLine);
+  const targetIsBeforeMatch = newLine < matchNewPosition;
   const linesInBetween = countLinesInBetween(lines, matchLineIndex);
   const isExpandBoth = linesInBetween !== -1 && linesInBetween < 20;
   const previousLine = lines[matchLineIndex - 1];
@@ -1160,6 +1210,15 @@ export function fetchLinkedExpandedLine({ fileHash, oldLine, newLine }) {
     });
   }
 
+  if (targetIsBeforeMatch && isExpandDown && previousLine && newLine < previousLine.new_line) {
+    return loadLines({
+      unfold: true,
+      since: newLine,
+      to: matchNewPosition - 1,
+      bottom: isLastMatchLine,
+    });
+  }
+
   if (!isExpandDown) {
     return loadLines({
       unfold: true,
