@@ -364,6 +364,12 @@ export const insertText = (target, text) => {
   const insertedText = text instanceof Function ? text(textBefore, textAfter) : text;
   const hasSelection = selectionEnd !== selectionStart;
 
+  const currentActiveElement = document.activeElement;
+
+  if (document.activeElement !== target) {
+    target.focus();
+  }
+
   // The `execCommand` is officially deprecated.  However, for `insertText`,
   // there is currently no alternative. We need to use it in order to trigger
   // the browser's undo tracking when we insert text.
@@ -398,6 +404,10 @@ export const insertText = (target, text) => {
   const event = document.createEvent('Event');
   event.initEvent('autosize:update', true, false);
   target.dispatchEvent(event);
+
+  if (currentActiveElement !== target) {
+    currentActiveElement.focus();
+  }
 };
 
 /**
@@ -526,10 +536,14 @@ export const backOff = (fn, timeout = 60000) => {
   });
 };
 
-export const spriteIcon = (icon, className = '') => {
+export const spriteIcon = (icon, className = '', color = '') => {
   const classAttribute = className.length > 0 ? `class="${className}"` : '';
+  // Leading space before `style` attribute is kept on purpose
+  // to prevent causing all snapshot tests to fail when `color`
+  // is not provided.
+  const styleAttribute = color ? ` style="color: ${color};"` : '';
 
-  return `<svg ${classAttribute}><use xlink:href="${gon.sprite_icons}#${escape(icon)}" /></svg>`;
+  return `<svg ${classAttribute}${styleAttribute}><use xlink:href="${gon.sprite_icons}#${escape(icon)}" /></svg>`;
 };
 
 /**
@@ -791,6 +805,8 @@ export const isCurrentUser = (userId) => {
 /**
  * Clones an object via JSON stringifying and re-parsing.
  * This ensures object references are not persisted (e.g. unlike lodash cloneDeep)
+ * See https://github.com/lodash/lodash/issues/4710#issuecomment-606892867 for details on cloneDeep circular references
+ * See https://developer.mozilla.org/en-US/docs/Web/API/Web_Workers_API/Structured_clone_algorithm for the underlying mechanism used by Lodash
  */
 export const cloneWithoutReferences = (obj) => {
   return JSON.parse(JSON.stringify(obj));
