@@ -1,6 +1,5 @@
 import Vue from 'vue';
 import DiscussionCounter from '~/notes/components/discussion_counter.vue';
-import store from '~/mr_notes/stores';
 import { pinia } from '~/pinia/instance';
 
 export function initDiscussionCounter() {
@@ -17,7 +16,6 @@ export function initDiscussionCounter() {
         DiscussionCounter,
       },
       pinia,
-      store,
       render(createElement) {
         return createElement('discussion-counter', {
           props: {
