@@ -1,6 +1,6 @@
 import initStaleRunnerCleanupSetting from 'ee_else_ce/group_settings/stale_runner_cleanup';
 import { initAllowRunnerRegistrationTokenToggle } from '~/group_settings/allow_runner_registration_token_toggle';
-import { initJwtCiCdJobTokenEnabledToggle } from '~/group_settings/jwt_ci_cd_job_token_enabled_toggle';
+import { initSettingsToggles } from '~/group_settings/settings_toggles';
 
 import initPipelineVariablesDefaultRole from '~/group_settings/pipeline_variables_default_role';
 import initVariableList from '~/ci/ci_variable_list';
@@ -12,7 +12,7 @@ import initDeployTokens from '~/deploy_tokens';
 initSettingsPanels();
 initDeployTokens();
 initAllowRunnerRegistrationTokenToggle();
-initJwtCiCdJobTokenEnabledToggle();
+initSettingsToggles();
 initSharedRunnersForm();
 initStaleRunnerCleanupSetting();
 initVariableList();
