@@ -1,10 +1,9 @@
 import initCommitActions from '~/projects/commit';
 import { initCommitBoxInfo } from '~/projects/commit_box/info';
-import { createRapidDiffsApp } from '~/rapid_diffs/app';
+import { createRapidDiffsApp } from '~/rapid_diffs';
 
 initCommitBoxInfo();
 initCommitActions();
 
 const app = createRapidDiffsApp();
-app.streamRemainingDiffs();
 app.init();
