@@ -1,6 +1,8 @@
 import PersistentUserCallout from './persistent_user_callout';
 
 const PERSISTENT_USER_CALLOUTS = [
+  '.js-persistent-callout',
+  // NOTE: unique callouts selectors are to be removed within https://gitlab.com/gitlab-org/gitlab/-/issues/527723
   '.js-recovery-settings-callout',
   '.js-users-over-license-callout',
   '.js-admin-licensed-user-count-threshold',
@@ -32,6 +34,7 @@ const PERSISTENT_USER_CALLOUTS = [
   '.js-pipl-compliance-alert',
   '.gcp-signup-offer',
   '.js-gold-trial-callout',
+  '.js-data-collection-callout',
 ];
 
 const initCallouts = () => {
