@@ -1,5 +1,6 @@
 import { getIdFromGraphQLId } from '~/graphql_shared/utils';
-import { availableGraphQLProjectActions } from 'ee_else_ce/vue_shared/components/projects_list/utils';
+import { availableGraphQLProjectActions } from '~/vue_shared/components/projects_list/utils';
+import { joinPaths } from '~/lib/utils/url_utility';
 
 export const formatGraphQLProjects = (projects, callback = () => {}) =>
   projects.map(
@@ -11,6 +12,7 @@ export const formatGraphQLProjects = (projects, callback = () => {}) =>
       forkingAccessLevel,
       maxAccessLevel: accessLevel,
       group,
+      fullPath,
       ...project
     }) => {
       const baseProject = {
@@ -25,6 +27,8 @@ export const formatGraphQLProjects = (projects, callback = () => {}) =>
         accessLevel,
         availableActions: availableGraphQLProjectActions(project),
         isPersonal: group === null,
+        fullPath,
+        relativeWebUrl: joinPaths('/', gon.relative_url_root, fullPath),
       };
 
       return {
