@@ -1,87 +1,144 @@
-import { escapeRegExp } from 'lodash';
+import { escapeRegExp, kebabCase } from 'lodash';
 import { getIdFromGraphQLId } from '~/graphql_shared/utils';
-import { queryToObject, joinPaths } from '~/lib/utils/url_utility';
+import { joinPaths, queryToObject } from '~/lib/utils/url_utility';
 import AccessorUtilities from '~/lib/utils/accessor';
 import { parseBoolean } from '~/lib/utils/common_utils';
+import { getDraft, updateDraft } from '~/lib/utils/autosave';
 import { TYPE_EPIC, TYPE_ISSUE } from '~/issues/constants';
-
 import {
+  DEFAULT_PAGE_SIZE_CHILD_ITEMS,
+  NAME_TO_ENUM_MAP,
+  NAME_TO_ICON_MAP,
+  NAME_TO_ROUTE_MAP,
+  NEW_WORK_ITEM_GID,
   NEW_WORK_ITEM_IID,
+  STATE_CLOSED,
   WIDGET_TYPE_ASSIGNEES,
+  WIDGET_TYPE_AWARD_EMOJI,
+  WIDGET_TYPE_COLOR,
+  WIDGET_TYPE_CRM_CONTACTS,
+  WIDGET_TYPE_CURRENT_USER_TODOS,
+  WIDGET_TYPE_CUSTOM_FIELDS,
   WIDGET_TYPE_DESCRIPTION,
   WIDGET_TYPE_DESIGNS,
+  WIDGET_TYPE_DEVELOPMENT,
+  WIDGET_TYPE_EMAIL_PARTICIPANTS,
+  WIDGET_TYPE_ERROR_TRACKING,
   WIDGET_TYPE_HEALTH_STATUS,
   WIDGET_TYPE_HIERARCHY,
+  WIDGET_TYPE_ITERATION,
   WIDGET_TYPE_LABELS,
+  WIDGET_TYPE_LINKED_ITEMS,
+  WIDGET_TYPE_LINKED_RESOURCES,
   WIDGET_TYPE_MILESTONE,
   WIDGET_TYPE_NOTES,
   WIDGET_TYPE_START_AND_DUE_DATE,
+  WIDGET_TYPE_STATUS,
+  WIDGET_TYPE_TIME_TRACKING,
+  WIDGET_TYPE_VULNERABILITIES,
   WIDGET_TYPE_WEIGHT,
-  WIDGET_TYPE_AWARD_EMOJI,
-  WIDGET_TYPE_LINKED_ITEMS,
-  ISSUABLE_EPIC,
-  WORK_ITEMS_TYPE_MAP,
-  WORK_ITEM_TYPE_ENUM_EPIC,
+  WORK_ITEM_TYPE_NAME_ISSUE,
   WORK_ITEM_TYPE_ROUTE_WORK_ITEM,
-  NEW_WORK_ITEM_GID,
-  DEFAULT_PAGE_SIZE_CHILD_ITEMS,
-  STATE_CLOSED,
-  WORK_ITEM_TYPE_VALUE_MAP,
 } from './constants';
 
 export const isAssigneesWidget = (widget) => widget.type === WIDGET_TYPE_ASSIGNEES;
 
-export const isHealthStatusWidget = (widget) => widget.type === WIDGET_TYPE_HEALTH_STATUS;
-
-export const isLabelsWidget = (widget) => widget.type === WIDGET_TYPE_LABELS;
-
 export const isMilestoneWidget = (widget) => widget.type === WIDGET_TYPE_MILESTONE;
 
 export const isNotesWidget = (widget) => widget.type === WIDGET_TYPE_NOTES;
 
-export const isStartAndDueDateWidget = (widget) => widget.type === WIDGET_TYPE_START_AND_DUE_DATE;
+export const findAssigneesWidget = (workItem) =>
+  workItem?.widgets?.find((widget) => widget.type === WIDGET_TYPE_ASSIGNEES);
 
-export const isWeightWidget = (widget) => widget.type === WIDGET_TYPE_WEIGHT;
+export const findAwardEmojiWidget = (workItem) =>
+  workItem?.widgets?.find((widget) => widget.type === WIDGET_TYPE_AWARD_EMOJI);
 
-export const findHierarchyWidgets = (widgets) =>
-  widgets?.find((widget) => widget.type === WIDGET_TYPE_HIERARCHY);
+export const findColorWidget = (workItem) =>
+  workItem?.widgets?.find((widget) => widget.type === WIDGET_TYPE_COLOR);
+
+export const findCrmContactsWidget = (workItem) =>
+  workItem?.widgets?.find((widget) => widget.type === WIDGET_TYPE_CRM_CONTACTS);
+
+export const findCurrentUserTodosWidget = (workItem) =>
+  workItem?.widgets?.find((widget) => widget.type === WIDGET_TYPE_CURRENT_USER_TODOS);
+
+export const findCustomFieldsWidget = (workItem) =>
+  workItem?.widgets?.find((widget) => widget.type === WIDGET_TYPE_CUSTOM_FIELDS);
 
 export const findDescriptionWidget = (workItem) =>
   workItem?.widgets?.find((widget) => widget.type === WIDGET_TYPE_DESCRIPTION);
 
+export const findDesignsWidget = (workItem) =>
+  workItem?.widgets?.find((widget) => widget.type === WIDGET_TYPE_DESIGNS);
+
+export const findDevelopmentWidget = (workItem) =>
+  workItem?.widgets?.find((widget) => widget.type === WIDGET_TYPE_DEVELOPMENT);
+
+export const findEmailParticipantsWidget = (workItem) =>
+  workItem?.widgets?.find((widget) => widget.type === WIDGET_TYPE_EMAIL_PARTICIPANTS);
+
+export const findErrorTrackingWidget = (workItem) =>
+  workItem?.widgets?.find((widget) => widget.type === WIDGET_TYPE_ERROR_TRACKING);
+
+export const findHealthStatusWidget = (workItem) =>
+  workItem?.widgets?.find((widget) => widget.type === WIDGET_TYPE_HEALTH_STATUS);
+
+export const findHierarchyWidget = (workItem) =>
+  workItem?.widgets?.find((widget) => widget.type === WIDGET_TYPE_HIERARCHY);
+
+export const findIterationWidget = (workItem) =>
+  workItem?.widgets?.find((widget) => widget.type === WIDGET_TYPE_ITERATION);
+
+export const findLabelsWidget = (workItem) =>
+  workItem?.widgets?.find((widget) => widget.type === WIDGET_TYPE_LABELS);
+
 export const findLinkedItemsWidget = (workItem) =>
-  workItem.widgets?.find((widget) => widget.type === WIDGET_TYPE_LINKED_ITEMS);
+  workItem?.widgets?.find((widget) => widget.type === WIDGET_TYPE_LINKED_ITEMS);
+
+export const findLinkedResourcesWidget = (workItem) =>
+  workItem?.widgets?.find((widget) => widget.type === WIDGET_TYPE_LINKED_RESOURCES);
+
+export const findMilestoneWidget = (workItem) =>
+  workItem?.widgets?.find((widget) => widget.type === WIDGET_TYPE_MILESTONE);
 
 export const findNotesWidget = (workItem) =>
   workItem?.widgets?.find((widget) => widget.type === WIDGET_TYPE_NOTES);
 
 export const findStartAndDueDateWidget = (workItem) =>
-  workItem.widgets?.find((widget) => widget.type === WIDGET_TYPE_START_AND_DUE_DATE);
+  workItem?.widgets?.find((widget) => widget.type === WIDGET_TYPE_START_AND_DUE_DATE);
 
-export const findAwardEmojiWidget = (workItem) =>
-  workItem.widgets?.find((widget) => widget.type === WIDGET_TYPE_AWARD_EMOJI);
+export const findStatusWidget = (workItem) =>
+  workItem?.widgets?.find((widget) => widget.type === WIDGET_TYPE_STATUS);
+
+export const findTimeTrackingWidget = (workItem) =>
+  workItem?.widgets?.find((widget) => widget.type === WIDGET_TYPE_TIME_TRACKING);
+
+export const findVulnerabilitiesWidget = (workItem) =>
+  workItem?.widgets?.find((widget) => widget.type === WIDGET_TYPE_VULNERABILITIES);
+
+export const findWeightWidget = (workItem) =>
+  workItem?.widgets?.find((widget) => widget.type === WIDGET_TYPE_WEIGHT);
 
 export const findHierarchyWidgetChildren = (workItem) =>
-  findHierarchyWidgets(workItem?.widgets)?.children?.nodes || [];
+  findHierarchyWidget(workItem)?.children?.nodes || [];
 
 export const findHierarchyWidgetAncestors = (workItem) =>
-  findHierarchyWidgets(workItem?.widgets)?.ancestors?.nodes || [];
+  findHierarchyWidget(workItem)?.ancestors?.nodes || [];
 
-export const findDesignWidget = (widgets) =>
-  widgets?.find((widget) => widget.type === WIDGET_TYPE_DESIGNS);
+export const formatLabelForListbox = (label) => ({
+  text: label.title,
+  value: label.id,
+  color: label.color,
+});
 
-export const findMilestoneWidget = (widgets) =>
-  widgets?.find((widget) => widget.type === WIDGET_TYPE_MILESTONE);
+export const formatUserForListbox = (user) => ({
+  ...user,
+  text: user.name,
+  value: user.id,
+});
 
 export const convertTypeEnumToName = (workItemTypeEnum) =>
-  Object.keys(WORK_ITEM_TYPE_VALUE_MAP).find(
-    (value) => WORK_ITEM_TYPE_VALUE_MAP[value] === workItemTypeEnum,
-  );
-
-export const getWorkItemIcon = (icon) => {
-  if (icon === ISSUABLE_EPIC) return WORK_ITEMS_TYPE_MAP[WORK_ITEM_TYPE_ENUM_EPIC].icon;
-  return icon;
-};
+  Object.keys(NAME_TO_ENUM_MAP).find((name) => NAME_TO_ENUM_MAP[name] === workItemTypeEnum);
 
 /**
  * TODO: Remove this method with https://gitlab.com/gitlab-org/gitlab/-/issues/479637
@@ -98,7 +155,7 @@ export const getDefaultHierarchyChildrenCount = () => {
 export const formatAncestors = (workItem) =>
   findHierarchyWidgetAncestors(workItem).map((ancestor) => ({
     ...ancestor,
-    icon: getWorkItemIcon(ancestor.workItemType?.iconName),
+    icon: NAME_TO_ICON_MAP[ancestor.workItemType?.name],
     href: ancestor.webUrl,
   }));
 
@@ -124,77 +181,148 @@ const autocompleteSourcesPath = ({ autocompleteType, fullPath, iid, workItemType
   return `${domain}/${basePath}/-/autocomplete_sources/${autocompleteType}?type=WorkItem&${typeId}`;
 };
 
-export const autocompleteDataSources = ({ fullPath, iid, workItemTypeId, isGroup = false }) => ({
-  labels: autocompleteSourcesPath({
-    autocompleteType: 'labels',
-    fullPath,
-    iid,
-    isGroup,
-    workItemTypeId,
-  }),
-  members: autocompleteSourcesPath({
-    autocompleteType: 'members',
-    fullPath,
-    iid,
-    isGroup,
-    workItemTypeId,
-  }),
-  commands: autocompleteSourcesPath({
-    autocompleteType: 'commands',
-    fullPath,
-    iid,
-    isGroup,
-    workItemTypeId,
-  }),
-  issues: autocompleteSourcesPath({
-    autocompleteType: 'issues',
-    fullPath,
-    iid,
-    isGroup,
-    workItemTypeId,
-  }),
-  mergeRequests: autocompleteSourcesPath({
-    autocompleteType: 'merge_requests',
-    fullPath,
-    iid,
-    isGroup,
-    workItemTypeId,
-  }),
-  epics: autocompleteSourcesPath({
-    autocompleteType: 'epics',
-    fullPath,
-    iid,
-    workItemTypeId,
-    isGroup,
-  }),
-  milestones: autocompleteSourcesPath({
-    autocompleteType: 'milestones',
-    fullPath,
-    iid,
-    workItemTypeId,
-    isGroup,
-  }),
-  iterations: autocompleteSourcesPath({
-    autocompleteType: 'iterations',
-    fullPath,
-    iid,
-    workItemTypeId,
-    isGroup,
-  }),
-});
+export const autocompleteDataSources = ({
+  fullPath,
+  iid,
+  workItemTypeId,
+  isGroup = false,
+  markdownPaths = {},
+}) => {
+  const fetchedPaths = markdownPaths;
+  const sources = {
+    labels: autocompleteSourcesPath({
+      autocompleteType: 'labels',
+      fullPath,
+      iid,
+      isGroup,
+      workItemTypeId,
+    }),
+    members: autocompleteSourcesPath({
+      autocompleteType: 'members',
+      fullPath,
+      iid,
+      isGroup,
+      workItemTypeId,
+    }),
+    commands: autocompleteSourcesPath({
+      autocompleteType: 'commands',
+      fullPath,
+      iid,
+      isGroup,
+      workItemTypeId,
+    }),
+    issues: autocompleteSourcesPath({
+      autocompleteType: 'issues',
+      fullPath,
+      iid,
+      isGroup,
+      workItemTypeId,
+    }),
+    mergeRequests: autocompleteSourcesPath({
+      autocompleteType: 'merge_requests',
+      fullPath,
+      iid,
+      isGroup,
+      workItemTypeId,
+    }),
+    epics: autocompleteSourcesPath({
+      autocompleteType: 'epics',
+      fullPath,
+      iid,
+      workItemTypeId,
+      isGroup,
+    }),
+    milestones: autocompleteSourcesPath({
+      autocompleteType: 'milestones',
+      fullPath,
+      iid,
+      workItemTypeId,
+      isGroup,
+    }),
+    iterations: autocompleteSourcesPath({
+      autocompleteType: 'iterations',
+      fullPath,
+      iid,
+      workItemTypeId,
+      isGroup,
+    }),
+    vulnerabilities: autocompleteSourcesPath({
+      autocompleteType: 'vulnerabilities',
+      fullPath,
+      iid,
+      isGroup,
+      workItemTypeId,
+    }),
+    wikis: autocompleteSourcesPath({
+      autocompleteType: 'wikis',
+      fullPath,
+      iid,
+      isGroup,
+      workItemTypeId,
+    }),
+    ...fetchedPaths,
+  };
+
+  const enableExtensibleReferenceFilters = gon.features?.extensibleReferenceFilters ?? false;
+  const extensibleReferenceFilters = enableExtensibleReferenceFilters
+    ? {
+        issuesAlternative: autocompleteSourcesPath({
+          autocompleteType: 'issues',
+          fullPath,
+          iid,
+          isGroup,
+          workItemTypeId,
+        }),
+        workItems: autocompleteSourcesPath({
+          autocompleteType: 'issues',
+          fullPath,
+          iid,
+          isGroup,
+          workItemTypeId,
+        }),
+      }
+    : {};
+
+  // contacts and snippets are only available in project scope
+  const projectOnlySources = !isGroup
+    ? {
+        contacts: autocompleteSourcesPath({
+          autocompleteType: 'contacts',
+          fullPath,
+          iid,
+          isGroup,
+          workItemTypeId,
+        }),
+        snippets: autocompleteSourcesPath({
+          autocompleteType: 'snippets',
+          fullPath,
+          iid,
+          isGroup,
+          workItemTypeId,
+        }),
+      }
+    : {};
+
+  return { ...sources, ...extensibleReferenceFilters, ...projectOnlySources };
+};
 
 export const markdownPreviewPath = ({ fullPath, iid, isGroup = false }) => {
   const domain = gon.relative_url_root || '';
   const basePath = isGroup ? `groups/${fullPath}` : fullPath;
-  return `${domain}/${basePath}/-/preview_markdown?target_type=WorkItem&target_id=${iid}`;
+  const targetId = iid === NEW_WORK_ITEM_IID ? '' : `&target_id=${iid}`;
+  return `${domain}/${basePath}/-/preview_markdown?target_type=WorkItem${targetId}`;
 };
 
 // the path for creating a new work item of that type, e.g. /groups/gitlab-org/-/epics/new
-export const newWorkItemPath = ({ fullPath, isGroup = false, workItemTypeName, query = '' }) => {
+export const newWorkItemPath = ({ fullPath, isGroup = false, workItemType, query = '' }) => {
   const domain = gon.relative_url_root || '';
   const basePath = isGroup ? `groups/${fullPath}` : fullPath;
+  // We have a special case to redirect to /groups/my-group/-/work_items/new
+  // instead of /groups/my-group/-/issues/new
   const type =
-    WORK_ITEMS_TYPE_MAP[workItemTypeName]?.routeParamName || WORK_ITEM_TYPE_ROUTE_WORK_ITEM;
+    isGroup && workItemType === WORK_ITEM_TYPE_NAME_ISSUE
+      ? WORK_ITEM_TYPE_ROUTE_WORK_ITEM
+      : NAME_TO_ROUTE_MAP[workItemType] || WORK_ITEM_TYPE_ROUTE_WORK_ITEM;
   return `${domain}/${basePath}/-/${type}/new${query}`;
 };
 
@@ -310,9 +438,93 @@ export const makeDrawerUrlParam = (activeItem, fullPath, issuableType = TYPE_ISS
   );
 };
 
-export const getNewWorkItemAutoSaveKey = (fullPath, workItemType) => {
-  if (!workItemType || !fullPath) return '';
-  return `new-${fullPath}-${workItemType.toLowerCase()}-draft`;
+export const getAutosaveKeyQueryParamString = () => {
+  const allowedKeysInQueryParamString = [
+    'vulnerability_id',
+    'discussion_to_resolve',
+    'issue[issue_type]',
+    'issuable_template',
+  ];
+  const queryParams = new URLSearchParams(window.location.search);
+  // Remove extra params from queryParams
+  const allKeys = Array.from(queryParams.keys());
+  for (const key of allKeys) {
+    if (!allowedKeysInQueryParamString.includes(key)) {
+      queryParams.delete(key);
+    }
+  }
+
+  return queryParams.toString();
+};
+
+const getBaseNewWorkItemAutoSaveKey = ({ fullPath, context, relatedItemId }) => {
+  const relatedId = getIdFromGraphQLId(relatedItemId);
+  const queryParamString = getAutosaveKeyQueryParamString();
+
+  let baseKey = `new-${fullPath}-${context}`;
+
+  if (relatedId) {
+    baseKey += `-related-id-${relatedId}`;
+  }
+  if (queryParamString) {
+    baseKey += `-${queryParamString}`;
+  }
+
+  return baseKey;
+};
+
+export const getNewWorkItemAutoSaveKey = ({ fullPath, context, workItemType, relatedItemId }) => {
+  if (!(fullPath && context && workItemType)) {
+    throw new Error('Must provide fullPath && context && workItemType');
+  }
+
+  const baseKey = getBaseNewWorkItemAutoSaveKey({ fullPath, context, workItemType, relatedItemId });
+  return `${baseKey}-${kebabCase(workItemType)}-draft`; // eslint-disable-line @gitlab/require-i18n-strings
+};
+
+export const getNewWorkItemWidgetsAutoSaveKey = ({ fullPath, context, relatedItemId }) => {
+  if (!(fullPath && context)) {
+    throw new Error('Must provide fullPath && context');
+  }
+
+  const baseKey = getBaseNewWorkItemAutoSaveKey({ fullPath, context, relatedItemId });
+  return `${baseKey}-widgets-draft`;
+};
+
+export const getWorkItemWidgets = (draftData) => {
+  if (!draftData?.workspace?.workItem) return {};
+
+  const widgets = {};
+  for (const widget of draftData.workspace.workItem.widgets || []) {
+    if (widget.type) {
+      widgets[widget.type] = widget;
+    }
+  }
+  widgets.TITLE = draftData.workspace.workItem.title;
+  widgets.TYPE = draftData.workspace.workItem.workItemType;
+
+  return widgets;
+};
+
+export const updateDraftWorkItemType = ({ fullPath, context, workItemType, relatedItemId }) => {
+  const widgetsAutosaveKey = getNewWorkItemWidgetsAutoSaveKey({
+    fullPath,
+    context,
+    relatedItemId,
+  });
+  const sharedCacheWidgets = JSON.parse(getDraft(widgetsAutosaveKey)) || {};
+  sharedCacheWidgets.TYPE = workItemType;
+  updateDraft(widgetsAutosaveKey, JSON.stringify(sharedCacheWidgets));
+};
+
+export const getDraftWorkItemType = ({ fullPath, context, relatedItemId }) => {
+  const widgetsAutosaveKey = getNewWorkItemWidgetsAutoSaveKey({
+    fullPath,
+    context,
+    relatedItemId,
+  });
+  const sharedCacheWidgets = JSON.parse(getDraft(widgetsAutosaveKey)) || {};
+  return sharedCacheWidgets.TYPE;
 };
 
 export const isItemDisplayable = (item, showClosed) => {
@@ -343,17 +555,18 @@ export const createBranchMRApiPathHelper = {
       `/${fullPath}/-/issues/${workItemIid}/can_create_branch`,
     );
   },
-  createBranch({ fullPath, workItemIid, sourceBranch, targetBranch }) {
-    return joinPaths(
-      gon.relative_url_root || '',
-      `/${fullPath}/-/branches?branch_name=${targetBranch}&format=json&issue_iid=${workItemIid}&ref=${sourceBranch}`,
-    );
+  createBranch(fullPath) {
+    return joinPaths(gon.relative_url_root || '', `/${fullPath}/-/branches`);
   },
   createMR({ fullPath, workItemIid, sourceBranch, targetBranch }) {
-    return joinPaths(
+    let url = joinPaths(
       gon.relative_url_root || '',
-      `/${fullPath}/-/merge_requests/new?merge_request%5Bissue_iid%5D=${workItemIid}&merge_request%5Bsource_branch%5D=${sourceBranch}&merge_request%5Btarget_branch%5D=${targetBranch}`,
+      `/${fullPath}/-/merge_requests/new?merge_request%5Bissue_iid%5D=${workItemIid}&merge_request%5Bsource_branch%5D=${encodeURIComponent(sourceBranch)}`,
     );
+    if (targetBranch) {
+      url += `&merge_request%5Btarget_branch%5D=${encodeURIComponent(targetBranch)}`;
+    }
+    return url;
   },
   getRefs({ fullPath }) {
     return joinPaths(gon.relative_url_root || '', `/${fullPath}/refs?search=`);
