@@ -5,16 +5,13 @@ module Groups
     before_action :authorize_read_usage_quotas!
     before_action :verify_usage_quotas_enabled!
 
-    before_action do
-      push_frontend_feature_flag(:virtual_registry_maven, current_user)
-    end
-
     feature_category :consumables_cost_management
     urgency :low
 
-    def index
+    def root
       # To be used in ee/app/controllers/ee/groups/usage_quotas_controller.rb
       @seat_count_data = seat_count_data
+      render :root
     end
 
     private
