@@ -7,6 +7,7 @@ class Projects::CompareController < Projects::ApplicationController
   include DiffHelper
   include RendersCommits
   include CompareHelper
+  include Projects::TargetProjects
   include RapidDiffs::Resource
 
   # Authorize
@@ -96,6 +97,10 @@ class Projects::CompareController < Projects::ApplicationController
     end
   end
 
+  def target_projects_json
+    render json: ProjectSerializer.new.represent(get_target_projects)
+  end
+
   private
 
   def build_from_to_vars
@@ -227,3 +232,5 @@ class Projects::CompareController < Projects::ApplicationController
       params.permit(:format)[:format].blank?
   end
 end
+
+Projects::CompareController.prepend_mod
