@@ -13,7 +13,7 @@ class Projects::MergeRequestsController < Projects::MergeRequests::ApplicationCo
   include Gitlab::Cache::Helpers
   include MergeRequestsHelper
   include ParseCommitDate
-  include RapidDiffsResource
+  include RapidDiffs::Resource
 
   prepend_before_action(only: [:index]) { authenticate_sessionless_user!(:rss) }
   skip_before_action :merge_request, only: [:index, :bulk_update, :export_csv]
@@ -34,15 +34,14 @@ class Projects::MergeRequestsController < Projects::MergeRequests::ApplicationCo
   before_action :authenticate_user!, only: [:assign_related_issues]
   before_action :check_user_can_push_to_source_branch!, only: [:rebase]
 
-  before_action only: :index do
-    push_frontend_feature_flag(:mr_approved_filter, type: :ops)
+  before_action only: [:index, :show] do
+    push_frontend_feature_flag(:show_merge_request_status_draft, current_user)
   end
 
   before_action only: [:show, :diffs, :rapid_diffs, :reports] do
-    push_frontend_feature_flag(:mr_experience_survey, project)
     push_frontend_feature_flag(:mr_pipelines_graphql, project)
     push_frontend_feature_flag(:notifications_todos_buttons, current_user)
-    push_frontend_feature_flag(:mr_show_reports_immediately, project)
+    push_frontend_feature_flag(:mr_review_batch_submit, current_user)
   end
 
   around_action :allow_gitaly_ref_name_caching, only: [:index, :show, :diffs, :rapid_diffs, :discussions]
@@ -61,6 +60,7 @@ class Projects::MergeRequestsController < Projects::MergeRequests::ApplicationCo
   feature_category :code_testing, [:accessibility_reports]
   feature_category :infrastructure_as_code, [:terraform_reports]
   feature_category :continuous_integration, [:pipeline_status, :pipelines, :exposed_artifacts]
+  feature_category :continuous_delivery, [:ci_environments_status]
 
   urgency :high, [:export_csv]
   urgency :low, [
@@ -87,6 +87,8 @@ class Projects::MergeRequestsController < Projects::MergeRequests::ApplicationCo
   ]
   urgency :low, [:pipeline_status, :pipelines, :exposed_artifacts]
 
+  helper_method :rapid_diffs_page_enabled?
+
   def index
     @merge_requests = @issuables
 
@@ -105,12 +107,13 @@ class Projects::MergeRequestsController < Projects::MergeRequests::ApplicationCo
   end
 
   def rapid_diffs
-    return render_404 unless ::Feature.enabled?(:rapid_diffs, current_user, type: :wip)
+    return render_404 unless rapid_diffs_page_enabled?
 
-    streaming_offset = 5
-    @reload_stream_url = diffs_stream_url(@merge_request)
-    @stream_url = diffs_stream_url(@merge_request, streaming_offset, diff_view)
-    @diffs_slice = @merge_request.first_diffs_slice(streaming_offset)
+    @rapid_diffs_presenter = ::RapidDiffs::MergeRequestPresenter.new(
+      @merge_request,
+      diff_view,
+      diff_options
+    )
 
     show_merge_request
   end
@@ -151,6 +154,8 @@ class Projects::MergeRequestsController < Projects::MergeRequests::ApplicationCo
 
   def pipelines
     set_pipeline_variables
+    # Capture total count before pagination to ensure accurate count regardless of current page
+    @pipelines_count = @pipelines.count
     @pipelines = @pipelines.page(params[:page])
 
     Gitlab::PollingInterval.set_header(response, interval: 10_000)
@@ -166,10 +171,11 @@ class Projects::MergeRequestsController < Projects::MergeRequests::ApplicationCo
           disable_manual_and_scheduled_actions: true,
           preload: true,
           preload_statuses: false,
-          preload_downstream_statuses: false
+          preload_downstream_statuses: false,
+          disable_stage_actions: true
         ),
       count: {
-        all: @pipelines.count
+        all: @pipelines_count
       }
     }
   end
@@ -409,7 +415,7 @@ class Projects::MergeRequestsController < Projects::MergeRequests::ApplicationCo
       )
     end
 
-    display_max_limit_warning
+    display_limit_warnings
 
     respond_to do |format|
       format.html do
@@ -518,13 +524,6 @@ class Projects::MergeRequestsController < Projects::MergeRequests::ApplicationCo
   end
 
   def merge!
-    # Disable the CI check if auto_merge_strategy is specified since we have
-    # to wait until CI completes to know
-    skipped_checks = @merge_request.skipped_mergeable_checks(
-      auto_merge_requested: auto_merge_requested?,
-      auto_merge_strategy: params[:auto_merge_strategy]
-    )
-
     return :failed unless @merge_request.mergeable?(**skipped_checks)
 
     squashing = params.fetch(:squash, false)
@@ -548,7 +547,7 @@ class Projects::MergeRequestsController < Projects::MergeRequests::ApplicationCo
         AutoMergeService.new(project, current_user, merge_params)
           .execute(
             merge_request,
-            params[:auto_merge_strategy] || merge_request.default_auto_merge_strategy
+            auto_merge_strategy
           )
       end
     else
@@ -676,26 +675,56 @@ class Projects::MergeRequestsController < Projects::MergeRequests::ApplicationCo
     payload[:metadata]['meta.diffs_files_count'] = @merge_request.merge_request_diff.files_count
   end
 
-  def diffs_stream_resource_url(merge_request, offset, diff_view)
-    diffs_stream_namespace_project_merge_request_path(
-      id: merge_request.iid,
-      project_id: merge_request.project.to_param,
-      namespace_id: merge_request.project.namespace.to_param,
-      offset: offset,
-      view: diff_view
+  def display_limit_warnings
+    if @merge_request.reached_versions_limit?
+      flash[:alert] = format(
+        _("This merge request has reached the maximum limit of %{limit} versions and cannot be updated further. " \
+          "Close this merge request and create a new one instead."), limit: MergeRequest::DIFF_VERSION_LIMIT)
+      return
+    end
+
+    return unless @merge_request.reached_diff_commits_limit?
+
+    flash[:alert] =
+      _("This merge request has too many diff commits, and can't be updated. " \
+        "Close this merge request and create a new one.")
+  end
+
+  def diffs_resource(diff_options = {})
+    @merge_request.latest_diffs(diff_options)
+  end
+
+  def diff_file_component(base_args)
+    ::RapidDiffs::MergeRequestDiffFileComponent.new(
+      **base_args.merge({ merge_request: @merge_request })
     )
   end
 
-  def display_max_limit_warning
-    return unless @merge_request.reached_versions_limit?
-
-    flash[:alert] = format(
-      _("This merge request has reached the maximum limit of %{limit} versions and cannot be updated further. " \
-        "Close this merge request and create a new one instead."), limit: MergeRequest::DIFF_VERSION_LIMIT)
+  def complete_diff_path
+    merge_request_path(merge_request, format: :diff)
   end
 
-  def diffs_resource
-    @merge_request.latest_diffs
+  def email_format_path
+    merge_request_path(merge_request, format: :patch)
+  end
+
+  def rapid_diffs_page_enabled?
+    ::Feature.enabled?(:rapid_diffs_on_mr_show, current_user, type: :wip) &&
+      params[:rapid_diffs] == 'true'
+  end
+
+  def skipped_checks
+    if auto_merge_requested?
+      @merge_request.skipped_mergeable_checks(
+        auto_merge_strategy: auto_merge_strategy
+      )
+    else
+      {}
+    end
+  end
+
+  def auto_merge_strategy
+    params[:auto_merge_strategy] || merge_request.default_auto_merge_strategy
   end
 end
 
