@@ -42,9 +42,6 @@ class ProjectsController < Projects::ApplicationController
     push_frontend_feature_flag(:edit_branch_rules, @project)
     # TODO: We need to remove the FF eventually when we rollout page_specific_styles
     push_frontend_feature_flag(:page_specific_styles, current_user)
-    push_frontend_feature_flag(:blob_repository_vue_header_app, @project)
-    push_frontend_feature_flag(:blob_overflow_menu, current_user)
-    push_frontend_feature_flag(:filter_blob_path, current_user)
     push_licensed_feature(:file_locks) if @project.present? && @project.licensed_feature_available?(:file_locks)
     push_frontend_feature_flag(:directory_code_dropdown_updates, current_user)
 
@@ -61,13 +58,13 @@ class ProjectsController < Projects::ApplicationController
 
   feature_category :groups_and_projects, [
     :index, :show, :new, :create, :edit, :update, :transfer,
-    :destroy, :archive, :unarchive, :toggle_star, :activity
+    :destroy, :archive, :unarchive, :toggle_star, :activity, :restore
   ]
 
   feature_category :source_code_management, [:remove_fork, :housekeeping, :refs]
   feature_category :team_planning, [:preview_markdown, :new_issuable_address]
   feature_category :importers, [:export, :remove_export, :generate_new_export, :download_export]
-  feature_category :code_review_workflow, [:unfoldered_environment_names]
+  feature_category :continuous_delivery, [:unfoldered_environment_names]
 
   urgency :low, [:export, :remove_export, :generate_new_export, :download_export]
   urgency :low, [:preview_markdown, :new_issuable_address]
@@ -194,12 +191,35 @@ class ProjectsController < Projects::ApplicationController
   def destroy
     return access_denied! unless can?(current_user, :remove_project, @project)
 
-    ::Projects::DestroyService.new(@project, current_user, {}).async_execute
-    flash[:toast] = safe_format(_("Project '%{project_name}' is being deleted."), project_name: @project.full_name)
+    return destroy_immediately if @project.self_deletion_scheduled? && params[:permanently_delete].present?
 
-    redirect_to dashboard_projects_path, status: :found
-  rescue Projects::DestroyService::DestroyError => e
-    redirect_to edit_project_path(@project), status: :found, alert: e.message
+    result = ::Projects::MarkForDeletionService.new(@project, current_user).execute
+
+    if result.success?
+      redirect_to project_path(@project), status: :found
+    else
+      flash.now[:alert] = result.message
+
+      render_edit
+    end
+  end
+
+  def restore
+    return access_denied! unless can?(current_user, :remove_project, @project)
+
+    result = ::Projects::RestoreService.new(@project, current_user, {}).execute
+
+    if result.success?
+      flash[:notice] = format(
+        _("Project '%{project_name}' has been successfully restored."), project_name: @project.full_name
+      )
+
+      redirect_to(edit_project_path(@project))
+    else
+      flash.now[:alert] = result.message
+
+      render_edit
+    end
   end
 
   def new_issuable_address
@@ -210,7 +230,7 @@ class ProjectsController < Projects::ApplicationController
   end
 
   def archive
-    ::Projects::UpdateService.new(@project, current_user, archived: true).execute
+    ::Projects::ArchiveService.new(project: @project, current_user: current_user).execute
 
     respond_to do |format|
       format.html { redirect_to project_path(@project) }
@@ -218,7 +238,7 @@ class ProjectsController < Projects::ApplicationController
   end
 
   def unarchive
-    ::Projects::UpdateService.new(@project, current_user, archived: false).execute
+    ::Projects::UnarchiveService.new(project: @project, current_user: current_user).execute
 
     respond_to do |format|
       format.html { redirect_to project_path(@project) }
@@ -373,6 +393,13 @@ class ProjectsController < Projects::ApplicationController
 
   private
 
+  def destroy_immediately
+    ::Projects::DestroyService.new(@project, current_user, {}).async_execute
+    flash[:toast] = safe_format(_("Project '%{project_name}' is being deleted."), project_name: @project.full_name)
+
+    redirect_to dashboard_projects_path, status: :found
+  end
+
   def refs_params
     params.permit(:search, :sort, :ref, find: [])
   end
@@ -467,6 +494,8 @@ class ProjectsController < Projects::ApplicationController
       mr_default_target_self
       warn_about_potentially_unwanted_characters
       enforce_auth_checks_on_uploads
+      merge_request_title_regex
+      merge_request_title_regex_description
       emails_enabled
     ]
 
@@ -507,6 +536,7 @@ class ProjectsController < Projects::ApplicationController
       :template_project_id,
       :merge_method,
       :initialize_with_sast,
+      :initialize_with_secret_detection,
       :initialize_with_readme,
       :ci_separated_caches,
       :suggestion_commit_message,
@@ -514,6 +544,8 @@ class ProjectsController < Projects::ApplicationController
       :service_desk_enabled,
       :merge_commit_template_or_default,
       :squash_commit_template_or_default,
+      :merge_request_title_regex,
+      :merge_request_title_regex_description,
       { project_setting_attributes: project_setting_attributes,
         project_feature_attributes: project_feature_attributes }
     ]
@@ -572,13 +604,16 @@ class ProjectsController < Projects::ApplicationController
   def redirect_git_extension
     return unless params[:format] == 'git'
 
+    git_extension_regex = %r{\.git/?\Z}
+    return unless request.path.match?(git_extension_regex)
+
     # `project` calls `find_routable!`, so this will trigger the usual not-found
     # behaviour when the user isn't authorized to see the project
     return if project.nil? || performed?
 
     uri = URI(request.original_url)
     # Strip the '.git' part from the path
-    uri.path = uri.path.sub(%r{\.git/?\Z}, '')
+    uri.path = uri.path.sub(git_extension_regex, '')
 
     redirect_to(uri.to_s)
   end
@@ -592,7 +627,7 @@ class ProjectsController < Projects::ApplicationController
   end
 
   def check_export_rate_limit!
-    prefixed_action = "project_#{params[:action]}".to_sym
+    prefixed_action = :"project_#{params[:action]}"
 
     project_scope = params[:action] == 'download_export' ? @project : nil
 
