@@ -4,17 +4,25 @@ module Types
   class ProjectType < BaseObject
     graphql_name 'Project'
 
+    include ::Namespaces::DeletableHelper
+
     connection_type_class Types::CountableConnectionType
 
     authorize :read_project
 
+    def self.authorization_scopes
+      super + [:ai_workflows]
+    end
+
     expose_permissions Types::PermissionTypes::Project
 
     implements Types::TodoableInterface
+    implements ::Types::Projects::ProjectInterface
 
     field :id, GraphQL::Types::ID,
       null: false,
-      description: 'ID of the project.'
+      description: 'ID of the project.',
+      scopes: [:api, :read_api, :ai_workflows]
 
     field :ci_config_path_or_default, GraphQL::Types::String,
       null: false,
@@ -40,7 +48,7 @@ module Types
         description: 'ID of the pipeline creation request.'
     end
 
-    field :ci_pipeline_creation_inputs, [Types::Ci::Inputs::InputSpecType],
+    field :ci_pipeline_creation_inputs, [Types::Ci::Inputs::SpecType],
       authorize: :create_pipeline,
       null: true,
       calls_gitaly: true,
@@ -53,6 +61,7 @@ module Types
 
     field :full_path, GraphQL::Types::ID,
       null: false,
+      scopes: [:api, :read_api, :ai_workflows],
       description: 'Full path of the project.'
 
     field :path, GraphQL::Types::String,
@@ -75,15 +84,17 @@ module Types
 
     field :name, GraphQL::Types::String,
       null: false,
-      description: 'Name of the project (without namespace).'
+      description: 'Name of the project without the namespace.',
+      scopes: [:api, :read_api, :ai_workflows]
 
     field :name_with_namespace, GraphQL::Types::String,
       null: false,
-      description: 'Full name of the project with its namespace.'
+      description: 'Name of the project including the namespace.'
 
     field :description, GraphQL::Types::String,
       null: true,
-      description: 'Short description of the project.'
+      description: 'Short description of the project.',
+      scopes: [:api, :read_api, :ai_workflows]
 
     field :tag_list, GraphQL::Types::String,
       null: true,
@@ -98,15 +109,18 @@ module Types
 
     field :http_url_to_repo, GraphQL::Types::String,
       null: true,
-      description: 'URL to connect to the project via HTTPS.'
+      description: 'URL to connect to the project via HTTPS.',
+      scopes: [:api, :read_api, :ai_workflows]
 
     field :ssh_url_to_repo, GraphQL::Types::String,
       null: true,
-      description: 'URL to connect to the project via SSH.'
+      description: 'URL to connect to the project via SSH.',
+      scopes: [:api, :read_api, :ai_workflows]
 
     field :web_url, GraphQL::Types::String,
       null: true,
-      description: 'Web URL of the project.'
+      description: 'Web URL of the project.',
+      scopes: [:api, :read_api, :ai_workflows]
 
     field :forks_count, GraphQL::Types::Int,
       null: false,
@@ -131,7 +145,38 @@ module Types
 
     field :archived, GraphQL::Types::Boolean,
       null: true,
-      description: 'Indicates the archived status of the project.'
+      description: 'Indicates the archived status of the project.',
+      method: :self_or_ancestors_archived?
+
+    field :is_self_deletion_in_progress, GraphQL::Types::Boolean,
+      null: false,
+      description: 'Indicates if project deletion is in progress.',
+      method: :self_deletion_in_progress?,
+      experiment: { milestone: '18.3' }
+
+    field :is_self_deletion_scheduled, GraphQL::Types::Boolean,
+      null: false,
+      description: 'Indicates if project deletion is scheduled.',
+      method: :self_deletion_scheduled?,
+      experiment: { milestone: '18.3' }
+
+    field :marked_for_deletion, GraphQL::Types::Boolean,
+      null: true,
+      description: 'Indicates if the project or any ancestor is scheduled for deletion.',
+      method: :scheduled_for_deletion_in_hierarchy_chain?,
+      experiment: { milestone: '18.1' }
+
+    field :marked_for_deletion_on, ::Types::TimeType,
+      null: true,
+      description: 'Date when project was scheduled to be deleted.',
+      experiment: { milestone: '16.10' }
+
+    field :permanent_deletion_date, GraphQL::Types::String,
+      null: true,
+      description: "For projects pending deletion, returns the project's scheduled deletion date. " \
+        'For projects not pending deletion, returns a theoretical date based on current settings ' \
+        'if marked for deletion today.',
+      experiment: { milestone: '16.11' }
 
     field :visibility, GraphQL::Types::String,
       null: true,
@@ -165,7 +210,7 @@ module Types
     field :avatar_url, GraphQL::Types::String,
       null: true,
       calls_gitaly: true,
-      description: 'URL to avatar image file of the project.'
+      description: 'Avatar URL of the project.'
 
     field :jobs_enabled, GraphQL::Types::Boolean,
       null: true,
@@ -262,6 +307,7 @@ module Types
     field :statistics_details_paths, Types::ProjectStatisticsRedirectType,
       null: true,
       description: 'Redirects for Statistics of the project.',
+      scopes: [:api, :read_api, :ai_workflows],
       calls_gitaly: true
 
     field :repository, Types::RepositoryType,
@@ -291,6 +337,7 @@ module Types
       Types::WorkItemType.connection_type,
       null: true,
       experiment: { milestone: '15.1' },
+      scopes: [:api, :read_api, :ai_workflows],
       description: 'Work items of the project.',
       extras: [:lookahead],
       resolver: Resolvers::WorkItemsResolver
@@ -390,6 +437,7 @@ module Types
 
     field :pipelines,
       null: true,
+      calls_gitaly: true,
       description: 'Pipelines of the project.',
       extras: [:lookahead],
       resolver: Resolvers::Ci::ProjectPipelinesResolver
@@ -503,7 +551,8 @@ module Types
     field :alert_management_integrations, Types::AlertManagement::IntegrationType.connection_type,
       null: true,
       description: 'Integrations which can receive alerts for the project.',
-      resolver: Resolvers::AlertManagement::IntegrationsResolver
+      resolver: Resolvers::AlertManagement::IntegrationsResolver,
+      deprecated: { reason: 'Use `alertManagementHttpIntegrations`', milestone: '18.2' }
 
     field :alert_management_http_integrations, Types::AlertManagement::HttpIntegrationType.connection_type,
       null: true,
@@ -554,8 +603,7 @@ module Types
       Types::ContainerRegistry::Protection::TagRuleType.connection_type,
       null: true,
       experiment: { milestone: '17.8' },
-      description: 'Container repository tag protection rules for the project. ' \
-        'Returns an empty array if the `container_registry_protected_tags` feature flag is disabled.'
+      description: 'Container repository tag protection rules for the project.'
 
     field :container_repositories, Types::ContainerRegistry::ContainerRepositoryType.connection_type,
       null: true,
@@ -655,6 +703,14 @@ module Types
       null: true,
       description: 'Template used to create squash commit message in merge requests.'
 
+    field :merge_request_title_regex, GraphQL::Types::String,
+      null: true,
+      description: 'Regex used to validate the title of merge requests.'
+
+    field :merge_request_title_regex_description, GraphQL::Types::String,
+      null: true,
+      description: 'Description of the regex used to validate the title of merge requests.'
+
     field :labels, Types::LabelType.connection_type,
       null: true,
       description: 'Labels available on this project.',
@@ -693,6 +749,7 @@ module Types
     field :languages, [Types::Projects::RepositoryLanguageType],
       null: true,
       description: "Programming languages used in the project.",
+      scopes: [:api, :read_api, :ai_workflows],
       calls_gitaly: true
 
     field :runners, Types::Ci::RunnerType.connection_type,
@@ -850,18 +907,23 @@ module Types
       end
     end
 
+    def container_protection_tag_rules
+      # Immutable tag rules are added in EE extension
+      object.container_registry_protection_tag_rules.mutable
+    end
+
     {
       issues: "Issues are",
       merge_requests: "Merge requests are",
       wiki: 'Wikis are',
       snippets: 'Snippets are',
-      container_registry: 'Container Registry is'
+      container_registry: 'Container registry is'
     }.each do |feature, name_string|
       field "#{feature}_enabled", GraphQL::Types::Boolean, null: true,
         description: "Indicates if #{name_string} enabled for the current user"
 
-      define_method "#{feature}_enabled" do
-        object.feature_available?(feature, context[:current_user])
+      define_method "#{feature}_enabled" do # rubocop:disable Performance/StringIdentifierArgument
+        object.feature_available?(feature, context[:current_user]) # rubocop:disable Gitlab/FeatureAvailableUsage
       end
     end
 
@@ -880,10 +942,6 @@ module Types
 
     markdown_field :description_html, null: true
 
-    def avatar_url
-      object.avatar_url(only_path: false)
-    end
-
     def jobs_enabled
       object.feature_available?(:builds, context[:current_user])
     end
@@ -1020,10 +1078,14 @@ module Types
       )
     end
 
-    def container_protection_tag_rules
-      return [] unless Feature.enabled?(:container_registry_protected_tags, object)
+    # marked_for_deletion_at is deprecated in our v5 REST API in favor of marked_for_deletion_on
+    # https://docs.gitlab.com/ee/api/projects.html#removals-in-api-v5
+    def marked_for_deletion_on
+      project.marked_for_deletion_at
+    end
 
-      object.container_registry_protection_tag_rules
+    def permanent_deletion_date
+      permanent_deletion_date_formatted(project) || permanent_deletion_date_formatted
     end
 
     private
