@@ -74,24 +74,38 @@ module ApplicationSettingsHelper
 
   def global_search_settings_checkboxes(form)
     [
+      form.gitlab_ui_checkbox_component(
+        :anonymous_searches_allowed,
+        _("Allow unauthenticated users to use search"),
+        checkbox_options: {
+          checked: @application_setting.anonymous_searches_allowed, multiple: false
+        }
+      ),
+      form.gitlab_ui_checkbox_component(
+        :global_search_block_anonymous_searches_enabled,
+        _("Restrict global search to authenticated users only"),
+        checkbox_options: {
+          checked: @application_setting.global_search_block_anonymous_searches_enabled, multiple: false
+        }
+      ),
       form.gitlab_ui_checkbox_component(
         :global_search_issues_enabled,
-        _("Enable issues tab in global search results"),
+        _("Show issues in global search results"),
         checkbox_options: { checked: @application_setting.global_search_issues_enabled, multiple: false }
       ),
       form.gitlab_ui_checkbox_component(
         :global_search_merge_requests_enabled,
-        _("Enable merge requests tab in global search results"),
+        _("Show merge requests in global search results"),
         checkbox_options: { checked: @application_setting.global_search_merge_requests_enabled, multiple: false }
       ),
       form.gitlab_ui_checkbox_component(
         :global_search_snippet_titles_enabled,
-        _("Enable snippet tab in global search results"),
+        _("Show snippets in global search results"),
         checkbox_options: { checked: @application_setting.global_search_snippet_titles_enabled, multiple: false }
       ),
       form.gitlab_ui_checkbox_component(
         :global_search_users_enabled,
-        _("Enable users tab in global search results"),
+        _("Show users in global search results"),
         checkbox_options: { checked: @application_setting.global_search_users_enabled, multiple: false }
       )
     ]
@@ -134,14 +148,18 @@ module ApplicationSettingsHelper
   end
 
   def import_sources_checkboxes(form)
-    Gitlab::ImportSources.options.map do |name, source|
-      checked = @application_setting.import_sources.include?(source)
+    import_sources_without_templates = Gitlab::ImportSources.import_table.reject do |importer|
+      Gitlab::ImportSources.template?(importer.name)
+    end
+
+    import_sources_without_templates.map do |source|
+      checked = @application_setting.import_sources.include?(source.name)
 
       form.gitlab_ui_checkbox_component(
         :import_sources,
-        name,
+        source.title,
         checkbox_options: { checked: checked, multiple: true, autocomplete: 'off' },
-        checked_value: source,
+        checked_value: source.name,
         unchecked_value: nil
       )
     end
@@ -186,7 +204,7 @@ module ApplicationSettingsHelper
   end
 
   def external_authorization_description
-    s_("ExternalAuthorization|Access to projects is validated on an external service "\
+    s_("ExternalAuthorization|Access to projects is validated on an external service " \
       "using their classification label.")
   end
 
@@ -195,39 +213,39 @@ module ApplicationSettingsHelper
   end
 
   def external_authorization_timeout_help_text
-    s_("ExternalAuthorization|Period GitLab waits for a response from the external "\
+    s_("ExternalAuthorization|Period GitLab waits for a response from the external " \
       "service. If there is no response, access is denied. Default: 0.5 seconds.")
   end
 
   def external_authorization_url_help_text
-    s_("ExternalAuthorization|URL to which the projects make authorization requests. If the URL is blank, cross-project "\
-      "features are available and can still specify classification "\
+    s_("ExternalAuthorization|URL to which the projects make authorization requests. If the URL is blank, cross-project " \
+      "features are available and can still specify classification " \
       "labels for projects.")
   end
 
   def external_authorization_client_certificate_help_text
-    s_("ExternalAuthorization|Certificate used to authenticate with the external authorization service. "\
+    s_("ExternalAuthorization|Certificate used to authenticate with the external authorization service. " \
       "If blank, the server certificate is validated when accessing over HTTPS.")
   end
 
   def external_authorization_client_key_help_text
-    s_("ExternalAuthorization|Private key of client authentication certificate. "\
+    s_("ExternalAuthorization|Private key of client authentication certificate. " \
       "Encrypted when stored.")
   end
 
   def external_authorization_client_pass_help_text
-    s_("ExternalAuthorization|Passphrase required to decrypt the private key. "\
+    s_("ExternalAuthorization|Passphrase required to decrypt the private key. " \
       "Encrypted when stored.")
   end
 
   def external_authorization_client_url_help_text
-    s_("ExternalAuthorization|Classification label to use when requesting authorization if no specific "\
+    s_("ExternalAuthorization|Classification label to use when requesting authorization if no specific " \
       "label is defined on the project.")
   end
 
   def sidekiq_job_limiter_mode_help_text
-    _("How the job limiter handles jobs exceeding the thresholds specified below. "\
-      "The 'track' mode only logs the jobs. The 'compress' mode compresses the jobs and "\
+    _("How the job limiter handles jobs exceeding the thresholds specified below. " \
+      "The 'track' mode only logs the jobs. The 'compress' mode compresses the jobs and " \
       "raises an exception if the compressed size exceeds the limit.")
   end
 
@@ -260,6 +278,10 @@ module ApplicationSettingsHelper
       :auto_devops_domain,
       :autocomplete_users_limit,
       :autocomplete_users_unauthenticated_limit,
+      :allow_bypass_placeholder_confirmation,
+      :ci_delete_pipelines_in_seconds_limit_human_readable,
+      :ci_job_live_trace_enabled,
+      :ci_partitions_size_limit,
       :concurrent_github_import_jobs_limit,
       :concurrent_bitbucket_import_jobs_limit,
       :concurrent_bitbucket_server_import_jobs_limit,
@@ -279,7 +301,9 @@ module ApplicationSettingsHelper
       :default_projects_limit,
       :default_snippet_visibility,
       :default_syntax_highlighting_theme,
+      :default_dark_syntax_highlighting_theme,
       :delete_inactive_projects,
+      :deletion_adjourned_period,
       :deny_all_requests_except_allowed,
       :disable_admin_oauth_scopes,
       :disable_feed_token,
@@ -308,6 +332,7 @@ module ApplicationSettingsHelper
       :enabled_git_access_protocol,
       :enforce_ci_inbound_job_token_scope_enabled,
       :enforce_email_subaddress_restrictions,
+      :require_email_verification_on_account_locked,
       :enforce_terms,
       :error_tracking_enabled,
       :error_tracking_api_url,
@@ -340,6 +365,7 @@ module ApplicationSettingsHelper
       :housekeeping_optimize_repository_period,
       :html_emails_enabled,
       :import_sources,
+      :inactive_resource_access_tokens_delete_after_days,
       :inactive_projects_delete_after_months,
       :inactive_projects_min_size_mb,
       :inactive_projects_send_warning_email_after_months,
@@ -355,6 +381,10 @@ module ApplicationSettingsHelper
       :max_attachment_size,
       :max_decompressed_archive_size,
       :max_export_size,
+      :max_github_response_size_limit,
+      :max_github_response_json_value_count,
+      :max_http_decompressed_size,
+      :max_http_response_size_limit,
       :max_import_size,
       :max_import_remote_file_size,
       :max_login_attempts,
@@ -367,7 +397,9 @@ module ApplicationSettingsHelper
       :minimum_password_length,
       :mirror_available,
       :notify_on_unknown_sign_in,
+      :organization_cluster_agent_authorization_enabled,
       :pages_domain_verification_enabled,
+      :pages_unique_domain_default_enabled,
       :password_authentication_enabled_for_web,
       :password_authentication_enabled_for_git,
       :performance_bar_allowed_group_path,
@@ -399,6 +431,7 @@ module ApplicationSettingsHelper
       :restricted_visibility_levels,
       :rsa_key_restriction,
       :session_expire_delay,
+      :session_expire_from_init,
       :shared_runners_enabled,
       :shared_runners_text,
       :sign_in_restrictions,
@@ -420,6 +453,9 @@ module ApplicationSettingsHelper
       :throttle_authenticated_api_enabled,
       :throttle_authenticated_api_period_in_seconds,
       :throttle_authenticated_api_requests_per_period,
+      :throttle_authenticated_git_http_enabled,
+      :throttle_authenticated_git_http_period_in_seconds,
+      :throttle_authenticated_git_http_requests_per_period,
       :throttle_authenticated_git_lfs_enabled,
       :throttle_authenticated_git_lfs_period_in_seconds,
       :throttle_authenticated_git_lfs_requests_per_period,
@@ -456,6 +492,7 @@ module ApplicationSettingsHelper
       :throttle_protected_paths_enabled,
       :throttle_protected_paths_period_in_seconds,
       :throttle_protected_paths_requests_per_period,
+      :top_level_group_creation_enabled,
       :protected_paths_raw,
       :protected_paths_for_get_request_raw,
       :time_tracking_limit_to_hours,
@@ -466,6 +503,7 @@ module ApplicationSettingsHelper
       :unique_ips_limit_time_window,
       :usage_ping_enabled,
       :usage_ping_features_enabled,
+      :use_clickhouse_for_analytics,
       :user_default_external,
       :user_show_add_ssh_key_message,
       :user_default_internal_regex,
@@ -484,6 +522,7 @@ module ApplicationSettingsHelper
       :snowplow_database_collector_hostname,
       :snowplow_enabled,
       :snowplow_app_id,
+      :gitlab_product_usage_data_enabled,
       :push_event_hooks_limit,
       :push_event_activities_limit,
       :custom_http_clone_url_root,
@@ -538,6 +577,7 @@ module ApplicationSettingsHelper
       :can_create_organization,
       :bulk_import_concurrent_pipeline_batch_limit,
       :concurrent_relation_batch_export_limit,
+      :relation_export_batch_size,
       :bulk_import_enabled,
       :bulk_import_max_download_file_size,
       :silent_admin_exports_enabled,
@@ -547,6 +587,7 @@ module ApplicationSettingsHelper
       :deactivation_email_additional_text,
       :projects_api_rate_limit_unauthenticated,
       :group_api_limit,
+      :group_archive_unarchive_api_limit,
       :group_invited_groups_api_limit,
       :group_shared_groups_api_limit,
       :group_projects_api_limit,
@@ -587,11 +628,19 @@ module ApplicationSettingsHelper
       :global_search_users_enabled,
       :global_search_issues_enabled,
       :global_search_merge_requests_enabled,
+      :global_search_block_anonymous_searches_enabled,
+      :enable_language_server_restrictions,
+      :minimum_language_server_version,
       :vscode_extension_marketplace,
-      :vscode_extension_marketplace_enabled
+      :vscode_extension_marketplace_enabled,
+      :reindexing_minimum_index_size,
+      :reindexing_minimum_relative_bloat_size,
+      :anonymous_searches_allowed,
+      :git_push_pipeline_limit,
+      :delay_user_account_self_deletion,
+      :resource_usage_limits
     ].tap do |settings|
       unless Gitlab.com?
-        settings << :resource_usage_limits
         settings << :deactivate_dormant_users
         settings << :deactivate_dormant_users_period
         settings << :nuget_skip_metadata_url_validation
@@ -671,7 +720,7 @@ module ApplicationSettingsHelper
       minimum_password_length_min: ApplicationSetting::DEFAULT_MINIMUM_PASSWORD_LENGTH,
       minimum_password_length_max: Devise.password_length.max,
       minimum_password_length_help_link:
-        'https://about.gitlab.com/handbook/security/#gitlab-password-policy-guidelines',
+        promo_url(path: '/handbook/security/', anchor: 'gitlab-password-policy-guidelines'),
       domain_allowlist_raw: @application_setting.domain_allowlist_raw,
       new_user_signups_cap: @application_setting[:new_user_signups_cap].to_s,
       domain_denylist_enabled: @application_setting[:domain_denylist_enabled].to_s,
@@ -687,9 +736,6 @@ module ApplicationSettingsHelper
   end
 
   def vscode_extension_marketplace_settings_view
-    # NOTE: This is intentionally not scoped to a specific actor since it affects instance-level settings.
-    return unless Feature.enabled?(:vscode_extension_marketplace_settings, nil)
-
     presets = ::WebIde::ExtensionMarketplacePreset.all.map do |preset|
       preset.to_h.deep_transform_keys { |key| key.to_s.camelize(:lower) }
     end
@@ -708,6 +754,17 @@ module ApplicationSettingsHelper
     # NOTE: description is overridden in EE
     _('Enable VS Code Extension Marketplace and configure the extensions registry for Web IDE.')
   end
+
+  def deletion_protection_data
+    {
+      deletion_adjourned_period: @application_setting[:deletion_adjourned_period]
+    }
+  end
+
+  # Overridden in EE
+  def custom_admin_roles_available?
+    false
+  end
 end
 
 ApplicationSettingsHelper.prepend_mod_with('ApplicationSettingsHelper')
