@@ -5,8 +5,6 @@ module ProjectsHelper
   include CompareHelper
   include Gitlab::Allowable
 
-  BANNED = 'banned'
-
   def project_incident_management_setting
     @project_incident_management_setting ||= @project.incident_management_setting ||
       @project.build_incident_management_setting
@@ -117,11 +115,12 @@ module ProjectsHelper
     push_to_schema_breadcrumb(simple_sanitize(project.name), project_path(project), project.try(:avatar_url))
   end
 
-  def remove_project_message(project)
-    _(
-      "You are going to delete %{project_full_name}. Deleted projects " \
-        "CANNOT be restored! Are you ABSOLUTELY sure?"
-    ) % { project_full_name: project.full_name }
+  def remove_project_message
+    format(
+      _("Deleting a project places it into a read-only state until %{date}, " \
+        "at which point the project will be permanently deleted. Are you ABSOLUTELY sure?"),
+      date: permanent_deletion_date_formatted(Date.current)
+    )
   end
 
   def link_to_namespace_change_doc
@@ -293,13 +292,13 @@ module ProjectsHelper
   def show_auto_devops_implicitly_enabled_banner?(project, user)
     return false unless user_can_see_auto_devops_implicitly_enabled_banner?(project, user)
 
-    cookies["hide_auto_devops_implicitly_enabled_banner_#{project.id}".to_sym].blank?
+    cookies[:"hide_auto_devops_implicitly_enabled_banner_#{project.id}"].blank?
   end
 
   def show_mobile_devops_project_promo?(project)
     return false unless (project.project_setting.target_platforms & ::ProjectSetting::ALLOWED_TARGET_PLATFORMS).any?
 
-    cookies["hide_mobile_devops_promo_#{project.id}".to_sym].blank?
+    cookies[:"hide_mobile_devops_promo_#{project.id}"].blank?
   end
 
   def no_password_message
@@ -346,16 +345,6 @@ module ProjectsHelper
     end
   end
 
-  def show_projects?(projects, params)
-    !!(
-      params[:personal] ||
-      params[:name] ||
-      params[:language] ||
-      params[:archived] == 'only' ||
-      any_projects?(projects)
-    )
-  end
-
   def push_to_create_project_command(user = current_user)
     repository_url =
       if Gitlab::CurrentSettings.current_application_settings.enabled_git_access_protocol == 'http'
@@ -410,15 +399,11 @@ module ProjectsHelper
                       .external_authorization_service_default_label
 
     s_(
-      "ExternalAuthorizationService|When no classification label is set the "\
+      "ExternalAuthorizationService|When no classification label is set the " \
         "default label `%{default_label}` will be used."
     ) % { default_label: default_label }
   end
 
-  def can_admin_project_member?(project)
-    Ability.allowed?(current_user, :admin_project_member, project) && !membership_locked?
-  end
-
   def project_can_be_shared?
     !membership_locked? || @project.allowed_to_share_with_group?
   end
@@ -446,6 +431,10 @@ module ProjectsHelper
   def show_lfs_misconfiguration_banner?(project)
     return false unless project.repository && project.lfs_enabled?
 
+    if current_user&.dismissed_callout_for_project?(feature_name: :lfs_misconfiguration_banner, project: project)
+      return false
+    end
+
     Rails.cache.fetch("show_lfs_misconfiguration_banner_#{project.id}", expires_in: 5.minutes) do
       project.lfs_objects_projects.project_repository_type.any? && !project.repository.has_gitattributes?
     end
@@ -471,7 +460,7 @@ module ProjectsHelper
         anchor: 'delete-a-git-lfs-file-from-repository-history'),
       pagesAvailable: Gitlab.config.pages.enabled,
       pagesAccessControlEnabled: Gitlab.config.pages.access_control,
-      pagesAccessControlForced: ::Gitlab::Pages.access_control_is_forced?(project.group),
+      pagesAccessControlForced: project.pages_access_control_forced_by_ancestor?,
       pagesHelpPath: help_page_path('user/project/pages/pages_access_control.md'),
       issuesHelpPath: help_page_path('user/project/issues/_index.md'),
       membersPagePath: project_project_members_path(project),
@@ -513,7 +502,7 @@ module ProjectsHelper
     return unless current_user
     return if project.empty_repo?
 
-    if current_user.already_forked?(project) && !current_user.has_forkable_groups?
+    if current_user.already_forked?(project) && !current_user.has_groups_allowing_project_creation?
       user_fork_url = namespace_project_path(current_user, current_user.fork_of(project))
     end
 
@@ -570,10 +559,11 @@ module ProjectsHelper
       cicd_catalog_path: cicd_catalog_path,
       is_project_archived: project.archived.to_s,
       is_project_empty: project.empty_repo?.to_s,
+      is_project_marked_for_deletion: project.self_deletion_scheduled?.to_s,
       project_avatar: project.avatar_url,
       project_name: project.name,
       project_id: project.id,
-      project_visibility_level: visibility_level_name(project)
+      project_visibility_level: Gitlab::VisibilityLevel.string_level(project.visibility_level)
     }.merge(
       dropdown_attributes,
       fork_button_attributes,
@@ -586,21 +576,27 @@ module ProjectsHelper
     configure_oauth_import_message('Bitbucket', help_page_path("integration/bitbucket.md"))
   end
 
-  def show_archived_project_banner?(project)
-    return false unless project.present? && project.saved?
+  def archiving_available?(project)
+    return false unless project
 
-    project.archived?
+    project.persisted? && !project.self_deletion_scheduled? && can?(current_user, :archive_project, project)
+  end
+
+  def show_archived_project_banner?(project)
+    return false unless project
+
+    project.persisted? && project.self_or_ancestors_archived?
   end
 
   def show_inactive_project_deletion_banner?(project)
-    return false unless project.present? && project.saved?
+    return false unless project
     return false unless delete_inactive_projects?
 
-    project.inactive?
+    project.persisted? && project.inactive?
   end
 
   def inactive_project_deletion_date(project)
-    Gitlab::InactiveProjectsDeletionWarningTracker.new(project.id).scheduled_deletion_date
+    Gitlab::DormantProjectsDeletionWarningTracker.new(project.id).scheduled_deletion_date
   end
 
   def show_clusters_alert?(project)
@@ -672,10 +668,6 @@ module ProjectsHelper
   end
 
   def visibility_level_content(project, css_class: nil, icon_css_class: nil, icon_variant: nil)
-    if project.created_and_owned_by_banned_user? && Feature.enabled?(:hide_projects_of_banned_users)
-      return hidden_resource_icon(project, css_class: css_class, variant: icon_variant)
-    end
-
     title = visibility_icon_description(project)
     container_class = [
       'has-tooltip gl-border-0 gl-bg-transparent gl-p-0 gl-leading-0 gl-text-inherit',
@@ -724,9 +716,7 @@ module ProjectsHelper
   def dashboard_projects_app_data
     {
       initial_sort: project_list_sort_by,
-      programming_languages: programming_languages,
-      empty_state_projects_svg_path: image_path('illustrations/empty-state/empty-projects-md.svg'),
-      empty_state_search_svg_path: image_path('illustrations/empty-state/empty-search-md.svg')
+      programming_languages: programming_languages
     }.to_json
   end
 
@@ -741,16 +731,6 @@ module ProjectsHelper
     dashboard_projects_landing_paths.include?(request.path) && !current_user.authorized_projects.exists?
   end
 
-  def delete_immediately_message(project)
-    _('This action will permanently delete this project, including all its resources.')
-  end
-
-  def project_delete_immediately_button_data(project, button_text = nil)
-    project_delete_button_shared_data(project, button_text).merge({
-      form_path: project_path(project, permanently_delete: true)
-    })
-  end
-
   def project_pages_domain_choices
     pages_url = build_pages_url(@project)
     blank_option = [[s_('GitLabPages|Don’t enforce a primary domain'), '']]
@@ -763,44 +743,33 @@ module ProjectsHelper
     )
   end
 
+  def project_archive_settings_app_data(project)
+    {
+      resource_type: 'project',
+      resource_id: project.id,
+      resource_path: project_path(project),
+      help_path: help_page_path('user/project/working_with_projects.md', anchor: 'archive-a-project')
+    }
+  end
+
+  def project_unarchive_settings_app_data(project)
+    {
+      resource_type: 'project',
+      resource_id: project.id,
+      resource_path: project_path(project),
+      ancestors_archived: project.ancestors_archived?.to_s,
+      help_path: help_page_path('user/project/working_with_projects.md', anchor: 'unarchive-a-project')
+    }
+  end
+
+  def show_archived_badge?(project)
+    return true if project.archived?
+
+    Feature.enabled?(:archive_group, project.root_ancestor) && project.ancestors_archived?
+  end
+
   private
 
-  def delete_message_data(project)
-    {
-      project_path_with_namespace: project.path_with_namespace,
-      project: project.path,
-      strongOpen: '<strong>'.html_safe,
-      strongClose: '</strong>'.html_safe,
-      codeOpen: '<code>'.html_safe,
-      codeClose: '</code>'.html_safe
-    }
-  end
-
-  def project_delete_button_shared_data(project, button_text = nil)
-    merge_requests_count = Projects::AllMergeRequestsCountService.new(project).count
-    issues_count = Projects::AllIssuesCountService.new(project).count
-    forks_count = Projects::ForksCountService.new(project).count
-
-    {
-      confirm_phrase: delete_confirm_phrase(project),
-      name_with_namespace: project.name_with_namespace,
-      is_fork: project.forked? ? 'true' : 'false',
-      issues_count: number_with_delimiter(issues_count),
-      merge_requests_count: number_with_delimiter(merge_requests_count),
-      forks_count: number_with_delimiter(forks_count),
-      stars_count: number_with_delimiter(project.star_count),
-      button_text: button_text.presence || _('Delete project')
-    }
-  end
-
-  def visibility_level_name(project)
-    if project.created_and_owned_by_banned_user? && Feature.enabled?(:hide_projects_of_banned_users)
-      BANNED
-    else
-      Gitlab::VisibilityLevel.string_level(project.visibility_level)
-    end
-  end
-
   def can_admin_project_clusters?(project)
     project.clusters.any? && can?(current_user, :admin_cluster, project)
   end
@@ -911,6 +880,8 @@ module ProjectsHelper
   end
 
   def current_ref
+    return current_branch if @repository.try(:branch_exists?, current_branch)
+
     @ref || @repository.try(:root_ref)
   end
 
@@ -1048,20 +1019,6 @@ module ProjectsHelper
   end
 
   def project_permissions_data(project, target_form_id = nil)
-    data = visibility_confirm_modal_data(project, target_form_id)
-    cascading_settings_data = project_cascading_namespace_settings_tooltip_data(
-      :duo_features_enabled,
-      project,
-      method(:edit_group_path)
-    ).to_json
-    data.merge!(
-      {
-        cascading_settings_data: cascading_settings_data
-      }
-    )
-  end
-
-  def visibility_confirm_modal_data(project, target_form_id = nil)
     {
       target_form_id: target_form_id,
       button_testid: 'reduce-project-visibility-button',
@@ -1074,6 +1031,16 @@ module ProjectsHelper
     }
   end
 
+  def gitlab_duo_settings_data(project)
+    {
+      cascadingSettingsData: project_cascading_namespace_settings_tooltip_data(
+        :duo_features_enabled,
+        project,
+        method(:edit_group_path)
+      )
+    }
+  end
+
   def delete_inactive_projects?
     strong_memoize(:delete_inactive_projects_setting) do
       ::Gitlab::CurrentSettings.delete_inactive_projects?
