@@ -45,6 +45,7 @@ module SidebarsHelper
   def super_sidebar_logged_out_context(panel:, panel_type:)
     super_sidebar_instance_version_data.merge(super_sidebar_whats_new_data).merge({
       is_logged_in: false,
+      compare_plans_url: compare_plans_url,
       context_switcher_links: context_switcher_links,
       current_menu_items: panel.super_sidebar_menu_items,
       current_context_header: panel.super_sidebar_context_header,
@@ -85,8 +86,8 @@ module SidebarsHelper
       },
       user_counts: {
         assigned_issues: user.assigned_open_issues_count,
-        assigned_merge_requests: user.assigned_open_merge_requests_count,
-        review_requested_merge_requests: user.review_requested_open_merge_requests_count,
+        assigned_merge_requests: user.assigned_open_merge_requests_count(cached_only: true),
+        review_requested_merge_requests: user.review_requested_open_merge_requests_count(cached_only: true),
         todos: user.todos_pending_count,
         last_update: time_in_milliseconds
       },
@@ -94,9 +95,8 @@ module SidebarsHelper
       sign_out_link: destroy_user_session_path,
       issues_dashboard_path: issues_dashboard_path(assignee_username: user.username),
       merge_request_dashboard_path: user.merge_request_dashboard_enabled? ? merge_requests_dashboard_path : nil,
-
       todos_dashboard_path: dashboard_todos_path,
-
+      compare_plans_url: compare_plans_url(user: user, project: project, group: group),
       create_new_menu_groups: create_new_menu_groups(group: group, project: project),
       merge_request_menu: create_merge_request_menu(user),
       projects_path: dashboard_projects_path,
@@ -111,7 +111,7 @@ module SidebarsHelper
       stop_impersonation_path: admin_impersonation_path,
       shortcut_links: shortcut_links(user: user, project: project),
       track_visits_path: track_namespace_visits_path,
-      work_items: work_items_modal_data(group)
+      work_items: work_items_modal_data(group, project)
     })
   end
 
@@ -133,7 +133,20 @@ module SidebarsHelper
     }
   end
 
-  def work_items_modal_data(group)
+  def work_items_modal_data(group, project)
+    if project&.persisted?
+      return {
+        full_path: project.full_path,
+        has_issuable_health_status_feature: project.licensed_feature_available?(:issuable_health_status).to_s,
+        issues_list_path: project_issues_path(project),
+        labels_manage_path: project_labels_path(project),
+        can_admin_label: can?(current_user, :admin_label, project).to_s,
+        has_issue_weights_feature: project.licensed_feature_available?(:issue_weights).to_s,
+        has_iterations_feature: project.licensed_feature_available?(:iterations).to_s,
+        work_item_planning_view_enabled: ::Feature.enabled?(:work_item_planning_view, project.group).to_s
+      }
+    end
+
     return unless group && group.id
 
     {
@@ -141,7 +154,9 @@ module SidebarsHelper
       has_issuable_health_status_feature: group.licensed_feature_available?(:issuable_health_status).to_s,
       issues_list_path: issues_group_path(group),
       labels_manage_path: group_labels_path(group),
-      can_admin_label: can?(current_user, :admin_label, group).to_s
+      can_admin_label: can?(current_user, :admin_label, group).to_s,
+      has_issue_weights_feature: group.licensed_feature_available?(:issue_weights).to_s,
+      work_item_planning_view_enabled: ::Feature.enabled?(:work_item_planning_view, group).to_s
     }
   end
 
@@ -187,20 +202,7 @@ module SidebarsHelper
     # We only return the panel if any menu item is rendered, otherwise fallback
     return panel if panel&.render?
 
-    # Fallback menu "Your work" for logged-in users, "Explore" for logged-out
-    if user
-      context = your_work_sidebar_context(user, **context_adds)
-      Sidebars::YourWork::Panel.new(context)
-    else
-      Sidebars::Explore::Panel.new(
-        Sidebars::Context.new(
-          current_user: nil,
-          container: nil,
-          current_organization: Current.organization,
-          **context_adds
-        )
-      )
-    end
+    fallback_sidebar_panel(nav, context_adds, user)
   end
 
   def command_palette_data(project: nil, current_ref: nil)
@@ -213,8 +215,31 @@ module SidebarsHelper
     }
   end
 
+  def compare_plans_url(*)
+    "#{promo_url}/pricing"
+  end
+
   private
 
+  def fallback_sidebar_panel(nav, context_adds, user = nil)
+    # Fallback when panels fail to render:
+    # - UserProfile panel failures (no accessible content) -> Explore navigation for private/blocked users
+    # - Other panel failures -> Your Work (logged-in) or Explore (anonymous)
+    if nav != 'user_profile' && user
+      context = your_work_sidebar_context(user, **context_adds)
+      return Sidebars::YourWork::Panel.new(context)
+    end
+
+    Sidebars::Explore::Panel.new(
+      Sidebars::Context.new(
+        current_user: user,
+        container: nil,
+        current_organization: Current.organization,
+        **context_adds
+      )
+    )
+  end
+
   def search_data
     {
       search_path: search_path,
@@ -273,7 +298,7 @@ module SidebarsHelper
           {
             text: _('Assigned'),
             href: merge_requests_dashboard_path(assignee_username: user.username),
-            count: user.assigned_open_merge_requests_count,
+            count: user.assigned_open_merge_requests_count(cached_only: true),
             userCount: 'assigned_merge_requests',
             extraAttrs: {
               'data-track-action': 'click_link',
@@ -285,7 +310,7 @@ module SidebarsHelper
           {
             text: _('Review requests'),
             href: merge_requests_dashboard_path(reviewer_username: user.username),
-            count: user.review_requested_open_merge_requests_count,
+            count: user.review_requested_open_merge_requests_count(cached_only: true),
             userCount: 'review_requested_merge_requests',
             extraAttrs: {
               'data-track-action': 'click_link',
@@ -506,7 +531,7 @@ module SidebarsHelper
   end
 
   def display_admin_area_link?
-    current_user&.can_admin_all_resources?
+    current_user&.can?(:access_admin_area)
   end
 end
 
