@@ -6,33 +6,16 @@ class ApplicationSetting < ApplicationRecord
   include TokenAuthenticatable
   include ChronicDurationAttribute
   include Sanitizable
+  include Gitlab::EncryptedAttribute
+  include SafelyChangeColumnDefault
+  include IgnorableColumns
+
+  columns_changing_default :enforce_ci_inbound_job_token_scope_enabled, :deletion_adjourned_period,
+    :wiki_page_max_content_bytes
 
   ignore_column :pre_receive_secret_detection_enabled, remove_with: '17.9', remove_after: '2025-02-15'
-
-  ignore_columns %i[
-    elasticsearch_aws
-    elasticsearch_search
-    elasticsearch_indexing
-    elasticsearch_username
-    elasticsearch_aws_region
-    elasticsearch_aws_access_key
-    elasticsearch_limit_indexing
-    elasticsearch_pause_indexing
-    elasticsearch_requeue_workers
-    elasticsearch_max_bulk_size_mb
-    elasticsearch_retry_on_failure
-    elasticsearch_max_bulk_concurrency
-    elasticsearch_client_request_timeout
-    elasticsearch_worker_number_of_shards
-    elasticsearch_analyzers_smartcn_search
-    elasticsearch_analyzers_kuromoji_search
-    elasticsearch_analyzers_smartcn_enabled
-    elasticsearch_analyzers_kuromoji_enabled
-    elasticsearch_indexed_field_length_limit
-    elasticsearch_indexed_file_size_limit_kb
-    elasticsearch_max_code_indexing_concurrency
-    security_policy_scheduled_scans_max_concurrency
-  ], remove_with: '17.11', remove_after: '2025-04-17'
+  ignore_column :model_prompt_cache_enabled, remove_with: '18.5', remove_after: '2025-10-05'
+  ignore_column :lock_model_prompt_cache_enabled, remove_with: '18.5', remove_after: '2025-10-05'
 
   INSTANCE_REVIEW_MIN_USERS = 50
   GRAFANA_URL_ERROR_MESSAGE = 'Please check your Grafana URL setting in ' \
@@ -56,11 +39,12 @@ class ApplicationSetting < ApplicationRecord
   # matches the size set in the database constraint
   DEFAULT_BRANCH_PROTECTIONS_DEFAULT_MAX_SIZE = 1.kilobyte
 
-  PACKAGE_REGISTRY_SETTINGS = [:nuget_skip_metadata_url_validation].freeze
-
   USERS_UNCONFIRMED_SECONDARY_EMAILS_DELETE_AFTER_DAYS = 3
 
-  INACTIVE_RESOURCE_ACCESS_TOKENS_DELETE_AFTER_DAYS = 30
+  DEFAULT_HELM_MAX_PACKAGES_COUNT = 1000
+
+  DEFAULT_AUTHENTICATED_GIT_HTTP_LIMIT = 3600
+  DEFAULT_AUTHENTICATED_GIT_HTTP_PERIOD = 3600
 
   enum :whats_new_variant, { all_tiers: 0, current_tier: 1, disabled: 2 }, prefix: true
   enum :email_confirmation_setting, { off: 0, soft: 1, hard: 2 }, prefix: true
@@ -104,13 +88,13 @@ class ApplicationSetting < ApplicationRecord
 
   serialize :restricted_visibility_levels # rubocop:disable Cop/ActiveRecordSerialize
   serialize :import_sources # rubocop:disable Cop/ActiveRecordSerialize
-  serialize :disabled_oauth_sign_in_sources, Array # rubocop:disable Cop/ActiveRecordSerialize
-  serialize :domain_allowlist, Array # rubocop:disable Cop/ActiveRecordSerialize
-  serialize :domain_denylist, Array # rubocop:disable Cop/ActiveRecordSerialize
+  serialize :disabled_oauth_sign_in_sources, type: Array # rubocop:disable Cop/ActiveRecordSerialize
+  serialize :domain_allowlist, type: Array # rubocop:disable Cop/ActiveRecordSerialize
+  serialize :domain_denylist, type: Array # rubocop:disable Cop/ActiveRecordSerialize
 
   # See https://gitlab.com/gitlab-org/gitlab/-/issues/300916
-  serialize :asset_proxy_allowlist, Array # rubocop:disable Cop/ActiveRecordSerialize
-  serialize :asset_proxy_whitelist, Array # rubocop:disable Cop/ActiveRecordSerialize
+  serialize :asset_proxy_allowlist, type: Array # rubocop:disable Cop/ActiveRecordSerialize
+  serialize :asset_proxy_whitelist, type: Array # rubocop:disable Cop/ActiveRecordSerialize
 
   cache_markdown_field :help_page_text
   cache_markdown_field :shared_runners_text, pipeline: :plain_markdown
@@ -266,6 +250,9 @@ class ApplicationSetting < ApplicationRecord
   validates :container_expiration_policies_enable_historic_entries,
     inclusion: { in: [true, false], message: N_('must be a boolean value') }
 
+  validates :pipeline_variables_default_allowed,
+    inclusion: { in: [true, false], message: N_('must be a boolean value') }
+
   validate :check_repository_storages_weighted
 
   validates :auto_devops_domain,
@@ -348,10 +335,10 @@ class ApplicationSetting < ApplicationRecord
     allow_blank: true
 
   jsonb_accessor :token_prefixes,
-    instance_token_prefix: [:string, { default: 'gl' }]
+    instance_token_prefix: [:string, { default: '' }]
 
   validates :instance_token_prefix,
-    format: { with: %r{\A[a-zA-Z0-9-]+\z} },
+    format: { with: %r{\A[a-zA-Z0-9]+\z} },
     length: { maximum: 20, message: N_('is too long (maximum is %{count} characters)') },
     allow_blank: true
 
@@ -448,6 +435,10 @@ class ApplicationSetting < ApplicationRecord
 
   validates :allowed_key_types, presence: true
 
+  validates :deletion_adjourned_period,
+    presence: true,
+    numericality: { only_integer: true, greater_than: 0, less_than_or_equal_to: 90 }
+
   validates_each :restricted_visibility_levels do |record, attr, value|
     value&.each do |level|
       unless Gitlab::VisibilityLevel.options.value?(level)
@@ -462,7 +453,12 @@ class ApplicationSetting < ApplicationRecord
 
   validates_each :import_sources, on: :update do |record, attr, value|
     value&.each do |source|
-      unless Gitlab::ImportSources.options.value?(source)
+      # Temporary allow "gitlab_custom_project_template" to avoid validation errors
+      # "gitlab_custom_project_template" can be excluded after incorrect values are removed from the database
+      # Issue: https://gitlab.com/gitlab-org/gitlab/-/issues/550410
+      allowed_import_sources = Gitlab::ImportSources.values - ['gitlab_built_in_project_template']
+
+      unless allowed_import_sources.include?(source)
         record.errors.add(attr, format(_("'%{source}' is not a import source"), source: source))
       end
     end
@@ -470,6 +466,8 @@ class ApplicationSetting < ApplicationRecord
 
   validate :check_valid_runner_registrars
 
+  validate :snowplow_and_product_usage_data_are_mutually_exclusive
+
   validate :terms_exist, if: :enforce_terms?
 
   validates :external_authorization_service_default_label,
@@ -526,6 +524,20 @@ class ApplicationSetting < ApplicationRecord
     pass: :external_auth_client_key_pass,
     if: ->(setting) { setting.external_auth_client_cert.present? }
 
+  jsonb_accessor :ci_cd_settings,
+    pipeline_variables_default_allowed: [:boolean, { default: true }],
+    ci_job_live_trace_enabled: [:boolean, { default: false }],
+    ci_partitions_size_limit: [::Gitlab::Database::Type::JsonbInteger.new, { default: 100.gigabytes }],
+    ci_delete_pipelines_in_seconds_limit: [:integer, { default: ChronicDuration.parse('1 year') }],
+    git_push_pipeline_limit: [:integer, { default: 4 }]
+
+  chronic_duration_attr :ci_delete_pipelines_in_seconds_limit_human_readable, :ci_delete_pipelines_in_seconds_limit
+
+  validate :validate_object_storage_for_live_trace_configuration, if: -> { ci_job_live_trace_enabled? }
+  validates :ci_partitions_size_limit, presence: true, numericality: { only_integer: true, greater_than: 0 }
+  validates :ci_delete_pipelines_in_seconds_limit, presence: true,
+    numericality: { only_integer: true, greater_than_or_equal_to: 1.day }
+
   validates :default_ci_config_path,
     format: { without: %r{(\.{2}|\A/)}, message: N_('cannot include leading slash or directory traversal.') },
     length: { maximum: 255 },
@@ -590,6 +602,7 @@ class ApplicationSetting < ApplicationRecord
       :max_yaml_size_bytes,
       :namespace_aggregation_schedule_lease_duration_in_seconds,
       :project_jobs_api_rate_limit,
+      :relation_export_batch_size,
       :session_expire_delay,
       :snippet_size_limit,
       :throttle_authenticated_api_period_in_seconds,
@@ -598,6 +611,8 @@ class ApplicationSetting < ApplicationRecord
       :throttle_authenticated_deprecated_api_requests_per_period,
       :throttle_authenticated_files_api_period_in_seconds,
       :throttle_authenticated_files_api_requests_per_period,
+      :throttle_authenticated_git_http_period_in_seconds,
+      :throttle_authenticated_git_http_requests_per_period,
       :throttle_authenticated_git_lfs_period_in_seconds,
       :throttle_authenticated_git_lfs_requests_per_period,
       :throttle_authenticated_packages_api_period_in_seconds,
@@ -633,6 +648,7 @@ class ApplicationSetting < ApplicationRecord
       :downstream_pipeline_trigger_limit_per_project_user_sha,
       :gitlab_shell_operation_limit,
       :group_api_limit,
+      :group_archive_unarchive_api_limit,
       :group_invited_groups_api_limit,
       :group_projects_api_limit,
       :group_shared_groups_api_limit,
@@ -642,6 +658,10 @@ class ApplicationSetting < ApplicationRecord
       :jobs_per_stage_page_size,
       :max_decompressed_archive_size,
       :max_export_size,
+      :max_github_response_size_limit,
+      :max_github_response_json_value_count,
+      :max_http_decompressed_size,
+      :max_http_response_size_limit,
       :max_import_remote_file_size,
       :max_import_size,
       :max_pages_custom_domains_per_project,
@@ -673,43 +693,39 @@ class ApplicationSetting < ApplicationRecord
       :users_api_limit_ssh_keys,
       :users_api_limit_ssh_key,
       :users_api_limit_gpg_keys,
-      :users_api_limit_gpg_key
+      :users_api_limit_gpg_key,
+      :git_push_pipeline_limit
   end
 
   attribute :resource_usage_limits, ::Gitlab::Database::Type::IndifferentJsonb.new, default: -> { {} }
   validates :resource_usage_limits, json_schema: { filename: 'resource_usage_limits' }
 
-  jsonb_accessor :rate_limits,
-    autocomplete_users_limit: [:integer, { default: 300 }],
-    autocomplete_users_unauthenticated_limit: [:integer, { default: 100 }],
-    concurrent_bitbucket_import_jobs_limit: [:integer, { default: 100 }],
-    concurrent_bitbucket_server_import_jobs_limit: [:integer, { default: 100 }],
-    concurrent_github_import_jobs_limit: [:integer, { default: 1000 }],
-    concurrent_relation_batch_export_limit: [:integer, { default: 8 }],
-    downstream_pipeline_trigger_limit_per_project_user_sha: [:integer, { default: 0 }],
-    group_api_limit: [:integer, { default: 400 }],
-    group_invited_groups_api_limit: [:integer, { default: 60 }],
-    group_projects_api_limit: [:integer, { default: 600 }],
-    group_shared_groups_api_limit: [:integer, { default: 60 }],
-    groups_api_limit: [:integer, { default: 200 }],
-    members_delete_limit: [:integer, { default: 60 }],
-    create_organization_api_limit: [:integer, { default: 10 }],
-    project_api_limit: [:integer, { default: 400 }],
-    project_invited_groups_api_limit: [:integer, { default: 60 }],
-    projects_api_limit: [:integer, { default: 2000 }],
-    user_contributed_projects_api_limit: [:integer, { default: 100 }],
-    user_projects_api_limit: [:integer, { default: 300 }],
-    user_starred_projects_api_limit: [:integer, { default: 100 }],
-    users_api_limit_followers: [:integer, { default: 100 }],
-    users_api_limit_following: [:integer, { default: 100 }],
-    users_api_limit_status: [:integer, { default: 240 }],
-    users_api_limit_ssh_keys: [:integer, { default: 120 }],
-    users_api_limit_ssh_key: [:integer, { default: 120 }],
-    users_api_limit_gpg_keys: [:integer, { default: 120 }],
-    users_api_limit_gpg_key: [:integer, { default: 120 }]
+  jsonb_accessor :resource_access_tokens_settings,
+    inactive_resource_access_tokens_delete_after_days: [:integer, { default: 30 }]
+
+  validates :resource_access_tokens_settings, json_schema: { filename: 'resource_access_tokens_settings' }
+
+  jsonb_accessor :group_settings,
+    top_level_group_creation_enabled: [:boolean, { default: true }],
+    disable_invite_members: [:boolean, { default: false }]
+
+  validates :group_settings,
+    json_schema: { filename: "application_setting_group_settings" }
+
+  jsonb_accessor :clickhouse,
+    use_clickhouse_for_analytics: [:boolean, { default: false }]
+
+  validates :clickhouse, json_schema: { filename: "application_setting_clickhouse" }
+
+  jsonb_accessor :response_limits,
+    max_http_response_size_limit: [:integer, { default: 100 }],
+    max_http_decompressed_size: [:integer, { default: 100 }],
+    max_github_response_size_limit: [:integer, { default: 8 }],
+    max_github_response_json_value_count: [:integer, { default: 250_000 }]
 
   jsonb_accessor :service_ping_settings,
-    gitlab_environment_toolkit_instance: [:boolean, { default: false }]
+    gitlab_environment_toolkit_instance: [:boolean, { default: false }],
+    gitlab_product_usage_data_enabled: [:boolean, { default: Settings.gitlab['initial_gitlab_product_usage_data'] }]
 
   jsonb_accessor :rate_limits_unauthenticated_git_http,
     throttle_unauthenticated_git_http_enabled: [:boolean, { default: false }],
@@ -718,11 +734,14 @@ class ApplicationSetting < ApplicationRecord
 
   jsonb_accessor :importers,
     silent_admin_exports_enabled: [:boolean, { default: false }],
-    allow_contribution_mapping_to_admins: [:boolean, { default: false }]
+    allow_contribution_mapping_to_admins: [:boolean, { default: false }],
+    allow_bypass_placeholder_confirmation: [:boolean, { default: false }],
+    relation_export_batch_size: [:integer, { default: 50 }]
 
   jsonb_accessor :sign_in_restrictions,
     disable_password_authentication_for_users_with_sso_identities: [:boolean, { default: false }],
-    root_moved_permanently_redirection: [:boolean, { default: false }]
+    root_moved_permanently_redirection: [:boolean, { default: false }],
+    session_expire_from_init: [:boolean, { default: false }]
 
   validates :sign_in_restrictions, json_schema: { filename: 'application_setting_sign_in_restrictions' }
 
@@ -730,7 +749,9 @@ class ApplicationSetting < ApplicationRecord
     global_search_issues_enabled: [:boolean, { default: true }],
     global_search_merge_requests_enabled: [:boolean, { default: true }],
     global_search_snippet_titles_enabled: [:boolean, { default: true }],
-    global_search_users_enabled: [:boolean, { default: true }]
+    global_search_users_enabled: [:boolean, { default: true }],
+    global_search_block_anonymous_searches_enabled: [:boolean, { default: false }],
+    anonymous_searches_allowed: [:boolean, { default: true }]
 
   validates :search, json_schema: { filename: 'application_setting_search' }
 
@@ -742,13 +763,22 @@ class ApplicationSetting < ApplicationRecord
 
   validates :rate_limits, json_schema: { filename: "application_setting_rate_limits" }
 
-  validates :importers, json_schema: { filename: "application_setting_importers" }
+  validates :response_limits, json_schema: { filename: "application_setting_response_limits" }
 
-  DEFAULT_HELM_MAX_PACKAGES_COUNT = 1000
+  validates :importers, json_schema: { filename: "application_setting_importers" }
 
   jsonb_accessor :package_registry,
     nuget_skip_metadata_url_validation: [:boolean, { default: false }],
-    helm_max_packages_count: [:integer, { default: DEFAULT_HELM_MAX_PACKAGES_COUNT }]
+    helm_max_packages_count: [:integer, { default: DEFAULT_HELM_MAX_PACKAGES_COUNT }],
+    package_registry_allow_anyone_to_pull_option: [:boolean, { default: true }],
+    package_registry_cleanup_policies_worker_capacity: [:integer, { default: 2 }],
+    packages_cleanup_package_file_worker_capacity: [:integer, { default: 2 }],
+    npm_package_requests_forwarding: [:boolean, { default: true }],
+    lock_npm_package_requests_forwarding: [:boolean, { default: false }],
+    maven_package_requests_forwarding: [:boolean, { default: true }],
+    lock_maven_package_requests_forwarding: [:boolean, { default: false }],
+    pypi_package_requests_forwarding: [:boolean, { default: true }],
+    lock_pypi_package_requests_forwarding: [:boolean, { default: false }]
 
   validates :helm_max_packages_count,
     presence: true,
@@ -828,8 +858,19 @@ class ApplicationSetting < ApplicationRecord
     numericality: { greater_than_or_equal_to: 0, less_than_or_equal_to: 1,
                     message: N_('must be a value between 0 and 1') }
 
-  validates :package_registry_allow_anyone_to_pull_option,
-    inclusion: { in: [true, false], message: N_('must be a boolean value') }
+  with_options(inclusion: { in: [true, false], message: N_('must be a boolean value') }) do
+    validates(
+      :package_registry_allow_anyone_to_pull_option,
+      :nuget_skip_metadata_url_validation,
+      :npm_package_requests_forwarding,
+      :lock_npm_package_requests_forwarding,
+      :pypi_package_requests_forwarding,
+      :lock_pypi_package_requests_forwarding,
+      :maven_package_requests_forwarding,
+      :lock_maven_package_requests_forwarding,
+      :pages_unique_domain_default_enabled
+    )
+  end
 
   validates :security_txt_content,
     length: { maximum: 2_048, message: N_('is too long (maximum is %{count} characters)') },
@@ -838,11 +879,16 @@ class ApplicationSetting < ApplicationRecord
   validates :asciidoc_max_includes,
     numericality: { only_integer: true, greater_than_or_equal_to: 0, less_than_or_equal_to: 64 }
 
-  jsonb_accessor :pages, pages_extra_deployments_default_expiry_seconds: [:integer, { default: 86400 }]
+  jsonb_accessor :pages,
+    pages_extra_deployments_default_expiry_seconds: [:integer, { default: 86400 }],
+    pages_unique_domain_default_enabled: [:boolean, { default: true }]
+
   validates :pages, json_schema: { filename: "application_setting_pages" }
 
   jsonb_accessor :anti_abuse_settings,
-    enforce_email_subaddress_restrictions: [::Gitlab::Database::Type::JsonbBoolean.new, { default: false }]
+    enforce_email_subaddress_restrictions: [::Gitlab::Database::Type::JsonbBoolean.new, { default: false }],
+    require_email_verification_on_account_locked: [::Gitlab::Database::Type::JsonbBoolean.new, { default: false }],
+    delay_user_account_self_deletion: [::Gitlab::Database::Type::JsonbBoolean.new, { default: false }]
 
   validates :anti_abuse_settings, json_schema: { filename: "anti_abuse_settings", detail_errors: true }
 
@@ -850,21 +896,32 @@ class ApplicationSetting < ApplicationRecord
     allow_nil: false,
     inclusion: { in: [true, false], message: N_('must be a boolean value') }
 
-  attr_encrypted :asset_proxy_secret_key,
+  migrate_to_encrypts :asset_proxy_secret_key,
     mode: :per_attribute_iv,
-    key: Settings.attr_encrypted_db_key_base_truncated,
+    key: :db_key_base_truncated,
     algorithm: 'aes-256-cbc',
     insecure_mode: true
 
   private_class_method def self.encryption_options_base_32_aes_256_gcm
     {
       mode: :per_attribute_iv,
-      key: Settings.attr_encrypted_db_key_base_32,
+      key: :db_key_base_32,
       algorithm: 'aes-256-gcm',
       encode: true
     }
   end
 
+  jsonb_accessor :cluster_agents,
+    organization_cluster_agent_authorization_enabled: [:boolean, { default: false }]
+
+  validates :cluster_agents, json_schema: { filename: 'application_setting_cluster_agents' }
+
+  jsonb_accessor :database_reindexing,
+    reindexing_minimum_index_size: [::Gitlab::Database::Type::JsonbInteger.new, { default: 1.gigabyte }],
+    reindexing_minimum_relative_bloat_size: [:float, { default: 0.2 }]
+
+  validates :database_reindexing, json_schema: { filename: "application_setting_database_reindexing" }
+
   attr_encrypted :external_auth_client_key, encryption_options_base_32_aes_256_gcm
   attr_encrypted :external_auth_client_key_pass, encryption_options_base_32_aes_256_gcm
   attr_encrypted :lets_encrypt_private_key, encryption_options_base_32_aes_256_gcm
@@ -925,11 +982,21 @@ class ApplicationSetting < ApplicationRecord
     allow_nil: false,
     inclusion: { in: [true, false], message: N_('must be a boolean value') }
 
+  jsonb_accessor :default_profile_preferences,
+    default_dark_syntax_highlighting_theme: [:integer, { default: 2 }]
+
+  validates :default_profile_preferences, json_schema: { filename: "application_setting_default_profile_preferences" }
+
   validates :default_syntax_highlighting_theme,
     allow_nil: false,
     numericality: { only_integer: true, greater_than: 0 },
     inclusion: { in: Gitlab::ColorSchemes.valid_ids, message: N_('must be a valid syntax highlighting theme ID') }
 
+  validates :default_dark_syntax_highlighting_theme,
+    allow_nil: false,
+    numericality: { only_integer: true, greater_than: 0 },
+    inclusion: { in: Gitlab::ColorSchemes.valid_ids, message: N_('must be a valid syntax highlighting theme ID') }
+
   validates :gitlab_dedicated_instance,
     allow_nil: false,
     inclusion: { in: [true, false], message: N_('must be a boolean value') }
@@ -952,6 +1019,13 @@ class ApplicationSetting < ApplicationRecord
   jsonb_accessor :vscode_extension_marketplace,
     vscode_extension_marketplace_enabled: [:boolean, { default: false, store_key: :enabled }]
 
+  jsonb_accessor :editor_extensions,
+    enable_language_server_restrictions: [:boolean, { default: false }],
+    minimum_language_server_version: [:string, { default: '0.1.0' }]
+
+  validates :editor_extensions,
+    json_schema: { filename: 'application_setting_editor_extensions', detail_errors: true }
+
   before_validation :ensure_uuid!
   before_validation :coerce_repository_storages_weighted, if: :repository_storages_weighted_changed?
   before_validation :normalize_default_branch_name
@@ -968,6 +1042,13 @@ class ApplicationSetting < ApplicationRecord
   }
   after_commit :reset_deletion_warning_redis_key, if: :should_reset_inactive_project_deletion_warning?
 
+  def validate_object_storage_for_live_trace_configuration
+    return if Gitlab.config.artifacts.object_store.enabled
+
+    errors.add(:ci_job_live_trace_enabled,
+      'Incremental logging cannot be turned on without configuring object storage for artifacts.')
+  end
+
   def validate_grafana_url
     validate_url(parsed_grafana_url, :grafana_url, GRAFANA_URL_ERROR_MESSAGE)
   end
@@ -1059,6 +1140,48 @@ class ApplicationSetting < ApplicationRecord
     HUMANIZED_ATTRIBUTES[attribute.to_sym] || super
   end
 
+  # overriden in EE
+  def self.rate_limits_definition
+    {
+      autocomplete_users_limit: [:integer, { default: 300 }],
+      autocomplete_users_unauthenticated_limit: [:integer, { default: 100 }],
+      concurrent_bitbucket_import_jobs_limit: [:integer, { default: 100 }],
+      concurrent_bitbucket_server_import_jobs_limit: [:integer, { default: 100 }],
+      concurrent_github_import_jobs_limit: [:integer, { default: 1000 }],
+      concurrent_relation_batch_export_limit: [:integer, { default: 8 }],
+      downstream_pipeline_trigger_limit_per_project_user_sha: [:integer, { default: 0 }],
+      group_api_limit: [:integer, { default: 400 }],
+      group_invited_groups_api_limit: [:integer, { default: 60 }],
+      group_projects_api_limit: [:integer, { default: 600 }],
+      group_shared_groups_api_limit: [:integer, { default: 60 }],
+      groups_api_limit: [:integer, { default: 200 }],
+      members_delete_limit: [:integer, { default: 60 }],
+      create_organization_api_limit: [:integer, { default: 10 }],
+      project_api_limit: [:integer, { default: 400 }],
+      group_archive_unarchive_api_limit: [:integer, { default: 60 }],
+      project_invited_groups_api_limit: [:integer, { default: 60 }],
+      projects_api_limit: [:integer, { default: 2000 }],
+      throttle_authenticated_git_http_enabled: [:boolean, { default: false }],
+      throttle_authenticated_git_http_requests_per_period:
+        [:integer, { default: DEFAULT_AUTHENTICATED_GIT_HTTP_LIMIT }],
+      throttle_authenticated_git_http_period_in_seconds:
+        [:integer, { default: DEFAULT_AUTHENTICATED_GIT_HTTP_PERIOD }],
+      user_contributed_projects_api_limit: [:integer, { default: 100 }],
+      user_projects_api_limit: [:integer, { default: 300 }],
+      user_starred_projects_api_limit: [:integer, { default: 100 }],
+      users_api_limit_followers: [:integer, { default: 100 }],
+      users_api_limit_following: [:integer, { default: 100 }],
+      users_api_limit_status: [:integer, { default: 240 }],
+      users_api_limit_ssh_keys: [:integer, { default: 120 }],
+      users_api_limit_ssh_key: [:integer, { default: 120 }],
+      users_api_limit_gpg_keys: [:integer, { default: 120 }],
+      users_api_limit_gpg_key: [:integer, { default: 120 }]
+    }
+  end
+
+  # this statement has to come after the rate_limits_definition function
+  jsonb_accessor :rate_limits, rate_limits_definition
+
   def recaptcha_or_login_protection_enabled
     recaptcha_enabled || login_recaptcha_protection_enabled
   end
@@ -1094,6 +1217,17 @@ class ApplicationSetting < ApplicationRecord
     self.class.database.cached_column_exists?(:failed_login_attempts_unlock_period_in_minutes)
   end
 
+  def ci_delete_pipelines_in_seconds_limit_human_readable_long
+    value = ci_delete_pipelines_in_seconds_limit
+    ChronicDuration.output(value, format: :long) if value
+  end
+
+  def allow_user_remember_me?
+    return false if session_expire_from_init?
+
+    remember_me_enabled?
+  end
+
   private
 
   def parsed_grafana_url
@@ -1113,6 +1247,15 @@ class ApplicationSetting < ApplicationRecord
     )
   end
 
+  def snowplow_and_product_usage_data_are_mutually_exclusive
+    return unless gitlab_product_usage_data_enabled_changed? || snowplow_enabled_changed?
+    return unless snowplow_enabled && gitlab_product_usage_data_enabled
+
+    message = _('Snowplow tracking and Product event tracking cannot be enabled at the same time. ' \
+      'Please disable one of them.')
+    errors.add(:base, message)
+  end
+
   def validate_url(parsed_url, name, error_message)
     return if parsed_url
 
@@ -1123,7 +1266,7 @@ class ApplicationSetting < ApplicationRecord
   end
 
   def reset_deletion_warning_redis_key
-    Gitlab::InactiveProjectsDeletionWarningTracker.reset_all
+    Gitlab::DormantProjectsDeletionWarningTracker.reset_all
   end
 
   def should_prevent_visibility_restriction?
