@@ -45,7 +45,7 @@ module Issuable
   }.with_indifferent_access.freeze
 
   included do
-    cache_markdown_field :title, pipeline: :single_line
+    cache_markdown_field :title, pipeline: :single_line_markdown
     cache_markdown_field :description, issuable_reference_expansion_enabled: true
 
     redact_field :description
@@ -79,7 +79,7 @@ module Issuable
     has_many :note_authors, -> { distinct }, through: :notes, source: :author
     has_many :user_note_authors, -> { distinct.where("notes.system = false") }, through: :notes, source: :author
 
-    has_many :label_links, as: :target, inverse_of: :target
+    has_many :label_links, as: :target, inverse_of: :target, dependent: :delete_all # rubocop:disable Cop/ActiveRecordDependent -- Polymorphic association, so no FK
     has_many :labels, through: :label_links
     has_many :todos, as: :target
 
@@ -153,7 +153,7 @@ module Issuable
       includes(*associations)
     end
 
-    attr_mentionable :title, pipeline: :single_line
+    attr_mentionable :title, pipeline: :single_line_markdown
     attr_mentionable :description
 
     participant :author
@@ -408,7 +408,7 @@ module Issuable
 
     def order_labels_priority(direction = 'ASC', excluded_labels: [], extra_select_columns: [], with_cte: false)
       highest_priority = highest_label_priority(
-        target_type: name,
+        target_type: name == "WorkItem" ? "Issue" : name,
         target_column: "#{table_name}.id",
         project_column: "#{table_name}.#{project_foreign_key}",
         excluded_labels: excluded_labels
