@@ -134,7 +134,34 @@ class Group < Namespace
   has_many :dependency_proxy_blobs, class_name: 'DependencyProxy::Blob'
   has_many :dependency_proxy_manifests, class_name: 'DependencyProxy::Manifest'
 
+  has_one :observability_group_o11y_setting, class_name: 'Observability::GroupO11ySetting', inverse_of: :group
+
+  has_one :deletion_schedule, class_name: 'GroupDeletionSchedule'
+  delegate :deleting_user, :marked_for_deletion_on, to: :deletion_schedule, allow_nil: true
+
+  scope :aimed_for_deletion, -> { where.associated(:deletion_schedule) }
+  scope :self_or_ancestors_aimed_for_deletion, -> { where(self_or_ancestors_deletion_schedule_subquery.exists) }
+
+  scope :not_aimed_for_deletion, -> { where.missing(:deletion_schedule) }
+  scope :self_and_ancestors_not_aimed_for_deletion, -> { where.not(self_or_ancestors_deletion_schedule_subquery.exists) }
+
+  scope :with_deletion_schedule, -> { preload(deletion_schedule: :deleting_user) }
+  scope :with_deletion_schedule_only, -> { preload(:deletion_schedule) }
+
+  scope :marked_for_deletion_before, ->(date) do
+    joins(:deletion_schedule)
+      .where('group_deletion_schedules.marked_for_deletion_on <= ?', date)
+  end
+
+  scope :marked_for_deletion_on, ->(date) do
+    joins(:deletion_schedule)
+      .where(group_deletion_schedules: { marked_for_deletion_on: date })
+  end
+
+  scope :with_integrations, -> { joins(:integrations) }
+
   has_one :harbor_integration, class_name: 'Integrations::Harbor'
+  has_one :jira_integration, class_name: 'Integrations::Jira'
 
   # debian_distributions and associated component_files must be destroyed by ruby code in order to properly remove carrierwave uploads
   has_many :debian_distributions, class_name: 'Packages::Debian::GroupDistribution', dependent: :destroy # rubocop:disable Cop/ActiveRecordDependent
@@ -145,14 +172,38 @@ class Group < Namespace
 
   has_one :group_feature, inverse_of: :group, class_name: 'Groups::FeatureSetting'
 
-  delegate :prevent_sharing_groups_outside_hierarchy, :new_user_signups_cap, :setup_for_company, :jobs_to_be_done, :seat_control, to: :namespace_settings
-  delegate :runner_token_expiration_interval, :runner_token_expiration_interval=, :runner_token_expiration_interval_human_readable, :runner_token_expiration_interval_human_readable=, to: :namespace_settings, allow_nil: true
-  delegate :subgroup_runner_token_expiration_interval, :subgroup_runner_token_expiration_interval=, :subgroup_runner_token_expiration_interval_human_readable, :subgroup_runner_token_expiration_interval_human_readable=, to: :namespace_settings, allow_nil: true
-  delegate :project_runner_token_expiration_interval, :project_runner_token_expiration_interval=, :project_runner_token_expiration_interval_human_readable, :project_runner_token_expiration_interval_human_readable=, to: :namespace_settings, allow_nil: true
-  delegate :force_pages_access_control, :force_pages_access_control=, to: :namespace_settings, allow_nil: true
+  delegate(
+    :default_branch_name,
+    :jobs_to_be_done,
+    :new_user_signups_cap,
+    :prevent_sharing_groups_outside_hierarchy,
+    :require_dpop_for_manage_api_endpoints,
+    :require_dpop_for_manage_api_endpoints?,
+    :require_dpop_for_manage_api_endpoints=,
+    :seat_control,
+    :setup_for_company,
+    to: :namespace_settings
+  )
 
-  delegate :require_dpop_for_manage_api_endpoints, :require_dpop_for_manage_api_endpoints=, to: :namespace_settings
-  delegate :require_dpop_for_manage_api_endpoints?, to: :namespace_settings
+  delegate(
+    :force_pages_access_control,
+    :force_pages_access_control=,
+    :model_prompt_cache_enabled,
+    :model_prompt_cache_enabled=,
+    :project_runner_token_expiration_interval_human_readable,
+    :project_runner_token_expiration_interval_human_readable=,
+    :project_runner_token_expiration_interval,
+    :project_runner_token_expiration_interval=,
+    :runner_token_expiration_interval_human_readable,
+    :runner_token_expiration_interval_human_readable=,
+    :runner_token_expiration_interval,
+    :runner_token_expiration_interval=,
+    :subgroup_runner_token_expiration_interval_human_readable,
+    :subgroup_runner_token_expiration_interval_human_readable=,
+    :subgroup_runner_token_expiration_interval,
+    :subgroup_runner_token_expiration_interval=,
+    to: :namespace_settings, allow_nil: true
+  )
 
   accepts_nested_attributes_for :variables, allow_destroy: true
   accepts_nested_attributes_for :group_feature, update_only: true
@@ -191,11 +242,28 @@ class Group < Namespace
 
   scope :with_users, -> { includes(:users) }
 
+  scope :active, -> { non_archived.not_aimed_for_deletion }
+  scope :self_and_ancestors_active, -> { self_and_ancestors_non_archived.self_and_ancestors_not_aimed_for_deletion }
+
+  scope :inactive, -> do
+    joins(:namespace_settings)
+      .left_joins(:deletion_schedule)
+      .where(<<~SQL)
+        #{reflections['namespace_settings'].table_name}.archived = TRUE
+        OR #{reflections['deletion_schedule'].table_name}.#{reflections['deletion_schedule'].foreign_key} IS NOT NULL
+      SQL
+  end
+  scope :self_or_ancestors_inactive, -> { self_or_ancestors_archived.or(self_or_ancestors_aimed_for_deletion) }
+
   scope :with_non_archived_projects, -> { includes(:non_archived_projects) }
 
   scope :with_non_invite_group_members, -> { includes(:non_invite_group_members) }
   scope :with_request_group_members, -> { includes(:request_group_members) }
 
+  scope :in_accessible_sub_namespaces, -> do
+    where('id IN (SELECT id FROM accessible_sub_namespace_ids)')
+  end
+
   scope :by_id, ->(groups) { where(id: groups) }
 
   scope :by_ids_or_paths, ->(ids, paths) do
@@ -298,6 +366,36 @@ class Group < Namespace
     end
   end
 
+  # .sorted_by_similarity_desc can generate poorly performing queries.
+  # Only apply this scope in combination with other filters, ideally on sets of
+  # less than 100,000 records.
+  scope :sorted_by_similarity_desc, ->(search) do
+    order_expression = Gitlab::Database::SimilarityScore.build_expression(
+      search: search,
+      rules: [
+        { column: arel_table["path"], multiplier: 1 },
+        { column: arel_table["name"], multiplier: 0.7 }
+      ])
+
+    order = Gitlab::Pagination::Keyset::Order.build(
+      [
+        Gitlab::Pagination::Keyset::ColumnOrderDefinition.new(
+          attribute_name: 'similarity',
+          column_expression: order_expression,
+          order_expression: order_expression.desc,
+          order_direction: :desc,
+          add_to_projections: true
+        ),
+        # Tie-breaker for if two results have the same similarity score.
+        Gitlab::Pagination::Keyset::ColumnOrderDefinition.new(
+          attribute_name: 'id',
+          order_expression: Namespace.arel_table['id'].asc
+        )
+      ])
+
+    order.apply_cursor_conditions(reorder(order))
+  end
+
   scope :order_path_asc, -> { reorder(self.arel_table['path'].asc) }
   scope :order_path_desc, -> { reorder(self.arel_table['path'].desc) }
   scope :in_organization, ->(organization) { where(organization: organization) }
@@ -403,7 +501,14 @@ class Group < Namespace
     end
 
     def with_api_scopes
-      preload(:namespace_settings, :group_feature, :parent)
+      preload(
+        :namespace_settings,
+        :namespace_settings_with_ancestors_inherited_settings,
+        :namespace_details,
+        :group_feature,
+        :parent,
+        :deletion_schedule
+      )
     end
 
     # Handle project creation permissions based on application setting and group setting. The `default_project_creation`
@@ -438,11 +543,24 @@ class Group < Namespace
 
     def prevent_project_creation?(user, project_creation_setting)
       return true if project_creation_setting == ::Gitlab::Access::NO_ONE_PROJECT_ACCESS
-      return false if user.can_admin_all_resources?
+      return false if Ability.allowed?(user, :admin_all_resources)
 
       project_creation_setting == ::Gitlab::Access::ADMINISTRATOR_PROJECT_ACCESS
     end
 
+    def self_or_ancestors_deletion_schedule_subquery
+      deletion_schedule_reflection = reflect_on_association(:deletion_schedule)
+      deletion_schedule_table = Arel::Table.new(deletion_schedule_reflection.table_name)
+      traversal_ids_ref = "#{arel_table.name}.#{arel_table[:traversal_ids].name}"
+
+      deletion_schedule_table
+        .project(1)
+        .where(
+          deletion_schedule_table[deletion_schedule_reflection.foreign_key]
+            .eq(Arel.sql("ANY (#{traversal_ids_ref})"))
+        )
+    end
+
     private
 
     def public_to_user_arel(user)
@@ -623,25 +741,33 @@ class Group < Namespace
   def last_owner?(user)
     return false unless user
 
-    all_owners = member_owners_excluding_project_bots
+    all_owners = member_owners_excluding_project_bots_and_service_accounts
+    last_owner_in_list?(user, all_owners)
+  end
+
+  # This is used in BillableMember Entity to
+  # avoid multiple "member_owners_excluding_project_bots_and_service_accounts" calls
+  # for each billable members
+  def last_owner_in_list?(user, all_owners)
+    return false unless user
 
     all_owners.size == 1 && all_owners.first.user_id == user.id
   end
 
   # Excludes non-direct owners for top-level group
   # Excludes project_bots
-  def member_owners_excluding_project_bots
-    members_from_hiearchy = if root?
-                              members.non_minimal_access.without_invites_and_requests
-                            else
-                              members_with_parents(only_active_users: false)
-                            end
+  # Excludes service accounts
+  def member_owners_excluding_project_bots_and_service_accounts
+    members_from_hierarchy = if root?
+                               members.non_minimal_access.without_invites_and_requests
+                             else
+                               members_with_parents(only_active_users: false)
+                             end
 
     owners = []
-
-    members_from_hiearchy.all_owners.non_invite.each_batch do |relation|
+    members_from_hierarchy.all_owners.non_invite.each_batch do |relation|
       owners += relation.preload(:user, :source).load.reject do |member|
-        member.user.nil? || member.user.project_bot?
+        member.user.nil? || member.user.project_bot? || member.user.service_account?
       end
     end
 
@@ -750,21 +876,21 @@ class Group < Namespace
   def members_with_descendants
     GroupMember
       .active_without_invites_and_requests
-      .where(source_id: self_and_descendants.reorder(nil).select(:id))
+      .where(source_id: self_and_descendants.without_order.select(:id))
   end
 
   # Returns all members that are part of the group, it's subgroups, and ancestor groups
   def hierarchy_members
     GroupMember
       .active_without_invites_and_requests
-      .where(source_id: self_and_hierarchy.reorder(nil).select(:id))
+      .where(source_id: self_and_hierarchy.without_order.select(:id))
   end
 
   def hierarchy_members_with_inactive
     GroupMember
       .non_request
       .non_invite
-      .where(source_id: self_and_hierarchy.reorder(nil).select(:id))
+      .where(source_id: self_and_hierarchy.without_order.select(:id))
   end
 
   def descendant_project_members_with_inactive
@@ -776,8 +902,8 @@ class Group < Namespace
 
   def users_with_descendants
     User
-      .where(id: members_with_descendants.select(:user_id))
-      .reorder(nil)
+      .id_in(members_with_descendants.select(:user_id))
+      .without_order
   end
 
   def users_count
@@ -892,10 +1018,6 @@ class Group < Namespace
     import_export_upload_by_user(user)&.export_archive_exists?
   end
 
-  def adjourned_deletion?
-    false
-  end
-
   def execute_hooks(data, hooks_scope)
     # NOOP
     # TODO: group hooks https://gitlab.com/gitlab-org/gitlab/-/issues/216904
@@ -1007,30 +1129,40 @@ class Group < Namespace
     feature_flag_enabled_for_self_or_ancestor?(:work_items_alpha)
   end
 
+  def work_items_project_issues_list_feature_flag_enabled?
+    feature_flag_enabled_for_self_or_ancestor?(:work_items_project_issues_list, type: :beta)
+  end
+
   def work_item_status_feature_available?
-    feature_flag_enabled_for_self_or_ancestor?(:work_item_status_feature_flag, type: :wip) &&
+    feature_flag_enabled_for_self_or_ancestor?(:work_item_status_feature_flag, type: :beta) &&
       licensed_feature_available?(:work_item_status)
   end
 
-  def continue_indented_text_feature_flag_enabled?
-    feature_flag_enabled_for_self_or_ancestor?(:continue_indented_text, type: :wip)
-  end
-
-  def glql_integration_feature_flag_enabled?
-    feature_flag_enabled_for_self_or_ancestor?(:glql_integration)
+  def markdown_placeholders_feature_flag_enabled?
+    feature_flag_enabled_for_self_or_ancestor?(:markdown_placeholders, type: :gitlab_com_derisk)
   end
 
   def glql_load_on_click_feature_flag_enabled?
-    feature_flag_enabled_for_self_or_ancestor?(:glql_load_on_click)
+    feature_flag_enabled_for_self_or_ancestor?(:glql_load_on_click, type: :ops)
   end
 
-  # Note: this method is overridden in EE to check the work_item_epics feature flag  which also enables this feature
-  def namespace_work_items_enabled?
-    ::Feature.enabled?(:namespace_level_work_items, self, type: :development)
+  # overriden in EE
+  def supports_group_work_items?
+    false
+  end
+
+  # overriden in EE
+  def has_active_hooks?(hooks_scope = :push_hooks)
+    false
+  end
+
+  # overriden in EE
+  def enterprise_user_settings_available?(user = nil)
+    false
   end
 
   def create_group_level_work_items_feature_flag_enabled?
-    ::Feature.enabled?(:create_group_level_work_items, self, type: :wip)
+    ::Feature.enabled?(:create_group_level_work_items, self, type: :wip) && supports_group_work_items?
   end
 
   def supports_lock_on_merge?
@@ -1131,6 +1263,16 @@ class Group < Namespace
     ::Clusters::Agent.for_projects(all_projects)
   end
 
+  def active?
+    self_and_ancestors.inactive.none?
+  end
+
+  def pending_delete?
+    return false unless deletion_schedule
+
+    deletion_schedule.marked_for_deletion_on.future?
+  end
+
   private
 
   def feature_flag_enabled_for_self_or_ancestor?(feature_flag, type: :development)
@@ -1213,6 +1355,12 @@ class Group < Namespace
     # We cannot disclose the Pages unique domain, hence returning generic error message
     errors.add(:path, _('has already been taken'))
   end
+
+  # Overriding of Namespaces::AdjournedDeletable method
+  override :all_scheduled_for_deletion_in_hierarchy_chain
+  def all_scheduled_for_deletion_in_hierarchy_chain
+    self_and_ancestors(hierarchy_order: :asc).joins(:deletion_schedule)
+  end
 end
 
 Group.prepend_mod_with('Group')
