@@ -26,6 +26,21 @@ class MergeRequest < ApplicationRecord
   include Todoable
   include Spammable
 
+  ignore_columns %i[
+    latest_merge_request_diff_id_convert_to_bigint
+    assignee_id_convert_to_bigint
+    author_id_convert_to_bigint
+    id_convert_to_bigint
+    last_edited_by_id_convert_to_bigint
+    merge_user_id_convert_to_bigint
+    milestone_id_convert_to_bigint
+    source_project_id_convert_to_bigint
+    target_project_id_convert_to_bigint
+    updated_by_id_convert_to_bigint
+  ], remove_with: '18.3', remove_after: '2025-07-17'
+
+  ignore_column :sprint_id, remove_with: '18.5', remove_after: '2025-09-18'
+
   extend ::Gitlab::Utils::Override
 
   sha_attribute :squash_commit_sha
@@ -40,6 +55,7 @@ class MergeRequest < ApplicationRecord
   CI_MERGE_REQUEST_DESCRIPTION_MAX_LENGTH = 2700
   MERGE_LEASE_TIMEOUT = 15.minutes.to_i
   DIFF_VERSION_LIMIT = 1_000
+  DIFF_COMMITS_LIMIT = 1_000_000
 
   belongs_to :target_project, class_name: "Project"
   belongs_to :source_project, class_name: "Project"
@@ -58,7 +74,12 @@ class MergeRequest < ApplicationRecord
     -> { regular }, inverse_of: :merge_request
   has_many :merge_request_context_commits, inverse_of: :merge_request
   has_many :merge_request_context_commit_diff_files, through: :merge_request_context_commits, source: :diff_files
-
+  has_many :generated_ref_commits,
+    primary_key: [:iid, :target_project_id],
+    class_name: 'MergeRequests::GeneratedRefCommit',
+    foreign_key: :merge_request_iid,
+    inverse_of: :merge_request,
+    query_constraints: [:merge_request_iid, :project_id]
   has_one :merge_request_diff,
     -> { regular.order('merge_request_diffs.id DESC') }, inverse_of: :merge_request
   has_one :merge_head_diff,
@@ -141,7 +162,7 @@ class MergeRequest < ApplicationRecord
     :sha,
     :skip_ci
   ].freeze
-  serialize :merge_params, Hash # rubocop:disable Cop/ActiveRecordSerialize
+  serialize :merge_params, type: Hash # rubocop:disable Cop/ActiveRecordSerialize
 
   before_validation :set_draft_status
 
@@ -315,9 +336,10 @@ class MergeRequest < ApplicationRecord
   scope :by_source_or_target_branch, ->(branch_name) do
     where("source_branch = :branch OR target_branch = :branch", branch: branch_name)
   end
+
   scope :by_milestone, ->(milestone) { where(milestone_id: milestone) }
   scope :of_projects, ->(ids) { where(target_project_id: ids) }
-  scope :from_project, ->(project) { where(source_project_id: project.id) }
+  scope :from_project, ->(project) { where(source_project_id: project) }
   scope :from_fork, -> { where('source_project_id <> target_project_id') }
   scope :from_and_to_forks, ->(project) do
     from_fork.where('source_project_id = ? OR target_project_id = ?', project.id, project.id)
@@ -400,14 +422,13 @@ class MergeRequest < ApplicationRecord
     preload_routables.preload(
       :assignees, :author, :unresolved_notes, :labels, :milestone,
       :timelogs, :latest_merge_request_diff, :reviewers,
-      :merge_schedule,
-      target_project: [:project_feature, :project_setting],
+      :merge_schedule, :merge_user,
+      target_project: [:project_feature, :project_setting, { namespace: :namespace_settings_with_ancestors_inherited_settings }],
       metrics: [:latest_closed_by, :merged_by]
     )
   }
 
   scope :with_csv_entity_associations, -> { preload(:assignees, :approved_by_users, :author, :milestone, metrics: [:merged_by]) }
-  scope :recently_unprepared, -> { where(prepared_at: nil).where(created_at: 2.hours.ago..).order(:created_at, :id) } # id is the tie-breaker
 
   scope :by_target_branch_wildcard, ->(wildcard_branch_name) do
     where("target_branch LIKE ?", ApplicationRecord.sanitize_sql_like(wildcard_branch_name).tr('*', '%'))
@@ -464,6 +485,52 @@ class MergeRequest < ApplicationRecord
     where(reviewers_subquery.exists.not)
   end
 
+  scope :with_review_states_or_no_reviewer, ->(states) do
+    where(
+      reviewers_subquery
+        .where(Arel::Table.new("#{to_ability_name}_reviewers")[:state].in(states))
+        .exists
+    ).or(
+      where(
+        reviewers_subquery.exists.not
+      )
+    )
+  end
+
+  scope :no_review_requested_or_only_user, ->(user) do
+    reviewers = Arel::Table.new("#{to_ability_name}_reviewers")
+
+    where.not(
+      MergeRequestReviewer
+        .where(reviewers[:merge_request_id].eq(Arel.sql('merge_requests.id')))
+        .where(reviewers[:user_id].not_eq(user.id))
+        .arel
+        .exists
+    )
+  end
+
+  scope :with_valid_or_no_reviewers, ->(states, user) do
+    reviewers = Arel::Table.new("#{to_ability_name}_reviewers")
+
+    valid_states_expr = reviewers_subquery
+      .where(reviewers[:user_id].not_eq(user.id))
+      .where(reviewers[:state].in(states))
+      .exists
+
+    no_reviewers_expr = reviewers_subquery.exists.not
+
+    only_user_expr = reviewers_subquery
+      .where(reviewers[:user_id].not_eq(user.id))
+      .exists
+      .not
+
+    where(
+      valid_states_expr
+        .or(no_reviewers_expr)
+        .or(only_user_expr.and(valid_states_expr.not))
+    )
+  end
+
   scope :review_requested_to, ->(user, states = nil) do
     scope = reviewers_subquery.where(Arel::Table.new("#{to_ability_name}_reviewers")[:user_id].eq(user.id))
     scope = scope.where(Arel::Table.new("#{to_ability_name}_reviewers")[:state].in(states)) if states
@@ -480,24 +547,37 @@ class MergeRequest < ApplicationRecord
     )
   end
 
-  scope :review_states, ->(states) do
-    where(
-      reviewers_subquery
-        .where(Arel::Table.new("#{to_ability_name}_reviewers")[:state].in(states))
-        .exists
-    )
+  scope :review_states, ->(states, ignored_reviewer = nil) do
+    reviewers = Arel::Table.new("#{to_ability_name}_reviewers")
+
+    scope = reviewers_subquery.where(reviewers[:state].in(states))
+    scope = scope.where(reviewers[:user_id].not_eq(ignored_reviewer.id)) if ignored_reviewer
+
+    where(scope.exists)
   end
 
-  scope :no_review_states, ->(states) do
-    where(
-      reviewers_subquery.exists
-    )
-    .where(
-      reviewers_subquery
-        .where(Arel::Table.new("#{to_ability_name}_reviewers")[:state].in(states))
-        .exists
-        .not
-    )
+  scope :not_only_reviewer, ->(user) do
+    reviewers = Arel::Table.new("#{to_ability_name}_reviewers")
+
+    subquery = reviewers
+      .project(Arel.sql('1'))
+      .where(reviewers[:merge_request_id].eq(Arel.sql('merge_requests.id')))
+      .group(reviewers[:merge_request_id])
+      .having(reviewers[:id].count.eq(1))
+      .having(reviewers[:user_id].maximum.eq(user.id))
+
+    review_requested.where.not(subquery.exists)
+  end
+
+  scope :no_review_states, ->(states, ignored_reviewer = nil) do
+    reviewers = Arel::Table.new("#{to_ability_name}_reviewers")
+
+    scope = reviewers_subquery
+    scope = scope.where(reviewers[:user_id].not_eq(ignored_reviewer.id)) if ignored_reviewer
+
+    forbidden = scope.clone.where(reviewers[:state].in(states))
+
+    where(scope.exists).where(forbidden.exists.not)
   end
 
   scope :assignee_or_reviewer, ->(user, assigned_review_states, reviewer_state) do
@@ -510,11 +590,23 @@ class MergeRequest < ApplicationRecord
     )
   end
 
+  scope :author_or_assignee, ->(user, review_states = nil) do
+    authored = where(author_id: user)
+    authored = authored.review_states(review_states) if review_states
+
+    assigned = joins(:merge_request_assignees).where(merge_request_assignees: { user_id: user })
+    assigned = assigned.review_states(review_states) if review_states
+
+    from("(#{from_union([authored, assigned], remove_duplicates: true).to_sql}) merge_requests")
+  end
+
   scope :without_hidden, -> {
-    if Feature.enabled?(:hide_merge_requests_from_banned_users)
-      where_not_exists(Users::BannedUser.where('merge_requests.author_id = banned_users.user_id'))
+    if Feature.enabled?(:optimize_merge_requests_banned_users_query, :instance)
+      # We add `+ 0` to the author_id to make the query planner use a nested loop and prevent
+      # loading of all banned user IDs for certain queries
+      where_not_exists(Users::BannedUser.where('banned_users.user_id = (merge_requests.author_id + 0)'))
     else
-      all
+      where_not_exists(Users::BannedUser.where('merge_requests.author_id = banned_users.user_id'))
     end
   }
 
@@ -539,7 +631,8 @@ class MergeRequest < ApplicationRecord
       .pick(MergeRequest::Metrics.time_to_merge_expression)
   end
 
-  alias_attribute :project, :target_project
+  alias_method :project, :target_project
+  alias_method :project=, :target_project=
   alias_attribute :project_id, :target_project_id
 
   # Currently, `merge_when_pipeline_succeeds` column is used as a flag
@@ -606,6 +699,10 @@ class MergeRequest < ApplicationRecord
       .pluck(:source_branch)
   end
 
+  def self.distinct_source_branches
+    distinct.pluck(:source_branch)
+  end
+
   def self.sort_by_attribute(method, excluded_labels: [])
     case method.to_s
     when 'merged_at', 'merged_at_asc' then order_merged_at_asc
@@ -642,7 +739,7 @@ class MergeRequest < ApplicationRecord
 
   def merge_pipeline
     if sha = merged_commit_sha
-      target_project.latest_pipeline(target_branch, sha)
+      target_project.latest_pipeline(target_branch, sha, :push)
     end
   end
 
@@ -897,11 +994,11 @@ class MergeRequest < ApplicationRecord
     if block_given?
       source_project.repository.diffs_by_changed_paths(diff.diff_refs, offset, &)
     else
-      diff.diffs(diff_options)
+      diff.diffs_for_streaming(diff_options)
     end
   end
 
-  def latest_diffs
+  def latest_diffs(diff_options = {})
     diff = diffable_merge_ref? ? merge_head_diff : merge_request_diff
 
     diff.diffs(diff_options)
@@ -919,7 +1016,7 @@ class MergeRequest < ApplicationRecord
   end
 
   def non_latest_diffs
-    merge_request_diffs.where.not(id: merge_request_diff.id)
+    merge_request_diffs.id_not_in(merge_request_diff.id)
   end
 
   def note_positions_for_paths(paths, user = nil)
@@ -1213,12 +1310,19 @@ class MergeRequest < ApplicationRecord
     merge_request_diff.persisted? || create_merge_request_diff
   end
 
-  def create_merge_request_diff
+  def create_merge_request_diff(preload_gitaly: false)
     fetch_ref!
 
     # n+1: https://gitlab.com/gitlab-org/gitlab/-/issues/19377
     Gitlab::GitalyClient.allow_n_plus_1_calls do
-      merge_request_diffs.create!
+      if preload_gitaly
+        new_diff = merge_request_diffs.build
+        new_diff.preload_gitaly_data
+        new_diff.save!
+      else
+        merge_request_diffs.create!
+      end
+
       reload_merge_request_diff
     end
   end
@@ -1264,6 +1368,7 @@ class MergeRequest < ApplicationRecord
 
     clear_memoization(:source_branch_head)
     clear_memoization(:target_branch_head)
+    clear_memoization(:diff_stats)
   end
 
   def reload_diff_if_branch_changed
@@ -1330,7 +1435,7 @@ class MergeRequest < ApplicationRecord
     merge_when_checks_pass_strat = options[:auto_merge_strategy] == ::AutoMergeService::STRATEGY_MERGE_WHEN_CHECKS_PASS || options[:auto_merge_strategy] == ::AutoMergeService::STRATEGY_ADD_TO_MERGE_TRAIN_WHEN_CHECKS_PASS
 
     {
-      skip_ci_check: options.fetch(:auto_merge_requested, false),
+      skip_ci_check: merge_when_checks_pass_strat,
       skip_approved_check: merge_when_checks_pass_strat,
       skip_draft_check: merge_when_checks_pass_strat,
       skip_blocked_check: merge_when_checks_pass_strat,
@@ -1341,7 +1446,8 @@ class MergeRequest < ApplicationRecord
       skip_jira_check: merge_when_checks_pass_strat,
       skip_locked_lfs_files_check: merge_when_checks_pass_strat,
       skip_security_policy_check: merge_when_checks_pass_strat,
-      skip_merge_time_check: merge_when_checks_pass_strat
+      skip_merge_time_check: merge_when_checks_pass_strat,
+      skip_merge_request_title_check: merge_when_checks_pass_strat
     }
   end
 
@@ -1373,6 +1479,7 @@ class MergeRequest < ApplicationRecord
       ::MergeRequests::Mergeability::CheckDraftStatusService,
       ::MergeRequests::Mergeability::CheckCommitsStatusService,
       ::MergeRequests::Mergeability::CheckDiscussionsStatusService,
+      ::MergeRequests::Mergeability::CheckMergeRequestTitleRegexService,
       ::MergeRequests::Mergeability::CheckCiStatusService,
       ::MergeRequests::Mergeability::CheckLfsFileLocksService
     ]
@@ -1568,7 +1675,7 @@ class MergeRequest < ApplicationRecord
   end
 
   def visible_closing_issues_for(current_user = self.author)
-    strong_memoize(:visible_closing_issues_for) do
+    strong_memoize_with(:visible_closing_issues_for, current_user&.id) do
       visible_issues = if self.target_project.has_external_issue_tracker?
                          closes_issues(current_user)
                        else
@@ -1581,7 +1688,7 @@ class MergeRequest < ApplicationRecord
         records: visible_issues.select { |issue| issue.is_a?(Issue) },
         associations: :project
       ).call
-      # Exclude isues that have been cached but their project setting has been disabled, or they belong to a group
+      # Exclude issues that have been cached but their project setting has been disabled, or they belong to a group
       visible_issues.select do |issue|
         !issue.is_a?(Issue) || issue.autoclose_by_merged_closing_merge_request?
       end
@@ -1592,7 +1699,7 @@ class MergeRequest < ApplicationRecord
   def closes_issues(current_user = self.author)
     if target_branch == project.default_branch
       messages = [title, description]
-      messages.concat(commits(load_from_gitaly: Feature.enabled?(:more_commits_from_gitaly, target_project)).map(&:safe_message)) if merge_request_diff.persisted?
+      messages.concat(commits(load_from_gitaly: true).map(&:safe_message)) if merge_request_diff.persisted?
 
       Gitlab::ClosingIssueExtractor.new(project, current_user)
         .closed_by_message(messages.join("\n"))
@@ -1614,7 +1721,7 @@ class MergeRequest < ApplicationRecord
     visible_notes = user.can?(:read_internal_note, project) ? notes : notes.not_internal
 
     messages = [title, description, *visible_notes.pluck(:note)]
-    messages += commits.map(&:safe_message) if merge_request_diff.persisted?
+    messages += commits(load_from_gitaly: true).map(&:safe_message) if merge_request_diff.persisted?
 
     ext = Gitlab::ReferenceExtractor.new(project, user)
     ext.analyze(messages.join("\n"))
@@ -1699,7 +1806,15 @@ class MergeRequest < ApplicationRecord
   # Returns the oldest multi-line commit
   def first_multiline_commit
     strong_memoize(:first_multiline_commit) do
-      recent_commits(load_from_gitaly: Feature.enabled?(:more_commits_from_gitaly, target_project)).without_merge_commits.reverse_each.find(&:description?)
+      recent_commits(load_from_gitaly: true).without_merge_commits.reverse_each.find(&:description?)
+    end
+  end
+
+  # Returns the description (without the first line/title) of the first multiline commit
+  def first_multiline_commit_description
+    strong_memoize(:first_multiline_commit_description) do
+      commit = first_multiline_commit
+      commit&.description
     end
   end
 
@@ -1784,6 +1899,10 @@ class MergeRequest < ApplicationRecord
     "refs/#{Repository::REF_MERGE_REQUEST}/#{iid}/train"
   end
 
+  def rebase_on_merge_path
+    "refs/#{Repository::REF_MERGE_REQUEST}/#{iid}/rebase_on_merge"
+  end
+
   def schedule_cleanup_refs(only: :all)
     if Feature.enabled?(:merge_request_delete_gitaly_refs_in_batches, target_project)
       async_cleanup_refs(only: only)
@@ -1799,6 +1918,7 @@ class MergeRequest < ApplicationRecord
     target_refs << ref_path       if %i[all head].include?(only)
     target_refs << merge_ref_path if %i[all merge].include?(only)
     target_refs << train_ref_path if %i[all train].include?(only)
+    target_refs << rebase_on_merge_path if %i[all rebase_on_merge_path].include?(only)
     target_refs
   end
 
@@ -1889,7 +2009,11 @@ class MergeRequest < ApplicationRecord
   end
 
   def has_test_reports?
-    diff_head_pipeline&.complete_and_has_reports?(Ci::JobArtifact.of_report_type(:test))
+    if Feature.enabled?(:show_child_reports_in_mr_page, project)
+      !!diff_head_pipeline&.has_test_reports?
+    else
+      diff_head_pipeline&.has_reports?(Ci::JobArtifact.of_report_type(:test))
+    end
   end
 
   # rubocop: disable Metrics/AbcSize -- Despite being long, this method is quite straightforward. Splitting it in smaller chunks would likely reduce readability.
@@ -1935,7 +2059,11 @@ class MergeRequest < ApplicationRecord
   end
 
   def has_terraform_reports?
-    diff_head_pipeline&.has_reports?(Ci::JobArtifact.of_report_type(:terraform))
+    if Feature.enabled?(:show_child_reports_in_mr_page, project)
+      !!diff_head_pipeline&.complete_and_has_self_or_descendant_reports?(Ci::JobArtifact.of_report_type(:terraform))
+    else
+      diff_head_pipeline&.has_reports?(Ci::JobArtifact.of_report_type(:terraform))
+    end
   end
 
   def compare_accessibility_reports
@@ -2025,11 +2153,21 @@ class MergeRequest < ApplicationRecord
   end
 
   def has_sast_reports?
-    !!diff_head_pipeline&.complete_or_manual_and_has_reports?(::Ci::JobArtifact.of_report_type(:sast))
+    if Feature.enabled?(:show_child_security_reports_in_mr_widget, project)
+      !!diff_head_pipeline&.complete_or_manual? &&
+        pipeline_has_report_in_self_or_descendants?(:sast)
+    else
+      !!diff_head_pipeline&.complete_or_manual_and_has_reports?(::Ci::JobArtifact.of_report_type(:sast))
+    end
   end
 
   def has_secret_detection_reports?
-    !!diff_head_pipeline&.complete_or_manual_and_has_reports?(::Ci::JobArtifact.of_report_type(:secret_detection))
+    if Feature.enabled?(:show_child_security_reports_in_mr_widget, project)
+      !!diff_head_pipeline&.complete_or_manual? &&
+        pipeline_has_report_in_self_or_descendants?(:secret_detection)
+    else
+      !!diff_head_pipeline&.complete_or_manual_and_has_reports?(::Ci::JobArtifact.of_report_type(:secret_detection))
+    end
   end
 
   def compare_sast_reports(current_user)
@@ -2073,12 +2211,11 @@ class MergeRequest < ApplicationRecord
   # Note that this could also return SHA from now dangling commits
   #
   def all_commit_shas
-    @all_commit_shas ||= begin
-      return commit_shas unless persisted?
+    return commit_shas unless persisted?
 
-      all_commits.pluck(:sha).uniq
-    end
+    all_commits.pluck(:sha).uniq
   end
+  strong_memoize_attr :all_commit_shas
 
   def merge_commit
     @merge_commit ||= project.commit(merge_commit_sha) if merge_commit_sha
@@ -2220,30 +2357,41 @@ class MergeRequest < ApplicationRecord
     end
   end
 
-  # Overridden in EE
-  def use_merge_base_pipeline_for_comparison?(_)
-    false
-  end
-
   def comparison_base_pipeline(service_class)
-    (use_merge_base_pipeline_for_comparison?(service_class) && merge_base_pipeline) || base_pipeline
-  end
+    target_shas = [
+      diff_head_pipeline&.target_sha,
+      diff_base_sha,
+      diff_start_sha
+    ]
 
-  def base_pipeline
-    @base_pipeline ||= base_pipelines.last
+    target_shas
+      .compact
+      .lazy
+      .filter_map { |sha| target_branch_pipelines_for(sha: sha).last }
+      .first
   end
 
   def merge_base_pipeline
-    @merge_base_pipeline ||= merge_base_pipelines.last
+    target_sha = diff_head_pipeline&.target_sha
+
+    return unless target_sha
+
+    target_branch_pipelines_for(sha: target_sha).last
   end
+  strong_memoize_attr :merge_base_pipeline
+
+  def base_pipeline
+    target_branch_pipelines_for(sha: diff_base_sha).last
+  end
+  strong_memoize_attr :base_pipeline
 
   def discussions_rendered_on_frontend?
     true
   end
 
   # rubocop: disable CodeReuse/ServiceClass
-  def update_project_counter_caches
-    Projects::OpenMergeRequestsCountService.new(target_project).refresh_cache
+  def invalidate_project_counter_caches
+    Projects::OpenMergeRequestsCountService.new(target_project).delete_cache
   end
   # rubocop: enable CodeReuse/ServiceClass
 
@@ -2379,7 +2527,7 @@ class MergeRequest < ApplicationRecord
   end
 
   def hidden?
-    Feature.enabled?(:hide_merge_requests_from_banned_users) && author&.banned?
+    author&.banned?
   end
 
   def diffs_batch_cache_with_max_age?
@@ -2390,10 +2538,6 @@ class MergeRequest < ApplicationRecord
     prepared_at.present?
   end
 
-  def prepare
-    NewMergeRequestWorker.perform_async(id, author_id)
-  end
-
   def check_for_spam?(*)
     spammable_attribute_changed? && project.public?
   end
@@ -2466,10 +2610,9 @@ class MergeRequest < ApplicationRecord
     Gitlab::MergeRequests::LockedSet.remove(self.id)
   end
 
-  def first_diffs_slice(limit)
+  def first_diffs_slice(limit, diff_options = {})
     diff = diffable_merge_ref? ? merge_head_diff : merge_request_diff
-
-    diff.paginated_diffs(1, limit).diff_files
+    diff.paginated_diffs(1, limit, diff_options).diff_files(sorted: true)
   end
 
   def squash_option
@@ -2484,18 +2627,19 @@ class MergeRequest < ApplicationRecord
     merge_request_diffs.count >= DIFF_VERSION_LIMIT
   end
 
+  def reached_diff_commits_limit?
+    return false if Feature.disabled?(:merge_requests_diff_commits_limit, target_project)
+
+    total_commits_count = MergeRequestDiff
+      .from(merge_request_diffs.limit(1000), :limited_diffs)
+      .pick('SUM(commits_count)')
+      .to_i
+
+    total_commits_count >= DIFF_COMMITS_LIMIT
+  end
+
   private
 
-  def merge_base_pipelines
-    return ::Ci::Pipeline.none unless diff_head_pipeline&.target_sha
-
-    target_branch_pipelines_for(sha: diff_head_pipeline.target_sha)
-  end
-
-  def base_pipelines
-    target_branch_pipelines_for(sha: diff_base_sha)
-  end
-
   def target_branch_pipelines_for(sha:)
     project.ci_pipelines
            .where(sha: sha, ref: target_branch)
@@ -2553,8 +2697,12 @@ class MergeRequest < ApplicationRecord
   end
 
   def report_type_enabled?(report_type)
+    supported_report_types_for_child_pipelines = [:sast, :secret_detection, :container_scanning]
+
     if report_type == :license_scanning
       ::Gitlab::LicenseScanning.scanner_for_pipeline(project, diff_head_pipeline).has_data?
+    elsif supported_report_types_for_child_pipelines.include?(report_type) && Feature.enabled?(:show_child_security_reports_in_mr_widget, project)
+      pipeline_has_report_in_self_or_descendants?(report_type)
     else
       !!diff_head_pipeline&.batch_lookup_report_artifact_for_file_type(report_type)
     end
@@ -2567,6 +2715,12 @@ class MergeRequest < ApplicationRecord
       [description, 'false']
     end
   end
+
+  def pipeline_has_report_in_self_or_descendants?(report_type)
+    !!diff_head_pipeline
+      &.latest_report_builds_in_self_and_project_descendants(::Ci::JobArtifact.of_report_type(report_type))
+      &.exists?
+  end
 end
 
 MergeRequest.prepend_mod_with('MergeRequest')
