@@ -15,6 +15,7 @@ module Ci
           params.merge!({
             runner_type: 'group_type',
             sharding_key_id: scope&.id,
+            organization_id: scope&.organization_id,
             groups: [scope]
           })
         end
@@ -24,7 +25,7 @@ module Ci
         end
 
         def authorized_user?
-          user.present? && user.can?(:create_runner, scope)
+          user.present? && user.can?(:create_runners, scope)
         end
 
         private
