@@ -40,6 +40,13 @@ InitializerConnections.raise_if_new_database_connection do
       controllers discovery: 'jwks'
     end
 
+    # MCP OAuth Discovery Support - Add path insertion endpoints
+    # MCP-Remote contrustcts well-known path for auth-related metadata discovery
+    # https://modelcontextprotocol.io/specification/draft/basic/authorization#server-metadata-discovery
+    # https://github.com/mcp-auth/mcp-typescript-sdk/blob/31acdcbb189056ec83d14a4f7a37ae2b1c67680e/src/client/auth.ts#L697-L702
+    get '/.well-known/oauth-authorization-server/api/v4/mcp', to: 'jwks#provider'
+    get '/.well-known/openid-configuration/api/v4/mcp', to: 'jwks#provider'
+
     use_doorkeeper_device_authorization_grant do
       controller device_authorizations: 'oauth/device_authorizations'
     end
@@ -50,6 +57,8 @@ InitializerConnections.raise_if_new_database_connection do
     match '/.well-known/openid-configuration' => 'jwks#provider', via: :options
     match '/.well-known/oauth-protected-resource' => 'oauth_protected_resource_metadata#show', via: :options
     match '/.well-known/webfinger' => 'jwks#webfinger', via: :options
+    match '/.well-known/oauth-authorization-server/api/v4/mcp', to: 'jwks#provider', via: :options
+    match '/.well-known/openid-configuration/api/v4/mcp', to: 'jwks#provider', via: :options
 
     match '/oauth/token' => 'oauth/tokens#create', via: :options
     match '/oauth/revoke' => 'oauth/tokens#revoke', via: :options
