@@ -4,12 +4,15 @@ module API
   class Groups < ::API::Base
     include PaginationParams
     include Helpers::CustomAttributes
+    include APIGuard
 
     before do
       authenticate_non_get!
       set_current_organization
     end
 
+    allow_access_with_scope :ai_workflows, if: ->(request) { request.get? || request.head? }
+
     helpers Helpers::GroupsHelpers
 
     feature_category :groups_and_projects, ['/groups/:id/custom_attributes', '/groups/:id/custom_attributes/:key']
@@ -21,6 +24,7 @@ module API
 
       params :group_list_params do
         use :statistics_params
+        optional :archived, type: Boolean, desc: 'Limit by archived status'
         optional :skip_groups, type: Array[Integer], coerce_with: ::API::Validations::Types::CommaSeparatedToIntegerArray.coerce, desc: 'Array of group ids to exclude from list'
         optional :all_available, type: Boolean, desc: 'When `true`, returns all accessible groups. When `false`, returns only groups where the user is a member.'
         optional :visibility, type: String, values: Gitlab::VisibilityLevel.string_values,
@@ -31,11 +35,12 @@ module API
         optional :sort, type: String, values: %w[asc desc], default: 'asc', desc: 'Sort by asc (ascending) or desc (descending)'
         optional :min_access_level, type: Integer, values: Gitlab::Access.all_values, desc: 'Minimum access level of authenticated user'
         optional :top_level_only, type: Boolean, desc: 'Only include top-level groups'
+        optional :marked_for_deletion_on, type: Date, desc: 'Return groups that are marked for deletion on this date'
+        optional :active, type: Boolean, desc: 'Limit by groups that are not archived and not marked for deletion'
         use :optional_group_list_params_ee
         use :pagination
       end
 
-      # rubocop: disable CodeReuse/ActiveRecord
       def find_groups(params, parent_id = nil)
         find_params = params.slice(*allowable_find_params)
 
@@ -49,17 +54,17 @@ module API
           find_params.fetch(:all_available, current_user&.can_read_all_resources?)
 
         groups = GroupsFinder.new(current_user, find_params).execute
-        groups = groups.where.not(id: params[:skip_groups]) if params[:skip_groups].present?
+        groups = groups.id_not_in(params[:skip_groups]) if params[:skip_groups].present?
 
         order_groups(groups).with_api_scopes
       end
-      # rubocop: enable CodeReuse/ActiveRecord
 
       def allowable_find_params
         [:all_available,
           :custom_attributes,
           :owned, :min_access_level,
-          :include_parent_descendants, :search, :visibility]
+          :include_parent_descendants, :search, :visibility, :archived,
+          :active, :marked_for_deletion_on]
       end
 
       # This is a separate method so that EE can extend its behaviour, without
@@ -74,7 +79,7 @@ module API
       def authorized_params?(group, params)
         return true if can?(current_user, :admin_group, group)
 
-        can?(current_user, :admin_runner, group) &&
+        can?(current_user, :admin_runners, group) &&
           params.keys == [:shared_runners_setting]
       end
 
@@ -167,12 +172,42 @@ module API
         present paginate_with_strategies(groups), options
       end
 
+      def immediately_delete_subgroup_error(group)
+        if !group.subgroup?
+          '`permanently_remove` option is only available for subgroups.'
+        elsif !group.self_deletion_scheduled?
+          'Group must be marked for deletion first.'
+        elsif group.full_path != params[:full_path]
+          '`full_path` is incorrect. You must enter the complete path for the subgroup.'
+        end
+      end
+
       def delete_group(group)
-        destroy_conditionally!(group) do |group|
-          ::Groups::DestroyService.new(group, current_user).async_execute
+        permanently_remove = ::Gitlab::Utils.to_boolean(params[:permanently_remove])
+
+        if permanently_remove
+          error = immediately_delete_subgroup_error(group)
+
+          render_api_error!(error, 400) if error
         end
 
-        accepted!
+        if permanently_remove
+          destroy_conditionally!(group) do
+            ::Groups::DestroyService.new(group, current_user).async_execute
+          end
+
+          return accepted!
+        end
+
+        result = destroy_conditionally!(group) do |group|
+          ::Groups::MarkForDeletionService.new(group, current_user).execute
+        end
+
+        if result[:status] == :success
+          accepted!
+        else
+          render_api_error!(result[:message], 400)
+        end
       end
 
       def reorder_projects_with_order_support(projects, group, order_by)
@@ -242,9 +277,7 @@ module API
         use :with_custom_attributes
       end
       get feature_category: :groups_and_projects do
-        if Feature.enabled?(:rate_limit_groups_and_projects_api, current_user)
-          check_rate_limit_by_user_or_ip!(:groups_api)
-        end
+        check_rate_limit_by_user_or_ip!(:groups_api)
 
         groups = find_groups(declared_params(include_missing: false), params[:id])
         present_groups_with_pagination_strategies params, groups
@@ -258,7 +291,7 @@ module API
         requires :name, type: String, desc: 'The name of the group'
         requires :path, type: String, desc: 'The path of the group'
         optional :parent_id, type: Integer, desc: 'The parent group id for creating nested group'
-        optional :organization_id, type: Integer, default: -> { Current.organization_id },
+        optional :organization_id, type: Integer, default: -> { Current.organization.id },
           desc: 'The organization id for the group'
 
         use :optional_params
@@ -307,7 +340,7 @@ module API
         group.preload_shared_group_links
 
         mark_throttle! :update_namespace_name, scope: group if params.key?(:name) && params[:name].present?
-        authorize_any! [:admin_group, :admin_runner], group
+        authorize_any! [:admin_group, :admin_runners], group
 
         group.remove_avatar! if params.key?(:avatar) && params[:avatar].nil?
 
@@ -318,6 +351,52 @@ module API
         end
       end
 
+      desc 'Archive a group' do
+        success code: 200, model: Entities::Group
+        failure [
+          { code: 403, message: 'Unauthenticated' }
+        ]
+        tags %w[groups]
+      end
+      post ':id/archive', feature_category: :groups_and_projects do
+        check_rate_limit_by_user_or_ip!(:group_archive_unarchive_api)
+
+        group = find_group!(params[:id])
+        authorize!(:archive_group, group)
+
+        response = ::Namespaces::Groups::ArchiveService.new(group, current_user).execute
+
+        if response.success?
+          status 200
+          present_group_details(params, group, with_projects: params[:with_projects])
+        else
+          render_api_error!(response.message, 422)
+        end
+      end
+
+      desc 'Unarchive a group' do
+        success code: 200, model: Entities::Group
+        failure [
+          { code: 403, message: 'Unauthenticated' }
+        ]
+        tags %w[groups]
+      end
+      post ':id/unarchive', feature_category: :groups_and_projects do
+        check_rate_limit_by_user_or_ip!(:group_archive_unarchive_api)
+
+        group = find_group!(params[:id])
+        authorize!(:archive_group, group)
+
+        response = ::Namespaces::Groups::UnarchiveService.new(group, current_user).execute
+
+        if response.success?
+          status 200
+          present_group_details(params, group, with_projects: params[:with_projects])
+        else
+          render_api_error!(response.message, 422)
+        end
+      end
+
       desc 'Get a single group, with containing projects.' do
         success Entities::GroupDetail
         tags %w[groups]
@@ -328,9 +407,7 @@ module API
       end
       # TODO: Set higher urgency after resolving https://gitlab.com/gitlab-org/gitlab/-/issues/357841
       get ":id", feature_category: :groups_and_projects, urgency: :low do
-        if Feature.enabled?(:rate_limit_groups_and_projects_api, current_user)
-          check_rate_limit_by_user_or_ip!(:group_api)
-        end
+        check_rate_limit_by_user_or_ip!(:group_api)
 
         group = find_group!(params[:id])
         group.preload_shared_group_links
@@ -349,6 +426,20 @@ module API
         delete_group(group)
       end
 
+      desc 'Restore a group.'
+      post ':id/restore', feature_category: :groups_and_projects do
+        authorize! :remove_group, user_group
+
+        result = ::Groups::RestoreService.new(user_group, current_user).execute
+        user_group.preload_shared_group_links
+
+        if result[:status] == :success
+          present user_group, with: ::API::Entities::GroupDetail, current_user: current_user
+        else
+          render_api_error!(result[:message], 400)
+        end
+      end
+
       desc 'Get a list of shared groups this group was invited to' do
         success Entities::Group
         is_array true
@@ -366,9 +457,7 @@ module API
         use :with_custom_attributes
       end
       get ":id/groups/shared", feature_category: :groups_and_projects do
-        if Feature.enabled?(:rate_limit_groups_and_projects_api, current_user)
-          check_rate_limit_by_user_or_ip!(:group_shared_groups_api)
-        end
+        check_rate_limit_by_user_or_ip!(:group_shared_groups_api)
 
         group = find_group!(params[:id])
         groups = ::Namespaces::Groups::SharedGroupsFinder.new(group, current_user, declared(params)).execute
@@ -428,9 +517,7 @@ module API
       end
       # TODO: Set higher urgency after resolving https://gitlab.com/gitlab-org/gitlab/-/issues/211498
       get ":id/projects", feature_category: :groups_and_projects, urgency: :low do
-        if Feature.enabled?(:rate_limit_groups_and_projects_api, current_user)
-          check_rate_limit_by_user_or_ip!(:group_projects_api)
-        end
+        check_rate_limit_by_user_or_ip!(:group_projects_api)
 
         finder_options = {
           exclude_shared: !params[:with_shared],
