@@ -268,7 +268,7 @@ module API
     def find_namespace(id)
       if INTEGER_ID_REGEX.match?(id.to_s)
         # We need to stick to an up-to-date replica or primary db here in order to properly observe the namespace
-        # recently created by GitlabSubscriptions::Trials::CreateService#create_group_flow.
+        # recently created by GitlabSubscriptions::Trials::UltimateCreateService.
         # See https://gitlab.com/gitlab-org/customers-gitlab-com/-/issues/9808
         ::Namespace.sticking.find_caught_up_replica(:namespace, id)
 
@@ -376,7 +376,8 @@ module API
     end
 
     def authorize_read_application_statistics!
-      authenticated_as_admin!
+      authenticate!
+      forbidden! unless current_user.can?(:read_application_statistics)
     end
 
     def authorize!(action, subject = :global, reason = nil)
@@ -498,11 +499,9 @@ module API
       permitted_attrs.to_h
     end
 
-    # rubocop: disable CodeReuse/ActiveRecord
     def filter_by_iid(items, iid)
-      items.where(iid: iid)
+      items.iid_in(iid)
     end
-    # rubocop: enable CodeReuse/ActiveRecord
 
     # rubocop: disable CodeReuse/ActiveRecord
     def filter_by_title(items, title)
@@ -568,8 +567,8 @@ module API
       render_api_error!(message || '405 Method Not Allowed', :method_not_allowed)
     end
 
-    def not_acceptable!
-      render_api_error!('406 Not Acceptable', 406)
+    def not_acceptable!(message = nil)
+      render_api_error!(message || '406 Not Acceptable', 406)
     end
 
     def service_unavailable!(message = nil)
@@ -584,8 +583,8 @@ module API
       render_api_error!(message || '422 Unprocessable Entity', :unprocessable_entity)
     end
 
-    def file_too_large!
-      render_api_error!('413 Request Entity Too Large', 413)
+    def file_too_large!(message = nil)
+      render_api_error!(message || '413 Request Entity Too Large', 413)
     end
 
     def too_many_requests!(message = nil, retry_after: 1.minute)
@@ -594,20 +593,20 @@ module API
       render_api_error!(message || '429 Too Many Requests', 429)
     end
 
-    def not_modified!
-      render_api_error!('304 Not Modified', 304)
+    def not_modified!(message = nil)
+      render_api_error!(message || '304 Not Modified', 304)
     end
 
-    def no_content!
-      render_api_error!('204 No Content', 204)
+    def no_content!(message = nil)
+      render_api_error!(message || '204 No Content', 204)
     end
 
-    def created!
-      render_api_error!('201 Created', 201)
+    def created!(message = nil)
+      render_api_error!(message || '201 Created', 201)
     end
 
-    def accepted!(message = '202 Accepted')
-      render_api_error!(message, 202)
+    def accepted!(message = nil)
+      render_api_error!(message || '202 Accepted', 202)
     end
 
     def render_validation_error!(models, status = 400)
@@ -727,7 +726,8 @@ module API
     # @content_disposition controls the Content-Disposition response header. nil by default. Forced to attachment for object storage disabled mode.
     # @content_type controls the Content-Type response header. By default, it will rely on the 'application/octet-stream' value or the content type detected by carrierwave.
     # @extra_response_headers. Set additional response headers. Not used in the direct download supported case.
-    def present_carrierwave_file!(file, supports_direct_download: true, content_disposition: nil, content_type: nil, extra_response_headers: {})
+    # @extra_send_url_params. Additional parameters to send to workhorse send_url call. See Gitlab::Workhorse.send_url for more information
+    def present_carrierwave_file!(file, supports_direct_download: true, content_disposition: nil, content_type: nil, extra_response_headers: {}, extra_send_url_params: {})
       return not_found! unless file&.exists?
 
       if content_disposition
@@ -749,7 +749,7 @@ module API
       else
         response_headers = extra_response_headers.merge('Content-Type' => content_type, 'Content-Disposition' => response_disposition).compact_blank
 
-        header(*Gitlab::Workhorse.send_url(file.url, response_headers: response_headers))
+        header(*Gitlab::Workhorse.send_url(file.url, response_headers: response_headers, **extra_send_url_params))
         status :ok
         body '' # to avoid an error from API::APIGuard::ResponseCoercerMiddleware
       end
@@ -809,6 +809,7 @@ module API
       finder_params[:non_public] = true if params[:membership].present?
       finder_params[:starred] = true if params[:starred].present?
       finder_params[:archived] = archived_param unless params[:archived].nil?
+      finder_params[:active] = params[:active] unless params[:active].nil?
       finder_params
     end
 
@@ -834,9 +835,11 @@ module API
       finder_params[:user] = params.delete(:user) if params[:user]
       finder_params[:id_after] = sanitize_id_param(params[:id_after]) if params[:id_after]
       finder_params[:id_before] = sanitize_id_param(params[:id_before]) if params[:id_before]
-      finder_params[:updated_after] = declared_params[:updated_after] if declared_params[:updated_after]
-      finder_params[:updated_before] = declared_params[:updated_before] if declared_params[:updated_before]
-      finder_params[:include_pending_delete] = declared_params[:include_pending_delete] if declared_params[:include_pending_delete]
+
+      %i[updated_after updated_before include_pending_delete marked_for_deletion_on].each do |param|
+        finder_params[param] = declared_params[param] if declared_params[param]
+      end
+
       finder_params
     end
 
@@ -1024,7 +1027,7 @@ module API
     end
 
     def handle_job_token_failure!(project)
-      if current_user&.from_ci_job_token? && current_user&.ci_job_token_scope
+      if current_user&.from_ci_job_token? && current_user.ci_job_token_scope
         source_project = current_user.ci_job_token_scope.current_project
         error_message = format("Authentication by CI/CD job token not allowed from %{source_project_path} to %{target_project_path}.", source_project_path: source_project.path, target_project_path: project.path)
 
