@@ -16,12 +16,14 @@ module Gitlab
     READ_USER_SCOPE = :read_user
     CREATE_RUNNER_SCOPE = :create_runner
     MANAGE_RUNNER_SCOPE = :manage_runner
+    MCP_SCOPE = :mcp
     API_SCOPES = [
       API_SCOPE, READ_API_SCOPE,
       READ_USER_SCOPE,
       CREATE_RUNNER_SCOPE, MANAGE_RUNNER_SCOPE,
       K8S_PROXY_SCOPE,
-      SELF_ROTATE_SCOPE
+      SELF_ROTATE_SCOPE,
+      MCP_SCOPE
     ].freeze
 
     # Scopes for Duo
@@ -76,8 +78,35 @@ module Gitlab
     # Default scopes for OAuth applications that don't define their own
     DEFAULT_SCOPES = [API_SCOPE].freeze
 
+    # Scopes ordered by permission level, from lowest to highest.
+    # This is used to determine the order of scopes in the UI.
+    # If the scope is not present in this list, it won't appear in the UI.
+    UI_SCOPES_ORDERED_BY_PERMISSION = [
+      READ_SERVICE_PING_SCOPE,
+      READ_USER_SCOPE,
+      READ_REPOSITORY_SCOPE,
+      READ_OBSERVABILITY_SCOPE,
+      READ_VIRTUAL_REGISTRY_SCOPE,
+      READ_REGISTRY_SCOPE,
+      READ_API_SCOPE,
+      SELF_ROTATE_SCOPE,
+      WRITE_REPOSITORY_SCOPE,
+      WRITE_OBSERVABILITY_SCOPE,
+      WRITE_VIRTUAL_REGISTRY_SCOPE,
+      WRITE_REGISTRY_SCOPE,
+      API_SCOPE,
+      AI_FEATURES,
+      CREATE_RUNNER_SCOPE,
+      MANAGE_RUNNER_SCOPE,
+      K8S_PROXY_SCOPE,
+      ADMIN_MODE_SCOPE,
+      SUDO_SCOPE
+    ].freeze
+
     CI_JOB_USER = 'gitlab-ci-token'
 
+    extend Gitlab::InternalEventsTracking
+
     class << self
       prepend_mod_with('Gitlab::Auth') # rubocop: disable Cop/InjectEnterpriseEditionModule
 
@@ -227,9 +256,22 @@ module Gitlab
       end
 
       def user_with_password_for_git(login, password)
+        # Prevent LDAP and database authentication attempts when password is a token
+        return if password.present? && Authn::AgnosticTokenIdentifier.token?(password)
+
         user = find_with_user_password(login, password)
         return unless user
 
+        if user.ldap_user? &&
+            Gitlab::CurrentSettings.password_authentication_enabled_for_git? &&
+            Gitlab::Auth::Ldap::Config.prevent_ldap_sign_in?
+          track_internal_event(
+            'authenticate_to_ldap_with_git_over_https_when_prevent_ldap_sign_in_is_enabled',
+            user: user,
+            category: name
+          )
+        end
+
         verifier = TwoFactorAuthVerifier.new(user)
 
         if user.two_factor_enabled? || verifier.two_factor_authentication_enforced?
@@ -247,7 +289,8 @@ module Gitlab
             identity = ::Gitlab::Auth::Identity.link_from_oauth_token(token)
             return if identity && !identity.valid?
 
-            user = User.id_in(token.resource_owner_id).first
+            resource_owner_id = identity&.composite? ? identity.scoped_user.id : token.resource_owner_id
+            user = User.id_in(resource_owner_id).first
             return unless user && user.can_log_in_with_non_expired_password?
 
             Gitlab::Auth::Result.new(user, nil, :oauth, abilities_for_scopes(token.scopes))
@@ -304,9 +347,10 @@ module Gitlab
           write_virtual_registry: %i[write_dependency_proxy],
           read_repository: %i[download_code],
           write_repository: %i[download_code push_code],
-          create_runner: %i[create_instance_runner create_runner],
+          create_runner: %i[create_instance_runners create_runners],
           manage_runner: %i[assign_runner update_runner delete_runner],
-          ai_workflows: %i[push_code download_code]
+          ai_workflows: %i[push_code download_code],
+          mcp: %i[execute_mcp_tool] # This ability doesn't exist yet
         }
 
         scopes.flat_map do |scope|
@@ -376,8 +420,9 @@ module Gitlab
         if build.user
           return unless build.user.can_log_in_with_non_expired_password? || bot_user_can_read_project?(build.user, build.project)
 
+          auth_context = { authentication_method: :ci_job_token, authentication_method_id: build.id }
           # If user is assigned to build, use restricted credentials of user
-          Gitlab::Auth::Result.new(build.user, build.project, :build, build_authentication_abilities)
+          Gitlab::Auth::Result.new(build.user, build.project, :build, build_authentication_abilities, auth_context)
         else
           # Otherwise use generic CI credentials (backward compatibility)
           Gitlab::Auth::Result.new(nil, build.project, :ci, build_authentication_abilities)
@@ -483,7 +528,8 @@ module Gitlab
 
       def unavailable_scopes_for_resource(resource)
         unavailable_ai_features_scopes +
-          unavailable_observability_scopes_for_resource(resource)
+          unavailable_observability_scopes_for_resource(resource) +
+          unavailable_virtual_registry_scopes_for_resource(resource)
       end
 
       def unavailable_ai_features_scopes
@@ -497,6 +543,12 @@ module Gitlab
         OBSERVABILITY_SCOPES
       end
 
+      def unavailable_virtual_registry_scopes_for_resource(resource)
+        return VIRTUAL_REGISTRY_SCOPES if resource.is_a?(Project)
+
+        []
+      end
+
       def non_admin_available_scopes
         API_SCOPES + REPOSITORY_SCOPES + registry_scopes + virtual_registry_scopes + OBSERVABILITY_SCOPES + AI_FEATURES_SCOPES
       end
