@@ -16,6 +16,12 @@ module Gitlab
       end
     end
 
+    class RestrictedLanguageServerClientError < AuthenticationError
+      def initialize(msg)
+        super("Language server client error: #{msg}")
+      end
+    end
+
     class InsufficientScopeError < AuthenticationError
       attr_reader :scopes
 
@@ -36,7 +42,6 @@ module Gitlab
       DEPLOY_TOKEN_HEADER = 'HTTP_DEPLOY_TOKEN'
       RUNNER_TOKEN_PARAM = :token
       RUNNER_JOB_TOKEN_PARAM = :token
-      PATH_DEPENDENT_FEED_TOKEN_REGEX = /\A#{User::FEED_TOKEN_PREFIX}(\h{64})-(\d+)\z/
 
       PARAM_TOKEN_KEYS = [
         PRIVATE_TOKEN_PARAM,
@@ -49,6 +54,8 @@ module Gitlab
         DEPLOY_TOKEN_HEADER
       ].freeze
 
+      attr_accessor :current_token
+
       # Check the Rails session for valid authentication details
       def find_user_from_warden
         current_request.env['warden']&.authenticate if verified_request?
@@ -148,13 +155,13 @@ module Gitlab
         return unless route_authentication_setting[:deploy_token_allowed]
         return unless Gitlab::ExternalAuthorization.allow_deploy_tokens_and_deploy_keys?
 
-        token = current_request.env[DEPLOY_TOKEN_HEADER].presence || parsed_oauth_token
+        self.current_token = current_request.env[DEPLOY_TOKEN_HEADER].presence || parsed_oauth_token
 
         if has_basic_credentials?(current_request)
-          _, token = user_name_and_password(current_request)
+          _, self.current_token = user_name_and_password(current_request)
         end
 
-        deploy_token = DeployToken.active.find_by_token(token.to_s)
+        deploy_token = DeployToken.active.find_by_token(current_token.to_s)
         @current_authenticated_deploy_token = deploy_token # rubocop:disable Gitlab/ModuleWithInstanceVariables
 
         deploy_token
@@ -163,19 +170,11 @@ module Gitlab
       def cluster_agent_token_from_authorization_token
         return unless route_authentication_setting[:cluster_agent_token_allowed]
 
-        # We are migrating from the `Authorization` header to one specific to cluster
-        # agents, `Gitlab-Agentk-Api-Request`. Both must be supported until KAS has
-        # been updated to use the new header, and then this first lookup can be removed.
-        # See https://gitlab.com/gitlab-org/gitlab/-/issues/406582.
-        token, _ = if current_request.authorization.present?
-                     token_and_options(current_request)
-                   else
-                     current_request.headers[Gitlab::Kas::INTERNAL_API_AGENTK_REQUEST_HEADER]
-                   end
+        self.current_token = current_request.headers[Gitlab::Kas::INTERNAL_API_AGENT_REQUEST_HEADER]
 
-        return unless token.present?
+        return unless current_token.present?
 
-        ::Clusters::AgentToken.active.find_by_token(token.to_s)
+        ::Clusters::AgentToken.active.find_by_token(current_token.to_s)
       end
 
       def find_runner_from_token
@@ -228,6 +227,10 @@ module Gitlab
           parsed_oauth_token.present?
       end
 
+      def self.path_dependent_feed_token_regex
+        /\A(#{User::FEED_TOKEN_PREFIX}|#{User.prefix_for_feed_token})(\h{64})-(\d+)\z/
+      end
+
       private
 
       def extract_personal_access_token
@@ -237,11 +240,15 @@ module Gitlab
       end
 
       def save_current_token_in_env
-        ::Current.token_info = {
+        token_info = {
           token_id: access_token.id,
           token_type: access_token.class.to_s,
           token_scopes: access_token.scopes.map(&:to_sym)
         }
+
+        token_info[:token_application_id] = access_token.application_id if access_token.respond_to?(:application_id)
+
+        ::Current.token_info = token_info
       end
 
       def save_auth_failure_in_application_context(access_token, cause, requested_scopes)
@@ -255,10 +262,10 @@ module Gitlab
       def find_user_from_job_bearer_token
         return unless route_authentication_setting[:job_token_allowed]
 
-        token = parsed_oauth_token
-        return unless token
+        self.current_token = parsed_oauth_token
+        return unless current_token
 
-        job = ::Ci::AuthJobFinder.new(token: token).execute
+        job = ::Ci::AuthJobFinder.new(token: current_token).execute
         return unless job
 
         @current_authenticated_job = job # rubocop:disable Gitlab/ModuleWithInstanceVariables
@@ -296,24 +303,24 @@ module Gitlab
       end
 
       def find_personal_access_token
-        token = extract_personal_access_token
-        return unless token
+        self.current_token = extract_personal_access_token
+        return unless current_token
 
         # The runner sends the job token for PUT /api/jobs/:id in the PRIVATE-TOKEN header
         # and the token JSON parameter. Ignore this personal access token so
         # that the job token can be authenticated.
-        return if api_request? && token.start_with?(::Ci::Build::TOKEN_PREFIX)
+        return if api_request? && current_token.start_with?(::Ci::Build::TOKEN_PREFIX)
 
         # Expiration, revocation and scopes are verified in `validate_access_token!`
-        PersonalAccessToken.find_by_token(token.to_s) || raise(UnauthorizedError)
+        PersonalAccessToken.find_by_token(current_token.to_s) || raise(UnauthorizedError)
       end
 
       def find_oauth_access_token
-        token = parsed_oauth_token
-        return unless token
+        self.current_token = parsed_oauth_token
+        return unless current_token
 
         # Expiration, revocation and scopes are verified in `validate_access_token!`
-        oauth_token = OauthAccessToken.by_token(token)
+        oauth_token = OauthAccessToken.by_token(current_token)
         raise UnauthorizedError unless oauth_token
 
         oauth_token.revoke_previous_refresh_token!
@@ -329,8 +336,8 @@ module Gitlab
         return unless route_authentication_setting[:basic_auth_personal_access_token]
         return unless has_basic_credentials?(current_request)
 
-        _username, password = user_name_and_password(current_request)
-        PersonalAccessToken.find_by_token(password.to_s)
+        _username, self.current_token = user_name_and_password(current_request)
+        PersonalAccessToken.find_by_token(current_token.to_s)
       end
 
       def find_feed_token_user(token)
@@ -339,13 +346,13 @@ module Gitlab
       end
 
       def find_user_from_path_feed_token(token)
-        glft = token.match(PATH_DEPENDENT_FEED_TOKEN_REGEX)
+        glft = token.match(AuthFinders.path_dependent_feed_token_regex)
 
         return unless glft
 
         # make sure that user id uses decimal notation
-        user_id = glft[2].to_i(10)
-        digest = glft[1]
+        user_id = glft[3].to_i(10)
+        digest = glft[2]
 
         user = User.find_by_id(user_id)
         return unless user
@@ -369,12 +376,12 @@ module Gitlab
       end
 
       def find_user_from_job_token_query_params_or_header
-        token = current_request.params[JOB_TOKEN_PARAM].presence ||
+        self.current_token = current_request.params[JOB_TOKEN_PARAM].presence ||
           current_request.params[RUNNER_JOB_TOKEN_PARAM].presence ||
           current_request.env[JOB_TOKEN_HEADER].presence
-        return unless token
+        return unless current_token
 
-        job = find_valid_running_job_by_token!(token.to_s)
+        job = find_valid_running_job_by_token!(current_token.to_s)
         @current_authenticated_job = job # rubocop:disable Gitlab/ModuleWithInstanceVariables
 
         job.user
@@ -383,11 +390,11 @@ module Gitlab
       def find_user_from_job_token_basic_auth
         return unless has_basic_credentials?(current_request)
 
-        login, password = user_name_and_password(current_request)
-        return unless login.present? && password.present?
+        login, self.current_token = user_name_and_password(current_request)
+        return unless login.present? && current_token.present?
         return unless ::Gitlab::Auth::CI_JOB_USER == login
 
-        job = find_valid_running_job_by_token!(password.to_s)
+        job = find_valid_running_job_by_token!(current_token.to_s)
         @current_authenticated_job = job # rubocop:disable Gitlab/ModuleWithInstanceVariables
 
         job.user
