@@ -7,25 +7,23 @@ module QA
         include Page::Component::Note
         include Page::Component::Issuable::Sidebar
 
-        view 'app/assets/javascripts/batch_comments/components/preview_dropdown.vue' do
-          element 'review-preview-dropdown'
-        end
-
-        view 'app/assets/javascripts/batch_comments/components/review_bar.vue' do
-          element 'review-bar-content'
-        end
-
-        view 'app/assets/javascripts/batch_comments/components/submit_dropdown.vue' do
-          element 'submit-review-dropdown'
+        view 'app/assets/javascripts/batch_comments/components/review_drawer.vue' do
           element 'submit-review-button'
         end
 
+        view 'app/assets/javascripts/batch_comments/components/submit_review_button.vue' do
+          element 'review-drawer-toggle'
+        end
+
         view 'app/assets/javascripts/diffs/components/compare_dropdown_layout.vue' do
           element 'version-dropdown-content'
         end
 
         view 'app/assets/javascripts/diffs/components/compare_versions.vue' do
           element 'target-version-dropdown'
+        end
+
+        view 'app/assets/javascripts/diffs/components/file_browser_toggle.vue' do
           element 'file-tree-button'
         end
 
@@ -182,17 +180,19 @@ module QA
             end
           end
 
-          within_element('review-bar-content') do
-            click_element('review-preview-dropdown')
-          end
+          retry_until(sleep_interval: 2, max_attempts: 5, message: "Retry closing review drawer") do
+            if has_element?('review-drawer-toggle', wait: 2)
+              all_elements('review-drawer-toggle', minimum: 1).first.click
+            end
 
-          click_element('submit-review-dropdown')
-          click_element('submit-review-button')
+            click_element('submit-review-button')
+            has_no_element?('review-drawer-toggle', wait: 2)
+          end
 
           # After clicking the button, wait for the review bar to disappear
           # before moving on to the next part of the test
           wait_until(reload: false) do
-            has_no_element?('review-bar-content')
+            has_no_element?('draft-note')
           end
         end
 
@@ -239,12 +239,6 @@ module QA
           click_by_javascript(find_element('edit-title-button', skip_finished_loading_check: true))
         end
 
-        def expand_merge_checks
-          within_element('.mr-widget-section') do
-            click_element('chevron-lg-down-icon')
-          end
-        end
-
         def has_file?(file_name)
           open_file_tree
 
@@ -271,7 +265,7 @@ module QA
         end
 
         def has_merge_button?
-          has_element?('merge-button', wait: 30)
+          has_element?('merge-button', skip_finished_loading_check: true, wait: 30)
         end
 
         def has_no_merge_button?
@@ -380,10 +374,10 @@ module QA
             # merge button, in such case we must retry loop otherwise find_element will raise ElementNotFound error
             next false unless has_element?('merge-button', wait: 1)
 
-            break true unless find_element('merge-button').disabled?
-
             # If the widget shows "Merge blocked: new changes were just added" we can refresh the page and check again
-            next false if has_element?('head-mismatch-content', wait: 1)
+            next false if merge_blocked_by_new_changes?
+
+            break true unless find_element('merge-button').disabled?
 
             QA::Runtime::Logger.debug("MR widget text: \"#{mr_widget_text}\"")
 
@@ -391,6 +385,11 @@ module QA
           end
         end
 
+        # Returns true when widget shows "Merge blocked: new changes were just added"
+        def merge_blocked_by_new_changes?
+          has_element?('head-mismatch-content', wait: 1)
+        end
+
         def rebase!
           # The rebase button is disabled on load
           wait_until do
@@ -421,6 +420,7 @@ module QA
         def try_to_merge!(wait_for_no_auto_merge: true)
           wait_until_ready_to_merge
           wait_until { !find_element('merge-button').text.include?('auto-merge') } if wait_for_no_auto_merge # rubocop:disable Rails/NegateInclude -- Wait for text auto-merge to change
+          wait_until { !merge_blocked_by_new_changes? }
 
           click_element('merge-button')
         end
@@ -499,7 +499,7 @@ module QA
 
         def cherry_pick!
           click_element('cherry-pick-button', Page::Component::CommitModal)
-          click_element('submit-commit')
+          submit_commit
         end
 
         def revert_change!
@@ -508,7 +508,7 @@ module QA
           retry_on_exception(reload: true) do
             click_element('revert-button', Page::Component::CommitModal)
           end
-          click_element('submit-commit')
+          submit_commit
         end
 
         def mr_widget_text
@@ -550,6 +550,13 @@ module QA
         def has_exposed_artifact_with_name?(name)
           has_link?(name)
         end
+
+        private
+
+        def submit_commit
+          # There may be two modals due to https://gitlab.com/gitlab-org/gitlab/-/issues/538079
+          all_elements('submit-commit', minimum: 1).last.click
+        end
       end
     end
   end
