@@ -4,6 +4,7 @@ require 'spec_helper'
 
 RSpec.describe Groups::ChildrenController, feature_category: :groups_and_projects do
   include ExternalAuthorizationServiceHelpers
+  using RSpec::Parameterized::TableSyntax
 
   let_it_be(:group) { create(:group, :public) }
   let_it_be(:user) { create(:user) }
@@ -11,7 +12,7 @@ RSpec.describe Groups::ChildrenController, feature_category: :groups_and_project
 
   describe 'GET #index' do
     context 'for projects' do
-      let_it_be(:public_project) { create(:project, :public, namespace: group) }
+      let_it_be_with_reload(:public_project) { create(:project, :public, namespace: group) }
       let_it_be(:private_project) { create(:project, :private, namespace: group) }
 
       context 'as a user' do
@@ -44,6 +45,29 @@ RSpec.describe Groups::ChildrenController, feature_category: :groups_and_project
           expect(assigns(:children)).to contain_exactly(public_project)
         end
       end
+
+      describe 'archived attribute' do
+        where(:project_archived, :group_archived, :expected_archived_attribute) do
+          false | false | false
+          false | true  | true
+          true  | false | true
+          true  | true  | true
+        end
+
+        with_them do
+          before do
+            public_project.update!(archived: project_archived)
+            public_project.group.update!(archived: group_archived)
+          end
+
+          it 'returns correct archived status' do
+            get :index, params: { group_id: group.to_param }, format: :json
+
+            project_response = json_response.find { |p| p['id'] == public_project.id }
+            expect(project_response['archived']).to be(expected_archived_attribute)
+          end
+        end
+      end
     end
 
     context 'for subgroups' do
@@ -239,31 +263,91 @@ RSpec.describe Groups::ChildrenController, feature_category: :groups_and_project
               ))
             end
           end
-
-          def descendant_ids(data)
-            return [] if data.blank?
-
-            data = Array.wrap(data)
-
-            ids = []
-            data.each do |item|
-              ids << item['id']
-              ids << descendant_ids(item['children'])
-            end
-
-            ids.flatten
-          end
         end
 
         it 'includes pagination headers' do
-          2.times { |i| create(:group, :public, parent: public_subgroup, name: "filterme#{i}") }
+          create_list(:group, 2, :public, parent: public_subgroup)
 
-          get :index, params: { group_id: group.to_param, filter: 'filter', per_page: 1 }, format: :json
+          get :index, params: { group_id: group.to_param, per_page: 1 }, format: :json
 
           expect(response).to include_pagination_headers
         end
       end
 
+      context 'with active parameter' do
+        let_it_be(:group) { create(:group) }
+
+        let_it_be(:active_subgroup) { create(:group, parent: group) }
+        let_it_be(:active_project) { create(:project, :public, group: group) }
+
+        let_it_be(:inactive_subgroup) { create(:group, :archived, parent: group) }
+        let_it_be(:inactive_project) { create(:project, :archived, :public, group: group) }
+
+        subject(:make_request) { get :index, params: { group_id: group.to_param, active: active_param }, format: :json }
+
+        context 'when true' do
+          let_it_be(:active_param) { true }
+
+          it 'returns active direct children', :aggregate_failures do
+            make_request
+
+            expect(response).to have_gitlab_http_status(:ok)
+            expect(descendant_ids(json_response)).to include(active_subgroup.id, active_project.id)
+            expect(descendant_ids(json_response)).not_to include(inactive_subgroup.id, inactive_project.id)
+          end
+        end
+
+        context 'when false' do
+          let_it_be(:active_param) { false }
+
+          it 'returns inactive direct children', :aggregate_failures do
+            make_request
+
+            expect(response).to have_gitlab_http_status(:ok)
+            expect(descendant_ids(json_response)).to include(inactive_subgroup.id, inactive_project.id)
+            expect(descendant_ids(json_response)).not_to include(active_subgroup.id, active_project.id)
+          end
+
+          context 'when active subgroup has children' do
+            let_it_be(:active_descendant_group) { create(:group, parent: active_subgroup) }
+            let_it_be(:active_descendant_project) { create(:project, :public, group: active_subgroup) }
+
+            let_it_be(:inactive_descendant_group) { create(:group, :archived, parent: active_subgroup) }
+            let_it_be(:inactive_descendant_project) { create(:project, :public, :archived, group: active_subgroup) }
+
+            it 'returns inactive descendants', :aggregate_failures do
+              make_request
+
+              expect(response).to have_gitlab_http_status(:ok)
+              expect(descendant_ids(json_response))
+                .to include(inactive_descendant_group.id, inactive_descendant_project.id)
+              expect(descendant_ids(json_response))
+                .not_to include(active_descendant_group.id, active_descendant_project.id)
+            end
+          end
+
+          context 'when inactive subgroup has children' do
+            let_it_be(:active_descendant_group) { create(:group, parent: inactive_subgroup) }
+            let_it_be(:active_descendant_project) { create(:project, :public, group: inactive_subgroup) }
+
+            let_it_be(:inactive_descendant_group) { create(:group, :archived, parent: inactive_subgroup) }
+            let_it_be(:inactive_descendant_project) { create(:project, :public, :archived, group: inactive_subgroup) }
+
+            it 'returns all descendants' do
+              make_request
+
+              expect(response).to have_gitlab_http_status(:ok)
+              expect(descendant_ids(json_response)).to include(
+                active_descendant_group.id,
+                active_descendant_project.id,
+                inactive_descendant_group.id,
+                inactive_descendant_project.id
+              )
+            end
+          end
+        end
+      end
+
       context 'sorting children' do
         it 'allows sorting projects' do
           project_1 = create(:project, :public, namespace: group, name: 'mobile')
@@ -319,7 +403,8 @@ RSpec.describe Groups::ChildrenController, feature_category: :groups_and_project
 
             matched_group.update!(parent: public_subgroup)
 
-            expect { get_filtered_list }.not_to exceed_query_limit(control).with_threshold(extra_queries_for_hierarchies)
+            # TODO: remove + 1 after fixing https://gitlab.com/gitlab-org/gitlab/-/issues/545708
+            expect { get_filtered_list }.not_to exceed_query_limit(control).with_threshold(extra_queries_for_hierarchies + 1)
           end
 
           it 'queries the expected amount when a new group match is added' do
@@ -340,7 +425,10 @@ RSpec.describe Groups::ChildrenController, feature_category: :groups_and_project
 
             matched_project.update!(namespace: public_subgroup)
 
-            expect { get_filtered_list }.not_to exceed_query_limit(control).with_threshold(extra_queries_for_hierarchies)
+            # TODO remove + 2 after we stop manually reloading namespace_details in
+            # https://gitlab.com/gitlab-org/gitlab/-/issues/545723
+            # N+1 queries in https://gitlab.com/gitlab-org/gitlab/-/issues/545708
+            expect { get_filtered_list }.not_to exceed_query_limit(control).with_threshold(extra_queries_for_hierarchies + 2)
           end
         end
       end
@@ -422,4 +510,10 @@ RSpec.describe Groups::ChildrenController, feature_category: :groups_and_project
       end
     end
   end
+
+  def descendant_ids(data)
+    Array.wrap(data).flat_map do |item|
+      [item['id'], descendant_ids(item['children'])].flatten
+    end
+  end
 end
