@@ -5,6 +5,7 @@ require 'spec_helper'
 RSpec.describe GroupsController, :with_current_organization, factory_default: :keep, feature_category: :code_review_workflow do
   include ExternalAuthorizationServiceHelpers
   include AdminModeHelper
+  include Namespaces::DeletableHelper
 
   let_it_be(:group_organization) { current_organization }
   let_it_be_with_refind(:group) { create_default(:group, :public, organization: group_organization) }
@@ -105,6 +106,61 @@ RSpec.describe GroupsController, :with_current_organization, factory_default: :k
         )
       end
     end
+
+    context 'adjourned deletion' do
+      render_views
+
+      let_it_be(:subgroup) { create(:group, :private, parent: group) }
+      let(:ancestor_notice_regex) do
+        /This group will be deleted on .* because its parent group is scheduled for deletion\./
+      end
+
+      subject(:get_show) { get :show, params: { id: subgroup.to_param } }
+
+      context 'when the parent group has not been scheduled for deletion' do
+        it 'does not show the notice' do
+          subject
+
+          expect(response.body).not_to match(ancestor_notice_regex)
+        end
+      end
+
+      context 'when the parent group has been scheduled for deletion' do
+        before do
+          create(:group_deletion_schedule,
+            group: subgroup.parent,
+            marked_for_deletion_on: Date.current,
+            deleting_user: user
+          )
+        end
+
+        it 'shows the notice that the parent group has been scheduled for deletion' do
+          subject
+
+          expect(response.body).to match(ancestor_notice_regex)
+        end
+
+        context 'when the group itself has also been scheduled for deletion' do
+          before do
+            create(:group_deletion_schedule,
+              group: subgroup,
+              marked_for_deletion_on: Date.current,
+              deleting_user: user
+            )
+          end
+
+          it 'does not show the notice that the parent group has been scheduled for deletion' do
+            subject
+
+            expect(response.body).not_to match(ancestor_notice_regex)
+            # However, shows the notice that the project has been marked for deletion.
+            expect(response.body).to match(
+              /This group and its subgroups and projects are pending deletion, and will be deleted on .*./
+            )
+          end
+        end
+      end
+    end
   end
 
   describe 'GET #details' do
@@ -434,37 +490,6 @@ RSpec.describe GroupsController, :with_current_organization, factory_default: :k
       end
     end
 
-    context 'when creating a group with the `setup_for_company` attribute present' do
-      before do
-        sign_in(user)
-      end
-
-      subject do
-        post :create, params: { group: { name: 'new_group', path: 'new_group', setup_for_company: 'false' } }
-      end
-
-      it 'sets the groups `setup_for_company` value' do
-        subject
-        expect(Group.last.setup_for_company).to be(false)
-      end
-
-      context 'when the user already has a value for `setup_for_company`' do
-        let_it_be(:user) { create(:user, setup_for_company: true) }
-
-        it 'does not change the users `setup_for_company` value' do
-          expect(Users::UpdateService).not_to receive(:new)
-          expect { subject }.not_to change { user.reload.setup_for_company }.from(true)
-        end
-      end
-
-      context 'when the user has no value for `setup_for_company`' do
-        it 'changes the users `setup_for_company` value' do
-          expect(Users::UpdateService).to receive(:new).and_call_original
-          expect { subject }.to change { user.reload.setup_for_company }.to(false)
-        end
-      end
-    end
-
     context 'when creating a group with the `jobs_to_be_done` attribute present' do
       it 'sets the groups `jobs_to_be_done` value' do
         sign_in(user)
@@ -526,42 +551,203 @@ RSpec.describe GroupsController, :with_current_organization, factory_default: :k
   end
 
   describe 'DELETE #destroy' do
-    context 'as another user' do
-      it 'returns 404' do
-        sign_in(create(:user))
+    let(:format) { :html }
+    let(:params) { {} }
 
-        delete :destroy, params: { id: group.to_param }
+    subject { delete :destroy, format: format, params: { id: group.to_param, **params } }
+
+    context 'when authenticated user can admin the group' do
+      let_it_be(:user) { owner }
+
+      before do
+        sign_in(user)
+      end
+
+      context 'success' do
+        it 'marks the group for delayed deletion' do
+          expect { subject }.to change { group.reload.self_deletion_scheduled? }.from(false).to(true)
+        end
+
+        it 'does not immediately delete the group' do
+          Sidekiq::Testing.fake! do
+            expect { subject }.not_to change { GroupDestroyWorker.jobs.size }
+          end
+        end
+
+        context 'for a html request' do
+          it 'redirects to group path' do
+            subject
+
+            expect(response).to redirect_to(group_path(group.reload))
+          end
+        end
+
+        context 'for a json request', :freeze_time do
+          let(:format) { :json }
+
+          it 'returns json with message' do
+            subject
+
+            expect(json_response['message'])
+            .to eq(
+              "'#{group.reload.name}' has been scheduled for deletion and will be deleted on " \
+                "#{permanent_deletion_date_formatted(group)}.")
+          end
+        end
+      end
+
+      context 'failure' do
+        before do
+          allow(::Groups::MarkForDeletionService).to receive_message_chain(:new, :execute).and_return(ServiceResponse.error(message: 'error'))
+        end
+
+        it 'does not mark the group for deletion' do
+          expect { subject }.not_to change { group.reload.self_deletion_scheduled? }.from(false)
+        end
+
+        context 'for a html request' do
+          it 'redirects to group edit page' do
+            subject
+
+            expect(response).to redirect_to(edit_group_path(group))
+            expect(flash[:alert]).to include 'error'
+          end
+        end
+
+        context 'for a json request' do
+          let(:format) { :json }
+
+          it 'returns json with message' do
+            subject
+
+            expect(json_response['message']).to eq("error")
+          end
+        end
+      end
+
+      context 'when group is already marked for deletion' do
+        before do
+          create(:group_deletion_schedule, group: group, marked_for_deletion_on: Date.current)
+        end
+
+        context 'when permanently_remove param is set' do
+          let(:params) { { permanently_remove: true } }
+
+          context 'for a html request' do
+            it 'deletes the group immediately and redirects to root path' do
+              expect(GroupDestroyWorker).to receive(:perform_async)
+
+              subject
+
+              expect(response).to redirect_to(root_path)
+              expect(flash[:toast]).to include "Group '#{group.name}' is being deleted."
+            end
+          end
+
+          context 'for a json request' do
+            let(:format) { :json }
+
+            it 'deletes the group immediately and returns json with message' do
+              expect(GroupDestroyWorker).to receive(:perform_async)
+
+              subject
+
+              expect(json_response['message']).to eq("Group '#{group.name}' is being deleted.")
+            end
+          end
+        end
+
+        context 'when permanently_remove param is not set' do
+          context 'for a html request' do
+            it 'redirects to edit path with error' do
+              subject
+
+              expect(response).to redirect_to(edit_group_path(group))
+              expect(flash[:alert]).to include "Group has been already marked for deletion"
+            end
+          end
+
+          context 'for a json request' do
+            let(:format) { :json }
+
+            it 'returns json with message' do
+              subject
+
+              expect(json_response['message']).to eq("Group has been already marked for deletion")
+            end
+          end
+        end
+      end
+    end
+
+    context 'when authenticated user cannot admin the group' do
+      before do
+        sign_in(create(:user))
+      end
+
+      it 'returns 404' do
+        subject
 
         expect(response).to have_gitlab_http_status(:not_found)
       end
     end
+  end
 
-    context 'as the group owner' do
-      let(:user) { create(:user) }
-      let(:group) { create(:group) }
+  describe 'POST #restore' do
+    let_it_be(:group) do
+      create(:group_with_deletion_schedule,
+        marked_for_deletion_on: 1.day.ago,
+        deleting_user: user)
+    end
 
+    subject { post :restore, params: { group_id: group.to_param } }
+
+    context 'when authenticated user can admin the group' do
       before do
         group.add_owner(user)
         sign_in(user)
       end
 
-      context 'for a html request' do
-        it 'schedules a group destroy and redirects to the root path' do
-          Sidekiq::Testing.fake! do
-            expect { delete :destroy, params: { id: group.to_param } }.to change(GroupDestroyWorker.jobs, :size).by(1)
-          end
-          expect(flash[:toast]).to eq(format(_("Group '%{group_name}' is being deleted."), group_name: group.full_name))
-          expect(response).to redirect_to(root_path)
+      context 'when the restore succeeds' do
+        it 'restores the group' do
+          expect { subject }.to change { group.reload.self_deletion_scheduled? }.from(true).to(false)
+        end
+
+        it 'renders success notice upon restoring' do
+          subject
+
+          expect(response).to redirect_to(edit_group_path(group))
+          expect(flash[:notice]).to include "Group '#{group.name}' has been successfully restored."
         end
       end
 
-      context 'for a json request' do
-        it 'schedules a group destroy and returns message' do
-          Sidekiq::Testing.fake! do
-            expect { delete :destroy, format: :json, params: { id: group.to_param } }.to change(GroupDestroyWorker.jobs, :size).by(1)
-          end
-          expect(Gitlab::Json.parse(response.body)).to eq({ 'message' => "Group '#{group.full_name}' is being deleted." })
+      context 'when the restore fails' do
+        before do
+          allow(::Groups::RestoreService).to receive_message_chain(:new, :execute).and_return(ServiceResponse.error(message: 'error'))
         end
+
+        it 'does not restore the group' do
+          expect { subject }.not_to change { group.reload.self_deletion_scheduled? }.from(true)
+        end
+
+        it 'redirects to group edit page' do
+          subject
+
+          expect(response).to redirect_to(edit_group_path(group))
+          expect(flash[:alert]).to include 'error'
+        end
+      end
+    end
+
+    context 'when authenticated user cannot admin the group' do
+      before do
+        sign_in(create(:user))
+      end
+
+      it 'returns 404' do
+        subject
+
+        expect(response).to have_gitlab_http_status(:not_found)
       end
     end
   end
@@ -674,7 +860,7 @@ RSpec.describe GroupsController, :with_current_organization, factory_default: :k
       it 'does not allow to path of the group to be changed' do
         post :update, params: { id: group.to_param, group: { path: 'new_path' } }
 
-        expect(assigns(:group).errors[:base].first).to match(/Docker images in their Container Registry/)
+        expect(assigns(:group).errors[:base].first).to match(/Docker images in their container registry/)
         expect(response).to have_gitlab_http_status(:ok)
       end
     end
@@ -1055,7 +1241,7 @@ RSpec.describe GroupsController, :with_current_organization, factory_default: :k
       end
 
       it 'does not allow the group to be transferred' do
-        expect(controller).to set_flash[:alert].to match(/Docker images in their Container Registry/)
+        expect(controller).to set_flash[:alert].to match(/Docker images in their container registry/)
         expect(response).to redirect_to(edit_group_path(group))
       end
     end
