@@ -692,13 +692,13 @@ RSpec.describe Projects::PipelinesController, feature_category: :continuous_inte
 
     def get_stage(name, params = {})
       get :stage, params: {
-**params.merge(
-  namespace_id: project.namespace,
-  project_id: project,
-  id: pipeline.id,
-  stage: name,
-  format: :json)
-}
+        **params.merge(
+          namespace_id: project.namespace,
+          project_id: project,
+          id: pipeline.id,
+          stage: name,
+          format: :json)
+      }
     end
   end
 
@@ -935,28 +935,6 @@ RSpec.describe Projects::PipelinesController, feature_category: :continuous_inte
           'my-job-build 1/2', 'my-job-build 2/2', 'my-job-test', 'my-job-test-2', 'my-job-deploy'
         )
       end
-
-      context 'when the FF ci_inputs_for_pipelines is disabled' do
-        before do
-          stub_feature_flags(ci_inputs_for_pipelines: false)
-        end
-
-        it 'behaves like the inputs are never passed and returns errors' do
-          expect { post_request }.not_to change { project.ci_pipelines.count }
-
-          expect(response).to have_gitlab_http_status(:bad_request)
-
-          expect(json_response['errors'][0]).to include(
-            '`deploy_strategy` input: required value has not been provided'
-          )
-          expect(json_response['errors'][0]).to include(
-            '`job_stage` input: required value has not been provided'
-          )
-          expect(json_response['errors'][0]).to include(
-            '`test_script` input: required value has not been provided'
-          )
-        end
-      end
     end
   end
 
@@ -1209,22 +1187,15 @@ RSpec.describe Projects::PipelinesController, feature_category: :continuous_inte
   end
 
   describe 'GET manual_variables' do
-    context 'when FF ci_show_manual_variables_in_pipeline is enabled' do
-      let(:pipeline) { create(:ci_pipeline, project: project) }
+    let(:pipeline) { create(:ci_pipeline, project: project) }
 
-      it_behaves_like 'the show page', 'manual_variables'
-    end
+    it_behaves_like 'the show page', 'manual_variables'
 
-    context 'when FF ci_show_manual_variables_in_pipeline is disabled' do
-      let(:pipeline) { create(:ci_pipeline, project: project) }
-
-      before do
-        stub_feature_flags(ci_show_manual_variables_in_pipeline: false)
-      end
-
-      it 'renders 404' do
-        get 'manual_variables', params: { namespace_id: project.namespace, project_id: project, id: pipeline }
+    context 'when unauthorized' do
+      it 'returns a 404' do
+        sign_in(build(:user))
 
+        get :manual_variables, params: { namespace_id: project.namespace, project_id: project, id: pipeline.id }
         expect(response).to have_gitlab_http_status(:not_found)
       end
     end
@@ -1349,10 +1320,10 @@ RSpec.describe Projects::PipelinesController, feature_category: :continuous_inte
 
     def delete_pipeline
       delete :destroy, params: {
-                         namespace_id: project.namespace,
-                         project_id: project,
-                         id: pipeline.id
-                       }
+        namespace_id: project.namespace,
+        project_id: project,
+        id: pipeline.id
+      }
     end
   end
 
