@@ -14,33 +14,6 @@ RSpec.describe 'Database schema',
   let(:tables) { connection.tables }
   let(:columns_name_with_jsonb) { retrieve_columns_name_with_jsonb }
 
-  let(:ignored_indexes_on_fks_map) do
-    {
-      ci_build_trace_metadata: [%w[partition_id build_id], %w[partition_id trace_artifact_id]], # the index on build_id is enough
-      ci_builds: [%w[partition_id stage_id], %w[partition_id execution_config_id], %w[auto_canceled_by_partition_id auto_canceled_by_id], %w[upstream_pipeline_partition_id upstream_pipeline_id], %w[partition_id commit_id]], # https://gitlab.com/gitlab-org/gitlab/-/merge_requests/142804#note_1745483081
-      ci_daily_build_group_report_results: [%w[partition_id last_pipeline_id]], # index on last_pipeline_id is sufficient
-      ci_pipeline_artifacts: [%w[partition_id pipeline_id]], # index on pipeline_id is sufficient
-      ci_pipeline_chat_data: [%w[partition_id pipeline_id]], # index on pipeline_id is sufficient
-      ci_pipeline_messages: [%w[partition_id pipeline_id]], # index on pipeline_id is sufficient
-      ci_pipeline_metadata: [%w[partition_id pipeline_id]], # index on pipeline_id is sufficient
-      ci_pipeline_variables: [%w[partition_id pipeline_id]], # index on pipeline_id is sufficient
-      ci_pipelines: [%w[auto_canceled_by_partition_id auto_canceled_by_id]], # index on auto_canceled_by_id is sufficient
-      ci_pipelines_config: [%w[partition_id pipeline_id]], # index on pipeline_id is sufficient
-      ci_sources_pipelines: [%w[source_partition_id source_pipeline_id], %w[partition_id pipeline_id]],
-      ci_sources_projects: [%w[partition_id pipeline_id]], # index on pipeline_id is sufficient
-      ci_stages: [%w[partition_id pipeline_id]], # the index on pipeline_id is sufficient
-      p_ci_build_trace_metadata: [%w[partition_id build_id], %w[partition_id trace_artifact_id]], # the index on build_id is enough
-      p_ci_builds: [%w[partition_id stage_id], %w[partition_id execution_config_id], %w[auto_canceled_by_partition_id auto_canceled_by_id], %w[upstream_pipeline_partition_id upstream_pipeline_id], %w[partition_id commit_id]], # https://gitlab.com/gitlab-org/gitlab/-/merge_requests/142804#note_1745483081
-      p_ci_builds_execution_configs: [%w[partition_id pipeline_id]], # the index on pipeline_id is enough
-      p_ci_pipelines: [%w[auto_canceled_by_partition_id auto_canceled_by_id]], # index on auto_canceled_by_id is sufficient
-      p_ci_pipeline_variables: [%w[partition_id pipeline_id]], # index on pipeline_id is sufficient
-      p_ci_stages: [%w[partition_id pipeline_id]], # the index on pipeline_id is sufficient
-      slack_integrations_scopes: [%w[slack_api_scope_id]],
-      users: [%w[accepted_term_id]],
-      subscription_add_on_purchases: [["subscription_add_on_id"]] # index handled via composite index with namespace_id
-    }.with_indifferent_access.freeze
-  end
-
   # If splitting FK and table removal into two MRs as suggested in the docs, use this constant in the initial FK removal MR.
   # In the subsequent table removal MR, remove the entries.
   # See: https://docs.gitlab.com/ee/development/migration_style_guide.html#dropping-a-database-table
@@ -52,14 +25,17 @@ RSpec.describe 'Database schema',
     }.with_indifferent_access.freeze
   end
 
-  # List of columns historically missing a FK, don't add more columns
+  # List of columns, ending with `_id` but missing a FK
   # See: https://docs.gitlab.com/ee/development/database/foreign_keys.html#naming-foreign-keys
+  # TODO: Automate this to reduce the list of exceptions: https://gitlab.com/gitlab-org/gitlab/-/issues/544795
   let(:ignored_fk_columns_map) do
     {
       abuse_reports: %w[reporter_id user_id],
       abuse_report_notes: %w[discussion_id],
       ai_code_suggestion_events: %w[user_id],
-      ai_duo_chat_events: %w[user_id organization_id],
+      ai_duo_chat_events: %w[user_id],
+      ai_troubleshoot_job_events: %w[user_id job_id],
+      ai_usage_events: %w[user_id],
       application_settings: %w[performance_bar_allowed_group_id slack_app_id snowplow_app_id eks_account_id
         eks_access_key_id],
       approvals: %w[user_id project_id],
@@ -82,16 +58,14 @@ RSpec.describe 'Database schema',
       group_audit_events: %w[author_id group_id target_id],
       project_audit_events: %w[author_id project_id target_id],
       instance_audit_events: %w[author_id target_id],
+      project_compliance_violations: %w[audit_event_id], # audit_events table doesn't have id as the primary key instead the primary key is btree (id, created_at)
       award_emoji: %w[awardable_id user_id],
       aws_roles: %w[role_external_id],
       boards: %w[milestone_id iteration_id],
       broadcast_messages: %w[namespace_id],
       catalog_resource_component_last_usages: %w[used_by_project_id], # No FK constraint because we want to preserve usage data even if project is deleted.
-      chat_names: %w[chat_id team_id user_id],
+      chat_names: %w[chat_id team_id],
       chat_teams: %w[team_id],
-      ci_builds: %w[project_id runner_id user_id erased_by_id trigger_request_id partition_id
-        auto_canceled_by_partition_id execution_config_id upstream_pipeline_partition_id],
-      ci_builds_metadata: %w[partition_id project_id build_id],
       ci_build_needs: %w[project_id],
       ci_build_pending_states: %w[project_id],
       ci_build_trace_chunks: %w[project_id],
@@ -99,42 +73,37 @@ RSpec.describe 'Database schema',
       ci_daily_build_group_report_results: %w[partition_id],
       ci_deleted_objects: %w[project_id],
       ci_gitlab_hosted_runner_monthly_usages: %w[root_namespace_id project_id runner_id],
-      ci_job_artifacts: %w[partition_id project_id job_id],
       ci_namespace_monthly_usages: %w[namespace_id],
       ci_pipeline_artifacts: %w[partition_id],
       ci_pipeline_chat_data: %w[partition_id project_id],
       ci_pipeline_messages: %w[partition_id project_id],
       ci_pipeline_metadata: %w[partition_id],
       ci_pipeline_schedule_variables: %w[project_id],
-      ci_pipeline_variables: %w[partition_id pipeline_id project_id],
       ci_pipelines_config: %w[partition_id project_id],
-      ci_pipelines: %w[partition_id auto_canceled_by_partition_id project_id user_id merge_request_id trigger_id], # LFKs are defined on the routing table
       ci_secure_file_states: %w[project_id],
       ci_unit_test_failures: %w[project_id],
       ci_resources: %w[project_id],
       p_ci_pipelines: %w[partition_id auto_canceled_by_partition_id auto_canceled_by_id trigger_id],
       p_ci_runner_machine_builds: %w[project_id],
-      ci_runner_taggings: %w[runner_id sharding_key_id], # The sharding_key_id value is meant to populate the partitioned table, no other usage. The runner_id FK exists at the partition level
-      ci_runner_taggings_instance_type: %w[sharding_key_id], # This field is always NULL in this partition
-      ci_runners: %w[sharding_key_id], # This value is meant to populate the partitioned table, no other usage
-      ci_runners_archived: %w[sharding_key_id creator_id], # This field is only used in the partitions, and has the appropriate FKs. We don't need the LFK for creator_id since that is already mirrored from ci_runners
-      instance_type_ci_runners: %w[creator_id sharding_key_id], # No need for LFKs on partition, already handled on ci_runners routing table.
-      group_type_ci_runners: %w[creator_id sharding_key_id], # No need for LFKs on partition, already handled on ci_runners routing table.
-      project_type_ci_runners: %w[creator_id sharding_key_id], # No need for LFKs on partition, already handled on ci_runners routing table.
-      ci_runner_machines: %w[runner_id sharding_key_id], # The runner_id and sharding_key_id fields are only used in the partitions, and have the appropriate FKs. The runner_id field will be removed with https://gitlab.com/gitlab-org/gitlab/-/issues/503749.
-      ci_runner_machines_archived: %w[runner_id sharding_key_id], # The sharding_key_id field is only used in the partitions, and has the appropriate FKs. The runner_id field will be removed with https://gitlab.com/gitlab-org/gitlab/-/issues/503749.
-      instance_type_ci_runner_machines: %w[sharding_key_id], # This field is always NULL in this partition.
-      group_type_ci_runner_machines: %w[sharding_key_id], # No need for LFK, rows will be deleted by the FK to ci_runners.
-      project_type_ci_runner_machines: %w[sharding_key_id], # No need for LFK, rows will be deleted by the FK to ci_runners.
+      ci_runner_taggings: %w[runner_id organization_id sharding_key_id], # The organization_id value is meant to populate the partitioned table, no other usage. The sharding_key_id will be dropped in https://gitlab.com/gitlab-org/gitlab/-/issues/547650. The runner_id FK exists at the partition level
+      ci_runner_taggings_instance_type: %w[tag_id organization_id sharding_key_id], # organization_id is always NULL in this partition, tag_id is handled on ci_runner_taggings. The sharding_key_id will be dropped in https://gitlab.com/gitlab-org/gitlab/-/issues/547650
+      ci_runner_taggings_group_type: %w[tag_id organization_id sharding_key_id], # tag_id is handled on ci_runner_taggings. The sharding_key_id will be dropped in https://gitlab.com/gitlab-org/gitlab/-/issues/547650. These records are indirectly deleted by the FK to group_type_ci_runners
+      ci_runner_taggings_project_type: %w[tag_id organization_id sharding_key_id], # tag_id is handled on ci_runner_taggings. The sharding_key_id will be dropped in https://gitlab.com/gitlab-org/gitlab/-/issues/547650. These records are indirectly deleted by the FK to project_type_ci_runners
+      ci_runners: %w[sharding_key_id], # The sharding_key_id will be dropped in https://gitlab.com/gitlab-org/gitlab/-/issues/547650.
+      instance_type_ci_runners: %w[creator_id organization_id sharding_key_id], # No need for LFKs on partition, already handled on ci_runners routing table. The sharding_key_id will be dropped in https://gitlab.com/gitlab-org/gitlab/-/issues/547650.
+      group_type_ci_runners: %w[creator_id organization_id sharding_key_id], # No need for LFKs on partition, already handled on ci_runners routing table. The sharding_key_id will be dropped in https://gitlab.com/gitlab-org/gitlab/-/issues/547650.
+      project_type_ci_runners: %w[creator_id organization_id sharding_key_id], # No need for LFKs on partition, already handled on ci_runners routing table. The sharding_key_id will be dropped in https://gitlab.com/gitlab-org/gitlab/-/issues/547650.
+      ci_runner_machines: %w[runner_id organization_id sharding_key_id], # The organization_id field is only used in the partitions, and have the appropriate FKs. The runner_id field will be removed with https://gitlab.com/gitlab-org/gitlab/-/issues/503749. The sharding_key_id will be dropped in https://gitlab.com/gitlab-org/gitlab/-/issues/547650.
+      instance_type_ci_runner_machines: %w[organization_id sharding_key_id], # This field is always NULL in this partition. The sharding_key_id will be dropped in https://gitlab.com/gitlab-org/gitlab/-/issues/547650.
+      group_type_ci_runner_machines: %w[organization_id sharding_key_id], # No need for LFK, rows will be deleted by the FK to ci_runners. The sharding_key_id will be dropped in https://gitlab.com/gitlab-org/gitlab/-/issues/547650.
+      project_type_ci_runner_machines: %w[organization_id sharding_key_id], # No need for LFK, rows will be deleted by the FK to ci_runners. The sharding_key_id will be dropped in https://gitlab.com/gitlab-org/gitlab/-/issues/547650.
       ci_runner_projects: %w[runner_id],
       ci_sources_pipelines: %w[partition_id source_partition_id source_job_id],
       ci_sources_projects: %w[partition_id],
-      ci_stages: %w[partition_id project_id pipeline_id],
-      ci_trigger_requests: %w[commit_id project_id],
       ci_job_artifact_states: %w[partition_id project_id],
       cluster_providers_aws: %w[security_group_id vpc_id access_key_id],
       cluster_providers_gcp: %w[gcp_project_id operation_id],
-      compliance_management_frameworks: %w[group_id],
+      compliance_management_frameworks: %w[group_id source_id],
       commit_user_mentions: %w[commit_id],
       dast_site_profiles_builds: %w[project_id],
       dast_scanner_profiles_builds: %w[project_id],
@@ -165,10 +134,11 @@ RSpec.describe 'Database schema',
       members: %w[source_id created_by_id],
       merge_requests: %w[last_edited_by_id state_id],
       merge_request_cleanup_schedules: %w[project_id],
+      merge_request_commits_metadata: %w[project_id commit_author_id committer_id],
       merge_requests_compliance_violations: %w[target_project_id],
       merge_request_diffs: %w[project_id],
       merge_request_diff_files: %w[project_id],
-      merge_request_diff_commits: %w[commit_author_id committer_id],
+      merge_request_diff_commits: %w[project_id commit_author_id committer_id merge_request_commits_metadata_id],
       # merge_request_diff_commits_b5377a7a34 is the temporary table for the merge_request_diff_commits partitioning
       # backfill. It will get foreign keys after the partitioning is finished.
       merge_request_diff_commits_b5377a7a34: %w[merge_request_diff_id commit_author_id committer_id project_id],
@@ -182,7 +152,7 @@ RSpec.describe 'Database schema',
       oauth_device_grants: %w[resource_owner_id application_id],
       packages_nuget_symbols: %w[project_id],
       packages_package_files: %w[project_id],
-      p_ci_builds: %w[erased_by_id trigger_request_id partition_id auto_canceled_by_partition_id execution_config_id
+      p_ci_builds: %w[erased_by_id partition_id auto_canceled_by_partition_id execution_config_id
         upstream_pipeline_partition_id],
       p_ci_builds_metadata: %w[project_id build_id partition_id],
       p_ci_build_trace_metadata: %w[project_id],
@@ -193,6 +163,7 @@ RSpec.describe 'Database schema',
       p_ci_finished_pipeline_ch_sync_events: %w[pipeline_id project_namespace_id],
       p_ci_job_annotations: %w[partition_id job_id project_id],
       p_ci_job_artifacts: %w[partition_id project_id job_id],
+      p_ci_job_definitions: %w[partition_id],
       p_ci_pipeline_variables: %w[partition_id pipeline_id project_id],
       p_ci_pipelines_config: %w[partition_id project_id],
       p_ci_builds_execution_configs: %w[partition_id],
@@ -205,21 +176,48 @@ RSpec.describe 'Database schema',
       push_event_payloads: %w[project_id],
       redirect_routes: %w[source_id],
       repository_languages: %w[programming_language_id],
+      resource_label_events: %w[namespace_id], # FK to be added in https://gitlab.com/gitlab-org/gitlab/-/merge_requests/197676
       routes: %w[source_id],
       security_findings: %w[project_id],
-      sent_notifications: %w[project_id noteable_id recipient_id commit_id in_reply_to_discussion_id],
+      sent_notifications: %w[project_id noteable_id recipient_id commit_id in_reply_to_discussion_id namespace_id], # namespace_id FK will be added to partitioned table
+      p_sent_notifications: %w[project_id noteable_id recipient_id commit_id in_reply_to_discussion_id],
       slack_integrations: %w[team_id user_id bot_user_id], # these are external Slack IDs
       snippets: %w[author_id],
-      spam_logs: %w[user_id],
+      spam_logs: %w[user_id target_id],
       status_check_responses: %w[external_approval_rule_id],
       subscriptions: %w[user_id subscribable_id],
       suggestions: %w[commit_id],
-      taggings: %w[tag_id taggable_id tagger_id],
       timelogs: %w[user_id],
       todos: %w[target_id commit_id],
       uploads: %w[model_id organization_id namespace_id project_id],
+      uploads_9ba88c4165: %w[model_id],
+      abuse_report_uploads: %w[model_id],
+      achievement_uploads: %w[model_id],
+      ai_vectorizable_file_uploads: %w[model_id],
+      alert_management_alert_metric_image_uploads: %w[model_id],
+      appearance_uploads: %w[model_id],
+      bulk_import_export_upload_uploads: %w[model_id],
+      dependency_list_export_part_uploads: %w[model_id],
+      dependency_list_export_uploads: %w[model_id],
+      design_management_action_uploads: %w[model_id],
+      import_export_upload_uploads: %w[model_id],
+      issuable_metric_image_uploads: %w[model_id],
+      namespace_uploads: %w[model_id],
+      note_uploads: %w[model_id],
+      organization_detail_uploads: %w[model_id],
+      project_import_export_relation_export_upload_uploads: %w[model_id],
+      project_topic_uploads: %w[model_id],
+      project_uploads: %w[model_id],
+      snippet_uploads: %w[model_id],
+      user_permission_export_upload_uploads: %w[model_id],
+      user_uploads: %w[model_id],
+      vulnerability_export_part_uploads: %w[model_id],
+      vulnerability_export_uploads: %w[model_id],
+      vulnerability_archive_export_uploads: %w[model_id],
+      vulnerability_remediation_uploads: %w[model_id],
       user_agent_details: %w[subject_id],
-      users: %w[color_mode_id color_scheme_id created_by_id theme_id managing_group_id],
+      users: %w[color_mode_id color_scheme_id created_by_id theme_id managing_group_id accepted_term_id organization_id],
+      user_preferences: %w[dark_color_scheme_id],
       users_star_projects: %w[user_id],
       vulnerability_finding_links: %w[project_id],
       vulnerability_identifiers: %w[external_id],
@@ -227,6 +225,7 @@ RSpec.describe 'Database schema',
       vulnerability_scanners: %w[external_id],
       security_scans: %w[pipeline_id project_id], # foreign key is not added as ci_pipeline table will be moved into different db soon
       dependency_list_exports: %w[pipeline_id], # foreign key is not added as ci_pipeline table is in different db
+      vulnerability_archived_records: %w[archive_id], # having a FK on this table prevents partitions from being detached. See: https://gitlab.com/gitlab-org/gitlab/-/issues/547116
       vulnerability_reads: %w[cluster_agent_id namespace_id], # namespace_id is a denormalization of `project.namespace`
       # See: https://gitlab.com/gitlab-org/gitlab/-/merge_requests/87584
       # Fixes performance issues with the deletion of web-hooks with many log entries
@@ -239,6 +238,7 @@ RSpec.describe 'Database schema',
       zoekt_indices: %w[namespace_id], # needed for cells sharding key
       zoekt_repositories: %w[namespace_id project_identifier], # needed for cells sharding key
       zoekt_tasks: %w[project_identifier partition_id zoekt_repository_id zoekt_node_id], # needed for: cells sharding key, partitioning, and performance reasons
+      p_knowledge_graph_tasks: %w[partition_id knowledge_graph_replica_id zoekt_node_id namespace_id], # needed for: partitioning, and performance reasons
       # TODO: To remove with https://gitlab.com/gitlab-org/gitlab/-/merge_requests/155256
       approval_group_rules: %w[approval_policy_rule_id],
       approval_project_rules: %w[approval_policy_rule_id],
@@ -252,45 +252,58 @@ RSpec.describe 'Database schema',
       instance_integrations: %w[project_id group_id inherit_from_id], # these columns are not used in instance integrations
       group_scim_identities: %w[temp_source_id], # temporary column that is not a foreign key
       group_scim_auth_access_tokens: %w[temp_source_id], # temporary column that is not a foreign key
+      secret_detection_token_statuses: %w[project_id],
+      security_finding_token_statuses: %w[security_finding_id project_id],
       system_access_group_microsoft_graph_access_tokens: %w[temp_source_id], # temporary column that is not a foreign key
       system_access_group_microsoft_applications: %w[temp_source_id], # temporary column that is not a foreign key
       subscription_user_add_on_assignment_versions: %w[item_id user_id purchase_id], # Managed by paper_trail gem, no need for FK on the historical data
       virtual_registries_packages_maven_cache_entries: %w[group_id], # We can't use a foreign key due to object storage references
       # system_defined_status_id reference to fixed items model which is stored in code
-      # custom_status_id to be implemented association, column exists for better column ordering
-      # TODO: Remove custom_status_id https://gitlab.com/gitlab-org/gitlab/-/work_items/520312
-      work_item_current_statuses: %w[system_defined_status_id custom_status_id]
+      work_item_current_statuses: %w[system_defined_status_id],
+      # we can't use a foreign key reference because we want to preserve namespace_id  for asynchronous deletion
+      p_knowledge_graph_replicas: %w[namespace_id],
+      # temp entry, removing FK on source_type_id and target_type_id until table is dropped in follow up MR
+      work_item_related_link_restrictions: %w[source_type_id target_type_id]
     }.with_indifferent_access.freeze
   end
 
   let(:ignored_tables_with_too_many_indexes) do
     {
       approval_merge_request_rules: 17,
-      ci_builds: 27,
-      ci_pipelines: 24,
-      ci_runners: 16,
-      ci_runners_archived: 17,
+      ci_runners: 17,
       deployments: 18,
       epics: 19,
       events: 16,
-      group_type_ci_runners: 17,
-      instance_type_ci_runners: 17,
-      issues: 39,
+      group_type_ci_runners: 18,
+      instance_type_ci_runners: 18,
+      issues: 32,
       members: 21,
-      merge_requests: 33,
+      merge_requests: 30,
       namespaces: 26,
-      p_ci_builds: 27,
+      notes: 16,
+      p_ci_builds: 26,
       p_ci_pipelines: 24,
       packages_package_files: 16,
-      packages_packages: 27,
-      project_type_ci_runners: 17,
+      packages_packages: 28,
+      project_type_ci_runners: 18,
       projects: 55,
       sbom_occurrences: 25,
-      users: 32,
+      users: 34, # Decrement by 1 after the removal of a temporary index https://gitlab.com/gitlab-org/gitlab/-/merge_requests/184848
       vulnerability_reads: 23
     }.with_indifferent_access.freeze
   end
 
+  # For partitioned CI references we do not require a composite index starting with `partition_id` as each partition
+  # only contains records with a single `partition_id`. As such the index on the other id in the foreign key will be
+  # sufficient.
+  def ci_partitioned_foreign_key?(foreign_key)
+    target = foreign_key.to_table.split('.').last
+    schema = Gitlab::Database::GitlabSchema.table_schema!(target)
+    schema == :gitlab_ci &&
+      Array.wrap(foreign_key.column).many? &&
+      foreign_key.column.first.end_with?('partition_id')
+  end
+
   context 'for table' do
     Gitlab::Database::EachDatabase.each_connection do |connection, _|
       schemas_for_connection = Gitlab::Database.gitlab_schemas_for_connection(connection)
@@ -311,7 +324,7 @@ RSpec.describe 'Database schema',
 
           context 'with all foreign keys' do
             # for index to be effective, the FK constraint has to be at first place
-            it 'are indexed' do
+            it 'are indexed', :aggregate_failures do
               indexed_columns = indexes.filter_map do |index|
                 columns = index.columns
 
@@ -324,22 +337,20 @@ RSpec.describe 'Database schema',
                 columns if index.where.nil? || index.where == "(#{columns.first} IS NOT NULL)"
               end
 
-              foreign_keys_columns = all_foreign_keys.filter_map do |fk|
-                conditions = fk.options[:conditions]
-                next fk.column unless conditions&.any?
-
-                [fk.column, *conditions.map { |c| c[:column] }]
+              required_indexed_foreign_keys = all_foreign_keys.reject do |fk|
+                ci_partitioned_foreign_key?(fk) ||
+                  fk.options[:conditions]&.any?
               end
 
-              required_indexed_columns = to_columns(foreign_keys_columns - ignored_index_columns(table))
-
               # Add the composite primary key to the list of indexed columns because
               # postgres and mysql both automatically create an index on the primary
               # key. Also, the rails connection.indexes() method does not return
               # automatically generated indexes (like the primary key index).
               indexed_columns.push(composite_primary_key)
 
-              expect(required_indexed_columns).to be_indexed_by(indexed_columns)
+              required_indexed_foreign_keys.each do |required_indexed_foreign_key| # rubocop:disable RSpec/IteratedExpectation -- We want to aggregate all failures
+                expect(required_indexed_foreign_key).to be_indexed_by(indexed_columns)
+              end
             end
           end
 
@@ -410,6 +421,7 @@ RSpec.describe 'Database schema',
     # These pre-existing enums have limits > 2 bytes
     let(:ignored_limit_enums_map) do
       {
+        'Ai::UsageEvent' => %w[event],
         'Analytics::CycleAnalytics::Stage' => %w[start_event_identifier end_event_identifier],
         'Ci::Bridge' => %w[failure_reason],
         'Ci::Build' => %w[failure_reason],
@@ -430,7 +442,7 @@ RSpec.describe 'Database schema',
         'Project' => %w[auto_cancel_pending_pipelines],
         'ProjectAutoDevops' => %w[deploy_strategy],
         'ResourceLabelEvent' => %w[action],
-        'User' => %w[layout dashboard project_view],
+        'User' => %w[layout dashboard project_view role],
         'Users::Callout' => %w[feature_name],
         'Vulnerability' => %w[confidence] # this enum is in the process of being deprecated
       }.freeze
@@ -459,7 +471,7 @@ RSpec.describe 'Database schema',
         "ApplicationSetting" => %w[repository_storages_weighted oauth_provider rate_limits_unauthenticated_git_http],
         "AlertManagement::Alert" => %w[payload],
         "AlertManagement::HttpIntegration" => %w[payload_example],
-        "Ci::BuildMetadata" => %w[config_options config_variables runtime_runner_features],
+        "Ci::BuildMetadata" => %w[config_options config_variables],
         "Ci::Runner" => %w[config],
         "ExperimentSubject" => %w[context],
         "ExperimentUser" => %w[context],
@@ -474,7 +486,7 @@ RSpec.describe 'Database schema',
         "Sbom::Occurrence" => %w[ancestors],
         "Security::ApprovalPolicyRule" => %w[content],
         "Security::Policy" => %w[metadata],
-        "ServicePing::NonSqlServicePing" => %w[payload], # Usage data payload changes often, we cannot use one schema
+        "ServicePing::NonSqlServicePing" => %w[payload metadata], # Usage data payloads change often, we cannot use one schema
         "ServicePing::QueriesServicePing" => %w[payload], # Usage data payload changes often, we cannot use one schema
         "Security::ScanExecutionPolicyRule" => %w[content],
         "Security::VulnerabilityManagementPolicyRule" => %w[content],
@@ -502,7 +514,8 @@ RSpec.describe 'Database schema',
       FAILURE_MESSAGE
     end
 
-    it 'uses json schema validator', :eager_load, :aggregate_failures, quarantine: 'https://gitlab.com/gitlab-org/gitlab/-/issues/500903' do
+    it 'uses json schema validator', :eager_load, :aggregate_failures,
+      quarantine: 'https://gitlab.com/gitlab-org/gitlab/-/issues/500903' do
       columns_name_with_jsonb.each do |jsonb_column|
         column_name = jsonb_column["column_name"]
         models = models_by_table_name[jsonb_column["table_name"]] || []
@@ -685,10 +698,6 @@ RSpec.describe 'Database schema',
     removed_fks_map.merge(ignored_fk_columns_map).fetch(table, [])
   end
 
-  def ignored_index_columns(table)
-    ignored_indexes_on_fks_map.fetch(table, [])
-  end
-
   def ignored_limit_enums(model)
     ignored_limit_enums_map.fetch(model, [])
   end
