@@ -6,7 +6,6 @@ FactoryBot.define do
     name { generate(:name) }
     username { generate(:username) }
     password { User.random_password }
-    role { 'software_developer' }
     confirmed_at { Time.now }
     confirmation_token { nil }
     can_create_group { true }
@@ -14,6 +13,26 @@ FactoryBot.define do
     color_mode_id { 1 }
 
     after(:build) do |user, evaluator|
+      owner_of = [evaluator.owner_of].grep(Organizations::Organization).first
+      overrides = evaluator.instance_variable_get(:@overrides) || {}
+
+      if overrides.key?(:organizations)
+        user.organizations = overrides.fetch(:organizations, [])
+      end
+
+      if user.organizations.any?
+        user.organization ||= user.organizations.first
+      end
+
+      user.organization ||= owner_of || create(:common_organization)
+
+      # Ensure user.organization will be added to user.organizations
+      # except when the organizations is explicitly overridden
+      # except when 'owner_of' is set
+      unless owner_of || overrides.key?(:organizations) || user.organizations.include?(user.organization)
+        user.organizations << user.organization
+      end
+
       # UserWithNamespaceShim is not defined in gdk reset-data. We assume the shim is enabled in this case.
       assign_ns = if defined?(UserWithNamespaceShim)
                     UserWithNamespaceShim.enabled?
@@ -22,27 +41,15 @@ FactoryBot.define do
                   end
 
       if assign_ns
-        org = user&.namespace&.organization ||
-          Organizations::Organization
-            .where(visibility_level: Gitlab::VisibilityLevel::PUBLIC)
-            .order(:created_at).first ||
-          # We create an organization next even though we are building here. We need to ensure
-          # that an organization exists so other entities can belong to the same organization
-          create(:organization)
-
-        user.assign_personal_namespace(org)
+        user.assign_personal_namespace(user.organization)
       end
     end
 
-    trait :without_default_org do
-      before(:create) { |user| user.define_singleton_method(:create_default_organization_user) { nil } }
-    end
-
+    # rubocop:disable RSpec/FactoryBot/InlineAssociation -- we don't use an association here
     trait :with_namespace do
-      # rubocop: disable RSpec/FactoryBot/InlineAssociation -- We need to pass an Organization to this method
-      namespace { assign_personal_namespace(create(:organization)) }
-      # rubocop: enable RSpec/FactoryBot/InlineAssociation
+      namespace { assign_personal_namespace(organization || create(:common_organization)) }
     end
+    # rubocop:enable RSpec/FactoryBot/InlineAssociation
 
     trait :admin do
       admin { true }
