@@ -145,7 +145,7 @@ RSpec.describe 'Admin updates settings', feature_category: :shared do
         user_internal_regex = find('#application_setting_user_default_internal_regex', visible: :all)
 
         expect(user_internal_regex).to be_readonly
-        expect(user_internal_regex['placeholder']).to eq 'To define internal users, first enable new users set to external'
+        expect(user_internal_regex['placeholder']).to eq 'Regex pattern. To use, select external by default setting'
 
         check 'application_setting_user_default_external'
 
@@ -289,6 +289,19 @@ RSpec.describe 'Admin updates settings', feature_category: :shared do
         expect(page).to have_current_path(general_admin_application_settings_path, ignore_query: true)
       end
 
+      context 'for project and group access tokens settings' do
+        it 'changes inactive_resource_access_tokens_delete_after_days' do
+          expect(current_settings.inactive_resource_access_tokens_delete_after_days).to eq 30
+
+          within_testid('account-and-limit-settings-content') do
+            fill_in 'Inactive project and group access token retention period', with: '42'
+            click_button 'Save changes'
+          end
+
+          expect(current_settings.inactive_resource_access_tokens_delete_after_days).to eq 42
+        end
+      end
+
       it 'modify oauth providers' do
         expect(current_settings.disabled_oauth_sign_in_sources).to be_empty
 
@@ -416,6 +429,37 @@ RSpec.describe 'Admin updates settings', feature_category: :shared do
           expect(page).to have_content 'Application settings saved successfully'
         end
       end
+
+      describe 'Analytics reports settings', feature_category: :value_stream_management do
+        before do
+          allow(Gitlab::ClickHouse).to receive(:configured?).and_return(true)
+        end
+
+        it 'enables clickhouse settings' do
+          visit general_admin_application_settings_path
+
+          page.within('#js-analytics-settings') do
+            check 'Enable ClickHouse'
+
+            click_button 'Save changes'
+          end
+
+          expect(page).to have_content 'Application settings saved successfully'
+          expect(current_settings.use_clickhouse_for_analytics).to be_truthy
+        end
+
+        context 'when ClickHouse is not configured' do
+          it 'disables checkbox to enable ClickHouse' do
+            allow(Gitlab::ClickHouse).to receive(:configured?).and_return(false)
+
+            visit general_admin_application_settings_path
+
+            page.within('#js-analytics-settings') do |page|
+              expect(page).to have_field('application_setting_use_clickhouse_for_analytics', disabled: true)
+            end
+          end
+        end
+      end
     end
 
     context 'Integrations page' do
@@ -548,17 +592,17 @@ RSpec.describe 'Admin updates settings', feature_category: :shared do
       end
 
       context 'Job token permissions' do
-        it 'allows admin to set allowlist enforcement' do
+        it 'allows admin to toggle allowlist enforcement' do
           visit ci_cd_admin_application_settings_path
 
-          expect(current_settings.enforce_ci_inbound_job_token_scope_enabled).to eq(false)
+          expect(current_settings.enforce_ci_inbound_job_token_scope_enabled).to eq(true)
 
           within_testid('job-token-permissions-settings') do
             find('input[type="checkbox"]').click
             click_button 'Save changes'
           end
 
-          expect(current_settings.enforce_ci_inbound_job_token_scope_enabled).to eq(true)
+          expect(current_settings.enforce_ci_inbound_job_token_scope_enabled).to eq(false)
           expect(page).to have_content 'Application settings saved successfully'
         end
       end
@@ -831,6 +875,67 @@ RSpec.describe 'Admin updates settings', feature_category: :shared do
         )
       end
 
+      context 'when git_authenticated_http_limit feature flag is enabled' do
+        before do
+          stub_feature_flags(git_authenticated_http_limit: true)
+        end
+
+        it 'changes authenticated Git HTTP rate limits settings' do
+          visit network_admin_application_settings_path
+
+          # Default settings
+          expect(current_settings.throttle_authenticated_git_http_enabled)
+            .to eq(false)
+          expect(current_settings.throttle_authenticated_git_http_requests_per_period)
+            .to eq(ApplicationSetting::DEFAULT_AUTHENTICATED_GIT_HTTP_PERIOD)
+          expect(current_settings.throttle_authenticated_git_http_period_in_seconds)
+            .to eq(ApplicationSetting::DEFAULT_AUTHENTICATED_GIT_HTTP_LIMIT)
+
+          within_testid('git-http-limits-settings') do
+            check 'Enable unauthenticated Git HTTP request rate limit'
+
+            fill_in(
+              'Maximum authenticated Git HTTP requests per period per user',
+              with: ApplicationSetting::DEFAULT_AUTHENTICATED_GIT_HTTP_LIMIT + 1
+            )
+
+            fill_in(
+              'Authenticated Git HTTP rate limit period in seconds',
+              with: ApplicationSetting::DEFAULT_AUTHENTICATED_GIT_HTTP_PERIOD + 2
+            )
+
+            click_button 'Save changes'
+          end
+
+          expect(page).to have_content 'Application settings saved successfully'
+
+          expect(current_settings.throttle_authenticated_git_http_enabled)
+            .to eq(false)
+
+          expect(current_settings.throttle_authenticated_git_http_requests_per_period)
+            .to eq(ApplicationSetting::DEFAULT_AUTHENTICATED_GIT_HTTP_PERIOD + 1)
+
+          expect(current_settings.throttle_authenticated_git_http_period_in_seconds)
+            .to eq(ApplicationSetting::DEFAULT_AUTHENTICATED_GIT_HTTP_LIMIT + 2)
+        end
+      end
+
+      context 'when git_authenticated_http_limit feature flag is disabled' do
+        before do
+          stub_feature_flags(git_authenticated_http_limit: false)
+        end
+
+        it 'does not show authenticated Git HTTP rate limit settings' do
+          stub_feature_flags(git_authenticated_http_limit: false)
+          visit network_admin_application_settings_path
+
+          within_testid('git-http-limits-settings') do
+            expect(page).not_to have_content('Authenticated Git HTTP request rate limit')
+            expect(page).not_to have_field('Enable authenticated Git HTTP request rate limit')
+          end
+        end
+      end
+
       it 'changes Issues rate limits settings' do
         visit network_admin_application_settings_path
 
@@ -1045,6 +1150,16 @@ RSpec.describe 'Admin updates settings', feature_category: :shared do
 
           it_behaves_like 'API rate limit setting'
         end
+
+        context 'for POST /groups/:id/archive API requests' do
+          let(:rate_limit_field) do
+            format(_('Maximum requests to the %{api_name} API per %{timeframe} per user or IP address'), api_name: 'POST /groups/:id/archive and POST /groups/:id/unarchive', timeframe: 'minute')
+          end
+
+          let(:application_setting_key) { :group_archive_unarchive_api_limit }
+
+          it_behaves_like 'API rate limit setting'
+        end
       end
 
       describe 'projects API rate limits' do
@@ -1274,7 +1389,7 @@ RSpec.describe 'Admin updates settings', feature_category: :shared do
 
     context 'Nav bar', :js do
       it 'shows default help links in nav' do
-        default_support_url = "https://#{ApplicationHelper.promo_host}/get-help/"
+        default_support_url = Gitlab::Routing.url_helpers.promo_url(path: '/get-help/')
 
         visit root_dashboard_path
 
