@@ -4,11 +4,12 @@
 
 require 'spec_helper'
 
-RSpec.describe 'Dashboard Todos', :js, feature_category: :notifications do
+RSpec.describe 'Dashboard Todos', :js, :with_organization_url_helpers, feature_category: :notifications do
   include DesignManagementTestHelpers
 
   let_it_be(:user) { create(:user) }
-  let_it_be(:user2) { create(:user, name: 'Michael Scott') }
+  let_it_be(:current_organization) { user.organization }
+  let_it_be(:user2) { create(:user) }
   let_it_be(:author) { create(:user) }
   let_it_be(:project) { create(:project, :public, developers: user) }
   let_it_be(:issue) { create(:issue, project: project, due_date: Date.today, title: "Fix bug") }
@@ -21,6 +22,10 @@ RSpec.describe 'Dashboard Todos', :js, feature_category: :notifications do
 
   it_behaves_like 'a "Your work" page with sidebar and breadcrumbs', :dashboard_todos_path, :todos
 
+  it_behaves_like 'page with product usage data collection banner' do
+    let(:page_path) { dashboard_todos_path }
+  end
+
   context 'when the todo references a merge request' do
     let(:referenced_mr) { create(:merge_request, source_project: project) }
     let(:note) { create(:note, project: project, note: "Check out #{referenced_mr.to_reference}", noteable: create(:issue, project: project)) }
@@ -132,7 +137,7 @@ RSpec.describe 'Dashboard Todos', :js, feature_category: :notifications do
       it 'shows you set yourself as an approver message' do
         within_testid('todo-item-list-container') do
           expect(page).to have_content("Fixes issue · #{project.namespace.owner_name} / #{project.name} #{merge_request.to_reference}")
-          expect(page).to have_content("You set yourself as an approver.")
+          expect(page).to have_content("You created a merge request you can approve.")
         end
       end
     end
@@ -355,7 +360,8 @@ RSpec.describe 'Dashboard Todos', :js, feature_category: :notifications do
     end
 
     it 'allows to mark a pending todo as done and find it in the Done tab' do
-      expect(page).to have_content 'Michael Scott assigned you.'
+      assigned_you_str = "#{todo_assigned.author.name} assigned you."
+      expect(page).to have_content assigned_you_str
       expect(page).to have_content 'You added a to-do item.'
       expect(page).to have_content 'To Do 2'
 
@@ -364,9 +370,9 @@ RSpec.describe 'Dashboard Todos', :js, feature_category: :notifications do
       end
       wait_for_requests
       click_on 'Done'
-      expect(page).to have_content 'Michael Scott assigned you.'
+      expect(page).to have_content assigned_you_str
       click_on 'To Do 1'
-      expect(page).not_to have_content 'Michael Scott assigned you.'
+      expect(page).not_to have_content assigned_you_str
     end
   end
 
@@ -380,7 +386,7 @@ RSpec.describe 'Dashboard Todos', :js, feature_category: :notifications do
     end
 
     it 'allows to change sort order and direction' do
-      # default sort is by `created_at` (desc)
+      # default sort is by `timestamp_coalesce(todos.snoozed_until, todos.created_at)` (desc)
       expect(page).to have_content(
         /#{newest_but_never_updated.target.title}.*#{middle_old_and_middle_updated.target.title}.*#{oldest_but_most_recently_updated.target.title}/
       )
@@ -392,7 +398,7 @@ RSpec.describe 'Dashboard Todos', :js, feature_category: :notifications do
       )
 
       # change order
-      click_on 'Created' # to open order dropdown
+      click_on 'Recommended' # to open order dropdown
       find('li', text: 'Updated').click # to change to `updated_at`
       expect(page).to have_content(
         /#{newest_but_never_updated.target.title}.*#{middle_old_and_middle_updated.target.title}.*#{oldest_but_most_recently_updated.target.title}/
@@ -464,60 +470,6 @@ RSpec.describe 'Dashboard Todos', :js, feature_category: :notifications do
     end
   end
 
-  describe '"Mark all as done" button' do
-    it 'does not show' do
-      create_todo
-      visit dashboard_todos_path
-      expect(page).not_to have_content 'Mark all as done'
-    end
-
-    context 'with todos_bulk_actions feature disabled' do
-      before do
-        stub_feature_flags(todos_bulk_actions: false)
-      end
-
-      context 'with no pending todos' do
-        it 'does not show' do
-          visit dashboard_todos_path
-          expect(page).not_to have_content 'Mark all as done'
-        end
-      end
-
-      context 'with pending todos' do
-        let_it_be(:self_assigned) { create_todo(author: user, target: issue) }
-        let_it_be(:self_marked) { create_todo(author: user, target: issue2, action: :marked) }
-        let_it_be(:other_assigned) { create_todo(author: user2, target: issue3) }
-
-        context 'with no filters applied' do
-          it 'marks all pending todos as done' do
-            visit dashboard_todos_path
-            click_on 'Mark all as done'
-
-            expect(page).to have_content 'Not sure where to go next?'
-            within('.gl-toast') do
-              expect(page).to have_content 'Marked 3 to-dos as done'
-              find('a.gl-toast-action', text: 'Undo').click
-            end
-            expect(page).to have_content 'Restored 3 to-dos'
-            expect(page).to have_selector('ol[data-testid="todo-item-list"] > li', count: 3)
-          end
-        end
-
-        context 'with filters applied' do
-          it 'only marks the filtered todos as done' do
-            visit dashboard_todos_path(author_id: user.id)
-            click_on 'Mark all as done'
-
-            expect(page).to have_content 'Sorry, your filter produced no results'
-            click_on 'Clear'
-            expect(page).to have_selector('ol[data-testid="todo-item-list"] > li', count: 1)
-            expect(page).to have_content(other_assigned.author.name)
-          end
-        end
-      end
-    end
-  end
-
   def create_todo(action: :assigned, state: :pending, created_at: nil, updated_at: nil, target: issue, author: user2)
     create(
       :todo,
