@@ -14,7 +14,6 @@ RSpec.describe 'Pipelines', :js, feature_category: :continuous_integration do
     let(:user) { create(:user) }
 
     before do
-      stub_feature_flags(ci_inputs_for_pipelines: false)
       sign_in(user)
 
       project.add_developer(user)
@@ -118,7 +117,7 @@ RSpec.describe 'Pipelines', :js, feature_category: :continuous_integration do
           end
 
           context 'when canceling' do
-            it 'indicates that pipelines was canceled', :sidekiq_inline do
+            it 'indicates that pipeline was canceled', :sidekiq_inline, quarantine: 'https://gitlab.com/gitlab-org/gitlab/-/issues/541901' do
               find('.js-pipelines-cancel-button').click
               click_button 'Stop pipeline'
 
@@ -128,7 +127,7 @@ RSpec.describe 'Pipelines', :js, feature_category: :continuous_integration do
               expect(page).to have_selector('[data-testid="ci-icon"]', text: 'Canceled')
             end
 
-            it 'targets the pipeline the cancel action was invoked on' do
+            it 'targets the pipeline the cancel action was invoked on', quarantine: 'https://gitlab.com/gitlab-org/gitlab/-/issues/514513' do
               allow_next_instance_of(Gitlab::EtagCaching::Store) do |instance|
                 allow(instance).to receive(:get).and_return(nil)
               end
@@ -305,7 +304,7 @@ RSpec.describe 'Pipelines', :js, feature_category: :continuous_integration do
         it 'contains badge with tooltip which contains error' do
           expect(pipeline).to have_yaml_errors
           expect(page).to have_selector(
-            %(span[title="#{pipeline.yaml_errors}"]))
+            %(button[title="#{pipeline.yaml_errors}"]))
         end
 
         it 'contains badge that indicates failure reason' do
@@ -315,7 +314,7 @@ RSpec.describe 'Pipelines', :js, feature_category: :continuous_integration do
         it 'contains badge with tooltip which contains failure reason' do
           expect(pipeline.failure_reason?).to eq true
           expect(page).to have_selector(
-            %(span[title="#{pipeline.present.failure_reason}"]))
+            %(button[title="#{pipeline.present.failure_reason}"]))
         end
       end
 
