@@ -6,6 +6,7 @@ import {
   GlPopover,
   GlModal,
   GlFormCheckbox,
+  GlAnimatedChevronRightDownIcon,
 } from '@gitlab/ui';
 import Vue, { nextTick } from 'vue';
 import VueApollo from 'vue-apollo';
@@ -57,6 +58,7 @@ describe('JobArtifactsTable component', () => {
 
   const findCount = () => wrapper.findByTestId('job-artifacts-count');
   const findCountAt = (i) => wrapper.findAllByTestId('job-artifacts-count').at(i);
+  const findCountIcon = () => findCount().findComponent(GlAnimatedChevronRightDownIcon);
 
   const findDeleteModal = () => wrapper.findComponent(ArtifactDeleteModal);
   const findBulkDeleteModal = () => wrapper.findComponent(BulkDeleteModal);
@@ -268,22 +270,25 @@ describe('JobArtifactsTable component', () => {
     });
 
     it('shows the created time', () => {
-      expect(findCreated().text()).toBe('5 years ago');
+      expect(findCreated().text()).toBe('Jul 3, 2015');
     });
 
     describe('row expansion', () => {
       it('toggles the visibility of the row details', async () => {
-        expect(findDetailsRows().length).toBe(0);
+        expect(findDetailsRows()).toHaveLength(0);
+        expect(findCountIcon().props('isOn')).toBe(false);
 
         findCount().trigger('click');
         await nextTick();
 
-        expect(findDetailsRows().length).toBe(1);
+        expect(findDetailsRows()).toHaveLength(1);
+        expect(findCountIcon().props('isOn')).toBe(true);
 
         findCount().trigger('click');
         await nextTick();
 
-        expect(findDetailsRows().length).toBe(0);
+        expect(findDetailsRows()).toHaveLength(0);
+        expect(findCountIcon().props('isOn')).toBe(false);
       });
 
       it('expands and collapses jobs', async () => {
