@@ -9,9 +9,11 @@ import { getDiffFileMock } from 'jest/diffs/mock_data/diff_file';
 import {
   DIFF_VIEW_COOKIE_NAME,
   INLINE_DIFF_VIEW_TYPE,
+  INLINE_DIFF_LINES_KEY,
   PARALLEL_DIFF_VIEW_TYPE,
   EVT_MR_PREPARED,
   FILE_DIFF_POSITION_TYPE,
+  OLD_LINE_TYPE,
 } from '~/diffs/constants';
 import {
   BUILDING_YOUR_MR,
@@ -1321,6 +1323,137 @@ describe('legacyDiffs actions', () => {
     });
   });
 
+  describe('getLinesForDiscussion', () => {
+    it('returns empty array when discussion is null or undefined', () => {
+      expect(store.getLinesForDiscussion({ discussion: null })).toEqual([]);
+      expect(store.getLinesForDiscussion({ discussion: undefined })).toEqual([]);
+    });
+
+    it('returns empty array when discussion has no position', () => {
+      const result = store.getLinesForDiscussion({ discussion: {} });
+      expect(result).toEqual([]);
+    });
+
+    it('returns empty array when line_range is missing', () => {
+      const discussion = { position: {} };
+      const result = store.getLinesForDiscussion({ discussion });
+      expect(result).toEqual([]);
+    });
+
+    it('returns empty array when diffFile is not found', () => {
+      const discussion = {
+        diff_file: { file_hash: 'nonexistent_hash' },
+        position: {
+          line_range: {
+            start: { line_code: 'start_line' },
+            end: { line_code: 'end_line' },
+          },
+        },
+      };
+
+      store.diffFiles = [{ file_hash: 'different_hash' }];
+
+      const result = store.getLinesForDiscussion({ discussion });
+      expect(result).toEqual([]);
+    });
+
+    it('returns correct lines for a valid discussion', () => {
+      const diffLines = [
+        { line_code: 'line1', type: 'new' },
+        { line_code: 'line2', type: 'new' },
+        { line_code: 'line3', type: 'new' },
+        { line_code: 'line4', type: 'new' },
+        { line_code: 'line5', type: 'new' },
+      ];
+
+      const diffFile = {
+        file_hash: 'abc123',
+        [INLINE_DIFF_LINES_KEY]: diffLines,
+      };
+
+      const discussion = {
+        diff_file: { file_hash: 'abc123' },
+        position: {
+          line_range: {
+            start: { line_code: 'line2' },
+            end: { line_code: 'line4' },
+          },
+        },
+      };
+
+      store.diffFiles = [diffFile];
+
+      const result = store.getLinesForDiscussion({ discussion });
+      expect(result).toEqual([
+        { line_code: 'line2', type: 'new' },
+        { line_code: 'line3', type: 'new' },
+        { line_code: 'line4', type: 'new' },
+      ]);
+    });
+
+    it('excludes old lines from the result', () => {
+      const diffLines = [
+        { line_code: 'line1', type: 'new' },
+        { line_code: 'line2', type: OLD_LINE_TYPE },
+        { line_code: 'line3', type: 'new' },
+        { line_code: 'line4', type: OLD_LINE_TYPE },
+        { line_code: 'line5', type: 'new' },
+      ];
+
+      const diffFile = {
+        file_hash: 'abc123',
+        [INLINE_DIFF_LINES_KEY]: diffLines,
+      };
+
+      const discussion = {
+        diff_file: { file_hash: 'abc123' },
+        position: {
+          line_range: {
+            start: { line_code: 'line1' },
+            end: { line_code: 'line5' },
+          },
+        },
+      };
+
+      store.diffFiles = [diffFile];
+
+      const result = store.getLinesForDiscussion({ discussion });
+      expect(result).toEqual([
+        { line_code: 'line1', type: 'new' },
+        { line_code: 'line3', type: 'new' },
+        { line_code: 'line5', type: 'new' },
+      ]);
+    });
+
+    it('handles case when start and end are the same line', () => {
+      const diffLines = [
+        { line_code: 'line1', type: 'new' },
+        { line_code: 'line2', type: 'new' },
+        { line_code: 'line3', type: 'new' },
+      ];
+
+      const diffFile = {
+        file_hash: 'abc123',
+        [INLINE_DIFF_LINES_KEY]: diffLines,
+      };
+
+      const discussion = {
+        diff_file: { file_hash: 'abc123' },
+        position: {
+          line_range: {
+            start: { line_code: 'line2' },
+            end: { line_code: 'line2' },
+          },
+        },
+      };
+
+      store.diffFiles = [diffFile];
+
+      const result = store.getLinesForDiscussion({ discussion });
+      expect(result).toEqual([{ line_code: 'line2', type: 'new' }]);
+    });
+  });
+
   describe('toggleTreeOpen', () => {
     it('commits TOGGLE_FOLDER_OPEN', () => {
       return testAction(
@@ -1423,7 +1556,7 @@ describe('legacyDiffs actions', () => {
 
   describe('scrollToFile', () => {
     beforeEach(() => {
-      getters = { isVirtualScrollingEnabled: false };
+      store.virtualScrollerDisabled = true;
     });
 
     it('updates location hash', () => {
@@ -2523,6 +2656,46 @@ describe('legacyDiffs actions', () => {
         });
       });
 
+      it('expands lines upwards when the match line is after the target line', async () => {
+        const linkedFile = {
+          file_hash: 'abc123',
+          context_lines_path: `${TEST_HOST}/linked-file`,
+          highlighted_diff_lines: [
+            { old_line: 250, new_line: 250 },
+            { meta_data: { old_pos: 300, new_pos: 300 } },
+            { old_line: 300, new_line: 300 },
+          ],
+        };
+
+        store.$patch({
+          diffFiles: [linkedFile],
+          linkedFileHash: linkedFile.file_hash,
+        });
+
+        await store.fetchLinkedExpandedLine({
+          fileHash: linkedFile.file_hash,
+          oldLine: 286,
+          newLine: 286,
+        });
+
+        expect(store.loadMoreLines).toHaveBeenCalledWith({
+          endpoint: linkedFile.context_lines_path,
+          fileHash: linkedFile.file_hash,
+          isExpandDown: false,
+          lineNumbers: {
+            oldLineNumber: 300,
+            newLineNumber: 300,
+          },
+          params: {
+            bottom: false,
+            offset: 0,
+            since: 286,
+            to: 299,
+            unfold: true,
+          },
+        });
+      });
+
       it('expands lines at the very bottom', async () => {
         const linkedFile = {
           file_hash: 'abc123',
@@ -2562,4 +2735,25 @@ describe('legacyDiffs actions', () => {
       });
     });
   });
+
+  describe('setCurrentFileHash', () => {
+    it('commits SET_CURRENT_DIFF_FILE if hash does not start with note_', () => {
+      return testAction(
+        store.setCurrentFileHash,
+        'filehash',
+        {},
+        [
+          {
+            type: store[types.SET_CURRENT_DIFF_FILE],
+            payload: 'filehash',
+          },
+        ],
+        [],
+      );
+    });
+
+    it('does not commit SET_CURRENT_DIFF_FILE if hash starts with note_', () => {
+      return testAction(store.setCurrentFileHash, 'note_filehash', {}, [], []);
+    });
+  });
 });
