@@ -34,7 +34,7 @@ describe('tags list row', () => {
   const tagWithOCIMediaType = tagsMock[2];
   const tagWithListMediaType = tagsMock[3];
 
-  const defaultProps = { tag, isMobile: false, index: 0 };
+  const defaultProps = { tag, isMobile: false, index: 0, canDelete: true };
 
   const findCheckbox = () => wrapper.findComponent(GlFormCheckbox);
   const findName = () => wrapper.findByTestId('name');
@@ -59,7 +59,7 @@ describe('tags list row', () => {
   const findProtectedBadge = () => wrapper.findByTestId('protected-badge');
   const findProtectedPopover = () => wrapper.findByTestId('protected-popover');
 
-  const mountComponent = (propsData = defaultProps, protectedTagsFeatureFlagState = false) => {
+  const mountComponent = (propsData = defaultProps) => {
     wrapper = shallowMountExtended(TagsListRow, {
       stubs: {
         GlSprintf,
@@ -70,11 +70,6 @@ describe('tags list row', () => {
       },
       propsData,
       directives: { GlTooltip: createMockDirective('gl-tooltip') },
-      provide: {
-        glFeatures: {
-          containerRegistryProtectedTags: protectedTagsFeatureFlagState,
-        },
-      },
     });
   };
 
@@ -85,10 +80,8 @@ describe('tags list row', () => {
       expect(findCheckbox().exists()).toBe(true);
     });
 
-    it("does not exist when the row can't be deleted", () => {
-      const customTag = { ...tag, userPermissions: { destroyContainerRepositoryTag: false } };
-
-      mountComponent({ ...defaultProps, tag: customTag });
+    it('is hidden when canDelete is false', () => {
+      mountComponent({ ...defaultProps, canDelete: false });
 
       expect(findCheckbox().exists()).toBe(false);
     });
@@ -102,7 +95,7 @@ describe('tags list row', () => {
     `(
       'disabled attribute is set to $isDisabled when the digest $digest and disabled is $disabled',
       ({ digest, disabled, isDisabled }) => {
-        mountComponent({ tag: { ...tag, digest }, disabled });
+        mountComponent({ ...defaultProps, tag: { ...tag, digest }, disabled });
 
         expect(findCheckbox().attributes().disabled).toBe(isDisabled);
       },
@@ -180,41 +173,35 @@ describe('tags list row', () => {
 
   describe('protected tag', () => {
     it('hidden if tag.protection does not exists', () => {
-      mountComponent(defaultProps, true);
+      mountComponent(defaultProps);
 
       expect(findProtectedBadge().exists()).toBe(false);
     });
 
     it('displays if tag.protection exists', () => {
-      mountComponent(
-        {
-          ...defaultProps,
-          tag: {
-            ...tag,
-            protection: {
-              ...protection,
-            },
+      mountComponent({
+        ...defaultProps,
+        tag: {
+          ...tag,
+          protection: {
+            ...protection,
           },
         },
-        true,
-      );
+      });
 
-      expect(findProtectedBadge().exists()).toBe(true);
+      expect(findProtectedBadge().text()).toBe('protected');
     });
 
     it('has the correct text for the popover', () => {
-      mountComponent(
-        {
-          ...defaultProps,
-          tag: {
-            ...tag,
-            protection: {
-              ...protection,
-            },
+      mountComponent({
+        ...defaultProps,
+        tag: {
+          ...tag,
+          protection: {
+            ...protection,
           },
         },
-        true,
-      );
+      });
 
       const popoverText = findProtectedPopover().text();
 
@@ -366,11 +353,8 @@ describe('tags list row', () => {
       expect(findAdditionalActionsMenu().classes('gl-pointer-events-none')).toBe(false);
     });
 
-    it('is not rendered when tag.userPermissions.destroyContainerRegistryTag is false', () => {
-      mountComponent({
-        ...defaultProps,
-        tag: { ...tag, userPermissions: { destroyContainerRepositoryTag: false } },
-      });
+    it('is not rendered when canDelete is false', () => {
+      mountComponent({ ...defaultProps, canDelete: false });
 
       expect(findAdditionalActionsMenu().exists()).toBe(false);
     });
@@ -412,14 +396,14 @@ describe('tags list row', () => {
         mountComponent();
         await nextTick();
 
-        expect(findDetailsRows().length).toBe(3);
+        expect(findDetailsRows()).toHaveLength(3);
       });
 
       it('has 2 details rows when revision is empty', async () => {
         mountComponent({ tag: { ...tag, revision: '' } });
         await nextTick();
 
-        expect(findDetailsRows().length).toBe(2);
+        expect(findDetailsRows()).toHaveLength(2);
       });
 
       describe.each`
@@ -481,7 +465,7 @@ describe('tags list row', () => {
         mountComponent({ tag: { ...tag, digest: null } });
 
         await nextTick();
-        expect(findDetailsRows().length).toBe(0);
+        expect(findDetailsRows()).toHaveLength(0);
       });
     });
   });
@@ -608,4 +592,22 @@ describe('tags list row', () => {
       expect(findSize().exists()).toBe(expectedSize);
     });
   });
+
+  describe('when `selectable` prop is false', () => {
+    beforeEach(() => {
+      mountComponent({ ...defaultProps, selectable: false });
+    });
+
+    it('disables checkbox', () => {
+      expect(findCheckbox().attributes().disabled).toBe('true');
+    });
+
+    it('disables additional actions menu', () => {
+      expect(findAdditionalActionsMenu().props('disabled')).toBe(true);
+    });
+
+    it('does not disable clipboard button', () => {
+      expect(findClipboardButton().attributes('disabled')).not.toBeDefined();
+    });
+  });
 });
