@@ -11,7 +11,7 @@ import axios from '~/lib/utils/axios_utils';
 import setWindowLocation from 'helpers/set_window_location_helper';
 import { HTTP_STATUS_INTERNAL_SERVER_ERROR, HTTP_STATUS_OK } from '~/lib/utils/http_status';
 import * as urlUtils from '~/lib/utils/url_utility';
-import * as actions from '~/search/store/actions';
+
 import {
   GROUPS_LOCAL_STORAGE_KEY,
   PROJECTS_LOCAL_STORAGE_KEY,
@@ -22,6 +22,7 @@ import {
 import * as types from '~/search/store/mutation_types';
 import createState from '~/search/store/state';
 import * as storeUtils from '~/search/store/utils';
+import * as actions from '~/search/store/actions';
 import {
   MOCK_QUERY,
   MOCK_GROUPS,
@@ -174,7 +175,7 @@ describe('Global Search Store Actions', () => {
   });
 
   describe('setQuery', () => {
-    describe('when search type is zoekt and scope is blob with zoektMultimatchFrontend feature enabled', () => {
+    describe('when search type is zoekt and scope is blob', () => {
       const payload = { key: 'some-key', value: 'some-value' };
       let originalGon;
       let commit;
@@ -188,7 +189,7 @@ describe('Global Search Store Actions', () => {
           .spyOn(actions, 'fetchSidebarCount')
           .mockImplementation(() => Promise.resolve());
 
-        window.gon = { features: { zoektMultimatchFrontend: true } };
+        window.gon = { features: {} };
         storeUtils.isSidebarDirty = jest.fn().mockReturnValue(false);
 
         state = createState({
@@ -203,26 +204,12 @@ describe('Global Search Store Actions', () => {
         fetchSidebarCountSpy.mockRestore();
       });
 
-      it('should update URL, document title, and history', async () => {
+      it('should update URL, document title, and history', () => {
         const getters = { currentScope: 'blobs' };
 
-        await actions.setQuery({ state, commit, getters }, payload);
-
-        expect(setUrlParams).toHaveBeenCalledWith(
-          { ...state.query },
-          window.location.href,
-          false,
-          true,
-        );
-
-        expect(document.title).toBe(state.query.search);
-
-        expect(updateHistory).toHaveBeenCalledWith({
-          state: state.query,
-          title: state.query.search,
-          url: 'mocked-new-url',
-          replace: false,
-        });
+        return testAction(actions.setQuery, payload, { ...state, ...getters }, [
+          { type: types.SET_QUERY, payload: { key: 'some-key', value: 'some-value' } },
+        ]);
       });
 
       it('does not update URL or fetch sidebar counts when conditions are not met', async () => {
@@ -247,19 +234,6 @@ describe('Global Search Store Actions', () => {
         expect(setUrlParams).not.toHaveBeenCalled();
         expect(updateHistory).not.toHaveBeenCalled();
         expect(fetchSidebarCountSpy).not.toHaveBeenCalled();
-
-        setUrlParams.mockClear();
-        updateHistory.mockClear();
-        fetchSidebarCountSpy.mockClear();
-
-        getters = { currentScope: 'blobs' };
-        window.gon.features.zoektMultimatchFrontend = false;
-
-        await actions.setQuery({ state, commit, getters }, payload);
-
-        expect(setUrlParams).not.toHaveBeenCalled();
-        expect(updateHistory).not.toHaveBeenCalled();
-        expect(fetchSidebarCountSpy).not.toHaveBeenCalled();
       });
     });
 
@@ -271,7 +245,7 @@ describe('Global Search Store Actions', () => {
       describe(`when query param is ${payload.key}`, () => {
         beforeEach(() => {
           storeUtils.setDataToLS = jest.fn();
-          window.gon = { features: { zoektMultimatchFrontend: false } };
+          window.gon = { features: {} };
           const getters = { currentScope: 'not-blobs' };
           actions.setQuery({ state, commit: jest.fn(), getters }, payload);
         });
@@ -281,6 +255,156 @@ describe('Global Search Store Actions', () => {
         });
       });
     });
+
+    describe('zoekt search type with blob scope - page handling scenarios', () => {
+      let originalGon;
+      let commit;
+      let fetchSidebarCountSpy;
+      let modifySearchQuerySpy;
+
+      beforeEach(() => {
+        originalGon = window.gon;
+        commit = jest.fn();
+
+        fetchSidebarCountSpy = jest
+          .spyOn(actions, 'fetchSidebarCount')
+          .mockImplementation(() => Promise.resolve());
+
+        modifySearchQuerySpy = jest
+          .spyOn(storeUtils, 'modifySearchQuery')
+          .mockReturnValue('mocked-clean-url');
+
+        window.gon = { features: {} };
+        storeUtils.isSidebarDirty = jest.fn().mockReturnValue(false);
+        storeUtils.buildDocumentTitle = jest.fn().mockReturnValue('Built Document Title');
+
+        state = createState({
+          query: { ...MOCK_QUERY, search: 'test-search' },
+          navigation: { ...MOCK_NAVIGATION },
+          searchType: 'zoekt',
+        });
+      });
+
+      afterEach(() => {
+        window.gon = originalGon;
+        fetchSidebarCountSpy.mockRestore();
+        modifySearchQuerySpy.mockRestore();
+      });
+
+      describe('when only "page" attribute changes', () => {
+        it('should only update history without fetching sidebar counts', async () => {
+          const getters = { currentScope: 'blobs' };
+          const payload = { key: 'page', value: 2 };
+
+          await actions.setQuery({ state, commit, getters }, payload);
+
+          expect(setUrlParams).toHaveBeenCalledWith(
+            { ...state.query },
+            window.location.href,
+            true,
+            true,
+          );
+
+          expect(updateHistory).toHaveBeenCalledWith({
+            state: state.query,
+            title: state.query.search,
+            url: 'mocked-new-url',
+            replace: true,
+          });
+
+          expect(fetchSidebarCountSpy).not.toHaveBeenCalled();
+          expect(commit).toHaveBeenCalledWith(types.SET_QUERY, payload);
+        });
+      });
+
+      describe('when "search" attribute changes and page attribute is not present', () => {
+        beforeEach(() => {
+          const res = { count: 666 };
+          mock.onGet().replyOnce(HTTP_STATUS_OK, res);
+        });
+
+        it('should update URL, title, history and fetch sidebar counts', async () => {
+          const getters = { currentScope: 'blobs' };
+          const payload = { key: 'search', value: 'new-search' };
+
+          state.query = { ...state.query };
+          delete state.query.page;
+          state.urlQuery = { ...state.urlQuery };
+          delete state.urlQuery.page;
+
+          await testAction(
+            actions.setQuery,
+            payload,
+            { ...state, ...getters },
+            [{ type: types.SET_QUERY, payload: { key: 'search', value: 'new-search' } }],
+            [{ type: 'fetchSidebarCount' }],
+          );
+        });
+      });
+
+      describe('when "search" attribute changes but page is present and not equal to 1', () => {
+        it('should reset page to 1, update URL with clean URL, and fetch sidebar counts', () => {
+          const getters = { currentScope: 'blobs' };
+          const payload = { key: 'search', value: 'new-search' };
+
+          state.query = { ...state.query, page: 3 };
+          state.urlQuery = { ...state.urlQuery, page: 3 };
+
+          return testAction(
+            actions.setQuery,
+            payload,
+            { ...state, ...getters },
+            [
+              { type: types.SET_QUERY, payload: { key: 'search', value: 'new-search' } },
+              { type: types.SET_QUERY, payload: { key: 'page', value: 1 } },
+            ],
+            [{ type: 'fetchSidebarCount' }],
+          );
+        });
+      });
+
+      describe('when "search" attribute changes but page is present and equal to 1', () => {
+        it('should not modify URL for page, update history with original URL', async () => {
+          const getters = { currentScope: 'blobs' };
+          const payload = { key: 'search', value: 'new-search' };
+
+          state.query = { ...state.query, page: 1 };
+          state.urlQuery = { ...state.urlQuery, page: 1 };
+
+          await testAction(
+            actions.setQuery,
+            payload,
+            { ...state, ...getters },
+            [{ type: types.SET_QUERY, payload: { key: 'search', value: 'new-search' } }],
+            [{ type: 'fetchSidebarCount' }],
+          );
+
+          expect(updateHistory).toHaveBeenCalled();
+        });
+      });
+
+      describe('when urlQuery has no page but state.query has page', () => {
+        it('should use original URL without modification', () => {
+          const getters = { currentScope: 'blobs' };
+          const payload = { key: 'search', value: 'new-search' };
+
+          state.query = { ...state.query, page: 2 };
+          state.urlQuery = { ...state.urlQuery };
+          delete state.urlQuery.page;
+
+          return testAction(
+            actions.setQuery,
+            payload,
+            { ...state, ...getters },
+            [
+              { type: types.SET_QUERY, payload: { key: 'search', value: 'new-search' } },
+              { type: types.SET_QUERY, payload: { key: 'page', value: 1 } },
+            ],
+            [{ type: 'fetchSidebarCount' }],
+          );
+        });
+      });
+    });
   });
 
   describe('applyQuery', () => {
@@ -423,7 +547,7 @@ describe('Global Search Store Actions', () => {
       it(`should ${expectedMutations.length === 0 ? 'NOT' : ''} dispatch ${
         expectedMutations.length === 0 ? '' : 'the correct'
       } mutations for ${scope}`, () => {
-        return testAction({ action, state, expectedMutations }).then(() => {
+        return testAction(action, undefined, state, expectedMutations, []).then(() => {
           expect(logger.logError).toHaveBeenCalledTimes(errorLogs);
         });
       });
@@ -441,7 +565,7 @@ describe('Global Search Store Actions', () => {
     it('should not request anything', async () => {
       await testAction({ action: actions.fetchSidebarCount, state, expectedMutations: [] });
 
-      expect(mock.history.get.length).toBe(0);
+      expect(mock.history.get).toHaveLength(0);
     });
   });
 
