@@ -82,7 +82,6 @@ describe('GlobalSearchModal', () => {
   let wrapper;
   let store;
   let handleClosingSpy;
-  let onKeyComboDownSpy;
 
   const actionSpies = {
     setSearch: jest.fn(),
@@ -138,12 +137,6 @@ describe('GlobalSearchModal', () => {
 
   beforeEach(() => {
     handleClosingSpy = jest.spyOn(GlobalSearchModal.methods, 'handleClosing');
-    onKeyComboDownSpy = jest.spyOn(GlobalSearchModal.methods, 'onKeyComboToggleDropdown');
-  });
-
-  afterEach(() => {
-    handleClosingSpy.mockRestore();
-    onKeyComboDownSpy.mockRestore();
   });
 
   const findGlobalSearchModal = () => wrapper.findComponent(GlModal);
@@ -270,7 +263,7 @@ describe('GlobalSearchModal', () => {
         });
 
         it('should provide an alternative placeholder to the search input', () => {
-          expect(findGlobalSearchInput().attributes('placeholder')).toBe('Type to search...');
+          expect(findGlobalSearchInput().attributes('placeholder')).toBe('Type to search…');
         });
       });
 
@@ -311,18 +304,41 @@ describe('GlobalSearchModal', () => {
           findGlobalSearchInput().vm.$emit('click');
         });
 
-        it('should handle command selection', async () => {
-          await findCommandPaletteDropdown().vm.$emit('selected', handle);
+        it('should handle command selection', () => {
+          wrapper.vm.handleCommandSelection(handle);
 
           expect(actionSpies.setCommand).toHaveBeenCalledWith(expect.any(Object), handle);
         });
 
         it('should focus search input', async () => {
-          await findCommandPaletteDropdown().vm.$emit('selected', handle);
+          wrapper.vm.handleCommandSelection(handle);
           await nextTick();
           expect(document.activeElement).toBe(findCommandPaletteInput().element);
         });
       });
+
+      describe('when searching for users in command palette', () => {
+        beforeEach(() => {
+          createComponent({
+            initialState: { search: '', commandChar: '@' },
+            mockGetters: {
+              ...defaultMockGetters,
+              isCommandMode: () => Boolean('@'),
+            },
+            stubs: {
+              GlModal,
+              GlSearchBoxByType,
+            },
+            attachTo: document.body,
+          });
+
+          findGlobalSearchInput().vm.$emit('click');
+        });
+
+        it('shows scoped search', () => {
+          expect(findGlobalSearchScopedItems().exists()).toBe(true);
+        });
+      });
     });
   });
 
