@@ -1,12 +1,14 @@
 import Vue, { nextTick } from 'vue';
 import VueApollo from 'vue-apollo';
-import { GlAlert, GlButton, GlFormSelect, GlLink, GlSprintf } from '@gitlab/ui';
-import { shallowMount } from '@vue/test-utils';
-import namespaceWorkItemTypesQueryResponse from 'test_fixtures/graphql/work_items/namespace_work_item_types.query.graphql.json';
+import { GlAlert, GlButton, GlFormSelect, GlLink, GlLoadingIcon, GlSprintf } from '@gitlab/ui';
+import { cloneDeep } from 'lodash';
+import { shallowMountExtended } from 'helpers/vue_test_utils_helper';
+import { setHTMLFixture } from 'helpers/fixtures';
 import { useLocalStorageSpy } from 'helpers/local_storage_helper';
 import createMockApollo from 'helpers/mock_apollo_helper';
 import waitForPromises from 'helpers/wait_for_promises';
 import { createAlert } from '~/alert';
+import { clearDraft, updateDraft } from '~/lib/utils/autosave';
 import CreateWorkItem from '~/work_items/components/create_work_item.vue';
 import WorkItemTitle from '~/work_items/components/work_item_title.vue';
 import WorkItemDescription from '~/work_items/components/work_item_description.vue';
@@ -16,49 +18,58 @@ import WorkItemCrmContacts from '~/work_items/components/work_item_crm_contacts.
 import WorkItemMilestone from '~/work_items/components/work_item_milestone.vue';
 import WorkItemParent from '~/work_items/components/work_item_parent.vue';
 import WorkItemProjectsListbox from '~/work_items/components/work_item_links/work_item_projects_listbox.vue';
+import WorkItemNamespaceListbox from '~/work_items/components/shared/work_item_namespace_listbox.vue';
 import TitleSuggestions from '~/issues/new/components/title_suggestions.vue';
 import {
-  WORK_ITEM_TYPE_ENUM_EPIC,
-  WORK_ITEM_TYPE_ENUM_ISSUE,
-  WORK_ITEM_TYPE_ENUM_INCIDENT,
-  WORK_ITEM_TYPE_VALUE_INCIDENT,
-  WORK_ITEM_TYPE_VALUE_ISSUE,
-  WORK_ITEM_TYPE_VALUE_MAP,
-  WORK_ITEM_TYPE_VALUE_TASK,
-  WORK_ITEMS_TYPE_MAP,
+  CREATION_CONTEXT_LIST_ROUTE,
+  WORK_ITEM_TYPE_NAME_EPIC,
+  WORK_ITEM_TYPE_NAME_INCIDENT,
+  WORK_ITEM_TYPE_NAME_ISSUE,
+  WORK_ITEM_TYPE_NAME_KEY_RESULT,
+  WORK_ITEM_TYPE_NAME_OBJECTIVE,
+  WORK_ITEM_TYPE_NAME_REQUIREMENTS,
+  WORK_ITEM_TYPE_NAME_TASK,
+  WORK_ITEM_TYPE_NAME_TEST_CASE,
+  WORK_ITEM_TYPE_NAME_TICKET,
 } from '~/work_items/constants';
+import PageHeading from '~/vue_shared/components/page_heading.vue';
 import { setNewWorkItemCache } from '~/work_items/graphql/cache_utils';
+import { updateDraftWorkItemType } from '~/work_items/utils';
 import namespaceWorkItemTypesQuery from '~/work_items/graphql/namespace_work_item_types.query.graphql';
 import createWorkItemMutation from '~/work_items/graphql/create_work_item.mutation.graphql';
+import updateNewWorkItemMutation from '~/work_items/graphql/update_new_work_item.mutation.graphql';
 import workItemByIidQuery from '~/work_items/graphql/work_item_by_iid.query.graphql';
 import { resolvers } from '~/graphql_shared/issuable_client';
 import setWindowLocation from 'helpers/set_window_location_helper';
 import {
-  createWorkItemMutationErrorResponse,
   createWorkItemMutationResponse,
+  createWorkItemMutationErrorResponse,
   createWorkItemQueryResponse,
-} from '../mock_data';
+  namespaceWorkItemTypesQueryResponse,
+} from 'ee_else_ce_jest/work_items/mock_data';
 
 jest.mock('~/alert');
 jest.mock('~/work_items/graphql/cache_utils', () => ({
   setNewWorkItemCache: jest.fn(),
 }));
-
-jest.mock('~/lib/utils/url_utility', () => ({
-  getParameterByName: jest.fn().mockReturnValue('13'),
-  mergeUrlParams: jest.fn().mockReturnValue('/branches?state=all&search=%5Emain%24'),
-  joinPaths: jest.fn(),
-  setUrlParams: jest
-    .fn()
-    .mockReturnValue('/project/Project/-/settings/repository/branch_rules?branch=main'),
-  setUrlFragment: jest.fn(),
-  visitUrl: jest.fn().mockName('visitUrlMock'),
-}));
+jest.mock('~/work_items/utils', () => {
+  return {
+    ...jest.requireActual('~/work_items/utils'),
+    updateDraftWorkItemType: jest.fn(),
+  };
+});
+jest.mock('~/lib/utils/autosave', () => {
+  return {
+    ...jest.requireActual('~/lib/utils/autosave'),
+    clearDraft: jest.fn(),
+  };
+});
 
 Vue.use(VueApollo);
 
 describe('Create work item component', () => {
   /** @type {import('@vue/test-utils').Wrapper} */
+  const originalFeatures = gon.features;
   let wrapper;
   let mockApollo;
 
@@ -67,10 +78,15 @@ describe('Create work item component', () => {
   const createWorkItemSuccessHandler = jest.fn().mockResolvedValue(createWorkItemMutationResponse);
   const mutationErrorHandler = jest.fn().mockResolvedValue(createWorkItemMutationErrorResponse);
   const errorHandler = jest.fn().mockRejectedValue('Houston, we have a problem');
-  const workItemQuerySuccessHandler = jest.fn().mockResolvedValue(createWorkItemQueryResponse);
-  const namespaceWorkItemTypesHandler = jest
-    .fn()
-    .mockResolvedValue(namespaceWorkItemTypesQueryResponse);
+  const workItemQuerySuccessHandler = jest.fn().mockResolvedValue(createWorkItemQueryResponse());
+  const namespaceWorkItemTypes =
+    namespaceWorkItemTypesQueryResponse.data.workspace.workItemTypes.nodes;
+  const mockRelatedItem = {
+    id: 'gid://gitlab/WorkItem/22',
+    type: 'Issue',
+    reference: 'full-path#22',
+    webUrl: '/full-path/-/issues/22',
+  };
 
   const findFormTitle = () => wrapper.find('h1');
   const findAlert = () => wrapper.findComponent(GlAlert);
@@ -82,20 +98,34 @@ describe('Create work item component', () => {
   const findMilestoneWidget = () => wrapper.findComponent(WorkItemMilestone);
   const findParentWidget = () => wrapper.findComponent(WorkItemParent);
   const findProjectsSelector = () => wrapper.findComponent(WorkItemProjectsListbox);
+  const findGroupProjectSelector = () => wrapper.findComponent(WorkItemNamespaceListbox);
+  const findLoadingIcon = () => wrapper.findComponent(GlLoadingIcon);
   const findSelect = () => wrapper.findComponent(GlFormSelect);
   const findTitleSuggestions = () => wrapper.findComponent(TitleSuggestions);
-  const findConfidentialCheckbox = () => wrapper.find('[data-testid="confidential-checkbox"]');
-  const findRelatesToCheckbox = () => wrapper.find('[data-testid="relates-to-checkbox"]');
-  const findCreateWorkItemView = () => wrapper.find('[data-testid="create-work-item-view"]');
-  const findFormButtons = () => wrapper.find('[data-testid="form-buttons"]');
-  const findCreateButton = () => wrapper.find('[data-testid="create-button"]');
-  const findCancelButton = () => wrapper.find('[data-testid="cancel-button"]');
+  const findConfidentialCheckbox = () => wrapper.findByTestId('confidential-checkbox');
+  const findRelatesToCheckbox = () => wrapper.findByTestId('relates-to-checkbox');
+  const findCreateWorkItemView = () => wrapper.findByTestId('create-work-item-view');
+  const findFormButtons = () => wrapper.findByTestId('form-buttons');
+  const findCreateButton = () => wrapper.findByTestId('create-button');
+  const findCancelButton = () => wrapper.findByTestId('cancel-button');
+  const findResolveDiscussionSection = () => wrapper.findByTestId('work-item-resolve-discussion');
+  const findResolveDiscussionLink = () =>
+    wrapper.findByTestId('work-item-resolve-discussion').findComponent(GlLink);
 
   const createComponent = ({
     props = {},
+    provide = {},
     mutationHandler = createWorkItemSuccessHandler,
-    workItemTypeName = WORK_ITEM_TYPE_ENUM_EPIC,
+    namespaceQueryResponse = namespaceWorkItemTypesQueryResponse,
+    preselectedWorkItemType = WORK_ITEM_TYPE_NAME_EPIC,
+    isGroupWorkItem = false,
   } = {}) => {
+    const namespaceResponseCopy = cloneDeep(namespaceQueryResponse);
+    namespaceResponseCopy.data.workspace.id = 'gid://gitlab/Group/33';
+    const namespaceResponse = isGroupWorkItem ? namespaceResponseCopy : namespaceQueryResponse;
+
+    const namespaceWorkItemTypesHandler = jest.fn().mockResolvedValue(namespaceResponse);
+
     mockApollo = createMockApollo(
       [
         [workItemByIidQuery, workItemQuerySuccessHandler],
@@ -105,20 +135,25 @@ describe('Create work item component', () => {
       resolvers,
     );
 
-    wrapper = shallowMount(CreateWorkItem, {
+    wrapper = shallowMountExtended(CreateWorkItem, {
       apolloProvider: mockApollo,
       propsData: {
-        workItemTypeName,
+        creationContext: CREATION_CONTEXT_LIST_ROUTE,
+        fullPath: 'full-path',
+        projectNamespaceFullPath: 'full-path',
+        preselectedWorkItemType,
         ...props,
       },
       provide: {
-        fullPath: 'full-path',
         groupPath: 'group-path',
         hasIssuableHealthStatusFeature: false,
         hasIterationsFeature: true,
         hasIssueWeightsFeature: false,
+        issuesSettings: '/groups/twitter/-/settings/issues',
+        ...provide,
       },
       stubs: {
+        PageHeading,
         GlSprintf,
       },
     });
@@ -147,11 +182,20 @@ describe('Create work item component', () => {
     gon.current_user_fullname = mockCurrentUser.name;
     gon.current_username = mockCurrentUser.username;
     gon.current_user_avatar_url = mockCurrentUser.avatar_url;
+    gon.features = {};
+  });
+
+  afterAll(() => {
+    gon.features = originalFeatures;
   });
 
   describe('Default', () => {
     beforeEach(async () => {
-      createComponent();
+      createComponent({
+        props: {
+          relatedItem: mockRelatedItem,
+        },
+      });
       await waitForPromises();
     });
 
@@ -160,6 +204,36 @@ describe('Create work item component', () => {
       expect(findAlert().exists()).toBe(false);
     });
 
+    it('calls `updateNewWorkItemMutation` mutation when any widget emits `updateWidgetDraft` event', () => {
+      jest.spyOn(mockApollo.defaultClient, 'mutate');
+      const mockInput = {
+        assignees: [
+          {
+            __typename: 'CurrentUser',
+            id: 'gid://gitlab/User/1',
+            name: 'Administrator',
+            username: 'root',
+            webUrl: 'http://127.0.0.1:3000/root',
+            webPath: '/root',
+          },
+        ],
+      };
+
+      findAssigneesWidget().vm.$emit('updateWidgetDraft', mockInput);
+      expect(mockApollo.defaultClient.mutate).toHaveBeenCalledWith({
+        mutation: updateNewWorkItemMutation,
+        variables: {
+          input: {
+            fullPath: 'full-path',
+            context: CREATION_CONTEXT_LIST_ROUTE,
+            workItemType: 'Epic',
+            relatedItemId: mockRelatedItem.id,
+            ...mockInput,
+          },
+        },
+      });
+    });
+
     it('emits "confirmCancel" event on Cancel button click if form is filled', async () => {
       await updateWorkItemTitle();
       findCancelButton().vm.$emit('click');
@@ -178,43 +252,62 @@ describe('Create work item component', () => {
     it('Default', async () => {
       createComponent();
       await waitForPromises();
-      const AUTO_SAVE_KEY = 'autosave/new-full-path-epic-draft';
+      const typeSpecificAutosaveKey = 'new-full-path-list-route-epic-draft';
+      const sharedWidgetsAutosaveKey = 'new-full-path-list-route-widgets-draft';
 
       findCancelButton().vm.$emit('click');
       await nextTick();
 
-      expect(localStorage.removeItem).toHaveBeenCalledWith(AUTO_SAVE_KEY);
+      expect(clearDraft).toHaveBeenCalledTimes(2);
+      expect(clearDraft).toHaveBeenNthCalledWith(1, typeSpecificAutosaveKey);
+      expect(clearDraft).toHaveBeenNthCalledWith(2, sharedWidgetsAutosaveKey);
       expect(setNewWorkItemCache).toHaveBeenCalled();
     });
 
-    it.each(Object.keys(WORK_ITEMS_TYPE_MAP))(
-      'Clears cache on cancel for workItemType: %s with the correct data',
-      async (type) => {
-        const typeName = WORK_ITEMS_TYPE_MAP[type].value;
-        const expectedWorkItemTypeData =
-          namespaceWorkItemTypesQueryResponse.data.workspace.workItemTypes.nodes.find(
-            ({ name }) => name === typeName,
-          );
-        createComponent({ workItemTypeName: WORK_ITEM_TYPE_VALUE_MAP[typeName] });
+    it.each`
+      workItemType
+      ${WORK_ITEM_TYPE_NAME_EPIC}
+      ${WORK_ITEM_TYPE_NAME_INCIDENT}
+      ${WORK_ITEM_TYPE_NAME_ISSUE}
+      ${WORK_ITEM_TYPE_NAME_KEY_RESULT}
+      ${WORK_ITEM_TYPE_NAME_OBJECTIVE}
+      ${WORK_ITEM_TYPE_NAME_REQUIREMENTS}
+      ${WORK_ITEM_TYPE_NAME_TASK}
+      ${WORK_ITEM_TYPE_NAME_TEST_CASE}
+      ${WORK_ITEM_TYPE_NAME_TICKET}
+    `(
+      'Clears cache on cancel for workItemType=$workItemType with the correct data',
+      async ({ workItemType }) => {
+        const expectedWorkItemTypeData = namespaceWorkItemTypes.find(
+          ({ name }) => name === workItemType,
+        );
+        createComponent({
+          props: {
+            preselectedWorkItemType: workItemType,
+            relatedItem: mockRelatedItem,
+          },
+        });
         await waitForPromises();
 
         findCancelButton().vm.$emit('click');
         await nextTick();
 
-        expect(setNewWorkItemCache).toHaveBeenCalledWith(
-          'full-path',
-          expectedWorkItemTypeData.widgetDefinitions,
-          expectedWorkItemTypeData.name,
-          expectedWorkItemTypeData.id,
-          expectedWorkItemTypeData.iconName,
-        );
+        expect(setNewWorkItemCache).toHaveBeenCalledWith({
+          fullPath: 'full-path',
+          context: CREATION_CONTEXT_LIST_ROUTE,
+          widgetDefinitions: expect.any(Array),
+          workItemType: expectedWorkItemTypeData.name,
+          workItemTypeId: expectedWorkItemTypeData.id,
+          workItemTypeIconName: expectedWorkItemTypeData.iconName,
+          relatedItemId: mockRelatedItem.id,
+        });
       },
     );
   });
 
   describe('When there is no work item type', () => {
     beforeEach(() => {
-      createComponent({ workItemTypeName: null });
+      createComponent({ props: { preselectedWorkItemType: null } });
       return waitForPromises();
     });
 
@@ -239,58 +332,88 @@ describe('Create work item component', () => {
     );
 
     it('defaults the selected project to the injected `fullPath` value', async () => {
-      createComponent({ props: { showProjectSelector: true } });
+      const namespaceFullName = 'GitLab.org / GitLab';
+      createComponent({
+        props: { showProjectSelector: true, namespaceFullName },
+      });
       await waitForPromises();
 
+      expect(findProjectsSelector().props('currentProjectName')).toBe(namespaceFullName);
       expect(findProjectsSelector().props('selectedProjectFullPath')).toBe('full-path');
     });
   });
 
+  describe('Group/project selector', () => {
+    it('renders with the current namespace selected by default', async () => {
+      createComponent({ provide: { workItemPlanningViewEnabled: true } });
+      await waitForPromises();
+
+      expect(findGroupProjectSelector().exists()).toBe(true);
+      expect(findGroupProjectSelector().props('fullPath')).toBe('full-path');
+    });
+  });
+
   describe('Work item types dropdown', () => {
-    it('displays a list of work item types including "Select type" option when workItemTypeName is not provided', async () => {
-      createComponent({ props: { workItemTypeName: null } });
+    it('renders with loading icon when namespaceWorkItemTypes query is loading', async () => {
+      createComponent({ props: { preselectedWorkItemType: null, showProjectSelector: true } });
+      await waitForPromises();
+
+      findProjectsSelector().vm.$emit('selectProject', 'fullPath');
+      await nextTick();
+
+      expect(findSelect().attributes('disabled')).not.toBeUndefined();
+      expect(findLoadingIcon().exists()).toBe(true);
+    });
+
+    it('displays a list of work item types including "Select type" option when preselectedWorkItemType is not provided', async () => {
+      createComponent({ props: { preselectedWorkItemType: null } });
       await waitForPromises();
       // +1 for the "Select type" option
-      const expectedOptions =
-        namespaceWorkItemTypesQueryResponse.data.workspace.workItemTypes.nodes.length + 1;
+      const expectedOptions = namespaceWorkItemTypes.length + 1;
 
       expect(findSelect().attributes('options').split(',')).toHaveLength(expectedOptions);
     });
 
-    it('hides the type selector if workItemTypeName is provided', async () => {
-      createComponent({ props: { workItemTypeName: WORK_ITEM_TYPE_ENUM_EPIC } });
+    it('hides the type selector if preselectedWorkItemType is provided', async () => {
+      createComponent({ props: { preselectedWorkItemType: WORK_ITEM_TYPE_NAME_EPIC } });
       await waitForPromises();
 
       expect(findSelect().exists()).toBe(false);
     });
 
-    it('shows the type selector when alwaysShowWorkItemTypeSelect=true even if workItemTypeName is provided', async () => {
+    it('shows the type selector when alwaysShowWorkItemTypeSelect=true even if preselectedWorkItemType is provided', async () => {
       createComponent({
-        props: { workItemTypeName: WORK_ITEM_TYPE_ENUM_EPIC, alwaysShowWorkItemTypeSelect: true },
+        props: {
+          preselectedWorkItemType: WORK_ITEM_TYPE_NAME_EPIC,
+          alwaysShowWorkItemTypeSelect: true,
+        },
       });
       await waitForPromises();
 
       expect(findSelect().exists()).toBe(true);
     });
 
-    it('does not show the "Select type" option when workItemTypeName is provided and alwaysShowWorkItemTypeSelect=true', async () => {
+    it('does not show the "Select type" option when preselectedWorkItemType is provided and alwaysShowWorkItemTypeSelect=true', async () => {
       createComponent({
-        props: { workItemTypeName: WORK_ITEM_TYPE_ENUM_EPIC, alwaysShowWorkItemTypeSelect: true },
+        props: {
+          preselectedWorkItemType: WORK_ITEM_TYPE_NAME_EPIC,
+          alwaysShowWorkItemTypeSelect: true,
+        },
       });
       await waitForPromises();
 
       expect(findSelect().attributes('options').split(',')).toHaveLength(
-        namespaceWorkItemTypesQueryResponse.data.workspace.workItemTypes.nodes.length,
+        namespaceWorkItemTypes.length,
       );
     });
 
     it('restricts the type selector to types provided by allowedWorkItemTypes', async () => {
       const allowedWorkItemTypes = [
-        WORK_ITEM_TYPE_VALUE_INCIDENT,
-        WORK_ITEM_TYPE_VALUE_ISSUE,
-        WORK_ITEM_TYPE_VALUE_TASK,
+        WORK_ITEM_TYPE_NAME_INCIDENT,
+        WORK_ITEM_TYPE_NAME_ISSUE,
+        WORK_ITEM_TYPE_NAME_TASK,
       ];
-      createComponent({ props: { workItemTypeName: null, allowedWorkItemTypes } });
+      createComponent({ props: { preselectedWorkItemType: null, allowedWorkItemTypes } });
       await waitForPromises();
       // +1 for the "Select type" option
       const expectedOptions = allowedWorkItemTypes.length + 1;
@@ -299,7 +422,7 @@ describe('Create work item component', () => {
     });
 
     it('selects a work item type on click', async () => {
-      createComponent({ props: { workItemTypeName: null } });
+      createComponent({ props: { preselectedWorkItemType: null } });
       await waitForPromises();
       const mockId = 'Issue';
 
@@ -309,6 +432,47 @@ describe('Create work item component', () => {
       expect(findSelect().attributes('value')).toBe(mockId);
     });
 
+    it('sets new work item cache and emits changeType on select', async () => {
+      createComponent({ props: { preselectedWorkItemType: null, relatedItem: mockRelatedItem } });
+      await waitForPromises();
+      const mockId = 'Issue';
+
+      findSelect().vm.$emit('change', mockId);
+      await nextTick();
+
+      expect(setNewWorkItemCache).toHaveBeenCalledWith({
+        fullPath: 'full-path',
+        context: CREATION_CONTEXT_LIST_ROUTE,
+        widgetDefinitions: expect.any(Array),
+        workItemType: mockId,
+        workItemTypeId: 'gid://gitlab/WorkItems::Type/1',
+        workItemTypeIconName: 'issue-type-issue',
+        relatedItemId: mockRelatedItem.id,
+      });
+
+      expect(wrapper.emitted('changeType')).toBeDefined();
+    });
+
+    it('sets selected work item type in localStorage draft', async () => {
+      createComponent({ props: { preselectedWorkItemType: null, relatedItem: mockRelatedItem } });
+      await waitForPromises();
+      const mockId = 'Issue';
+
+      findSelect().vm.$emit('change', mockId);
+      await nextTick();
+
+      expect(updateDraftWorkItemType).toHaveBeenCalledWith({
+        fullPath: 'full-path',
+        context: CREATION_CONTEXT_LIST_ROUTE,
+        relatedItemId: mockRelatedItem.id,
+        workItemType: {
+          id: 'gid://gitlab/WorkItems::Type/1',
+          name: mockId,
+          iconName: 'issue-type-issue',
+        },
+      });
+    });
+
     it('hides title if set', async () => {
       createComponent({ props: { hideFormTitle: true } });
       await waitForPromises();
@@ -327,6 +491,9 @@ describe('Create work item component', () => {
 
   describe('Create work item', () => {
     it('emits workItemCreated on successful mutation', async () => {
+      setWindowLocation(
+        '?discussion_to_resolve=f20989738bfe845f73a77a7109b1588852901befJD9I3FGU&merge_request_id=13',
+      );
       const workItem = { ...createWorkItemMutationResponse.data.workItemCreate.workItem };
       // there is a mismatch between the response and the expected workItem object between CE and EE fixture
       // so we need to remove the `promotedToEpicUrl` property from the expected workItem object
@@ -349,6 +516,27 @@ describe('Create work item component', () => {
       ]);
     });
 
+    it('clears autosave draft on successful mutation', async () => {
+      const typeSpecificAutosaveKey = 'new-full-path-list-route-related-id-22-epic-draft';
+      const sharedWidgetsAutosaveKey = 'new-full-path-list-route-related-id-22-widgets-draft';
+      updateDraft(typeSpecificAutosaveKey, JSON.stringify({ foo: 'bar' }));
+      updateDraft(sharedWidgetsAutosaveKey, JSON.stringify({ foo: 'bar' }));
+      createComponent({
+        props: {
+          relatedItem: mockRelatedItem,
+        },
+      });
+      await waitForPromises();
+
+      findTitleInput().vm.$emit('updateDraft', 'Test title');
+      await waitForPromises();
+      await submitCreateForm();
+
+      expect(clearDraft).toHaveBeenCalledTimes(2);
+      expect(clearDraft).toHaveBeenNthCalledWith(1, typeSpecificAutosaveKey);
+      expect(clearDraft).toHaveBeenNthCalledWith(2, sharedWidgetsAutosaveKey);
+    });
+
     it('emits workItemCreated for confidential work item', async () => {
       createComponent();
       await waitForPromises();
@@ -397,6 +585,20 @@ describe('Create work item component', () => {
       });
     });
 
+    it('correct fullPath is provided to components when project is selected', async () => {
+      const fullPath = 'chosen/full/path';
+      createComponent({ props: { showProjectSelector: true } });
+      await waitForPromises();
+
+      expect(findAssigneesWidget().props('fullPath')).toBe('full-path');
+
+      findProjectsSelector().vm.$emit('selectProject', fullPath);
+
+      await nextTick();
+
+      expect(findAssigneesWidget().props('fullPath')).toBe(fullPath);
+    });
+
     it('does not commit when title is empty', async () => {
       createComponent();
       await waitForPromises();
@@ -517,7 +719,7 @@ describe('Create work item component', () => {
   describe('Create work item widgets for Issue work item type', () => {
     describe('default', () => {
       beforeEach(async () => {
-        createComponent({ workItemTypeName: WORK_ITEM_TYPE_ENUM_ISSUE });
+        createComponent({ props: { preselectedWorkItemType: WORK_ITEM_TYPE_NAME_ISSUE } });
         await waitForPromises();
       });
 
@@ -544,17 +746,13 @@ describe('Create work item component', () => {
       it('renders the work item milestone widget', () => {
         expect(findMilestoneWidget().exists()).toBe(true);
       });
-
-      it('renders the work item parent widget', () => {
-        expect(findParentWidget().exists()).toBe(true);
-      });
     });
   });
 
   describe('Create work item widgets for Incident work item type', () => {
     describe('default', () => {
       beforeEach(async () => {
-        createComponent({ workItemTypeName: WORK_ITEM_TYPE_ENUM_INCIDENT });
+        createComponent({ props: { preselectedWorkItemType: WORK_ITEM_TYPE_NAME_INCIDENT } });
         await waitForPromises();
       });
 
@@ -588,10 +786,56 @@ describe('Create work item component', () => {
     });
   });
 
+  describe('confidentiality checkbox', () => {
+    it('is checked when parameter issue[confidential]=true', async () => {
+      setWindowLocation('?issue[confidential]=true');
+      createComponent();
+      await waitForPromises();
+
+      expect(findConfidentialCheckbox().attributes('checked')).toBe('true');
+    });
+
+    it('is not checked when parameter issue[confidential]!=true', async () => {
+      setWindowLocation('?issue[confidential]=tru');
+      createComponent();
+      await waitForPromises();
+
+      expect(findConfidentialCheckbox().attributes('checked')).toBeUndefined();
+    });
+
+    it('renders confidentiality checkbox for a group', async () => {
+      createComponent({
+        props: {
+          isGroup: true,
+        },
+      });
+
+      await waitForPromises();
+
+      const confidentialCheckbox = findConfidentialCheckbox();
+
+      expect(confidentialCheckbox.text()).toBe(
+        'Turn on confidentiality: Limit visibility to group members with at least the Planner role.',
+      );
+    });
+
+    it('renders confidentiality checkbox for a project', async () => {
+      createComponent();
+
+      await waitForPromises();
+
+      const confidentialCheckbox = findConfidentialCheckbox();
+
+      expect(confidentialCheckbox.text()).toBe(
+        'Turn on confidentiality: Limit visibility to project members with at least the Planner role.',
+      );
+    });
+  });
+
   describe('With related item', () => {
     const id = 'gid://gitlab/WorkItem/1';
     const type = 'Epic';
-    const reference = 'full-path#1';
+    const reference = 'related-full-path#1';
     const webUrl = 'web/url';
 
     beforeEach(async () => {
@@ -617,7 +861,13 @@ describe('Create work item component', () => {
     it('provides the related item fullPath to the project listbox', () => {
       const listbox = findProjectsSelector();
 
-      expect(listbox.props('selectedProjectFullPath')).toBe('full-path');
+      expect(listbox.props('selectedProjectFullPath')).toBe('related-full-path');
+    });
+
+    it('provides the related item fullPath to the widget components', () => {
+      const assigneesWidget = findAssigneesWidget();
+
+      expect(assigneesWidget.props('fullPath')).toBe('related-full-path');
     });
 
     it('includes the related item in the create work item request', async () => {
@@ -649,25 +899,42 @@ describe('Create work item component', () => {
   });
 
   describe('form buttons', () => {
-    it('shows buttons on right and sticky when stickyFormSubmit', async () => {
-      createComponent({ props: { stickyFormSubmit: true } });
+    it('shows buttons on right and sticky when isModal', async () => {
+      createComponent({ props: { isModal: true } });
       await waitForPromises();
 
       expect(findFormButtons().classes('gl-sticky')).toBe(true);
-      expect(findFormButtons().classes('gl-justify-end')).toBe(true);
+      expect(findFormButtons().classes('gl-justify-between')).toBe(true);
       expect(findFormButtons().findAllComponents(GlButton).at(0).text()).toBe('Cancel');
       expect(findFormButtons().findAllComponents(GlButton).at(1).text()).toBe('Create epic');
     });
 
-    it('shows buttons on left and inside the grid when not stickyFormSubmit', async () => {
-      createComponent({ props: { stickyFormSubmit: false } });
+    it('shows buttons on left and sticky when not isModal', async () => {
+      createComponent({ props: { isModal: false } });
       await waitForPromises();
 
-      expect(findFormButtons().classes('gl-sticky')).toBe(false);
-      expect(findFormButtons().classes('gl-justify-end')).toBe(false);
+      expect(findFormButtons().classes('gl-sticky')).toBe(true);
+      expect(findFormButtons().classes('gl-justify-between')).toBe(true);
       expect(findFormButtons().findAllComponents(GlButton).at(0).text()).toBe('Create epic');
       expect(findFormButtons().findAllComponents(GlButton).at(1).text()).toBe('Cancel');
     });
+
+    it('shows contribution guidelines link when contributing.md exists', async () => {
+      createComponent({ provide: { contributionGuidePath: 'contribution/guide/path' } });
+      await waitForPromises();
+
+      expect(findFormButtons().findComponent(GlLink).text()).toBe('contribution guidelines');
+      expect(findFormButtons().findComponent(GlLink).attributes('href')).toBe(
+        'contribution/guide/path',
+      );
+    });
+
+    it('does not show contribution guidelines link when contributing.md does not exist', async () => {
+      createComponent({ provide: { contributionGuidePath: undefined } });
+      await waitForPromises();
+
+      expect(findFormButtons().findComponent(GlLink).exists()).toBe(false);
+    });
   });
 
   describe('Keyboard submit events', () => {
@@ -706,9 +973,75 @@ describe('Create work item component', () => {
     });
   });
 
+  it('does not show work item widgets when userPermissions.setNewWorkItemMetadata is false', async () => {
+    const namespaceQueryResponse = {
+      data: {
+        workspace: {
+          ...namespaceWorkItemTypesQueryResponse.data.workspace,
+          userPermissions: {
+            setNewWorkItemMetadata: false,
+          },
+        },
+      },
+    };
+
+    createComponent({ namespaceQueryResponse });
+    await waitForPromises();
+
+    const widgetsContainer = wrapper.findByTestId('work-item-overview-right-sidebar');
+    expect(widgetsContainer.exists()).toBe(true);
+    expect(widgetsContainer.find('strong').text()).toContain('Limited access');
+    expect(widgetsContainer.find('div').text()).toContain('Only project members can add metadata.');
+  });
+
+  describe('title and description query parameters', () => {
+    it('saves to the cache when the backend provides them', async () => {
+      setHTMLFixture(`
+        <div class="new-issue-params hidden">
+          <div class="params-title">
+            i am a title
+          </div>
+          <div class="params-description">
+            i
+            am
+            a
+            description!
+          </div>
+          <div class="params-add-related-issue">
+            234
+          </div>
+          <div class="params-discussion-to-resolve">
+
+          </div>
+        </div>`);
+      createComponent({
+        props: {
+          relatedItem: mockRelatedItem,
+        },
+      });
+      await waitForPromises();
+
+      expect(setNewWorkItemCache).toHaveBeenCalledWith({
+        fullPath: expect.anything(),
+        context: CREATION_CONTEXT_LIST_ROUTE,
+        widgetDefinitions: expect.anything(),
+        workItemType: expect.anything(),
+        workItemTypeId: expect.anything(),
+        workItemTypeIconName: expect.anything(),
+        workItemTitle: 'i am a title',
+        workItemDescription: `i
+            am
+            a
+            description!`,
+        confidential: false,
+        relatedItemId: mockRelatedItem.id,
+      });
+    });
+  });
+
   describe('New work item to resolve threads', () => {
     it('when not resolving any thread, does not pass resolve params to mutation', async () => {
-      createComponent({ singleWorkItemType: true, workItemTypeName: WORK_ITEM_TYPE_ENUM_ISSUE });
+      createComponent({ props: { preselectedWorkItemType: WORK_ITEM_TYPE_NAME_ISSUE } });
       await waitForPromises();
 
       await updateWorkItemTitle();
@@ -722,30 +1055,11 @@ describe('Create work item component', () => {
     });
 
     it('when resolving all threads in a merge request', async () => {
-      setWindowLocation('?merge_request_id=13');
-
-      createComponent({ singleWorkItemType: true, workItemTypeName: WORK_ITEM_TYPE_ENUM_ISSUE });
-      await waitForPromises();
-
-      await updateWorkItemTitle();
-      await submitCreateForm();
-
-      expect(createWorkItemSuccessHandler).toHaveBeenCalledWith({
-        input: expect.objectContaining({
-          discussionsToResolve: {
-            discussionId: '13',
-            noteableId: 'gid://gitlab/MergeRequest/13',
-          },
-        }),
-      });
-    });
-
-    it('when resolving one thread in a merge request', async () => {
       setWindowLocation(
         '?discussion_to_resolve=13&merge_request_to_resolve_discussions_of=112&merge_request_id=13',
       );
 
-      createComponent({ singleWorkItemType: true, workItemTypeName: WORK_ITEM_TYPE_ENUM_ISSUE });
+      createComponent({ props: { preselectedWorkItemType: WORK_ITEM_TYPE_NAME_ISSUE } });
       await waitForPromises();
 
       await updateWorkItemTitle();
@@ -760,5 +1074,61 @@ describe('Create work item component', () => {
         }),
       });
     });
+
+    describe('when resolving one thread in a merge request', () => {
+      beforeEach(async () => {
+        setHTMLFixture(`
+        <div class="new-issue-params hidden">
+          <div class="params-title">
+            Follow-up from "Necessitatibus delectus ex animi consequatur facere ipsum quaerat iusto veniam architecto."
+          </div>
+          <div class="params-description">
+            The following discussion from !1 should be addressed:
+
+            - [ ] @marlen started a [discussion](http://127.0.0.1:3000/flightjs/Flight/-/merge_requests/1#note_1224):  (+1 comment)
+
+                &gt; Quis nihil est molestias nemo rerum aspernatur.
+          </div>
+          <div class="params-add-related-issue">
+
+          </div>
+          <div class="params-discussion-to-resolve">
+            <a href="http://127.0.0.1:3000/flightjs/Flight/-/merge_requests/1#note_1224">!1 (discussion 1224)</a>
+          </div>
+        </div>`);
+        setWindowLocation(
+          '?discussion_to_resolve=13&merge_request_to_resolve_discussions_of=112&merge_request_id=13',
+        );
+        createComponent({ props: { preselectedWorkItemType: WORK_ITEM_TYPE_NAME_ISSUE } });
+        await waitForPromises();
+      });
+
+      it('renders text', () => {
+        expect(findResolveDiscussionSection().text()).toMatchInterpolatedText(
+          'Creating this issue will resolve the thread in !1 (discussion 1224)',
+        );
+      });
+
+      it('renders "resolve the thread" information', () => {
+        expect(findResolveDiscussionLink().text()).toBe('!1 (discussion 1224)');
+        expect(findResolveDiscussionLink().props('href')).toBe(
+          'http://127.0.0.1:3000/flightjs/Flight/-/merge_requests/1#note_1224',
+        );
+      });
+
+      it('calls mutation', async () => {
+        await updateWorkItemTitle();
+        await submitCreateForm();
+
+        expect(createWorkItemSuccessHandler).toHaveBeenCalledWith({
+          input: expect.objectContaining({
+            discussionsToResolve: {
+              discussionId: '13',
+              noteableId: 'gid://gitlab/MergeRequest/13',
+            },
+          }),
+        });
+      });
+    });
   });
 });
