@@ -6,6 +6,7 @@ import mockApollo from 'helpers/mock_apollo_helper';
 import waitForPromises from 'helpers/wait_for_promises';
 import { updateDraft, clearDraft } from '~/lib/utils/autosave';
 import EditedAt from '~/issues/show/components/edited.vue';
+import gfmEventHub from '~/vue_shared/components/markdown/eventhub';
 import WorkItemNote from '~/work_items/components/notes/work_item_note.vue';
 import WorkItemNoteAwardsList from '~/work_items/components/notes/work_item_note_awards_list.vue';
 import TimelineEntryItem from '~/vue_shared/components/notes/timeline_entry_item.vue';
@@ -19,12 +20,12 @@ import workItemByIidQuery from '~/work_items/graphql/work_item_by_iid.query.grap
 import {
   mockAssignees,
   mockWorkItemCommentNote,
+  mockWorkItemCommentNoteByContributor,
+  mockWorkItemCommentByMaintainer,
   updateWorkItemMutationResponse,
   workItemByIidResponseFactory,
   workItemQueryResponse,
-  mockWorkItemCommentNoteByContributor,
-  mockWorkItemCommentByMaintainer,
-} from 'jest/work_items/mock_data';
+} from 'ee_else_ce_jest/work_items/mock_data';
 import { i18n, TRACKING_CATEGORY_SHOW } from '~/work_items/constants';
 import { mockTracking } from 'helpers/tracking_helper';
 
@@ -89,6 +90,7 @@ describe('Work Item Note', () => {
   const createComponent = ({
     note = mockWorkItemCommentNote,
     isFirstNote = false,
+    canReply = false,
     updateNoteMutationHandler = successHandler,
     workItemId = mockWorkItemId,
     updateWorkItemMutationHandler = updateWorkItemMutationSuccessHandler,
@@ -101,9 +103,11 @@ describe('Work Item Note', () => {
         workItemId,
         workItemIid: '1',
         note,
+        canReply,
         isFirstNote,
         workItemType: 'Task',
         markdownPreviewPath: '/group/project/preview_markdown?target_type=WorkItem',
+        uploadsPath: '/test-project-path/uploads',
         autocompleteDataSources: {},
         assignees,
       },
@@ -275,7 +279,7 @@ end`;
 
     describe('main comment', () => {
       beforeEach(async () => {
-        createComponent({ isFirstNote: true });
+        createComponent({ isFirstNote: true, canReply: true });
         await waitForPromises();
       });
 
@@ -510,4 +514,41 @@ end`;
       expect(findNoteActions().props('showAssignUnassign')).toBe(false);
     });
   });
+
+  describe('markdown-editor event-hub edit-note event', () => {
+    const setupComponent = async ({ id = mockWorkItemCommentNote.id, adminNote = true } = {}) => {
+      createComponent({
+        note: {
+          ...mockWorkItemCommentNote,
+          id,
+          userPermissions: {
+            ...mockWorkItemCommentNote.userPermissions,
+            adminNote,
+          },
+        },
+      });
+
+      gfmEventHub.$emit('edit-note', { note: mockWorkItemCommentNote });
+
+      await nextTick();
+    };
+
+    it('enables editing on the note for a matching note when adminNote is true', async () => {
+      await setupComponent();
+
+      expect(wrapper.emitted('startEditing')).toHaveLength(1);
+      expect(findCommentForm().exists()).toBe(true);
+    });
+
+    it.each`
+      setupProps                         | description
+      ${{ adminNote: false }}            | ${'a matching note when adminNote is false'}
+      ${{ id: 'gid://gitlab/Note/100' }} | ${'non-matching note when adminNote is true'}
+    `('does not enable editing on the note for $description', async ({ setupProps }) => {
+      await setupComponent(setupProps);
+
+      expect(wrapper.emitted('startEditing')).toBeUndefined();
+      expect(findCommentForm().exists()).toBe(false);
+    });
+  });
 });
