@@ -1,7 +1,6 @@
-import { GlDisclosureDropdown, GlModal, GlDisclosureDropdownItem } from '@gitlab/ui';
+import { GlDisclosureDropdown, GlModal, GlDisclosureDropdownItem, GlLoadingIcon } from '@gitlab/ui';
 import Vue, { nextTick } from 'vue';
 import VueApollo from 'vue-apollo';
-import namespaceWorkItemTypesQueryResponse from 'test_fixtures/graphql/work_items/namespace_work_item_types.query.graphql.json';
 
 import createMockApollo from 'helpers/mock_apollo_helper';
 import { stubComponent } from 'helpers/stub_component';
@@ -18,24 +17,28 @@ import CreateWorkItemModal from '~/work_items/components/create_work_item_modal.
 import WorkItemChangeTypeModal from 'ee_else_ce/work_items/components/work_item_change_type_modal.vue';
 import MoveWorkItemModal from '~/work_items/components/move_work_item_modal.vue';
 import {
+  CREATION_CONTEXT_RELATED_ITEM,
   STATE_OPEN,
-  WORK_ITEM_TYPE_VALUE_INCIDENT,
-  WORK_ITEM_TYPE_VALUE_ISSUE,
-  WORK_ITEM_TYPE_VALUE_KEY_RESULT,
-  WORK_ITEM_TYPE_VALUE_OBJECTIVE,
-  WORK_ITEM_TYPE_VALUE_TASK,
+  WORK_ITEM_TYPE_NAME_INCIDENT,
+  WORK_ITEM_TYPE_NAME_ISSUE,
+  WORK_ITEM_TYPE_NAME_KEY_RESULT,
+  WORK_ITEM_TYPE_NAME_OBJECTIVE,
+  WORK_ITEM_TYPE_NAME_TASK,
 } from '~/work_items/constants';
 import updateWorkItemMutation from '~/work_items/graphql/update_work_item.mutation.graphql';
 import updateWorkItemNotificationsMutation from '~/work_items/graphql/update_work_item_notifications.mutation.graphql';
 import namespaceWorkItemTypesQuery from '~/work_items/graphql/namespace_work_item_types.query.graphql';
+import getWorkItemNotificationsByIdQuery from '~/work_items/graphql/get_work_item_notifications_by_id.query.graphql';
 import convertWorkItemMutation from '~/work_items/graphql/work_item_convert.mutation.graphql';
 
 import {
-  convertWorkItemMutationResponse,
   convertWorkItemMutationErrorResponse,
+  convertWorkItemMutationResponse,
+  namespaceWorkItemTypesQueryResponse,
   updateWorkItemMutationResponse,
   updateWorkItemNotificationsMutationResponse,
-} from '../mock_data';
+  workItemNotificationsResponse,
+} from 'ee_else_ce_jest/work_items/mock_data';
 
 jest.mock('~/lib/utils/common_utils');
 jest.mock('~/vue_shared/plugins/global_toast');
@@ -88,9 +91,11 @@ describe('WorkItemActions component', () => {
         text: x.text(),
       };
     });
+  const findNotificationsToggleForm = () => wrapper.findByTestId('notifications-toggle-form');
   const findNotificationsToggle = () => wrapper.findByTestId('notifications-toggle');
   const findMoveButton = () => wrapper.findByTestId('move-action');
   const findMoveModal = () => wrapper.findComponent(MoveWorkItemModal);
+  const findLoadingIcon = () => wrapper.findComponent(GlLoadingIcon);
 
   const modalShowSpy = jest.fn();
   const $toast = {
@@ -99,6 +104,12 @@ describe('WorkItemActions component', () => {
   };
 
   const typesQuerySuccessHandler = jest.fn().mockResolvedValue(namespaceWorkItemTypesQueryResponse);
+  const notificationOffQueryHandler = jest
+    .fn()
+    .mockResolvedValue(workItemNotificationsResponse(false));
+  const notificationOnQueryHandler = jest
+    .fn()
+    .mockResolvedValue(workItemNotificationsResponse(true));
   const convertWorkItemMutationSuccessHandler = jest
     .fn()
     .mockResolvedValue(convertWorkItemMutationResponse);
@@ -130,7 +141,6 @@ describe('WorkItemActions component', () => {
     isGroup = false,
     isParentConfidential = false,
     okrsMvc = false,
-    subscribed = false,
     convertWorkItemMutationHandler = convertWorkItemMutationSuccessHandler,
     notificationsMutationHandler,
     lockDiscussionMutationHandler = lockDiscussionMutationResolver,
@@ -140,14 +150,17 @@ describe('WorkItemActions component', () => {
     hideSubscribe = undefined,
     hasChildren = false,
     canCreateRelatedItem = true,
-    workItemsBeta = true,
     parentId = null,
     projectId = 'gid://gitlab/Project/1',
+    namespaceFullName = 'GitLab.org / GitLab Test',
+    updateInProgress = false,
+    notificationsQueryHandler = notificationOnQueryHandler,
   } = {}) => {
     wrapper = shallowMountExtended(WorkItemActions, {
       isLoggedIn: isLoggedIn(),
       apolloProvider: createMockApollo([
         [namespaceWorkItemTypesQuery, typesQuerySuccessHandler],
+        [getWorkItemNotificationsByIdQuery, notificationsQueryHandler],
         [convertWorkItemMutation, convertWorkItemMutationHandler],
         [updateWorkItemNotificationsMutation, notificationsMutationHandler],
         [updateWorkItemMutation, lockDiscussionMutationHandler],
@@ -169,7 +182,6 @@ describe('WorkItemActions component', () => {
         canMove,
         isConfidential,
         isDiscussionLocked,
-        subscribed,
         isParentConfidential,
         workItemType,
         workItemReference,
@@ -179,8 +191,10 @@ describe('WorkItemActions component', () => {
         canCreateRelatedItem,
         parentId,
         projectId,
+        namespaceFullName,
         showSidebar: true,
         truncationEnabled: true,
+        updateInProgress,
       },
       mocks: {
         $toast,
@@ -188,7 +202,6 @@ describe('WorkItemActions component', () => {
       provide: {
         glFeatures: {
           okrsMvc,
-          workItemsBeta,
         },
         hasOkrsFeature,
       },
@@ -231,7 +244,7 @@ describe('WorkItemActions component', () => {
     expect(findDropdownItemsActual()).toEqual([
       {
         testId: 'notifications-toggle-form',
-        text: '',
+        text: 'Notifications',
       },
       {
         divider: true,
@@ -270,7 +283,7 @@ describe('WorkItemActions component', () => {
         text: 'Copy issue email address',
       },
       {
-        divider: true,
+        group: true,
       },
       {
         testId: 'report-abuse-action',
@@ -289,7 +302,7 @@ describe('WorkItemActions component', () => {
       },
       {
         testId: 'truncation-toggle-action',
-        text: '',
+        text: 'Truncate descriptions',
       },
       {
         testId: 'sidebar-toggle-action',
@@ -380,12 +393,14 @@ describe('WorkItemActions component', () => {
       },
     );
 
-    it('emits `toggleWorkItemConfidentiality` event when clicked', () => {
+    it('emits `toggleWorkItemConfidentiality` event when clicked', async () => {
       createComponent();
 
       findConfidentialityToggleButton().vm.$emit('action');
 
       expect(wrapper.emitted('toggleWorkItemConfidentiality')[0]).toEqual([true]);
+
+      await nextTick();
       expect(toast).toHaveBeenCalledWith('Confidentiality turned on.');
     });
 
@@ -400,6 +415,12 @@ describe('WorkItemActions component', () => {
         extraAttrs: { disabled: true },
       });
     });
+
+    it('shows loading icon badge when the work item is confidential', () => {
+      createComponent({ updateInProgress: true });
+
+      expect(findLoadingIcon().exists()).toBe(true);
+    });
   });
 
   describe('delete action', () => {
@@ -452,24 +473,28 @@ describe('WorkItemActions component', () => {
       ${'shows notification subscription'}         | ${undefined}
     `('$scenario when hideSubscribe is set to $hideSubscribe', ({ hideSubscribe }) => {
       createComponent({ hideSubscribe });
-      expect(findNotificationsToggle().exists()).toBe(!hideSubscribe);
+      expect(findNotificationsToggleForm().exists()).toBe(!hideSubscribe);
     });
 
     it.each`
-      scenario        | subscribedToNotifications | notificationsMutationHandler     | subscribed | toastMessage
-      ${'turned off'} | ${false}                  | ${toggleNotificationsOffHandler} | ${false}   | ${'Notifications turned off.'}
-      ${'turned on'}  | ${true}                   | ${toggleNotificationsOnHandler}  | ${true}    | ${'Notifications turned on.'}
+      scenario        | subscribedToNotification | notificationsQueryHandler      | notificationsMutationHandler     | subscribed | toastMessage
+      ${'turned off'} | ${true}                  | ${notificationOnQueryHandler}  | ${toggleNotificationsOffHandler} | ${false}   | ${'Notifications turned off.'}
+      ${'turned on'}  | ${false}                 | ${notificationOffQueryHandler} | ${toggleNotificationsOnHandler}  | ${true}    | ${'Notifications turned on.'}
     `(
       'calls mutation and displays toast when notification toggle is $scenario',
       async ({
-        subscribedToNotifications,
+        subscribedToNotification,
         notificationsMutationHandler,
         subscribed,
         toastMessage,
+        notificationsQueryHandler,
       }) => {
-        createComponent({ notificationsMutationHandler });
+        createComponent({ notificationsMutationHandler, notificationsQueryHandler });
+        await waitForPromises();
 
-        findNotificationsToggle().vm.$emit('change', subscribedToNotifications);
+        expect(findNotificationsToggle().props().value).toBe(subscribedToNotification);
+
+        findNotificationsToggleForm().vm.$emit('action', subscribed);
         await waitForPromises();
 
         expect(notificationsMutationHandler).toHaveBeenCalledWith({
@@ -484,8 +509,9 @@ describe('WorkItemActions component', () => {
 
     it('emits error when the update notification mutation fails', async () => {
       createComponent({ notificationsMutationHandler: toggleNotificationsFailureHandler });
+      await waitForPromises();
 
-      findNotificationsToggle().vm.$emit('change', false);
+      findNotificationsToggleForm().vm.$emit('action', false);
       await waitForPromises();
 
       expect(wrapper.emitted('error')).toEqual([['Failed to subscribe']]);
@@ -623,9 +649,9 @@ describe('WorkItemActions component', () => {
         createComponent({ hasOkrsFeature: false, okrsMvc: false });
 
         expect(findCreateWorkItemModal().props('allowedWorkItemTypes')).toEqual([
-          WORK_ITEM_TYPE_VALUE_INCIDENT,
-          WORK_ITEM_TYPE_VALUE_ISSUE,
-          WORK_ITEM_TYPE_VALUE_TASK,
+          WORK_ITEM_TYPE_NAME_INCIDENT,
+          WORK_ITEM_TYPE_NAME_ISSUE,
+          WORK_ITEM_TYPE_NAME_TASK,
         ]);
       });
     });
@@ -635,11 +661,11 @@ describe('WorkItemActions component', () => {
         createComponent({ hasOkrsFeature: true, okrsMvc: true });
 
         expect(findCreateWorkItemModal().props('allowedWorkItemTypes')).toEqual([
-          WORK_ITEM_TYPE_VALUE_INCIDENT,
-          WORK_ITEM_TYPE_VALUE_ISSUE,
-          WORK_ITEM_TYPE_VALUE_TASK,
-          WORK_ITEM_TYPE_VALUE_KEY_RESULT,
-          WORK_ITEM_TYPE_VALUE_OBJECTIVE,
+          WORK_ITEM_TYPE_NAME_INCIDENT,
+          WORK_ITEM_TYPE_NAME_ISSUE,
+          WORK_ITEM_TYPE_NAME_TASK,
+          WORK_ITEM_TYPE_NAME_KEY_RESULT,
+          WORK_ITEM_TYPE_NAME_OBJECTIVE,
         ]);
       });
     });
@@ -666,11 +692,15 @@ describe('WorkItemActions component', () => {
     it('passes related item data to create work item modal', () => {
       createComponent();
 
-      expect(findCreateWorkItemModal().props('relatedItem')).toEqual({
-        id: 'gid://gitlab/WorkItem/1',
-        reference: 'gitlab-org/gitlab-test#1',
-        type: 'Task',
-        webUrl: 'gitlab-org/gitlab-test/-/work_items/1',
+      expect(findCreateWorkItemModal().props()).toMatchObject({
+        creationContext: CREATION_CONTEXT_RELATED_ITEM,
+        namespaceFullName: 'GitLab.org / GitLab Test',
+        relatedItem: {
+          id: 'gid://gitlab/WorkItem/1',
+          reference: 'gitlab-org/gitlab-test#1',
+          type: 'Task',
+          webUrl: 'gitlab-org/gitlab-test/-/work_items/1',
+        },
       });
     });
 
@@ -739,7 +769,7 @@ describe('WorkItemActions component', () => {
   describe('move issue button', () => {
     it('shows move button when workItemType is issue and `canMove` is true', async () => {
       createComponent({
-        workItemType: WORK_ITEM_TYPE_VALUE_ISSUE,
+        workItemType: WORK_ITEM_TYPE_NAME_ISSUE,
       });
       await waitForPromises();
 
@@ -748,7 +778,7 @@ describe('WorkItemActions component', () => {
 
     it('renders with text "Move"', async () => {
       createComponent({
-        workItemType: WORK_ITEM_TYPE_VALUE_ISSUE,
+        workItemType: WORK_ITEM_TYPE_NAME_ISSUE,
       });
 
       await waitForPromises();
@@ -758,7 +788,7 @@ describe('WorkItemActions component', () => {
 
     it('hides move button when `canMove` is false', async () => {
       createComponent({
-        workItemType: WORK_ITEM_TYPE_VALUE_ISSUE,
+        workItemType: WORK_ITEM_TYPE_NAME_ISSUE,
         canMove: false,
       });
       await waitForPromises();
@@ -768,7 +798,7 @@ describe('WorkItemActions component', () => {
 
     it('hides move button when workItemType is not issue', async () => {
       createComponent({
-        workItemType: WORK_ITEM_TYPE_VALUE_TASK,
+        workItemType: WORK_ITEM_TYPE_NAME_TASK,
       });
 
       await waitForPromises();
@@ -780,7 +810,7 @@ describe('WorkItemActions component', () => {
   describe('move modal', () => {
     it('does not render move modal when there is no projectId', async () => {
       createComponent({
-        workItemType: WORK_ITEM_TYPE_VALUE_ISSUE,
+        workItemType: WORK_ITEM_TYPE_NAME_ISSUE,
         projectId: null,
       });
 
@@ -791,7 +821,7 @@ describe('WorkItemActions component', () => {
 
     it('renders move modal when move button is clicked', async () => {
       createComponent({
-        workItemType: WORK_ITEM_TYPE_VALUE_ISSUE,
+        workItemType: WORK_ITEM_TYPE_NAME_ISSUE,
       });
 
       await waitForPromises();
@@ -805,7 +835,7 @@ describe('WorkItemActions component', () => {
 
     it('passes correct props to move modal', async () => {
       createComponent({
-        workItemType: WORK_ITEM_TYPE_VALUE_ISSUE,
+        workItemType: WORK_ITEM_TYPE_NAME_ISSUE,
       });
 
       await waitForPromises();
@@ -823,7 +853,7 @@ describe('WorkItemActions component', () => {
 
     it('closes modal when hideModal event is emitted', async () => {
       createComponent({
-        workItemType: WORK_ITEM_TYPE_VALUE_ISSUE,
+        workItemType: WORK_ITEM_TYPE_NAME_ISSUE,
       });
 
       await waitForPromises();
