@@ -15,17 +15,22 @@ import WorkItemDescriptionTemplatesListbox from '~/work_items/components/work_it
 import updateWorkItemMutation from '~/work_items/graphql/update_work_item.mutation.graphql';
 import workItemByIidQuery from '~/work_items/graphql/work_item_by_iid.query.graphql';
 import workItemDescriptionTemplateQuery from '~/work_items/graphql/work_item_description_template.query.graphql';
-import { autocompleteDataSources, markdownPreviewPath, newWorkItemId } from '~/work_items/utils';
+import namespacePathsQuery from '~/work_items/graphql/namespace_paths.query.graphql';
+import projectPermissionsQuery from '~/work_items/graphql/ai_permissions_for_project.query.graphql';
+import { autocompleteDataSources, newWorkItemId } from '~/work_items/utils';
 import { ROUTES, NEW_WORK_ITEM_IID, NEW_WORK_ITEM_GID } from '~/work_items/constants';
 import {
   updateWorkItemMutationResponse,
   workItemByIidResponseFactory,
   workItemQueryResponse,
-} from '../mock_data';
+  namespacePathsQueryResponse,
+} from 'ee_else_ce_jest/work_items/mock_data';
 
 jest.mock('~/lib/utils/confirm_via_gl_modal/confirm_via_gl_modal');
 jest.mock('~/lib/utils/autosave');
 
+const { markdownPaths } = namespacePathsQueryResponse.data.namespace;
+
 describe('WorkItemDescription', () => {
   let wrapper;
   let router;
@@ -60,6 +65,24 @@ describe('WorkItemDescription', () => {
     },
   });
 
+  const mockWorkspacePermissionsResponse = {
+    data: {
+      workspace: {
+        id: 'gid://gitlab/Project/1',
+        userPermissions: {
+          generateDescription: true,
+        },
+        __typename: 'Project',
+      },
+    },
+  };
+
+  const mockWorkspacePermissionsHandler = jest
+    .fn()
+    .mockResolvedValue(mockWorkspacePermissionsResponse);
+
+  const mockNamespacePathsHandler = jest.fn().mockResolvedValue(namespacePathsQueryResponse);
+
   const mockFullPath = 'test-project-path';
 
   const createComponent = async ({
@@ -70,10 +93,10 @@ describe('WorkItemDescription', () => {
     workItemResponseHandler = jest.fn().mockResolvedValue(workItemResponse),
     isEditing = false,
     isGroup = false,
+    newWorkItemType = workItemQueryResponse.data.workItem.workItemType.name,
     workItemId = workItemQueryResponse.data.workItem.id,
     workItemIid = '1',
     workItemTypeId = workItemQueryResponse.data.workItem.workItemType.id,
-    workItemTypeName = workItemQueryResponse.data.workItem.workItemType.name,
     editMode = false,
     showButtonsBelowField,
     descriptionTemplateHandler = successfulTemplateHandler,
@@ -81,6 +104,7 @@ describe('WorkItemDescription', () => {
     routeQuery = {},
     fullPath = mockFullPath,
     hideFullscreenMarkdownButton = false,
+    workspacePermissionsHandler = mockWorkspacePermissionsHandler,
   } = {}) => {
     router = {
       replace: jest.fn(),
@@ -91,17 +115,20 @@ describe('WorkItemDescription', () => {
         [workItemByIidQuery, workItemResponseHandler],
         [updateWorkItemMutation, mutationHandler],
         [workItemDescriptionTemplateQuery, descriptionTemplateHandler],
+        [projectPermissionsQuery, workspacePermissionsHandler],
+        [namespacePathsQuery, mockNamespacePathsHandler],
       ]),
       propsData: {
         fullPath,
         workItemId,
         workItemIid,
         workItemTypeId,
-        workItemTypeName,
+        newWorkItemType,
         editMode,
         showButtonsBelowField,
         isCreateFlow,
         hideFullscreenMarkdownButton,
+        uploadsPath: 'http://127.0.0.1:3000/test-project-path/uploads',
       },
       provide: {
         isGroup,
@@ -138,8 +165,8 @@ describe('WorkItemDescription', () => {
 
       expect(findMarkdownEditor().props()).toMatchObject({
         supportsQuickActions: true,
-        renderMarkdownPath: markdownPreviewPath({ fullPath, iid }),
-        autocompleteDataSources: autocompleteDataSources({ fullPath, iid }),
+        renderMarkdownPath: markdownPaths.markdownPreviewPath,
+        autocompleteDataSources: autocompleteDataSources({ fullPath, iid, markdownPaths }),
       });
     });
 
@@ -163,6 +190,7 @@ describe('WorkItemDescription', () => {
                 fullPath: 'gitlab-org',
                 name: 'Gitlab Org',
                 fullName: 'Gitlab Org',
+                webUrl: 'http://127.0.0.1:3000/test-project-path',
                 __typename: 'Namespace',
               },
             },
@@ -176,11 +204,12 @@ describe('WorkItemDescription', () => {
 
       expect(findMarkdownEditor().props()).toMatchObject({
         supportsQuickActions: true,
-        renderMarkdownPath: markdownPreviewPath({ fullPath, iid, isGroup: true }),
+        renderMarkdownPath: markdownPaths.markdownPreviewPath,
         autocompleteDataSources: autocompleteDataSources({
           fullPath,
           iid,
           isGroup: true,
+          markdownPaths,
         }),
       });
     });
@@ -203,6 +232,7 @@ describe('WorkItemDescription', () => {
                 fullPath: 'gitlab-org',
                 name: 'Gitlab Org',
                 fullName: 'Gitlab Org',
+                webUrl: 'http://127.0.0.1:3000/test-project-path',
                 __typename: 'Namespace',
               },
             },
@@ -226,16 +256,13 @@ describe('WorkItemDescription', () => {
 
       expect(findMarkdownEditor().props()).toMatchObject({
         supportsQuickActions: true,
-        renderMarkdownPath: markdownPreviewPath({
-          fullPath,
-          iid: NEW_WORK_ITEM_IID,
-          isGroup: true,
-        }),
+        renderMarkdownPath: markdownPaths.markdownPreviewPath,
         autocompleteDataSources: autocompleteDataSources({
           fullPath,
           iid: NEW_WORK_ITEM_IID,
           isGroup: true,
           workItemTypeId: 'gid://gitlab/WorkItems::Type/5',
+          markdownPaths,
         }),
       });
     });
@@ -339,21 +366,41 @@ describe('WorkItemDescription', () => {
   });
 
   describe('when edit mode is active', () => {
-    it('shows markdown editor in edit mode only when the correct props are passed', () => {
+    it('does not show markdown editor while markdown paths are loading', () => {
       createComponent({ editMode: true });
 
+      expect(findMarkdownEditor().exists()).toBe(false);
+    });
+
+    it('shows markdown editor in edit mode only when the correct props are passed', async () => {
+      createComponent({ editMode: true });
+      await waitForPromises();
+
       expect(findMarkdownEditor().exists()).toBe(true);
     });
 
-    it('emits the `updateDraft` event when the description is updated', () => {
+    it('emits the `updateDraft` event when the description is updated', async () => {
       createComponent({ editMode: true });
       const updatedDesc = 'updated desc with inline editing disabled';
 
+      await waitForPromises();
+
       findMarkdownEditor().vm.$emit('input', updatedDesc);
 
       expect(wrapper.emitted('updateDraft')).toEqual([[updatedDesc]]);
     });
 
+    it('does not emit the `updateDraft` event when the description is updated from mounted hook of markdown-editor', async () => {
+      createComponent({ editMode: true, isCreateFlow: true });
+      const updatedDesc = 'updated desc with inline editing disabled';
+
+      await waitForPromises();
+
+      findMarkdownEditor().vm.$emit('input', updatedDesc, true);
+
+      expect(wrapper.emitted('updateDraft')).toBeUndefined();
+    });
+
     it('emits the `updateWorkItem` event when submitting the description', async () => {
       await createComponent({ isEditing: true });
       editDescription('updated description');
@@ -399,6 +446,28 @@ describe('WorkItemDescription', () => {
           expect(findApplyTemplate().exists()).toBe(true);
         });
 
+        it('does not display a warning when a description is pre-populated in create mode', async () => {
+          // Mimic component mount with a pre-populated description
+          await createComponent({
+            editMode: true,
+            workItemResponseHandler: jest
+              .fn()
+              .mockResolvedValue(
+                workItemByIidResponseFactory({ description: 'Pre-filled description' }),
+              ),
+            workItemId: newWorkItemId(workItemQueryResponse.data.workItem.workItemType.name),
+          });
+          await nextTick();
+          await waitForPromises();
+
+          expect(findDescriptionTemplateWarning().exists()).toBe(false);
+          expect(findCancelApplyTemplate().exists()).toBe(false);
+          expect(findApplyTemplate().exists()).toBe(false);
+
+          // No template is selected when description is pre-filled
+          expect(findDescriptionTemplateListbox().props('template')).toBeNull();
+        });
+
         it('hides the warning when the cancel button is clicked', async () => {
           expect(findDescriptionTemplateWarning().exists()).toBe(true);
           findCancelApplyTemplate().vm.$emit('click');
@@ -765,46 +834,102 @@ describe('WorkItemDescription', () => {
     });
   });
 
-  it.each`
-    namespaceId                | uploadsPath                            | namespaceType
-    ${'gid://gitlab/Group/24'} | ${`/groups/${mockFullPath}/-/uploads`} | ${'group'}
-    ${'123'}                   | ${`/${mockFullPath}/uploads`}          | ${'project'}
-  `(
-    'passes correct uploads path for markdown editor when namespace is $namespaceType',
+  describe('workspacePermissions query', () => {
+    it('is not called for groups', async () => {
+      const workspacePermissionsHandler = jest
+        .fn()
+        .mockResolvedValue(mockWorkspacePermissionsResponse);
 
-    async ({ namespaceId, uploadsPath }) => {
-      const workItemResponse = workItemByIidResponseFactory({
-        iid: NEW_WORK_ITEM_IID,
-        id: NEW_WORK_ITEM_GID,
+      await createComponent({
+        isGroup: true,
+        isEditing: true,
+        workspacePermissionsHandler,
       });
 
-      const newGroupWorkItem = {
-        data: {
-          workspace: {
-            __typename: 'Group',
-            id: namespaceId,
-            workItem: {
-              ...workItemResponse.data.workspace.workItem,
-              namespace: {
-                id: namespaceId,
-                fullPath: 'gitlab-org',
-                name: 'Gitlab Org',
-                fullName: 'Gitlab Org',
-                __typename: 'Namespace',
+      expect(workspacePermissionsHandler).not.toHaveBeenCalled();
+    });
+
+    it('is called for projects', async () => {
+      const workspacePermissionsHandler = jest
+        .fn()
+        .mockResolvedValue(mockWorkspacePermissionsResponse);
+
+      await createComponent({
+        isGroup: false,
+        isEditing: true,
+        workspacePermissionsHandler,
+      });
+
+      expect(workspacePermissionsHandler).toHaveBeenCalledWith({
+        fullPath: mockFullPath,
+      });
+    });
+
+    describe('user has generateDescription permission', () => {
+      beforeEach(async () => {
+        const workspacePermissionsHandler = jest
+          .fn()
+          .mockResolvedValue(mockWorkspacePermissionsResponse);
+
+        await createComponent({
+          isGroup: false,
+          isEditing: true,
+          workspacePermissionsHandler,
+        });
+      });
+
+      it('passes editorAiActions prop to MarkdownEditor', () => {
+        const editorAiActions = findMarkdownEditor().props('editorAiActions');
+        expect(editorAiActions).toHaveLength(1);
+      });
+    });
+
+    describe('user does not have generateDescription permission', () => {
+      beforeEach(async () => {
+        const workspacePermissionsHandlerNoPermission = jest.fn().mockResolvedValue({
+          data: {
+            workspace: {
+              id: 'gid://gitlab/Project/1',
+              userPermissions: {
+                generateDescription: false,
               },
+              __typename: 'Project',
             },
           },
-        },
-      };
+        });
 
-      createComponent({
-        isEditing: true,
-        isGroup: true,
-        workItemResponse: newGroupWorkItem,
+        await createComponent({
+          isGroup: false,
+          isEditing: true,
+          workspacePermissionsHandler: workspacePermissionsHandlerNoPermission,
+        });
       });
-      await waitForPromises();
 
-      expect(findMarkdownEditor().props('uploadsPath')).toBe(uploadsPath);
-    },
-  );
+      it('passes empty editorAiActions prop to MarkdownEditor', () => {
+        const editorAiActions = findMarkdownEditor().props('editorAiActions');
+        expect(editorAiActions).toHaveLength(0);
+      });
+    });
+
+    describe('when workspace is null', () => {
+      beforeEach(async () => {
+        const workspacePermissionsHandlerNullWorkspace = jest.fn().mockResolvedValue({
+          data: {
+            workspace: null,
+          },
+        });
+
+        await createComponent({
+          isGroup: false,
+          isEditing: true,
+          workspacePermissionsHandler: workspacePermissionsHandlerNullWorkspace,
+        });
+      });
+
+      it('passes empty editorAiActions prop to MarkdownEditor', () => {
+        const editorAiActions = findMarkdownEditor().props('editorAiActions');
+        expect(editorAiActions).toHaveLength(0);
+      });
+    });
+  });
 });
