@@ -319,32 +319,45 @@ RSpec.describe AuthHelper, feature_category: :system_access do
   describe '#auth_app_owner_text' do
     shared_examples 'generates text with the correct info' do
       it 'includes the name of the application owner' do
-        auth_app_owner_text = helper.auth_app_owner_text(owner)
+        auth_app_owner_text = helper.auth_app_owner_text(application)
 
-        expect(auth_app_owner_text).to include(owner.name)
+        expect(auth_app_owner_text).to include(application.owner.name)
         expect(auth_app_owner_text).to include(path_to_owner)
       end
     end
 
     context 'when owner is a user' do
-      let_it_be(:owner) { create(:user) }
+      let_it_be(:application) { create(:oauth_application) }
 
-      let(:path_to_owner) { user_path(owner) }
+      let(:path_to_owner) { user_path(application.owner) }
 
       it_behaves_like 'generates text with the correct info'
     end
 
     context 'when owner is a group' do
-      let_it_be(:owner) { create(:group) }
+      let_it_be(:application) { create(:oauth_application, :group_owned) }
 
-      let(:path_to_owner) { user_path(owner) }
+      let(:path_to_owner) { user_path(application.owner) }
 
       it_behaves_like 'generates text with the correct info'
     end
 
     context 'when the user is missing' do
-      it 'returns nil' do
-        expect(helper.auth_app_owner_text(nil)).to be('An administrator added this OAuth application ')
+      let_it_be(:application) { create(:oauth_application, :without_owner) }
+
+      context 'when the application is dynamically created' do
+        let_it_be(:application) { create(:oauth_application, :dynamic) }
+
+        it 'returns a warning' do
+          expect(helper.auth_app_owner_text(application))
+            .to be('An anonymous service added this dynamically created OAuth application ')
+        end
+      end
+
+      context 'when the application is not dynamically generated' do
+        it 'returns nil' do
+          expect(helper.auth_app_owner_text(application)).to be('An administrator added this OAuth application ')
+        end
       end
     end
   end
@@ -574,6 +587,7 @@ RSpec.describe AuthHelper, feature_category: :system_access do
       it 'returns data to delete the OTP authenticator' do
         expect(helper.delete_otp_authenticator_data(true)).to match(a_hash_including({
           button_text: _('Delete one-time password authenticator'),
+          icon: 'remove',
           message: _('Are you sure you want to delete this one-time password authenticator? ' \
             'Enter your password to continue.'),
           path: destroy_otp_profile_two_factor_auth_path,
@@ -631,7 +645,8 @@ RSpec.describe AuthHelper, feature_category: :system_access do
           message: _('Are you sure you want to invalidate your one-time password authenticator and WebAuthn devices? ' \
             'Enter your password to continue. This action cannot be undone.'),
           path: profile_two_factor_auth_path,
-          password_required: 'true'
+          password_required: 'true',
+          size: 'small'
         }))
       end
     end
@@ -658,6 +673,7 @@ RSpec.describe AuthHelper, feature_category: :system_access do
           method: 'post',
           path: codes_profile_two_factor_auth_path,
           password_required: 'true',
+          size: 'small',
           variant: 'default'
         }))
       end
@@ -676,4 +692,112 @@ RSpec.describe AuthHelper, feature_category: :system_access do
       end
     end
   end
+
+  describe '#certificate_fingerprint_algorithm' do
+    let_it_be(:sha1_fingerprint_upper) { "DD:80:B1:FA:A9:A7:8D:9D:41:7E:09:10:D8:6F:7D:0A:7E:58:4C:C4" }
+    let_it_be(:sha1_fingerprint_lower) { "dd:80:b1:fa:a9:a7:8d:9d:41:7e:09:10:d8:6f:7d:0a:7e:58:4c:c4" }
+    let_it_be(:sha256_fingerprint_upper) do
+      "73:2D:28:C2:D2:D0:34:9F:F8:9A:9C:74:23:BF:0A:CB:66:75:78:9B:01:4D:1F:7D:60:8F:AD:47:A2:30:D7:4A"
+    end
+
+    let_it_be(:sha256_fingerprint_mixed) do
+      "73:2d:28:c2:d2:d0:34:9F:F8:9a:9c:74:23:BF:0a:cb:66:75:78:9b:01:4D:1F:7D:60:8f:ad:47:a2:30:d7:4a"
+    end
+
+    it 'detects SHA1 fingerprint with upper case characters' do
+      expect(helper.certificate_fingerprint_algorithm(sha1_fingerprint_upper))
+        .to eq('http://www.w3.org/2000/09/xmldsig#sha1')
+    end
+
+    it 'detects SHA1 fingerprint with lower case characters' do
+      expect(helper.certificate_fingerprint_algorithm(sha1_fingerprint_lower))
+        .to eq('http://www.w3.org/2000/09/xmldsig#sha1')
+    end
+
+    it 'detects SHA256 fingerprint with upper case characters' do
+      expect(helper.certificate_fingerprint_algorithm(sha256_fingerprint_upper))
+        .to eq('http://www.w3.org/2001/04/xmlenc#sha256')
+    end
+
+    it 'detects SHA256 fingerprint with mixed case characters' do
+      expect(helper.certificate_fingerprint_algorithm(sha256_fingerprint_mixed))
+        .to eq('http://www.w3.org/2001/04/xmlenc#sha256')
+    end
+  end
+
+  describe '#step_up_auth_params' do
+    using RSpec::Parameterized::TableSyntax
+
+    let(:current_user) { instance_double('User', flipper_id: '1') }
+
+    let(:oidc_setting_with_step_up_auth) do
+      GitlabSettings::Options.new(
+        name: "openid_connect",
+        step_up_auth: {
+          admin_mode: {
+            params: {
+              claims: { acr_values: 'gold' },
+              prompt: 'login'
+            }
+          }
+        }
+      )
+    end
+
+    let(:oidc_setting_without_step_up_auth_params) do
+      GitlabSettings::Options.new(name: "openid_connect",
+        step_up_auth: { admin_mode: { id_token: { required: { acr: 'gold' } } } })
+    end
+
+    let(:oidc_setting_without_step_up_auth) do
+      GitlabSettings::Options.new(name: "openid_connect")
+    end
+
+    subject { helper.step_up_auth_params(provider_name, scope) }
+
+    before do
+      allow(helper).to receive(:current_user).and_return(current_user)
+      stub_omniauth_setting(enabled: true, providers: omniauth_setting_providers)
+    end
+
+    # rubocop:disable Layout/LineLength -- Ensure one-line table syntax for better readability
+    where(:omniauth_setting_providers, :provider_name, :scope, :expected_result) do
+      [ref(:oidc_setting_with_step_up_auth)]           | 'openid_connect'        | :admin_mode  | { step_up_auth_scope: :admin_mode, 'claims' => '{"acr_values":"gold"}', 'prompt' => 'login' }
+      [ref(:oidc_setting_with_step_up_auth)]           | 'openid_connect'        | 'admin_mode' | { step_up_auth_scope: 'admin_mode', 'claims' => '{"acr_values":"gold"}', 'prompt' => 'login' }
+      [ref(:oidc_setting_with_step_up_auth)]           | 'openid_connect'        | nil          | {}
+      [ref(:oidc_setting_with_step_up_auth)]           | 'missing_provider_name' | :admin_mode  | {}
+      [ref(:oidc_setting_with_step_up_auth)]           | nil                     | nil          | {}
+
+      []                                               | 'openid_connect'        | :admin_mode  | {}
+      [ref(:oidc_setting_without_step_up_auth)]        | 'openid_connect'        | :admin_mode  | {}
+      [ref(:oidc_setting_without_step_up_auth_params)] | 'openid_connect'        | :admin_mode  | { step_up_auth_scope: :admin_mode }
+    end
+    # rubocop:enable Layout/LineLength
+
+    with_them do
+      it { is_expected.to eq expected_result }
+
+      context 'when feature flag :omniauth_step_up_auth_for_admin_mode is disabled' do
+        before do
+          stub_feature_flags(omniauth_step_up_auth_for_admin_mode: false)
+        end
+
+        it { is_expected.to eq({}) }
+      end
+    end
+  end
+
+  def omniauth_providers_with_step_up_auth_config(step_up_auth_scope)
+    auth_providers.map { |provider| Gitlab::Auth::OAuth::Provider.config_for(provider) }
+                  .select { |provider_config| provider_config.dig("step_up_auth", step_up_auth_scope.to_s).present? }
+  end
+
+  def step_up_auth_params(provider_name, scope)
+    return {} if Feature.disabled?(:omniauth_step_up_auth_for_admin_mode, current_user)
+
+    provider_config_for_scope = Gitlab::Auth::OAuth::Provider.config_for(provider_name)&.dig('step_up_auth', scope)
+    return {} if provider_config_for_scope&.dig('enabled').blank?
+
+    provider_config_for_scope&.dig('params')&.transform_values { |v| v.is_a?(Hash) ? v.to_json : v }
+  end
 end
