@@ -431,6 +431,25 @@ RSpec.describe GroupsHelper, feature_category: :groups_and_projects do
     end
   end
 
+  describe '#can_invite_group_member?' do
+    let_it_be(:user) { create(:user) }
+    let_it_be(:group) { create(:group) }
+
+    before do
+      allow(helper).to receive(:current_user) { user }
+    end
+
+    it 'returns true when current_user can invite members' do
+      group.add_owner(user)
+
+      expect(helper.can_invite_group_member?(group)).to be(true)
+    end
+
+    it 'returns false when current_user can not invite members' do
+      expect(helper.can_invite_group_member?(group)).to be(false)
+    end
+  end
+
   describe '#localized_jobs_to_be_done_choices' do
     it 'has a translation for all `jobs_to_be_done` values' do
       expect(localized_jobs_to_be_done_choices.keys).to match_array(NamespaceSetting.jobs_to_be_dones.keys)
@@ -505,9 +524,10 @@ RSpec.describe GroupsHelper, feature_category: :groups_and_projects do
       expect(helper.group_overview_tabs_app_data(group)).to match(
         {
           group_id: group.id,
-          subgroups_and_projects_endpoint: including("/groups/#{group.path}/-/children.json"),
+          subgroups_and_projects_endpoint:
+            including("/groups/#{group.path}/-/children.json?archived=false&not_aimed_for_deletion=true"),
           shared_projects_endpoint: including("/groups/#{group.path}/-/shared_projects.json"),
-          inactive_projects_endpoint: including("/groups/#{group.path}/-/children.json?archived=only"),
+          inactive_projects_endpoint: including("/groups/#{group.path}/-/children.json?active=false"),
           current_group_visibility: group.visibility,
           initial_sort: initial_sort,
           show_schema_markup: 'true',
@@ -556,6 +576,53 @@ RSpec.describe GroupsHelper, feature_category: :groups_and_projects do
     end
   end
 
+  describe '#group_archive_settings_app_data' do
+    let_it_be(:group) { create(:group) }
+
+    subject { helper.group_archive_settings_app_data(group) }
+
+    it 'returns correct data' do
+      is_expected.to match({
+        resource_type: 'group',
+        resource_id: group.id,
+        resource_path: including(group.full_path)
+      })
+    end
+  end
+
+  describe '#group_unarchive_settings_app_data' do
+    let_it_be_with_reload(:ancestor) { create(:group) }
+    let_it_be(:group) { create(:group, parent: ancestor) }
+
+    subject { helper.group_unarchive_settings_app_data(group) }
+
+    context 'when ancestor is not archived' do
+      it 'returns correct data' do
+        is_expected.to match({
+          resource_type: 'group',
+          resource_id: group.id,
+          resource_path: including(group.full_path),
+          ancestors_archived: 'false'
+        })
+      end
+    end
+
+    context 'when ancestor is archived' do
+      before do
+        ancestor.archive
+      end
+
+      it 'returns correct data' do
+        is_expected.to match({
+          resource_type: 'group',
+          resource_id: group.id,
+          resource_path: including(group.full_path),
+          ancestors_archived: 'true'
+        })
+      end
+    end
+  end
+
   describe "#enabled_git_access_protocol_options_for_group" do
     subject { helper.enabled_git_access_protocol_options_for_group }
 
@@ -733,34 +800,16 @@ RSpec.describe GroupsHelper, feature_category: :groups_and_projects do
     end
   end
 
-  describe('#group_confirm_modal_data') do
-    using RSpec::Parameterized::TableSyntax
+  describe '#groups_list_with_filtered_search_app_data' do
+    let_it_be(:endpoint) { '/groups' }
 
-    let_it_be(:group) { create(:group, path: "foo") }
-
-    fake_form_id = "fake_form_id"
-    where(:prevent_delete_response, :is_button_disabled, :form_value_id, :permanently_remove, :button_text, :has_security_policy_project) do
-      true      | "true"      | nil           |  false  | "Delete" | true
-      true      | "true"      | fake_form_id  |  true   | nil | false
-      false     | "true" | nil | false | "Delete group" | true
-      false     | "false" | fake_form_id | true | nil | false
-    end
-
-    with_them do
-      it "returns expected parameters" do
-        allow(group).to receive(:linked_to_subscription?).and_return(prevent_delete_response)
-
-        expected = helper.group_confirm_modal_data(group: group, remove_form_id: form_value_id, button_text: button_text, has_security_policy_project: has_security_policy_project)
-        expect(expected).to eq({
-          button_text: button_text.nil? ? "Delete group" : button_text,
-          confirm_danger_message: remove_group_message(group, permanently_remove),
-          remove_form_id: form_value_id,
-          phrase: group.full_path,
-          button_testid: "remove-group-button",
-          disabled: is_button_disabled,
-          html_confirmation_message: 'true'
-        })
-      end
+    it 'returns expected json' do
+      expect(Gitlab::Json.parse(helper.groups_list_with_filtered_search_app_data(endpoint))).to eq(
+        {
+          'endpoint' => endpoint,
+          'initial_sort' => 'created_desc'
+        }
+      )
     end
   end
 
