@@ -414,32 +414,6 @@ RSpec.describe ProjectsHelper, feature_category: :source_code_management do
     end
   end
 
-  describe '#show_projects' do
-    let(:projects) do
-      Project.all
-    end
-
-    it 'returns true when there are projects' do
-      expect(helper.show_projects?(projects, {})).to eq(true)
-    end
-
-    it 'returns true when there are no projects but a name is given' do
-      expect(helper.show_projects?(Project.none, name: 'foo')).to eq(true)
-    end
-
-    it 'returns true when there are no projects but personal is present' do
-      expect(helper.show_projects?(Project.none, personal: 'true')).to eq(true)
-    end
-
-    it 'returns false when there are no projects and there is no name' do
-      expect(helper.show_projects?(Project.none, {})).to eq(false)
-    end
-
-    it 'returns true when there are no projects but archived param is "only"' do
-      expect(helper.show_projects?(Project.none, archived: 'only')).to eq(true)
-    end
-  end
-
   describe '#push_to_create_project_command' do
     let(:user) { build_stubbed(:user, username: 'john') }
 
@@ -735,37 +709,6 @@ RSpec.describe ProjectsHelper, feature_category: :source_code_management do
     end
   end
 
-  describe '#can_admin_project_member?' do
-    context 'when user is project owner' do
-      let(:user) { project.owner }
-
-      it 'returns true for owner of project' do
-        expect(helper.can_admin_project_member?(project)).to eq true
-      end
-    end
-
-    context 'when user is not a project owner' do
-      using RSpec::Parameterized::TableSyntax
-
-      where(:user_project_role, :can_admin) do
-        :maintainer | true
-        :developer | false
-        :reporter | false
-        :guest | false
-      end
-
-      with_them do
-        before do
-          project.add_role(user, user_project_role)
-        end
-
-        it 'resolves if the user can import members' do
-          expect(helper.can_admin_project_member?(project)).to eq can_admin
-        end
-      end
-    end
-  end
-
   describe '#project_license_name(project)', :request_store do
     let_it_be(:repository) { project.repository }
 
@@ -907,6 +850,16 @@ RSpec.describe ProjectsHelper, feature_category: :source_code_management do
 
             it { is_expected.to be_falsey }
           end
+
+          context 'when user has dismissed the callout' do
+            before do
+              allow(user).to receive(:dismissed_callout_for_project?)
+                .with(feature_name: :lfs_misconfiguration_banner, project: project)
+                .and_return(true)
+            end
+
+            it { is_expected.to be_falsey }
+          end
         end
       end
 
@@ -965,6 +918,17 @@ RSpec.describe ProjectsHelper, feature_category: :source_code_management do
     end
   end
 
+  describe '#remove_project_message' do
+    subject(:message) { helper.remove_project_message }
+
+    specify do
+      deletion_date = helper.permanent_deletion_date_formatted(Date.current)
+
+      expect(message).to eq "Deleting a project places it into a read-only state until #{deletion_date}, " \
+        "at which point the project will be permanently deleted. Are you ABSOLUTELY sure?"
+    end
+  end
+
   describe '#project_permissions_panel_data' do
     subject { helper.project_permissions_panel_data(project) }
 
@@ -1140,7 +1104,7 @@ RSpec.describe ProjectsHelper, feature_category: :source_code_management do
 
     subject { helper.fork_button_data_attributes(project) }
 
-    where(:has_user, :project_already_forked, :has_forkable_groups, :expected) do
+    where(:has_user, :project_already_forked, :has_groups_allowing_project_creation, :expected) do
       false | false | false | nil
       true  | false | false | data_attributes_without_user_fork_url
       true  | false | true  | data_attributes_without_user_fork_url
@@ -1157,7 +1121,7 @@ RSpec.describe ProjectsHelper, feature_category: :source_code_management do
         allow(user).to receive(:can?).with(:fork_project, project).and_return(true)
         allow(user).to receive(:can?).with(:create_projects, anything).and_return(true)
         allow(user).to receive(:already_forked?).with(project).and_return(project_already_forked)
-        allow(user).to receive(:has_forkable_groups?).and_return(has_forkable_groups)
+        allow(user).to receive(:has_groups_allowing_project_creation?).and_return(has_groups_allowing_project_creation)
 
         allow(project).to receive(:forks_count).and_return(4)
         allow(project).to receive(:full_path).and_return(project_path)
@@ -1292,27 +1256,25 @@ RSpec.describe ProjectsHelper, feature_category: :source_code_management do
 
       it { is_expected.to include(expected) }
     end
-  end
 
-  describe '#visibility_level_name' do
-    using RSpec::Parameterized::TableSyntax
-
-    where(:banned_user, :feature_flag_enabled, :expected) do
-      true  | true  | 'banned'
-      false | false | 'private'
-      true  | false | 'private'
-      false | true  | 'private'
-    end
-
-    with_them do
+    context "when project is not marked for deletion" do
       before do
-        stub_feature_flags(hide_projects_of_banned_users: feature_flag_enabled)
-        allow(project).to receive(:created_and_owned_by_banned_user?).and_return(banned_user)
+        allow(project).to receive(:self_deletion_scheduled?).and_return(false)
       end
 
-      subject { visibility_level_name(project) }
+      subject { helper.home_panel_data_attributes }
 
-      it { is_expected.to eq(expected) }
+      it { is_expected.to include({ is_project_marked_for_deletion: "false" }) }
+    end
+
+    context "when project is marked for deletion" do
+      before do
+        allow(project).to receive(:self_deletion_scheduled?).and_return(true)
+      end
+
+      subject { helper.home_panel_data_attributes }
+
+      it { is_expected.to include({ is_project_marked_for_deletion: "true" }) }
     end
   end
 
@@ -1342,44 +1304,126 @@ RSpec.describe ProjectsHelper, feature_category: :source_code_management do
     it_behaves_like 'configure import method modal'
   end
 
-  describe "#show_archived_project_banner?" do
-    shared_examples 'does not show the banner' do |pass_project: true|
-      it do
-        expect(project.archived?).to be(false)
-        expect(helper.show_archived_project_banner?(pass_project ? project : nil)).to be(false)
-      end
-    end
+  describe "#archiving_available?" do
+    subject(:archiving_available?) { helper.archiving_available?(project) }
 
-    context 'with no project' do
-      it_behaves_like 'does not show the banner', pass_project: false
+    context 'with nil project' do
+      let_it_be(:project) { nil }
+
+      it { is_expected.to be(false) }
     end
 
     context 'with unsaved project' do
       let_it_be(:project) { build(:project) }
 
-      it_behaves_like 'does not show the banner'
+      it { is_expected.to be(false) }
     end
 
-    context 'with the setting enabled' do
-      context 'with an active project' do
-        it_behaves_like 'does not show the banner'
+    shared_context 'with current user :archive_project permission' do |can_manage|
+      before do
+        allow(helper)
+          .to receive(:can?)
+          .with(user, :archive_project, project)
+          .and_return(can_manage)
+      end
+    end
+
+    context 'with an active project' do
+      context 'when current user cannot manage archiving' do
+        include_context 'with current user :archive_project permission', false
+
+        it { is_expected.to be(false) }
       end
 
-      context 'with an inactive project' do
-        before do
-          project.archived = true
-          project.save!
-        end
+      context 'when current user can manage archiving' do
+        include_context 'with current user :archive_project permission', true
 
-        it 'shows the banner' do
-          expect(project.present?).to be(true)
-          expect(project.saved?).to be(true)
-          expect(project.archived?).to be(true)
-          expect(helper.show_archived_project_banner?(project)).to be(true)
-          expect(helper.show_inactive_project_deletion_banner?(project)).to be(false)
-        end
+        it { is_expected.to be(true) }
       end
     end
+
+    context 'with an archived project' do
+      before do
+        project.archived = true
+        project.save!
+      end
+
+      context 'when current user cannot manage archiving' do
+        include_context 'with current user :archive_project permission', false
+
+        it { is_expected.to be(false) }
+      end
+
+      context 'when current user can manage archiving' do
+        include_context 'with current user :archive_project permission', true
+
+        it { is_expected.to be(true) }
+      end
+    end
+
+    context 'with a project marked for deletion' do
+      before do
+        project.marked_for_deletion_at = Time.current
+        project.save!
+      end
+
+      context 'when current user cannot manage archiving' do
+        include_context 'with current user :archive_project permission', false
+
+        it { is_expected.to be(false) }
+      end
+
+      context 'when current user can manage archiving' do
+        include_context 'with current user :archive_project permission', true
+
+        it { is_expected.to be(false) }
+      end
+    end
+  end
+
+  describe "#show_archived_project_banner?" do
+    subject(:show_archived_project_banner?) { helper.show_archived_project_banner?(project) }
+
+    context 'with nil project' do
+      let_it_be(:project) { nil }
+
+      it { is_expected.to be(false) }
+    end
+
+    context 'with unsaved project' do
+      let_it_be(:project) { build(:project) }
+
+      it { is_expected.to be(false) }
+    end
+
+    context 'with an active project' do
+      it { is_expected.to be(false) }
+    end
+
+    context 'with an archived project' do
+      before do
+        project.archived = true
+        project.save!
+      end
+
+      it { is_expected.to be(true) }
+    end
+
+    context 'with a project marked for deletion' do
+      before do
+        project.marked_for_deletion_at = Time.current
+        project.save!
+      end
+
+      it { is_expected.to be(false) }
+    end
+
+    context 'with archived group' do
+      let_it_be(:group) { create(:group, :archived) }
+      let_it_be(:project) { create(:project, group: group) }
+
+      it { is_expected.to be(true) }
+    end
   end
 
   describe '#show_inactive_project_deletion_banner?' do
@@ -1432,13 +1476,13 @@ RSpec.describe ProjectsHelper, feature_category: :source_code_management do
   end
 
   describe '#inactive_project_deletion_date' do
-    let(:tracker) { instance_double(::Gitlab::InactiveProjectsDeletionWarningTracker) }
+    let(:tracker) { instance_double(::Gitlab::DormantProjectsDeletionWarningTracker) }
 
     before do
       stub_application_setting(inactive_projects_delete_after_months: 2)
       stub_application_setting(inactive_projects_send_warning_email_after_months: 1)
 
-      allow(::Gitlab::InactiveProjectsDeletionWarningTracker).to receive(:new).with(project.id).and_return(tracker)
+      allow(::Gitlab::DormantProjectsDeletionWarningTracker).to receive(:new).with(project.id).and_return(tracker)
       allow(tracker).to receive(:scheduled_deletion_date).and_return('2022-03-01')
     end
 
@@ -1835,35 +1879,6 @@ RSpec.describe ProjectsHelper, feature_category: :source_code_management do
     end
 
     it_behaves_like 'returns visibility level content_tag'
-
-    context 'when project creator is banned' do
-      let(:hidden_resource_icon) { '<svg>fake hidden resource icon</svg>' }
-
-      before do
-        allow(project).to receive(:created_and_owned_by_banned_user?).and_return(true)
-        allow(helper).to receive(:hidden_resource_icon).and_return(hidden_resource_icon)
-      end
-
-      it 'returns hidden resource icon' do
-        expect(helper.visibility_level_content(project)).to eq hidden_resource_icon
-      end
-    end
-
-    context 'with hide_projects_of_banned_users feature flag disabled' do
-      before do
-        stub_feature_flags(hide_projects_of_banned_users: false)
-      end
-
-      it_behaves_like 'returns visibility level content_tag'
-
-      context 'when project creator is banned' do
-        before do
-          allow(project).to receive(:created_and_owned_by_banned_user?).and_return(true)
-        end
-
-        it_behaves_like 'returns visibility level content_tag'
-      end
-    end
   end
 
   describe '#hidden_issue_icon' do
@@ -1980,9 +1995,7 @@ RSpec.describe ProjectsHelper, feature_category: :source_code_management do
       expect(Gitlab::Json.parse(helper.dashboard_projects_app_data)).to eq(
         {
           'initial_sort' => 'created_desc',
-          'programming_languages' => ProgrammingLanguage.most_popular,
-          'empty_state_projects_svg_path' => helper.image_path('illustrations/empty-state/empty-projects-md.svg'),
-          'empty_state_search_svg_path' => helper.image_path('illustrations/empty-state/empty-search-md.svg')
+          'programming_languages' => ProgrammingLanguage.most_popular
         }
       )
     end
@@ -2019,45 +2032,6 @@ RSpec.describe ProjectsHelper, feature_category: :source_code_management do
     end
   end
 
-  describe '#delete_immediately_message' do
-    subject { helper.delete_immediately_message(project) }
-
-    it 'returns correct message' do
-      expect(subject).to eq "This action will permanently delete this project, including all its resources."
-    end
-  end
-
-  describe '#project_delete_immediately_button_data' do
-    let(:base_button_data) do
-      {
-        form_path: project_path(project, permanently_delete: true),
-        confirm_phrase: project.path_with_namespace,
-        name_with_namespace: project.name_with_namespace,
-        is_fork: 'false',
-        issues_count: '0',
-        merge_requests_count: '0',
-        forks_count: '0',
-        stars_count: '0'
-      }
-    end
-
-    describe 'with default button text' do
-      subject { helper.project_delete_immediately_button_data(project) }
-
-      it 'returns expected hash' do
-        expect(subject).to match(base_button_data.merge(button_text: 'Delete project'))
-      end
-    end
-
-    describe 'with custom button text' do
-      subject { helper.project_delete_immediately_button_data(project, 'Delete project immediately') }
-
-      it 'returns expected hash' do
-        expect(subject).to match(base_button_data.merge(button_text: 'Delete project immediately'))
-      end
-    end
-  end
-
   describe '#project_pages_domain_choices' do
     subject { helper.project_pages_domain_choices }
 
@@ -2090,4 +2064,97 @@ RSpec.describe ProjectsHelper, feature_category: :source_code_management do
       end
     end
   end
+
+  describe '#project_archive_settings_app_data' do
+    let_it_be(:project) { create(:project) }
+
+    subject { helper.project_archive_settings_app_data(project) }
+
+    it 'returns correct data' do
+      is_expected.to match({
+        resource_type: 'project',
+        resource_id: project.id,
+        resource_path: including(project.full_path),
+        help_path: '/help/user/project/working_with_projects.md#archive-a-project'
+      })
+    end
+  end
+
+  describe '#project_unarchive_settings_app_data' do
+    let_it_be_with_reload(:ancestor) { create(:group) }
+    let_it_be(:project) { create(:project, group: ancestor) }
+
+    subject { helper.project_unarchive_settings_app_data(project) }
+
+    context 'when ancestor is not archived' do
+      it 'returns correct data' do
+        is_expected.to match({
+          resource_type: 'project',
+          resource_id: project.id,
+          resource_path: including(project.full_path),
+          ancestors_archived: 'false',
+          help_path: '/help/user/project/working_with_projects.md#unarchive-a-project'
+        })
+      end
+    end
+
+    context 'when ancestor is archived' do
+      before do
+        ancestor.archive
+      end
+
+      it 'returns correct data' do
+        is_expected.to match({
+          resource_type: 'project',
+          resource_id: project.id,
+          resource_path: including(project.full_path),
+          ancestors_archived: 'true',
+          help_path: '/help/user/project/working_with_projects.md#unarchive-a-project'
+        })
+      end
+    end
+  end
+
+  describe '#show_archived_badge?' do
+    let_it_be_with_reload(:group) { create(:group) }
+    let_it_be_with_reload(:project) { create(:project, group: group) }
+
+    subject { helper.show_archived_badge?(project) }
+
+    context 'when project is archived' do
+      before do
+        project.update!(archived: true)
+      end
+
+      it { is_expected.to be(true) }
+    end
+
+    context 'when ancestor is archived' do
+      before do
+        group.archive
+      end
+
+      it { is_expected.to be(true) }
+
+      context 'when `archive_group` flag is disabled' do
+        before do
+          stub_feature_flags(archive_group: false)
+        end
+
+        it { is_expected.to be(false) }
+      end
+    end
+
+    context 'when project and ancestor is not archived' do
+      it { is_expected.to be(false) }
+
+      context 'when `archive_group` flag is disabled' do
+        before do
+          stub_feature_flags(archive_group: false)
+        end
+
+        it { is_expected.to be(false) }
+      end
+    end
+  end
 end
