@@ -96,9 +96,11 @@ RSpec.describe TreeHelper, feature_category: :source_code_management do
   end
 
   describe '#vue_tree_header_app_data' do
+    let(:organization) { build_stubbed(:organization) }
     let(:pipeline) { build_stubbed(:ci_pipeline, project: project) }
 
     before do
+      Current.organization = organization
       helper.instance_variable_set(:@project, project)
       helper.instance_variable_set(:@ref, sha)
       allow(helper).to receive(:can?).and_return(false)
@@ -110,13 +112,14 @@ RSpec.describe TreeHelper, feature_category: :source_code_management do
       allow(helper).to receive(:show_xcode_link?).and_return(false)
     end
 
-    subject { helper.vue_tree_header_app_data(project, repository, sha, pipeline) }
+    subject { helper.vue_tree_header_app_data(project, repository, sha, pipeline, 'heads') }
 
     it 'returns a list of attributes related to the project' do
       is_expected.to include(
         project_id: project.id,
         ref: sha,
         ref_type: '',
+        root_ref: repository.root_ref,
         breadcrumbs: helper.breadcrumb_data_attributes,
         project_root_path: project_path(project),
         project_path: project.full_path,
@@ -126,7 +129,7 @@ RSpec.describe TreeHelper, feature_category: :source_code_management do
         ssh_url: ssh_clone_url_to_repo(project),
         http_url: http_clone_url_to_repo(project),
         xcode_url: '',
-        download_links: helper.download_links(project, sha, "#{project.path}-#{sha.tr('/', '-')}").to_json,
+        download_links: helper.download_links(project, sha, "#{project.path}-#{sha.tr('/', '-')}", 'heads').to_json,
         download_artifacts: '[]',
         escaped_ref: sha
       )
@@ -158,7 +161,7 @@ RSpec.describe TreeHelper, feature_category: :source_code_management do
       end
 
       it 'does not include download_links' do
-        expect(subject[:download_links]).to be_empty
+        expect(subject[:download_links]).to eq([])
       end
     end
 
@@ -166,7 +169,7 @@ RSpec.describe TreeHelper, feature_category: :source_code_management do
       let(:pipeline) { nil }
 
       it 'does not include download_artifacts' do
-        expect(subject[:download_artifacts]).to be nil
+        expect(subject[:download_artifacts]).to be_nil
       end
     end
   end
@@ -190,11 +193,13 @@ RSpec.describe TreeHelper, feature_category: :source_code_management do
 
   describe '#web_ide_button_data' do
     let(:blob) { project.repository.blob_at('refs/heads/master', @path) }
+    let(:organization) { build_stubbed(:organization) }
 
     let_it_be(:user_preferences_gitpod_path) { '/-/profile/preferences#user_gitpod_enabled' }
     let_it_be(:user_profile_enable_gitpod_path) { '/-/user_settings/profile?user%5Bgitpod_enabled%5D=true' }
 
     before do
+      Current.organization = organization
       @path = ''
       @project = project
       @ref = sha
@@ -405,6 +410,70 @@ RSpec.describe TreeHelper, feature_category: :source_code_management do
     end
   end
 
+  describe '#code_dropdown_ide_data' do
+    before do
+      helper.instance_variable_set(:@project, project)
+      helper.instance_variable_set(:@ref, sha)
+      allow(helper).to receive(:current_user).and_return(user)
+      allow(helper).to receive(:show_web_ide_button?).and_return(true)
+      allow(helper).to receive(:show_gitpod_button?).and_return(false)
+      allow(helper).to receive(:web_ide_url).and_return("/-/ide/project/#{project.full_path}/edit/#{sha}")
+      allow(helper).to receive(:gitpod_url).and_return('')
+    end
+
+    subject { helper.code_dropdown_ide_data }
+
+    it 'returns a hash with IDE-related attributes' do
+      expect(subject).to include(
+        gitpod_enabled: false,
+        show_web_ide_button: true,
+        show_gitpod_button: false,
+        web_ide_url: "/-/ide/project/#{project.full_path}/edit/#{sha}",
+        gitpod_url: ''
+      )
+    end
+
+    context 'when user has gitpod enabled' do
+      before do
+        user.gitpod_enabled = true
+      end
+
+      it 'includes gitpod_enabled: true' do
+        expect(subject).to include(gitpod_enabled: true)
+      end
+    end
+
+    context 'when there is no current user' do
+      before do
+        allow(helper).to receive(:current_user).and_return(nil)
+      end
+
+      it 'includes gitpod_enabled: false' do
+        expect(subject).to include(gitpod_enabled: false)
+      end
+    end
+
+    context 'when web IDE button is not shown' do
+      before do
+        allow(helper).to receive(:show_web_ide_button?).and_return(false)
+      end
+
+      it 'includes show_web_ide_button: false' do
+        expect(subject).to include(show_web_ide_button: false)
+      end
+    end
+
+    context 'when gitpod button is shown' do
+      before do
+        allow(helper).to receive(:show_gitpod_button?).and_return(true)
+      end
+
+      it 'includes show_gitpod_button: true' do
+        expect(subject).to include(show_gitpod_button: true)
+      end
+    end
+  end
+
   describe '.patch_branch_name' do
     before do
       allow(helper).to receive(:current_user).and_return(user)
@@ -424,7 +493,7 @@ RSpec.describe TreeHelper, feature_category: :source_code_management do
       let(:user) { nil }
 
       it 'returns nil' do
-        expect(subject).to be nil
+        expect(subject).to be_nil
       end
     end
   end
@@ -467,4 +536,153 @@ RSpec.describe TreeHelper, feature_category: :source_code_management do
       end
     end
   end
+
+  describe '#compact_code_dropdown_data' do
+    let(:ref) { 'main' }
+    let(:archive_prefix) { "#{project.path}-#{ref}" }
+
+    before do
+      helper.instance_variable_set(:@project, project)
+      helper.instance_variable_set(:@ref, ref)
+      allow(helper).to receive(:current_user).and_return(user)
+      allow(helper).to receive(:ssh_enabled?).and_return(true)
+      allow(helper).to receive(:http_enabled?).and_return(true)
+      allow(helper).to receive(:show_xcode_link?).and_return(false)
+      allow(helper).to receive(:code_dropdown_ide_data)
+                         .and_return({
+                           gitpod_enabled: false,
+                           show_web_ide_button: true,
+                           show_gitpod_button: false,
+                           web_ide_url: "/-/ide/project/#{project.full_path}/edit/#{ref}",
+                           gitpod_url: ''
+                         })
+    end
+
+    subject { helper.compact_code_dropdown_data(project, ref, 'heads') }
+
+    it 'returns a hash with the expected keys' do
+      expected_keys = [
+        :ssh_url, :http_url, :xcode_url,
+        :ide_data, :directory_download_links
+      ]
+      expect(subject.keys).to match_array(expected_keys)
+    end
+
+    it 'includes SSH URL when SSH is enabled' do
+      expect(subject[:ssh_url]).to eq(ssh_clone_url_to_repo(project))
+    end
+
+    it 'includes HTTP URL when HTTP is enabled' do
+      expect(subject[:http_url]).to eq(http_clone_url_to_repo(project))
+    end
+
+    it 'includes empty Xcode URL when Xcode link is not shown' do
+      expect(subject[:xcode_url]).to eq('')
+    end
+
+    context 'when current user has a namespace' do
+      before do
+        allow(user).to receive(:namespace).and_return(build_stubbed(:namespace))
+      end
+
+      it 'includes IDE data as JSON' do
+        ide_data = {
+          gitpod_enabled: false,
+          show_web_ide_button: true,
+          show_gitpod_button: false,
+          web_ide_url: "/-/ide/project/#{project.full_path}/edit/#{ref}",
+          gitpod_url: ''
+        }
+        expect(subject[:ide_data]).to eq(ide_data.to_json)
+      end
+    end
+
+    context 'when current user does not have a namespace' do
+      before do
+        allow(user).to receive(:namespace).and_return(nil)
+      end
+
+      it 'returns empty IDE data' do
+        expect(subject[:ide_data]).to eq('')
+      end
+    end
+
+    context 'when there is no current user' do
+      before do
+        allow(helper).to receive(:current_user).and_return(nil)
+      end
+
+      it 'returns empty IDE data' do
+        expect(subject[:ide_data]).to eq('')
+      end
+    end
+
+    context 'for repository' do
+      context 'when it is not empty' do
+        before do
+          allow(project).to receive(:empty_repo?).and_return(false)
+        end
+
+        it 'includes directory download links as JSON' do
+          expected_links = helper.download_links(project, ref, archive_prefix, 'heads').to_json
+          expect(subject[:directory_download_links]).to eq(expected_links)
+        end
+      end
+
+      context 'when it is empty' do
+        before do
+          allow(project).to receive(:empty_repo?).and_return(true)
+        end
+
+        it 'includes empty directory download links' do
+          expect(subject[:directory_download_links]).to be_empty
+        end
+      end
+    end
+
+    context 'when SSH is disabled' do
+      before do
+        allow(helper).to receive(:ssh_enabled?).and_return(false)
+      end
+
+      it 'returns empty SSH URL' do
+        expect(subject[:ssh_url]).to eq('')
+      end
+    end
+
+    context 'when HTTP is disabled' do
+      before do
+        allow(helper).to receive(:http_enabled?).and_return(false)
+      end
+
+      it 'returns empty HTTP URL' do
+        expect(subject[:http_url]).to eq('')
+      end
+    end
+
+    context 'when Xcode link should be shown' do
+      before do
+        allow(helper).to receive(:show_xcode_link?).and_return(true)
+        allow(helper).to receive(:xcode_uri_to_repo).with(project).and_return('xcode://example.com/project.git')
+      end
+
+      it 'includes Xcode URL' do
+        expect(subject[:xcode_url]).to eq('xcode://example.com/project.git')
+      end
+    end
+
+    context 'when ref is nil' do
+      let(:ref) { nil }
+
+      before do
+        allow(project).to receive(:empty_repo?).and_return(false)
+      end
+
+      it 'uses empty string for archive prefix' do
+        expect(helper).to receive(:download_links).with(project, nil, '', 'heads').and_return([])
+
+        subject
+      end
+    end
+  end
 end
