@@ -191,13 +191,28 @@ RSpec.describe Banzai::Filter::References::IssueReferenceFilter, feature_categor
     it_behaves_like 'an internal reference'
   end
 
-  context 'alternative internal_reference' do
+  context 'alternative GL- internal reference' do
     let(:written_reference) { "GL-#{issue.iid}" }
     let(:reference) { "##{issue.iid}" }
 
     it_behaves_like 'an internal reference'
   end
 
+  context 'alternative [issue:XXX] internal reference' do
+    let(:written_reference) { "[issue:#{issue.iid}]" }
+    let(:reference) { "##{issue.iid}" }
+
+    it_behaves_like 'an internal reference'
+  end
+
+  context 'project [issue:project/path/XXX] reference' do
+    let(:reference) { "[issue:#{project.full_path}/#{issue.iid}]" }
+
+    it_behaves_like 'a reference containing an element node'
+
+    it_behaves_like 'a reference with issue type information'
+  end
+
   context 'cross-project / cross-namespace complete reference' do
     let(:reference) { "#{project2.full_path}##{issue.iid}" }
     let(:issue)     { create(:issue, project: project2) }
