@@ -259,6 +259,33 @@ RSpec.describe Gitlab::Auth::AuthFinders, feature_category: :system_access do
 
           expect { find_user_from_feed_token(:rss) }.to raise_error(Gitlab::Auth::UnauthorizedError)
         end
+
+        context 'with instance prefix' do
+          let(:instance_prefix) { 'instanceprefix' }
+          let(:feed_token_with_prefix) { "#{instance_prefix}-#{feed_token}" }
+
+          before do
+            stub_application_setting(instance_token_prefix: instance_prefix)
+          end
+
+          it 'returns user if valid feed_token' do
+            set_param(:feed_token, feed_token)
+
+            expect(find_user_from_feed_token(:rss)).to eq feed_user
+          end
+
+          it 'returns user if valid feed_token_with_prefix' do
+            set_param(:feed_token, feed_token_with_prefix)
+
+            expect(find_user_from_feed_token(:rss)).to eq feed_user
+          end
+
+          it 'returns exception if invalid feed_token prefix' do
+            set_param(:feed_token, "invalid#{feed_token}")
+
+            expect { find_user_from_feed_token(:rss) }.to raise_error(Gitlab::Auth::UnauthorizedError)
+          end
+        end
       end
 
       context 'when old format rss_token param is provided' do
@@ -765,18 +792,15 @@ RSpec.describe Gitlab::Auth::AuthFinders, feature_category: :system_access do
     end
 
     context 'with composite identity', :request_store do
-      let_it_be(:user) { create(:user, username: 'user-with-composite-identity') }
+      let_it_be(:user) { create(:user, :service_account, composite_identity_enforced: true) }
 
       before do
-        allow_any_instance_of(::User).to receive(:composite_identity_enforced) do |user|
-          user.username == 'user-with-composite-identity'
-        end
-
         set_bearer_token(oauth_access_token.plaintext_token)
       end
 
       context 'when scoped user is specified' do
-        let(:scopes) { "user:#{user.id}" }
+        let(:scoped_user) { create(:user) }
+        let(:scopes) { "user:#{scoped_user.id}" }
 
         context 'when linking composite identitiy succeeds' do
           it 'returns the oauth token' do
@@ -1151,6 +1175,14 @@ RSpec.describe Gitlab::Auth::AuthFinders, feature_category: :system_access do
         allow_any_instance_of(described_class).to receive(:access_token).and_return(oauth_access_token)
       end
 
+      it 'includes the OAuth application ID in the token info' do
+        validate_and_save_access_token!(reset_token: true)
+
+        expect(::Current.token_info).to match(a_hash_including({
+          token_application_id: oauth_access_token.application_id
+        }))
+      end
+
       context 'when reset_token is true' do
         it 'reloads the access token before validation' do
           expect(oauth_access_token).to receive(:reload)
@@ -1317,29 +1349,21 @@ RSpec.describe Gitlab::Auth::AuthFinders, feature_category: :system_access do
     context 'when route_setting allows cluster agent token' do
       let(:route_authentication_setting) { { cluster_agent_token_allowed: true } }
 
-      context 'Authorization header is empty' do
+      context 'Gitlab-Agent-Api-Request header is empty' do
         it { is_expected.to be_nil }
       end
 
-      context 'Authorization header is incorrect' do
+      context 'Gitlab-Agent-Api-Request header does not matches the agent token' do
         before do
-          request.headers['Authorization'] = 'Bearer ABCD'
+          request.headers['Gitlab-Agent-Api-Request'] = 'ABCD'
         end
 
         it { is_expected.to be_nil }
       end
 
-      context 'Authorization header is malformed' do
+      context 'Gitlab-Agent-Api-Request header matches agent token' do
         before do
-          request.headers['Authorization'] = 'Bearer'
-        end
-
-        it { is_expected.to be_nil }
-      end
-
-      context 'Authorization header matches agent token' do
-        before do
-          request.headers['Authorization'] = "Bearer #{agent_token.token}"
+          request.headers['Gitlab-Agent-Api-Request'] = agent_token.token
         end
 
         it { is_expected.to eq(agent_token) }
@@ -1352,32 +1376,6 @@ RSpec.describe Gitlab::Auth::AuthFinders, feature_category: :system_access do
           it { is_expected.to be_nil }
         end
       end
-
-      context 'when using Gitlab-Agentk-Api-Request header' do
-        context 'when the token is incorrect' do
-          before do
-            request.headers['Gitlab-Agentk-Api-Request'] = 'ABCD'
-          end
-
-          it { is_expected.to be_nil }
-        end
-
-        context 'when the token is correct' do
-          before do
-            request.headers['Gitlab-Agentk-Api-Request'] = agent_token.token
-          end
-
-          it { is_expected.to eq(agent_token) }
-
-          context 'when the token has been revoked' do
-            before do
-              agent_token.revoked!
-            end
-
-            it { is_expected.to be_nil }
-          end
-        end
-      end
     end
   end
 
