@@ -175,120 +175,6 @@ RSpec.describe Gitlab::Diff::File, feature_category: :shared do
     it { expect(diff_lines.first).to be_kind_of(Gitlab::Diff::Line) }
   end
 
-  describe '#diff_lines_by_hunk' do
-    let(:diff_lines) do
-      [
-        instance_double(Gitlab::Diff::Line, type: 'match', added?: false, removed?: false, meta?: true),
-        instance_double(Gitlab::Diff::Line, type: nil, added?: false, removed?: false, meta?: false),
-        instance_double(Gitlab::Diff::Line, type: nil, added?: false, removed?: false, meta?: false),
-        instance_double(Gitlab::Diff::Line, type: nil, added?: false, removed?: false, meta?: false),
-        instance_double(Gitlab::Diff::Line, type: 'new', added?: true, removed?: false, text: 'First Hunk Added 1', meta?: false),
-        instance_double(Gitlab::Diff::Line, type: 'new', added?: true, removed?: false, text: 'First Hunk Added 2', meta?: false),
-        instance_double(Gitlab::Diff::Line, type: 'old', added?: false, removed?: true, text: 'First Hunk Removed 1', meta?: false),
-        instance_double(Gitlab::Diff::Line, type: 'old', added?: false, removed?: true, text: 'First Hunk Removed 2', meta?: false),
-        instance_double(Gitlab::Diff::Line, type: nil, added?: false, removed?: false, meta?: false),
-        instance_double(Gitlab::Diff::Line, type: nil, added?: false, removed?: false, meta?: false),
-        instance_double(Gitlab::Diff::Line, type: nil, added?: false, removed?: false, meta?: false),
-        instance_double(Gitlab::Diff::Line, type: 'match', added?: false, removed?: false, meta?: true),
-        instance_double(Gitlab::Diff::Line, type: nil, added?: false, removed?: false, meta?: false),
-        instance_double(Gitlab::Diff::Line, type: nil, added?: false, removed?: false, meta?: false),
-        instance_double(Gitlab::Diff::Line, type: nil, added?: false, removed?: false, meta?: false),
-        instance_double(Gitlab::Diff::Line, type: 'old', added?: false, removed?: true, text: 'Second Hunk Removed', meta?: false),
-        instance_double(Gitlab::Diff::Line, type: 'new-nonewline', added?: true, removed?: false, meta?: true)
-      ]
-    end
-
-    before do
-      allow(diff_file).to receive(:diff_lines).and_return(diff_lines)
-    end
-
-    subject(:diff_lines_by_hunk) { diff_file.diff_lines_by_hunk }
-
-    it 'returns lines grouped by hunk' do
-      expect(diff_lines_by_hunk.size).to eq(2)
-
-      expect(diff_lines_by_hunk.first[:added].size).to eq(2)
-      expect(diff_lines_by_hunk.first[:added].map(&:text)).to eq([
-        'First Hunk Added 1',
-        'First Hunk Added 2'
-      ])
-
-      expect(diff_lines_by_hunk.first[:removed].size).to eq(2)
-      expect(diff_lines_by_hunk.first[:removed].map(&:text)).to eq([
-        'First Hunk Removed 1',
-        'First Hunk Removed 2'
-      ])
-
-      expect(diff_lines_by_hunk.last[:added].size).to eq(0)
-      expect(diff_lines_by_hunk.last[:removed].size).to eq(1)
-      expect(diff_lines_by_hunk.last[:removed].map(&:text)).to eq([
-        'Second Hunk Removed'
-      ])
-    end
-  end
-
-  describe '#diff_hunks' do
-    let(:diff_lines) do
-      [
-        instance_double(Gitlab::Diff::Line, type: 'match', added?: false, removed?: false, meta?: true),
-        instance_double(Gitlab::Diff::Line, type: nil, old_pos: 1, new_pos: 1, added?: false, removed?: false, meta?: false, text: 'First Hunk Unchanged'),
-        instance_double(Gitlab::Diff::Line, type: nil, old_pos: 2, new_pos: 2, added?: false, removed?: false, meta?: false, text: 'First Hunk Unchanged'),
-        instance_double(Gitlab::Diff::Line, type: nil, old_pos: 3, new_pos: 3, added?: false, removed?: false, meta?: false, text: 'First Hunk Unchanged'),
-        instance_double(Gitlab::Diff::Line, type: 'old', old_pos: 4, new_pos: 4, added?: false, removed?: true, text: 'First Hunk Removed 1', meta?: false),
-        instance_double(Gitlab::Diff::Line, type: 'old', old_pos: 5, new_pos: 4, added?: false, removed?: true, text: 'First Hunk Removed 2', meta?: false),
-        instance_double(Gitlab::Diff::Line, type: 'new', old_pos: 5, new_pos: 4, added?: true, removed?: false, text: 'First Hunk Added 1', meta?: false),
-        instance_double(Gitlab::Diff::Line, type: 'new', old_pos: 5, new_pos: 5, added?: true, removed?: false, text: 'First Hunk Added 2', meta?: false),
-        instance_double(Gitlab::Diff::Line, type: nil, old_pos: 5, new_pos: 6, added?: false, removed?: false, meta?: false, text: 'First Hunk Unchanged'),
-        instance_double(Gitlab::Diff::Line, type: nil, old_pos: 6, new_pos: 7, added?: false, removed?: false, meta?: false, text: 'First Hunk Unchanged'),
-        instance_double(Gitlab::Diff::Line, type: nil, old_pos: 7, new_pos: 8, added?: false, removed?: false, meta?: false, text: 'First Hunk Unchanged'),
-        instance_double(Gitlab::Diff::Line, type: 'match', old_pos: 8, new_pos: 9, added?: false, removed?: false, meta?: true),
-        instance_double(Gitlab::Diff::Line, type: nil, old_pos: 9, new_pos: 10, added?: false, removed?: false, meta?: false, text: 'Second Hunk Unchanged'),
-        instance_double(Gitlab::Diff::Line, type: nil, old_pos: 10, new_pos: 11, added?: false, removed?: false, meta?: false, text: 'Second Hunk Unchanged'),
-        instance_double(Gitlab::Diff::Line, type: nil, old_pos: 11, new_pos: 12, added?: false, removed?: false, meta?: false, text: 'Second Hunk Unchanged'),
-        instance_double(Gitlab::Diff::Line, type: 'old', old_pos: 12, new_pos: 13, added?: false, removed?: true, text: 'Second Hunk Removed', meta?: false),
-        instance_double(Gitlab::Diff::Line, type: 'new-nonewline', old_pos: 13, new_pos: 13, added?: true, removed?: false, meta?: true)
-      ]
-    end
-
-    before do
-      allow(diff_file).to receive(:diff_lines).and_return(diff_lines)
-    end
-
-    subject(:diff_hunks) { diff_file.diff_hunks }
-
-    it 'returns lines per hunk' do
-      expect(diff_hunks.size).to eq(2)
-
-      expect(diff_hunks.first[:last_removed_line_pos]).to eq(5)
-      expect(diff_hunks.first[:last_added_line_pos]).to eq(5)
-      expect(diff_hunks.first[:text]).to eq(
-        <<~HUNK.chomp
-          First Hunk Unchanged
-          First Hunk Unchanged
-          First Hunk Unchanged
-          First Hunk Removed 1
-          First Hunk Removed 2
-          First Hunk Added 1
-          First Hunk Added 2
-          First Hunk Unchanged
-          First Hunk Unchanged
-          First Hunk Unchanged
-        HUNK
-      )
-
-      expect(diff_hunks.last[:last_removed_line_pos]).to eq(12)
-      expect(diff_hunks.last[:last_added_line_pos]).to be_nil
-      expect(diff_hunks.last[:text]).to eq(
-        <<~HUNK.chomp
-          Second Hunk Unchanged
-          Second Hunk Unchanged
-          Second Hunk Unchanged
-          Second Hunk Removed
-        HUNK
-      )
-    end
-  end
-
   describe '#highlighted_diff_lines' do
     it 'highlights the diff and memoises the result' do
       expect(Gitlab::Diff::Highlight).to receive(:new)
@@ -1253,29 +1139,25 @@ RSpec.describe Gitlab::Diff::File, feature_category: :shared do
 
   describe '#ai_reviewable?' do
     let(:diffable?) { true }
-    let(:deleted_file?) { false }
+    let(:text?) { true }
 
     before do
       allow(diff_file).to receive(:diffable?).and_return(diffable?)
-      allow(diff_file).to receive(:deleted_file?).and_return(deleted_file?)
+      allow(diff_file).to receive(:text?).and_return(text?)
     end
 
     subject(:ai_reviewable?) { diff_file.ai_reviewable? }
 
     it { is_expected.to eq(true) }
 
-    it 'returns true' do
-      expect(diff_file.ai_reviewable?).to eq(true)
-    end
-
     context 'when not diffable' do
       let(:diffable?) { false }
 
       it { is_expected.to eq(false) }
     end
 
-    context 'when deleted file' do
-      let(:deleted_file?) { true }
+    context 'when not text' do
+      let(:text?) { false }
 
       it { is_expected.to eq(false) }
     end
@@ -1304,6 +1186,40 @@ RSpec.describe Gitlab::Diff::File, feature_category: :shared do
     end
   end
 
+  describe '#whitespace_only?' do
+    subject(:whitespace_only?) { diff_file.whitespace_only? }
+
+    it 'returns true for non-collapsed empty diffs' do
+      allow(diff_file).to receive(:collapsed?).and_return(false)
+      allow(diff_file).to receive(:diff_lines_for_serializer).and_return(nil)
+      allow(diff_file).to receive(:added_lines).and_return(2)
+      allow(diff_file).to receive(:removed_lines).and_return(2)
+      expect(whitespace_only?).to eq(true)
+    end
+  end
+
+  describe '#image_diff?' do
+    subject(:image_diff?) { diff_file.image_diff? }
+
+    it 'returns true for image diffs' do
+      allow(diff_file).to receive_messages(different_type?: false, external_storage_error?: false)
+      allow(DiffViewer::Image).to receive(:can_render?).and_return(true)
+      expect(image_diff?).to eq(true)
+    end
+
+    it 'returns false for different types' do
+      allow(diff_file).to receive_messages(different_type?: true, external_storage_error?: false)
+      allow(DiffViewer::Image).to receive(:can_render?).and_return(true)
+      expect(image_diff?).to eq(false)
+    end
+
+    it 'returns false for storage error' do
+      allow(diff_file).to receive_messages(different_type?: false, external_storage_error?: true)
+      allow(DiffViewer::Image).to receive(:can_render?).and_return(true)
+      expect(image_diff?).to eq(false)
+    end
+  end
+
   describe '#modified_file?' do
     subject(:modified_file?) { diff_file.modified_file? }
 
@@ -1336,4 +1252,18 @@ RSpec.describe Gitlab::Diff::File, feature_category: :shared do
   describe '#viewer_hunks' do
     it { expect(diff_file.viewer_hunks).to all(be_instance_of(Gitlab::Diff::ViewerHunk)) }
   end
+
+  describe '#no_preview?' do
+    subject(:no_preview?) { diff_file.no_preview? }
+
+    it 'returns true for collapsed file' do
+      allow(diff_file).to receive(:collapsed?).and_return(true)
+      expect(no_preview?).to eq(true)
+    end
+
+    it 'returns true for unmodified file' do
+      allow(diff_file).to receive(:modified_file?).and_return(false)
+      expect(no_preview?).to eq(true)
+    end
+  end
 end
