@@ -145,9 +145,7 @@ RSpec.describe Gitlab::Middleware::JsonValidation, feature_category: :shared do
     context 'with different JSON content types' do
       shared_examples 'validates JSON content type' do
         it 'validates the request' do
-          validator = instance_double(::Gitlab::Json::StreamValidator, metadata: {})
-          expect(::Gitlab::Json::StreamValidator).to receive(:new).and_return(validator)
-          expect(::Oj).to receive(:sc_parse).with(validator, body)
+          expect(::Oj).to receive(:sc_parse).with(an_instance_of(Gitlab::Json::StreamValidator), body)
           expect(app).to receive(:call).with(env)
 
           middleware.call(env)
