@@ -596,6 +596,32 @@ RSpec.describe Notify, feature_category: :code_review_workflow do
       end
     end
 
+    describe 'pipeline variables migration complete' do
+      let(:updated_count) { 5 }
+      let(:skipped_count) { 2 }
+
+      subject { described_class.pipeline_variables_migration_complete_email(recipient, group, { updated_count: updated_count, skipped_count: skipped_count }) }
+
+      it_behaves_like 'an email sent to a user'
+      it_behaves_like 'an email sent from GitLab'
+      it_behaves_like 'it should not have Gmail Actions links'
+      it_behaves_like "a user cannot unsubscribe through footer link"
+      it_behaves_like 'appearance header and footer enabled'
+      it_behaves_like 'appearance header and footer not enabled'
+
+      it 'has the correct subject and body' do
+        is_expected.to have_subject("#{group.name} | Pipeline variables settings migration complete")
+        is_expected.to have_body_text('All projects in the')
+        is_expected.to have_body_text(group.name)
+        is_expected.to have_body_text('group were checked for pipeline variables usage')
+        is_expected.to have_body_text("#{updated_count} projects were not using pipeline variables")
+        is_expected.to have_body_text('CI/CD settings were updated to prevent future pipeline variable usage')
+        is_expected.to have_body_text("#{skipped_count} have used pipeline variables in the past")
+        is_expected.to have_body_text('These projects\' CI/CD settings were not updated as there is a risk')
+        is_expected.to have_body_text('Projects that could not be updated need manual review')
+      end
+    end
+
     def invite_to_project(project, inviter:, user: nil)
       create(
         :project_member,
@@ -658,7 +684,12 @@ RSpec.describe Notify, feature_category: :code_review_workflow do
         end
 
         it_behaves_like 'it should show Gmail Actions View Merge request link'
-        it_behaves_like 'an unsubscribeable thread'
+        it_behaves_like 'an unsubscribeable thread' do
+          before do
+            group.add_developer(recipient)
+          end
+        end
+
         it_behaves_like 'appearance header and footer enabled'
         it_behaves_like 'appearance header and footer not enabled'
 
@@ -679,6 +710,8 @@ RSpec.describe Notify, feature_category: :code_review_workflow do
       end
 
       shared_examples 'a discussion note email' do |model|
+        let(:noteable_url_args) { {} }
+
         it_behaves_like 'it should have Gmail Actions links'
 
         # Two tests with flakiness:1 are coming from this test:
@@ -699,9 +732,15 @@ RSpec.describe Notify, feature_category: :code_review_workflow do
 
         it 'contains an introduction' do
           issuable_url = "project_#{note.noteable_type.underscore}_url"
+          issuable_url = "project_wiki_url" if note.for_wiki_page?
           anchor = "note_#{note.id}"
 
-          is_expected.to have_body_text "started a new <a href=\"#{public_send(issuable_url, project, note.noteable, anchor: anchor)}\">discussion</a>"
+          is_expected.to have_body_text(
+            format(
+              "started a new <a href=\"%{url}\">discussion</a>",
+              url: public_send(issuable_url, project, note.noteable, anchor: anchor, **noteable_url_args)
+            )
+          )
         end
 
         context 'when a comment on an existing discussion' do
@@ -767,7 +806,12 @@ RSpec.describe Notify, feature_category: :code_review_workflow do
         end
 
         it_behaves_like 'it should show Gmail Actions View Merge request link'
-        it_behaves_like 'an unsubscribeable thread'
+        it_behaves_like 'an unsubscribeable thread' do
+          before do
+            group.add_developer(recipient)
+          end
+        end
+
         it_behaves_like 'appearance header and footer enabled'
         it_behaves_like 'appearance header and footer not enabled'
 
@@ -800,7 +844,12 @@ RSpec.describe Notify, feature_category: :code_review_workflow do
         end
 
         it_behaves_like 'it should show Gmail Actions View Issue link'
-        it_behaves_like 'an unsubscribeable thread'
+        it_behaves_like 'an unsubscribeable thread' do
+          before do
+            group.add_developer(recipient)
+          end
+        end
+
         it_behaves_like 'appearance header and footer enabled'
         it_behaves_like 'appearance header and footer not enabled'
 
@@ -812,6 +861,49 @@ RSpec.describe Notify, feature_category: :code_review_workflow do
           is_expected.to have_body_text note_on_issue_path
         end
       end
+
+      describe 'on a wiki_page' do
+        let(:wiki_page_meta) { create(:wiki_page_meta, canonical_slug: 'slug', container: project) }
+        let(:note) { create_note }
+
+        let(:note_on_wiki_path) { project_wiki_page_url(wiki_page_meta, anchor: "note_#{note.id}") }
+
+        def create_note
+          create(:discussion_note_on_wiki_page, noteable: wiki_page_meta, project: project, author: note_author)
+        end
+
+        before do
+          allow(note).to receive(:noteable).and_return(wiki_page_meta)
+        end
+
+        subject { described_class.note_wiki_page_email(recipient.id, note.id) }
+
+        it_behaves_like 'a discussion note email', :discussion_note_on_wiki_page do
+          let(:noteable_url_args) { { id: wiki_page_meta.canonical_slug } }
+        end
+
+        it_behaves_like 'an answer to an existing thread with reply-by-email enabled' do
+          let(:model) { wiki_page_meta }
+        end
+
+        it_behaves_like 'it should show Gmail Actions View Wiki link'
+        it_behaves_like 'an unsubscribeable thread' do
+          before do
+            group.add_developer(recipient)
+          end
+        end
+
+        it_behaves_like 'appearance header and footer enabled'
+        it_behaves_like 'appearance header and footer not enabled'
+
+        it 'has the correct subject' do
+          is_expected.to have_subject("Re: a-known-name | #{wiki_page_meta.title} (slug)")
+        end
+
+        it 'contains a link to the wiki page note' do
+          is_expected.to have_body_text note_on_wiki_path
+        end
+      end
     end
 
     context 'items that are noteable, the email for a diff discussion note' do
@@ -903,7 +995,12 @@ RSpec.describe Notify, feature_category: :code_review_workflow do
 
         it_behaves_like 'an email for a note on a diff discussion', :diff_note_on_merge_request
         it_behaves_like 'it should show Gmail Actions View Merge request link'
-        it_behaves_like 'an unsubscribeable thread'
+        it_behaves_like 'an unsubscribeable thread' do
+          before do
+            group.add_developer(recipient)
+          end
+        end
+
         it_behaves_like 'appearance header and footer enabled'
         it_behaves_like 'appearance header and footer not enabled'
       end
@@ -1444,7 +1541,12 @@ RSpec.describe Notify, feature_category: :code_review_workflow do
           end
 
           it_behaves_like 'it should show Gmail Actions View Issue link', group_level
-          it_behaves_like 'an unsubscribeable thread'
+          it_behaves_like 'an unsubscribeable thread', group_level do
+            before do
+              group.add_developer(recipient)
+            end
+          end
+
           it_behaves_like 'appearance header and footer enabled'
           it_behaves_like 'appearance header and footer not enabled'
 
