@@ -308,72 +308,6 @@ RSpec.describe Ability, feature_category: :system_access do
         .to eq(described_class.method(:work_items_readable_by_user))
     end
 
-    context 'with an admin when admin mode is enabled', :enable_admin_mode do
-      it 'returns all given issues' do
-        user = build(:user, admin: true)
-        issue = build(:issue)
-
-        expect(described_class.issues_readable_by_user([issue], user))
-          .to eq([issue])
-      end
-    end
-
-    context 'with an admin when admin mode is disabled' do
-      it 'returns the issues readable by the admin' do
-        user = build(:user, admin: true)
-        issue = build(:issue)
-
-        expect(issue).to receive(:readable_by?).with(user).and_return(true)
-
-        expect(described_class.issues_readable_by_user([issue], user))
-          .to eq([issue])
-      end
-
-      it 'returns no issues when not given access' do
-        user = build(:user, admin: true)
-        issue = build(:issue)
-
-        expect(described_class.issues_readable_by_user([issue], user))
-          .to be_empty
-      end
-    end
-
-    context 'with a regular user' do
-      it 'returns the issues readable by the user' do
-        user = build(:user)
-        issue = build(:issue)
-
-        expect(issue).to receive(:readable_by?).with(user).and_return(true)
-
-        expect(described_class.issues_readable_by_user([issue], user))
-          .to eq([issue])
-      end
-
-      it 'returns an empty Array when no issues are readable' do
-        user = build(:user)
-        issue = build(:issue)
-
-        expect(issue).to receive(:readable_by?).with(user).and_return(false)
-
-        expect(described_class.issues_readable_by_user([issue], user)).to eq([])
-      end
-    end
-
-    context 'without a regular user' do
-      it 'returns issues that are publicly visible' do
-        hidden_issue = build(:issue)
-        visible_issue = build(:issue)
-
-        expect(hidden_issue).to receive(:publicly_visible?).and_return(false)
-        expect(visible_issue).to receive(:publicly_visible?).and_return(true)
-
-        issues = described_class
-          .issues_readable_by_user([hidden_issue, visible_issue])
-
-        expect(issues).to eq([visible_issue])
-      end
-    end
-
     context 'when the user cannot read cross project' do
       let(:user) { create(:user) }
       let(:issue) { create(:issue) }
@@ -478,7 +412,7 @@ RSpec.describe Ability, feature_category: :system_access do
 
   describe '.allowed?' do
     let_it_be(:group) { create(:group, :private) }
-    let_it_be(:user) { create(:user) }
+    let_it_be_with_reload(:user) { create(:user, :service_account) }
     let_it_be(:delegated_user) { create(:user) }
 
     let(:request_store_key) { format(::Gitlab::Auth::Identity::COMPOSITE_IDENTITY_KEY_FORMAT, user.id) }
@@ -488,7 +422,7 @@ RSpec.describe Ability, feature_category: :system_access do
     context 'with composite identity', :request_store do
       before do
         ::Gitlab::SafeRequestStore[request_store_key] = delegated_user
-        allow(user).to receive(:composite_identity_enforced).and_return(true)
+        user.update!(composite_identity_enforced: true)
       end
 
       context 'when both users are members' do
@@ -523,7 +457,7 @@ RSpec.describe Ability, feature_category: :system_access do
 
         context 'with unenforced composite identity' do
           before do
-            allow(user).to receive(:composite_identity_enforced).and_return(false)
+            user.update!(composite_identity_enforced: false)
           end
 
           it 'returns true' do
@@ -547,6 +481,16 @@ RSpec.describe Ability, feature_category: :system_access do
           expect(subject).to be_falsey
         end
       end
+
+      context 'when delegated user is a composite identity' do
+        let_it_be(:delegated_user) { user }
+
+        it 'returns false' do
+          group.add_developer(user)
+
+          expect(subject).to be_falsey
+        end
+      end
     end
   end
 
