@@ -10,6 +10,7 @@ RSpec.describe Ci::JobArtifact, feature_category: :job_artifacts do
     it { is_expected.to belong_to(:job).class_name('Ci::Build').with_foreign_key(:job_id).inverse_of(:job_artifacts) }
     it { is_expected.to validate_presence_of(:job) }
     it { is_expected.to validate_presence_of(:partition_id) }
+    it { is_expected.to validate_length_of(:exposed_as).is_at_most(100) }
   end
 
   it { is_expected.to respond_to(:file) }
@@ -505,6 +506,35 @@ RSpec.describe Ci::JobArtifact, feature_category: :job_artifacts do
     end
   end
 
+  describe 'validates exposed_paths' do
+    using RSpec::Parameterized::TableSyntax
+
+    subject(:job_artifact) { build(:ci_job_artifact, exposed_paths: exposed_paths) }
+
+    where(:exposed_paths, :valid) do
+      nil                  | true
+      123                  | false
+      { path: 'test' }     | false
+      []                   | true
+      ['path']             | true
+      ['p/path2', 'path3'] | true
+      ['path/*']           | false
+      [1, 2, 3]            | true # Array elements are automatically cast as String
+    end
+
+    with_them do
+      it 'provides the expected validation result' do
+        if valid
+          expect(job_artifact).to be_valid
+        else
+          expect(job_artifact).not_to be_valid
+          expect(job_artifact.errors.full_messages)
+            .to contain_exactly('Exposed paths must be an array of strings without `*`')
+        end
+      end
+    end
+  end
+
   describe '#file' do
     subject { artifact.file }
 
@@ -668,6 +698,28 @@ RSpec.describe Ci::JobArtifact, feature_category: :job_artifacts do
     end
   end
 
+  it_behaves_like 'object storable' do
+    let(:locally_stored) do
+      ci_job_artifact = create(:ci_job_artifact)
+
+      if ci_job_artifact.file_store == ObjectStorage::Store::REMOTE
+        ci_job_artifact.update_column(described_class::STORE_COLUMN, ObjectStorage::Store::LOCAL)
+      end
+
+      ci_job_artifact
+    end
+
+    let(:remotely_stored) do
+      ci_job_artifact = create(:ci_job_artifact)
+
+      if ci_job_artifact.file_store == ObjectStorage::Store::LOCAL
+        ci_job_artifact.update_column(described_class::STORE_COLUMN, ObjectStorage::Store::REMOTE)
+      end
+
+      ci_job_artifact
+    end
+  end
+
   describe '.file_types' do
     context 'all file types have corresponding limit' do
       let_it_be(:plan_limits) { create(:plan_limits) }
@@ -744,8 +796,8 @@ RSpec.describe Ci::JobArtifact, feature_category: :job_artifacts do
 
   context 'FastDestroyAll' do
     let_it_be(:project) { create(:project) }
-    let_it_be(:pipeline) { create(:ci_pipeline, project: project) }
-    let_it_be(:job) { create(:ci_build, pipeline: pipeline, project: project) }
+    let_it_be_with_refind(:pipeline) { create(:ci_pipeline, project: project) }
+    let_it_be_with_refind(:job) { create(:ci_build, pipeline: pipeline, project: project) }
 
     let!(:job_artifact) { create(:ci_job_artifact, :archive, job: job) }
     let(:subjects) { pipeline.job_artifacts }
