@@ -8,7 +8,9 @@ RSpec.describe Ci::Processable, feature_category: :continuous_integration do
 
   describe 'associations' do
     it { is_expected.to have_one(:trigger).through(:pipeline) }
-    it { is_expected.to belong_to(:trigger_request) }
+    it { is_expected.to have_one(:job_environment).class_name('Environments::Job').inverse_of(:job) }
+    it { is_expected.to have_one(:job_definition_instance) }
+    it { is_expected.to have_one(:job_definition).through(:job_definition_instance) }
   end
 
   describe 'delegations' do
@@ -61,7 +63,7 @@ RSpec.describe Ci::Processable, feature_category: :continuous_integration do
       let_it_be(:internal_job_variable) { create(:ci_job_variable, job: processable) }
 
       let(:clone_accessors) do
-        %i[pipeline project ref tag options name allow_failure stage_idx trigger_request yaml_variables
+        %i[pipeline project ref tag options name allow_failure stage_idx yaml_variables
            when environment coverage_regex description tag_list protected needs_attributes job_variables_attributes
            resource_group scheduling_type ci_stage partition_id id_tokens interruptible]
       end
@@ -88,8 +90,8 @@ RSpec.describe Ci::Processable, feature_category: :continuous_integration do
 
       let(:ignore_accessors) do
         %i[type namespace lock_version target_url base_tags trace_sections
-           commit_id deployment erased_by_id project_id project_mirror
-           runner_id taggings tags trigger_request_id trigger trigger_id
+           commit_id deployment job_environment erased_by_id project_id project_mirror
+           runner_id taggings tags trigger trigger_id
            user_id auto_canceled_by_id retried failure_reason
            sourced_pipelines sourced_pipeline artifacts_file_store artifacts_metadata_store
            metadata runner_manager_build runner_manager runner_session trace_chunks
@@ -100,7 +102,7 @@ RSpec.describe Ci::Processable, feature_category: :continuous_integration do
            queuing_entry runtime_metadata trace_metadata
            dast_site_profile dast_scanner_profile stage_id dast_site_profiles_build
            dast_scanner_profiles_build auto_canceled_by_partition_id execution_config_id execution_config
-           build_source id_value].freeze
+           build_source id_value inputs job_definition job_definition_instance].freeze
       end
 
       before_all do
@@ -151,6 +153,27 @@ RSpec.describe Ci::Processable, feature_category: :continuous_integration do
           expect(new_processable.needs).not_to match(processable.needs)
         end
 
+        context 'when processable has a job definition' do
+          let_it_be(:job_definition) { create(:ci_job_definition, project: pipeline.project) }
+
+          let_it_be(:job_definition_instance) do
+            create(:ci_job_definition_instance,
+              job: processable,
+              job_definition: job_definition,
+              project: pipeline.project)
+          end
+
+          it 'creates a new job definition instance for the new processable' do
+            expect(new_processable.job_definition)
+              .to be_present
+              .and eq(processable.job_definition)
+
+            expect(new_processable.job_definition_instance).to be_present
+            expect(new_processable.job_definition_instance)
+              .not_to eq(processable.job_definition_instance)
+          end
+        end
+
         context 'when the processable has protected: nil' do
           before do
             processable.update_attribute(:protected, nil)
@@ -343,6 +366,45 @@ RSpec.describe Ci::Processable, feature_category: :continuous_integration do
     end
   end
 
+  it_behaves_like 'a degenerable job' do
+    subject(:job) { create(:ci_bridge, pipeline: pipeline) }
+  end
+
+  describe '#archived?' do
+    shared_examples 'an archivable job' do
+      it { is_expected.not_to be_archived }
+
+      context 'when job is degenerated' do
+        before do
+          job.degenerate!
+        end
+
+        it { is_expected.to be_archived }
+      end
+
+      context 'when pipeline is archived' do
+        before do
+          pipeline.update!(created_at: 1.day.ago)
+          stub_application_setting(archive_builds_in_seconds: 3600)
+        end
+
+        it { is_expected.to be_archived }
+      end
+    end
+
+    context 'when job is a build' do
+      subject(:job) { create(:ci_build, pipeline: pipeline) }
+
+      it_behaves_like 'an archivable job'
+    end
+
+    context 'when job is a bridge' do
+      subject(:job) { create(:ci_bridge, pipeline: pipeline) }
+
+      it_behaves_like 'an archivable job'
+    end
+  end
+
   describe '#aggregated_needs_names' do
     let(:with_aggregated_needs) { pipeline.processables.select_with_aggregated_needs(project) }
 
@@ -586,17 +648,25 @@ RSpec.describe Ci::Processable, feature_category: :continuous_integration do
 
   describe 'manual_confirmation_message' do
     context 'when job is manual' do
-      subject { build(:ci_build, :manual, :with_manual_confirmation) }
+      subject(:job) { build(:ci_build, :manual, :with_manual_confirmation) }
 
       it 'return manual_confirmation from option' do
-        expect(subject.manual_confirmation_message).to eq('Please confirm. Do you want to proceed?')
+        expect(job.manual_confirmation_message).to eq('Please confirm. Do you want to proceed?')
+      end
+
+      context "when job is not playable because it's archived" do
+        before do
+          allow(job).to receive(:archived?).and_return(true)
+        end
+
+        it { expect(job.manual_confirmation_message).to be_nil }
       end
     end
 
     context 'when job is not manual' do
-      subject { build(:ci_build) }
+      subject(:job) { build(:ci_build) }
 
-      it { expect(subject.manual_confirmation_message).to be_nil }
+      it { expect(job.manual_confirmation_message).to be_nil }
     end
   end
 
@@ -688,16 +758,37 @@ RSpec.describe Ci::Processable, feature_category: :continuous_integration do
       expect(processable.trigger).to receive(:short_token)
       processable.trigger_short_token
     end
+  end
 
-    context 'when ff ci_read_trigger_from_ci_pipeline is disabled' do
-      before do
-        stub_feature_flags(ci_read_trigger_from_ci_pipeline: false)
-      end
+  describe '#redis_state' do
+    let(:processable) { build_stubbed(:ci_processable, pipeline: pipeline) }
 
-      it 'delegates to trigger_request' do
-        expect(processable.trigger_request).to receive(:trigger_short_token)
-        processable.trigger_short_token
+    it 'is a memoized Ci::JobRedisState record' do
+      expect(processable.redis_state).to be_an_instance_of(Ci::JobRedisState)
+      expect(processable.strong_memoized?(:redis_state)).to be(true)
+    end
+  end
+
+  describe '#enqueue_immediately?', :clean_gitlab_redis_shared_state do
+    let(:processable) { build_stubbed(:ci_processable, pipeline: pipeline) }
+
+    [true, false].each do |value|
+      context "when enqueue_immediately is set to #{value}" do
+        before do
+          processable.redis_state.enqueue_immediately = value
+        end
+
+        it { expect(processable.enqueue_immediately?).to be(value) }
       end
     end
   end
+
+  describe '#set_enqueue_immediately!', :clean_gitlab_redis_shared_state do
+    let(:processable) { build_stubbed(:ci_processable, pipeline: pipeline) }
+
+    it 'changes enqueue_immediately to true' do
+      expect { processable.set_enqueue_immediately! }
+        .to change { processable.enqueue_immediately? }.to(true)
+    end
+  end
 end
