@@ -29,6 +29,8 @@ RSpec.describe Clusters::Cluster, :use_clean_rails_memory_store_caching,
   it { is_expected.to have_many(:deployment_clusters) }
   it { is_expected.to have_many(:environments).through(:deployments) }
 
+  it { is_expected.to validate_length_of(:environment_scope).is_at_most(described_class::MAX_ENVIRONMENT_SCOPE_LENGTH) }
+
   it { is_expected.to delegate_method(:status).to(:provider) }
   it { is_expected.to delegate_method(:status_reason).to(:provider) }
 
@@ -345,6 +347,12 @@ RSpec.describe Clusters::Cluster, :use_clean_rails_memory_store_caching,
           it { is_expected.to be_falsey }
         end
 
+        context 'when name is too long' do
+          let(:name) { 'a' * 2049 }
+
+          it { is_expected.to be_falsey }
+        end
+
         context 'when name is present' do
           let(:name) { 'cluster-name-1' }
 
