@@ -474,32 +474,6 @@ RSpec.describe Issue, feature_category: :team_planning do
         expect(described_class.with_issue_type(%w[issue incident]))
           .to contain_exactly(issue, incident)
       end
-
-      it 'joins the work_item_types table for filtering with issues.work_item_type_id column' do
-        expect do
-          described_class.with_issue_type([:issue, :incident]).to_a
-        end.to make_queries_matching(
-          %r{
-            INNER\sJOIN\s"work_item_types"\sON\s"work_item_types"\."id"\s=\s"issues"\."work_item_type_id"
-            \sWHERE\s"work_item_types"\."base_type"\sIN\s\(0,\s1\)
-          }x
-        )
-      end
-    end
-
-    context 'when a single issue_type is provided' do
-      it 'uses an optimized query for a single work item type using issues.work_item_type_id column' do
-        expect do
-          described_class.with_issue_type([:incident]).to_a
-        end.to make_queries_matching(
-          %r{
-            WHERE\s\("issues"\."work_item_type_id"\s=
-            \s\(SELECT\s"work_item_types"\."id"\sFROM\s"work_item_types"
-            \sWHERE\s"work_item_types"\."base_type"\s=\s1
-            \sLIMIT\s1\)\)
-          }x
-        )
-      end
     end
 
     context 'when no types are provided' do
@@ -523,17 +497,6 @@ RSpec.describe Issue, feature_category: :team_planning do
       expect(described_class.without_issue_type(%w[issue incident]))
         .to contain_exactly(task)
     end
-
-    it 'uses the work_item_types table and issues.work_item_type_id for filtering' do
-      expect do
-        described_class.without_issue_type(:issue).to_a
-      end.to make_queries_matching(
-        %r{
-          INNER\sJOIN\s"work_item_types"\sON\s"work_item_types"\."id"\s=\s"issues"\."work_item_type_id"
-          \sWHERE\s"work_item_types"\."base_type"\s!=\s0
-        }x
-      )
-    end
   end
 
   describe '.order_severity' do
@@ -940,8 +903,7 @@ RSpec.describe Issue, feature_category: :team_planning do
 
     describe 'when a user cannot read cross project' do
       it 'only returns issues within the same project' do
-        expect(Ability).to receive(:allowed?).with(user, :read_all_resources, :global).at_least(:once).and_call_original
-        expect(Ability).to receive(:allowed?).with(user, :read_cross_project).and_return(false)
+        allow(Gitlab::ExternalAuthorization).to receive_messages(perform_check?: true, access_allowed?: true)
 
         expect(authorized_issue_a.related_issues(user))
           .to contain_exactly(authorized_issue_b, authorized_incident_a)
@@ -1270,387 +1232,6 @@ RSpec.describe Issue, feature_category: :team_planning do
     end
   end
 
-  describe '#visible_to_user?' do
-    let(:project) { reusable_project }
-    let(:issue)   { build(:issue, project: project) }
-
-    subject { issue.visible_to_user?(user) }
-
-    context 'with a project' do
-      it 'returns false when feature is disabled' do
-        project.add_developer(user)
-        project.project_feature.update_attribute(:issues_access_level, ProjectFeature::DISABLED)
-
-        is_expected.to eq(false)
-      end
-    end
-
-    context 'with a group level issue' do
-      let_it_be(:group) { create(:group) }
-      let(:issue) { build(:work_item, :group_level, namespace: group) }
-
-      context 'when readable_by? is false' do
-        it 'returns false' do
-          allow(issue).to receive(:readable_by?).and_return false
-          is_expected.to eq(false)
-        end
-      end
-
-      context 'when readable_by? is true' do
-        before do
-          allow(issue).to receive(:readable_by?).and_return true
-        end
-
-        it { is_expected.to eq(true) }
-
-        context 'when user.can_read_all_resources? is true' do
-          before do
-            allow(user).to receive(:can_read_all_resources?).and_return true
-          end
-
-          it { is_expected.to eq(true) }
-
-          it 'does not check project external authorization' do
-            expect(::Gitlab::ExternalAuthorization).not_to receive(:access_allowed?)
-
-            is_expected.to eq(true)
-          end
-        end
-
-        context 'when user.can_read_all_resources? is false' do
-          before do
-            allow(user).to receive(:can_read_all_resources?).and_return false
-          end
-
-          it { is_expected.to eq(true) }
-
-          it 'does not check project external authorization' do
-            expect(::Gitlab::ExternalAuthorization).not_to receive(:access_allowed?)
-
-            is_expected.to eq(true)
-          end
-        end
-      end
-    end
-
-    context 'without a user' do
-      let(:user) { nil }
-
-      context 'with issue available as public' do
-        before do
-          project.project_feature.update_attribute(:issues_access_level, ProjectFeature::PUBLIC)
-        end
-
-        it 'returns true when the issue is publicly visible' do
-          expect(issue).to receive(:publicly_visible?).and_return(true)
-
-          is_expected.to eq(true)
-        end
-
-        it 'returns false when the issue is not publicly visible' do
-          expect(issue).to receive(:publicly_visible?).and_return(false)
-
-          is_expected.to eq(false)
-        end
-      end
-
-      context 'with issues available only to team members in a public project' do
-        let(:public_project) { create(:project, :public) }
-        let(:issue) { build(:issue, project: public_project) }
-
-        before do
-          public_project.project_feature.update_attribute(:issues_access_level, ProjectFeature::PRIVATE)
-        end
-
-        it 'returns false' do
-          is_expected.to eq(false)
-        end
-      end
-    end
-
-    context 'with a user' do
-      shared_examples 'issue readable by user' do
-        it { is_expected.to eq(true) }
-      end
-
-      shared_examples 'issue not readable by user' do
-        it { is_expected.to eq(false) }
-      end
-
-      shared_examples 'confidential issue readable by user' do
-        specify do
-          issue.confidential = true
-
-          is_expected.to eq(true)
-        end
-      end
-
-      shared_examples 'confidential issue not readable by user' do
-        specify do
-          issue.confidential = true
-
-          is_expected.to eq(false)
-        end
-      end
-
-      shared_examples 'hidden issue readable by user' do
-        before do
-          issue.author.ban!
-        end
-
-        specify do
-          is_expected.to eq(true)
-        end
-
-        after do
-          issue.author.activate!
-        end
-      end
-
-      shared_examples 'hidden issue not readable by user' do
-        before do
-          issue.author.ban!
-        end
-
-        specify do
-          is_expected.to eq(false)
-        end
-
-        after do
-          issue.author.activate!
-        end
-      end
-
-      context 'with an admin user' do
-        let(:user) { build(:admin) }
-
-        context 'when admin mode is enabled', :enable_admin_mode do
-          it_behaves_like 'issue readable by user'
-          it_behaves_like 'confidential issue readable by user'
-          it_behaves_like 'hidden issue readable by user'
-        end
-
-        context 'when admin mode is disabled' do
-          it_behaves_like 'issue not readable by user'
-          it_behaves_like 'confidential issue not readable by user'
-          it_behaves_like 'hidden issue not readable by user'
-        end
-      end
-
-      # TODO update when we have multiple owners of a project
-      # https://gitlab.com/gitlab-org/gitlab/-/issues/350605
-      context 'with an owner' do
-        before do
-          project.add_maintainer(user)
-        end
-
-        it_behaves_like 'issue readable by user'
-        it_behaves_like 'confidential issue readable by user'
-        it_behaves_like 'hidden issue not readable by user'
-      end
-
-      context 'with a reporter user' do
-        before do
-          project.add_reporter(user)
-        end
-
-        it_behaves_like 'issue readable by user'
-        it_behaves_like 'confidential issue readable by user'
-        it_behaves_like 'hidden issue not readable by user'
-      end
-
-      context 'with a guest user' do
-        before do
-          project.add_guest(user)
-        end
-
-        it_behaves_like 'issue readable by user'
-        it_behaves_like 'confidential issue not readable by user'
-        it_behaves_like 'hidden issue not readable by user'
-
-        context 'when user is an assignee' do
-          before do
-            issue.update!(assignees: [user])
-          end
-
-          it_behaves_like 'issue readable by user'
-          it_behaves_like 'confidential issue readable by user'
-          it_behaves_like 'hidden issue not readable by user'
-        end
-
-        context 'when user is the author' do
-          before do
-            issue.update!(author: user)
-          end
-
-          it_behaves_like 'issue readable by user'
-          it_behaves_like 'confidential issue readable by user'
-          it_behaves_like 'hidden issue not readable by user'
-        end
-      end
-
-      context 'with a user that is not a member' do
-        context 'using a public project' do
-          let(:project) { build(:project, :public) }
-
-          it_behaves_like 'issue readable by user'
-          it_behaves_like 'confidential issue not readable by user'
-          it_behaves_like 'hidden issue not readable by user'
-        end
-
-        context 'using an internal project' do
-          let(:project) { build(:project, :internal) }
-
-          context 'using an internal user' do
-            before do
-              allow(user).to receive(:external?).and_return(false)
-            end
-
-            it_behaves_like 'issue readable by user'
-            it_behaves_like 'confidential issue not readable by user'
-            it_behaves_like 'hidden issue not readable by user'
-          end
-
-          context 'using an external user' do
-            before do
-              allow(user).to receive(:external?).and_return(true)
-            end
-
-            it_behaves_like 'issue not readable by user'
-            it_behaves_like 'confidential issue not readable by user'
-            it_behaves_like 'hidden issue not readable by user'
-          end
-        end
-
-        context 'using an external user' do
-          before do
-            allow(user).to receive(:external?).and_return(true)
-          end
-
-          it_behaves_like 'issue not readable by user'
-          it_behaves_like 'confidential issue not readable by user'
-          it_behaves_like 'hidden issue not readable by user'
-        end
-      end
-
-      context 'with an external authentication service' do
-        before do
-          enable_external_authorization_service_check
-        end
-
-        it 'is `false` when an external authorization service is enabled' do
-          issue = build(:issue, project: build(:project, :public))
-
-          expect(issue).not_to be_visible_to_user
-        end
-
-        it 'checks the external service to determine if an issue is readable by a user' do
-          project = build(:project, :public, external_authorization_classification_label: 'a-label')
-          issue = build(:issue, project: project)
-          user = build(:user)
-
-          allow(::Gitlab::ExternalAuthorization).to receive(:access_allowed?).with(user, 'a-label', project.full_path).and_call_original
-          expect(::Gitlab::ExternalAuthorization).to receive(:access_allowed?).with(user, 'a-label') { false }
-          expect(issue.visible_to_user?(user)).to be_falsy
-        end
-
-        it 'does not check the external service if a user does not have access to the project' do
-          project = build(:project, :private, external_authorization_classification_label: 'a-label')
-          issue = build(:issue, project: project)
-          user = build(:user)
-
-          expect(::Gitlab::ExternalAuthorization).not_to receive(:access_allowed?)
-          expect(issue.visible_to_user?(user)).to be_falsy
-        end
-
-        context 'with an admin' do
-          context 'when admin mode is enabled', :enable_admin_mode do
-            it 'does not check the external webservice' do
-              issue = build(:issue)
-              user = build(:admin)
-
-              expect(::Gitlab::ExternalAuthorization).not_to receive(:access_allowed?)
-
-              issue.visible_to_user?(user)
-            end
-          end
-
-          context 'when admin mode is disabled' do
-            it 'checks the external service to determine if an issue is readable by the admin' do
-              project = build(:project, :public, external_authorization_classification_label: 'a-label')
-              issue = build(:issue, project: project)
-              user = build(:admin)
-
-              allow(::Gitlab::ExternalAuthorization).to receive(:access_allowed?).with(user, 'a-label', project.full_path).and_call_original
-              expect(::Gitlab::ExternalAuthorization).to receive(:access_allowed?).with(user, 'a-label') { false }
-              expect(issue.visible_to_user?(user)).to be_falsy
-            end
-          end
-        end
-      end
-
-      context 'when issue is moved to a private project' do
-        let(:private_project) { build(:project, :private) }
-
-        before do
-          issue.update!(project: private_project) # move issue to private project
-        end
-
-        shared_examples 'issue visible if user has guest access' do
-          context 'when user is not a member' do
-            it_behaves_like 'issue not readable by user'
-            it_behaves_like 'confidential issue not readable by user'
-          end
-
-          context 'when user is a guest' do
-            before do
-              private_project.add_guest(user)
-            end
-
-            it_behaves_like 'issue readable by user'
-            it_behaves_like 'confidential issue readable by user'
-          end
-        end
-
-        context 'when user is the author of the original issue' do
-          before do
-            issue.update!(author: user)
-          end
-
-          it_behaves_like 'issue visible if user has guest access'
-        end
-
-        context 'when user is an assignee in the original issue' do
-          before do
-            issue.update!(assignees: [user])
-          end
-
-          it_behaves_like 'issue visible if user has guest access'
-        end
-
-        context 'when user is not the author or an assignee in original issue' do
-          context 'when user is a guest' do
-            before do
-              private_project.add_guest(user)
-            end
-
-            it_behaves_like 'issue readable by user'
-            it_behaves_like 'confidential issue not readable by user'
-          end
-
-          context 'when user is a reporter' do
-            before do
-              private_project.add_reporter(user)
-            end
-
-            it_behaves_like 'issue readable by user'
-            it_behaves_like 'confidential issue readable by user'
-          end
-        end
-      end
-    end
-  end
-
   describe '#publicly_visible?' do
     let(:project) { build(:project, project_visibility) }
     let(:issue) { build(:issue, confidential: confidential, project: project) }
@@ -2256,119 +1837,6 @@ RSpec.describe Issue, feature_category: :team_planning do
     end
   end
 
-  describe '#readable_by?' do
-    let_it_be(:admin_user) { create(:user, :admin) }
-
-    subject { issue_subject.readable_by?(user) }
-
-    context 'when issue belongs directly to a project' do
-      let_it_be_with_reload(:project_issue) { create(:issue, project: reusable_project) }
-      let_it_be(:project_reporter) { create(:user, reporter_of: reusable_project) }
-      let_it_be(:project_guest) { create(:user, guest_of: reusable_project) }
-
-      let(:issue_subject) { project_issue }
-
-      context 'when user is in admin mode', :enable_admin_mode do
-        let(:user) { admin_user }
-
-        it { is_expected.to be_truthy }
-      end
-
-      context 'when user is a reporter' do
-        let(:user) { project_reporter }
-
-        it { is_expected.to be_truthy }
-
-        context 'when issues project feature is not enabled' do
-          before do
-            reusable_project.project_feature.update!(issues_access_level: ProjectFeature::DISABLED)
-          end
-
-          it { is_expected.to be_falsey }
-        end
-
-        context 'when issue is hidden (banned author)' do
-          before do
-            issue_subject.author.ban!
-          end
-
-          it { is_expected.to be_falsey }
-        end
-      end
-
-      context 'when user is a guest' do
-        let(:user) { project_guest }
-
-        context 'when issue is confidential' do
-          before do
-            issue_subject.update!(confidential: true)
-          end
-
-          it { is_expected.to be_falsey }
-
-          context 'when user is assignee of the issue' do
-            before do
-              issue_subject.update!(assignees: [user])
-            end
-
-            it { is_expected.to be_truthy }
-          end
-        end
-      end
-    end
-
-    context 'when issue belongs directly to the group' do
-      let_it_be(:group) { create(:group) }
-      let_it_be_with_reload(:group_issue) { create(:issue, :group_level, namespace: group) }
-      let_it_be(:group_reporter) { create(:user, reporter_of: group) }
-      let_it_be(:group_guest) { create(:user, guest_of: group) }
-
-      let(:issue_subject) { group_issue }
-
-      context 'when user is in admin mode', :enable_admin_mode do
-        let(:user) { admin_user }
-
-        it { is_expected.to be_truthy }
-      end
-
-      context 'when user is a reporter' do
-        let(:user) { group_reporter }
-
-        it { is_expected.to be_truthy }
-
-        context 'when issue is hidden (banned author)' do
-          before do
-            issue_subject.author.ban!
-          end
-
-          it { is_expected.to be_falsey }
-        end
-      end
-
-      context 'when user is a guest' do
-        let(:user) { group_guest }
-
-        it { is_expected.to be_truthy }
-
-        context 'when issue is confidential' do
-          before do
-            issue_subject.update!(confidential: true)
-          end
-
-          it { is_expected.to be_falsey }
-
-          context 'when user is assignee of the issue' do
-            before do
-              issue_subject.update!(assignees: [user])
-            end
-
-            it { is_expected.to be_truthy }
-          end
-        end
-      end
-    end
-  end
-
   describe '#gfm_reference' do
     where(:issue_type, :expected_name) do
       :issue     | 'issue'
@@ -2509,21 +1977,27 @@ RSpec.describe Issue, feature_category: :team_planning do
     end
   end
 
-  describe '#work_item_type_id=', :aggregate_failures do
-    let_it_be(:type1) do
-      create(:work_item_type, :non_default).tap do |type|
-        type.update!(old_id: type.id, id: type.id * 1000)
+  describe ".invalidate_project_counter_caches" do
+    let(:count_service) { instance_double(Projects::OpenIssuesCountService) }
+
+    context "when the project exists" do
+      it "calls Projects::OpenIssuesCountService" do
+        allow(Projects::OpenIssuesCountService).to receive(:new).with(reusable_project).and_return(count_service)
+        expect(count_service).to receive(:delete_cache)
+
+        subject.invalidate_project_counter_caches
       end
     end
 
-    it 'fallbacks to work_item_types.old_id if passed' do
-      issue = build(:issue, project: reusable_project, work_item_type: nil)
+    context "when the project does not exist" do
+      let_it_be(:group) { create(:group) }
+      let_it_be(:group_work_item) { create(:work_item, :group_level, namespace: group) }
 
-      expect(issue.work_item_type_id).to be_nil
+      it "does not call Projects::OpenIssuesCountService" do
+        expect(Projects::OpenIssuesCountService).not_to receive(:new).with(reusable_project)
 
-      issue.work_item_type_id = type1.old_id
-
-      expect(issue.work_item_type_id).to eq(type1.id)
+        group_work_item.invalidate_project_counter_caches
+      end
     end
   end
 end
