@@ -386,6 +386,96 @@ RSpec.describe GlobalPolicy, feature_category: :shared do
     end
   end
 
+  describe 'receive confirmation instructions' do
+    describe 'regular user' do
+      it { is_expected.to be_disallowed(:receive_confirmation_instructions) }
+
+      context 'with unconfirmed email address' do
+        before do
+          current_user.update!(unconfirmed_email: 'custom_email@example.com')
+        end
+
+        it { is_expected.to be_allowed(:receive_confirmation_instructions) }
+      end
+    end
+
+    describe 'admin' do
+      let(:current_user) { admin_user }
+
+      it { is_expected.to be_disallowed(:receive_confirmation_instructions) }
+
+      context 'with unconfirmed email address' do
+        before do
+          current_user.update!(unconfirmed_email: 'custom_email@example.com')
+        end
+
+        it { is_expected.to be_allowed(:receive_confirmation_instructions) }
+      end
+    end
+
+    describe 'anonymous' do
+      let(:current_user) { nil }
+
+      it { is_expected.to be_disallowed(:receive_confirmation_instructions) }
+    end
+
+    describe 'blocked user' do
+      before do
+        current_user.block
+      end
+
+      it { is_expected.to be_disallowed(:receive_confirmation_instructions) }
+    end
+
+    describe 'deactivated user' do
+      before do
+        current_user.deactivate
+      end
+
+      it { is_expected.to be_disallowed(:receive_confirmation_instructions) }
+    end
+
+    context 'project bot' do
+      let(:current_user) { project_bot }
+
+      it { is_expected.to be_disallowed(:receive_confirmation_instructions) }
+    end
+
+    context 'service account' do
+      let(:current_user) { service_account }
+
+      it { is_expected.to be_disallowed(:receive_confirmation_instructions) }
+
+      context 'with unconfirmed email address' do
+        let(:current_user) { build(:user, :service_account, unconfirmed_email: 'custom_email@example.com') }
+
+        it { is_expected.to be_allowed(:receive_confirmation_instructions) }
+      end
+
+      context 'with unconfirmed email address ending with no-reply domain' do
+        let(:current_user) do
+          build(:user, :service_account, unconfirmed_email: "custom_email@#{User::NOREPLY_EMAIL_DOMAIN}")
+        end
+
+        it { is_expected.to be_disallowed(:receive_confirmation_instructions) }
+      end
+    end
+
+    context 'migration bot' do
+      let(:current_user) { migration_bot }
+
+      it { is_expected.to be_disallowed(:receive_confirmation_instructions) }
+    end
+
+    context 'user blocked pending approval' do
+      before do
+        current_user.block_pending_approval
+      end
+
+      it { is_expected.to be_disallowed(:receive_confirmation_instructions) }
+    end
+  end
+
   describe 'git access' do
     describe 'regular user' do
       it { is_expected.to be_allowed(:access_git) }
@@ -644,35 +734,35 @@ RSpec.describe GlobalPolicy, feature_category: :shared do
     end
   end
 
-  describe 'create_instance_runner' do
+  describe 'create_instance_runners' do
     context 'admin' do
       let(:current_user) { admin_user }
 
       context 'when admin mode is enabled', :enable_admin_mode do
-        it { is_expected.to be_allowed(:create_instance_runner) }
+        it { is_expected.to be_allowed(:create_instance_runners) }
       end
 
       context 'when admin mode is disabled' do
-        it { is_expected.to be_disallowed(:create_instance_runner) }
+        it { is_expected.to be_disallowed(:create_instance_runners) }
       end
     end
 
     context 'with project_bot' do
       let(:current_user) { project_bot }
 
-      it { is_expected.to be_disallowed(:create_instance_runner) }
+      it { is_expected.to be_disallowed(:create_instance_runners) }
     end
 
     context 'with migration_bot' do
       let(:current_user) { migration_bot }
 
-      it { is_expected.to be_disallowed(:create_instance_runner) }
+      it { is_expected.to be_disallowed(:create_instance_runners) }
     end
 
     context 'with security_bot' do
       let(:current_user) { security_bot }
 
-      it { is_expected.to be_disallowed(:create_instance_runner) }
+      it { is_expected.to be_disallowed(:create_instance_runners) }
     end
 
     context 'with llm_bot' do
@@ -684,13 +774,13 @@ RSpec.describe GlobalPolicy, feature_category: :shared do
     context 'with regular user' do
       let(:current_user) { user }
 
-      it { is_expected.to be_disallowed(:create_instance_runner) }
+      it { is_expected.to be_disallowed(:create_instance_runners) }
     end
 
     context 'with anonymous' do
       let(:current_user) { nil }
 
-      it { is_expected.to be_disallowed(:create_instance_runner) }
+      it { is_expected.to be_disallowed(:create_instance_runners) }
     end
   end
 
@@ -751,14 +841,20 @@ RSpec.describe GlobalPolicy, feature_category: :shared do
       let(:current_user) { admin_user }
       let(:permissions) do
         [
+          :access_admin_area,
           :read_admin_audit_log,
           :read_admin_background_jobs,
           :read_admin_background_migrations,
           :read_admin_cicd,
+          :read_admin_database_diagnostics,
           :read_admin_gitaly_servers,
+          :read_admin_groups,
           :read_admin_health_check,
           :read_admin_metrics_dashboard,
-          :read_admin_system_information
+          :read_admin_projects,
+          :read_admin_system_information,
+          :read_admin_users,
+          :read_application_statistics
         ]
       end
 
