@@ -24,7 +24,7 @@ RSpec.describe API::Ci::Runner, :clean_gitlab_redis_shared_state, feature_catego
 
   context 'job artifact endpoints' do
     before do
-      stub_feature_flags(ci_enable_live_trace: true)
+      stub_application_setting(ci_job_live_trace_enabled: true)
       stub_gitlab_calls
       allow_any_instance_of(::Ci::Runner).to receive(:cache_attributes)
       stub_artifacts_object_storage
@@ -1100,6 +1100,12 @@ RSpec.describe API::Ci::Runner, :clean_gitlab_redis_shared_state, feature_catego
 
           it_behaves_like 'unauthorized request'
         end
+
+        context 'when token is missing' do
+          let(:token) { nil }
+
+          it_behaves_like 'unauthorized request'
+        end
       end
 
       context 'when job does not have artifacts' do
