@@ -5,27 +5,37 @@ require 'spec_helper'
 RSpec.describe API::Ci::Runners, :aggregate_failures, factory_default: :keep, feature_category: :fleet_visibility do
   using RSpec::Parameterized::TableSyntax
 
+  let_it_be(:users) { create_list(:user, 2) }
+
+  let_it_be(:group) { create(:group, owners: users.first) }
+  let_it_be(:subgroup) { create(:group, parent: group) }
+
   let_it_be(:organization) { create_default(:organization) }
   let_it_be(:admin) { create(:user, :admin, last_activity_on: Time.current) }
-  let_it_be(:users) { create_list(:user, 2) }
   let_it_be(:group_guest) { create(:user, guest_of: group) }
   let_it_be(:group_reporter) { create(:user, reporter_of: group) }
   let_it_be(:group_developer) { create(:user, developer_of: group) }
   let_it_be(:group_maintainer) { create(:user, maintainer_of: group) }
 
-  let_it_be(:group) { create(:group, owners: users.first) }
-  let_it_be(:subgroup) { create(:group, parent: group) }
-
   let_it_be(:project) do
     create(:project, creator_id: users.first.id, maintainers: users.first, reporters: users.second)
   end
 
   let_it_be(:project2) { create(:project, creator_id: users.first.id, maintainers: users.first) }
 
-  let_it_be(:shared_runner, reload: true) { create(:ci_runner, :instance, :with_runner_manager, description: 'Shared runner') }
-  let_it_be(:project_runner, reload: true) { create(:ci_runner, :project, description: 'Project runner', projects: [project]) }
+  let_it_be(:shared_runner, reload: true) do
+    create(:ci_runner, :instance, :with_runner_manager, description: 'Shared runner', maintenance_note: 'Maintenance note')
+  end
+
+  let_it_be(:project_runner, reload: true) do
+    create(:ci_runner, :project, description: 'Project runner', projects: [project], maintenance_note: 'Maintenance note')
+  end
+
   let_it_be(:two_projects_runner) { create(:ci_runner, :project, description: 'Two projects runner', projects: [project, project2]) }
-  let_it_be(:group_runner_a) { create(:ci_runner, :group, description: 'Group runner A', groups: [group]) }
+  let_it_be(:group_runner_a) do
+    create(:ci_runner, :group, description: 'Group runner A', groups: [group], maintenance_note: 'Maintenance note')
+  end
+
   let_it_be(:group_runner_b) { create(:ci_runner, :group, description: 'Group runner B', groups: [subgroup]) }
 
   let(:query) { {} }
@@ -81,12 +91,12 @@ RSpec.describe API::Ci::Runners, :aggregate_failures, factory_default: :keep, fe
       it 'returns user available runners' do
         perform_request
 
-        expect(json_response).to match_array [
+        expect(json_response).to contain_exactly(
           a_hash_including('description' => 'Project runner'),
           a_hash_including('description' => 'Two projects runner'),
           a_hash_including('description' => 'Group runner A'),
           a_hash_including('description' => 'Group runner B')
-        ]
+        )
       end
 
       context 'with request authorized with access token' do
@@ -203,6 +213,41 @@ RSpec.describe API::Ci::Runners, :aggregate_failures, factory_default: :keep, fe
           end
         end
       end
+
+      context 'job_execution_status attribute' do
+        context 'when no executing builds present for runners' do
+          it 'returns "idle" as job execution status' do
+            perform_request
+
+            expect(json_response.find { |runner| runner['id'] == project_runner.id }['job_execution_status']).to eq 'idle'
+          end
+        end
+
+        context 'when executing build present' do
+          before do
+            create(:ci_build, :running, runner: project_runner, project: project)
+          end
+
+          it 'returns "active" as job execution status' do
+            perform_request
+
+            expect(json_response.find { |runner| runner['id'] == project_runner.id }['job_execution_status']).to eq 'active'
+          end
+        end
+
+        context 'N+1 query performance' do
+          it 'does not trigger N+1 query for job_execution_status', :use_sql_query_cache do
+            control = ActiveRecord::QueryRecorder.new(skip_cached: false) { get api(path, current_user) }
+            create_list(:ci_runner, 5, :project, projects: [project], creator: users.first)
+
+            expect do
+              perform_request
+
+              expect(json_response).to all(include('job_execution_status'))
+            end.not_to exceed_query_limit(control)
+          end
+        end
+      end
     end
 
     context 'unauthorized user' do
@@ -228,15 +273,46 @@ RSpec.describe API::Ci::Runners, :aggregate_failures, factory_default: :keep, fe
         let(:runner) { shared_runner }
         let(:manager) { runner.runner_managers.first }
 
+        before do
+          create(:ci_build, :running, runner_manager: manager, runner: shared_runner)
+        end
+
         it 'returns all managers of the runner' do
           perform_request
 
           expect(response).to have_gitlab_http_status(:ok)
 
           expect(json_response).to contain_exactly(
-            a_hash_including('id' => manager.id, 'version' => manager.version, 'architecture' => manager.architecture)
+            a_hash_including('id' => manager.id, 'version' => manager.version, 'architecture' => manager.architecture,
+              'job_execution_status' => 'active')
           )
         end
+
+        context 'job_execution_status' do
+          before do
+            create(:ci_build, :running, runner_manager: manager, project: project)
+          end
+
+          it 'returns job execution status' do
+            perform_request
+
+            expect(json_response).to all(include('job_execution_status'))
+            expect(json_response.find { |runner_manager| runner_manager['id'] == manager.id }['job_execution_status']).to eq 'active'
+          end
+
+          context 'N+1 query performance' do
+            it 'does not trigger N+1 query for job_execution_status', :use_sql_query_cache do
+              control = ActiveRecord::QueryRecorder.new(skip_cached: false) { get api(path, current_user) }
+              create_list(:ci_runner_machine, 5, runner: runner)
+
+              expect do
+                perform_request
+
+                expect(json_response).to all(include('job_execution_status'))
+              end.not_to exceed_query_limit(control)
+            end
+          end
+        end
       end
 
       context 'when runner does not have managers' do
@@ -286,13 +362,37 @@ RSpec.describe API::Ci::Runners, :aggregate_failures, factory_default: :keep, fe
         it 'returns all runners' do
           perform_request
 
-          expect(json_response).to match_array [
+          expect(json_response).to contain_exactly(
             a_hash_including('description' => 'Project runner', 'is_shared' => false, 'active' => true, 'paused' => false, 'runner_type' => 'project_type'),
             a_hash_including('description' => 'Two projects runner', 'is_shared' => false, 'runner_type' => 'project_type'),
             a_hash_including('description' => 'Group runner A', 'is_shared' => false, 'runner_type' => 'group_type'),
             a_hash_including('description' => 'Group runner B', 'is_shared' => false, 'runner_type' => 'group_type'),
             a_hash_including('description' => 'Shared runner', 'is_shared' => true, 'runner_type' => 'instance_type')
-          ]
+          )
+        end
+
+        context 'created_by' do
+          let_it_be(:runner_with_creator) { create(:ci_runner, :project, creator: admin, projects: [project]) }
+
+          it 'returns created_at and created_by in the response' do
+            perform_request
+
+            expect(json_response.find { |runner| runner['id'] == runner_with_creator.id }['created_by']['username'])
+              .to eq(admin.username)
+            expect(json_response).to all(include('created_at'))
+          end
+
+          it 'does not trigger N+1 query for creator', :use_sql_query_cache do
+            control = ActiveRecord::QueryRecorder.new(skip_cached: false) do
+              get api(path, current_user)
+            end
+
+            create_list(:ci_runner, 5, :project, projects: [project], creator: users.first)
+
+            expect do
+              perform_request
+            end.not_to exceed_query_limit(control)
+          end
         end
 
         context 'with request authorized with access token' do
@@ -547,6 +647,16 @@ RSpec.describe API::Ci::Runners, :aggregate_failures, factory_default: :keep, fe
           expect(json_response['paused']).to eq(false)
           expect(json_response['maintenance_note']).to be_nil
         end
+
+        context 'with admin mode enabled', :enable_admin_mode do
+          it "returns runner's details" do
+            perform_request
+
+            expect(response).to have_gitlab_http_status(:ok)
+            expect(json_response['maintenance_note']).not_to be_nil
+            expect(json_response['maintenance_note']).to eq(shared_runner.maintenance_note)
+          end
+        end
       end
 
       context 'when runner is a project runner' do
@@ -564,6 +674,8 @@ RSpec.describe API::Ci::Runners, :aggregate_failures, factory_default: :keep, fe
 
             expect(response).to have_gitlab_http_status(:ok)
             expect(json_response['description']).to eq(runner.description)
+            expect(json_response['maintenance_note']).not_to be_nil
+            expect(json_response['maintenance_note']).to eq(runner.maintenance_note)
           end
 
           it "returns the project's details" do
@@ -595,8 +707,23 @@ RSpec.describe API::Ci::Runners, :aggregate_failures, factory_default: :keep, fe
 
           expect(response).to have_gitlab_http_status(:ok)
           expect(json_response['description']).to eq(runner.description)
+          expect(json_response['maintenance_note']).not_to be_nil
+          expect(json_response['maintenance_note']).to eq(runner.maintenance_note)
           expect(json_response['groups'].first['id']).to eq(group.id)
         end
+
+        context 'and user is not a group owner' do
+          let(:current_user) { group_maintainer }
+
+          it "returns the runner's details without maintenance note" do
+            perform_request
+
+            expect(response).to have_gitlab_http_status(:ok)
+            expect(json_response['description']).to eq(runner.description)
+            expect(json_response['maintenance_note']).to be_nil
+            expect(json_response['groups'].first['id']).to eq(group.id)
+          end
+        end
       end
 
       context "runner project's administrative user" do
@@ -610,6 +737,8 @@ RSpec.describe API::Ci::Runners, :aggregate_failures, factory_default: :keep, fe
 
             expect(response).to have_gitlab_http_status(:ok)
             expect(json_response['description']).to eq(runner.description)
+            expect(json_response['maintenance_note']).not_to be_nil
+            expect(json_response['maintenance_note']).to eq(runner.maintenance_note)
           end
         end
 
@@ -621,6 +750,7 @@ RSpec.describe API::Ci::Runners, :aggregate_failures, factory_default: :keep, fe
 
             expect(response).to have_gitlab_http_status(:ok)
             expect(json_response['description']).to eq(runner.description)
+            expect(json_response['maintenance_note']).to be_nil
           end
         end
       end
@@ -2227,7 +2357,7 @@ RSpec.describe API::Ci::Runners, :aggregate_failures, factory_default: :keep, fe
         let(:runner) { project_runner }
 
         it 'avoids changes' do
-          expect { perform_request }.to change { project.runners.count }.by(0)
+          expect { perform_request }.not_to change { project.runners.count }
 
           expect(response).to have_gitlab_http_status(:bad_request)
         end
