@@ -865,6 +865,62 @@ RSpec.describe 'Update a work item', feature_category: :team_planning do
           end
         end
       end
+
+      context 'when updating hierarchy for incident' do
+        let_it_be(:incident) { create(:work_item, :incident, project: project) }
+        let_it_be(:child_item) { create(:work_item, :task, project: project) }
+        let(:mutation_work_item) { incident }
+
+        let(:input) do
+          { 'hierarchyWidget' => { 'childrenIds' => [child_item.to_global_id.to_s] } }
+        end
+
+        context 'when user is a guest' do
+          let(:current_user) { guest }
+
+          it 'returns an error and does not update' do
+            expect do
+              post_graphql_mutation(mutation, current_user: current_user)
+              incident.reload
+            end.not_to change { incident.work_item_children.count }
+
+            expect(mutation_response['workItem']).to be_nil
+            expect(mutation_response['errors']).to include(
+              "No matching work item found. Make sure that you are adding a valid work item ID."
+            )
+          end
+        end
+
+        context 'when user is an admin' do
+          let_it_be(:admin) { create(:admin) }
+          let(:current_user) { admin }
+
+          it 'successfully updates the incident hierarchy' do
+            expect do
+              post_graphql_mutation(mutation, current_user: current_user)
+              incident.reload
+            end.to change { incident.work_item_children.count }.by(1)
+
+            expect(response).to have_gitlab_http_status(:success)
+            expect(mutation_response['workItem']).not_to be_nil
+          end
+        end
+
+        context 'when guest updates hierarchy for non-incident work item' do
+          let(:current_user) { guest }
+          let(:mutation_work_item) { work_item } # regular work item, not incident
+
+          it 'successfully updates the work item hierarchy' do
+            expect do
+              post_graphql_mutation(mutation, current_user: current_user)
+              work_item.reload
+            end.to change { work_item.work_item_children.count }.by(1)
+
+            expect(response).to have_gitlab_http_status(:success)
+            expect(mutation_response['workItem']).not_to be_nil
+          end
+        end
+      end
     end
 
     context 'when updating assignees' do
@@ -1352,7 +1408,7 @@ RSpec.describe 'Update a work item', feature_category: :team_planning do
           let_it_be(:current_user) { create(:user) }
 
           it 'does not create a new todo' do
-            expect { update_work_item }.to change { Todo.count }.by(0)
+            expect { update_work_item }.not_to change { Todo.count }
 
             expect(response).to have_gitlab_http_status(:success)
           end
@@ -1393,7 +1449,7 @@ RSpec.describe 'Update a work item', feature_category: :team_planning do
           let_it_be(:current_user) { create(:user) }
 
           it 'does not mark todos as done' do
-            expect { update_work_item }.to change { Todo.done.count }.by(0)
+            expect { update_work_item }.not_to change { Todo.done.count }
 
             expect(response).to have_gitlab_http_status(:success)
           end
@@ -1436,7 +1492,7 @@ RSpec.describe 'Update a work item', feature_category: :team_planning do
           let_it_be(:current_user) { create(:user) }
 
           it 'does not mark the todo as done' do
-            expect { update_work_item }.to change { Todo.done.count }.by(0)
+            expect { update_work_item }.not_to change { Todo.done.count }
 
             expect(response).to have_gitlab_http_status(:success)
           end
@@ -1695,6 +1751,10 @@ RSpec.describe 'Update a work item', feature_category: :team_planning do
           expect(mutation_response['workItem']['widgets']).to include(
             'timeEstimate' => expected_result[:time_estimate],
             'totalTimeSpent' => expected_result[:time_spent],
+            'humanReadableAttributes' => {
+              'timeEstimate' => Gitlab::TimeTrackingFormatter.output(mutation_work_item.time_estimate),
+              'totalTimeSpent' => Gitlab::TimeTrackingFormatter.output(mutation_work_item.total_time_spent)
+            },
             'timelogs' => {
               'nodes' => [
                 {
@@ -1723,6 +1783,10 @@ RSpec.describe 'Update a work item', feature_category: :team_planning do
                 type
                 timeEstimate
                 totalTimeSpent
+                humanReadableAttributes {
+                  timeEstimate
+                  totalTimeSpent
+                }
                 timelogs {
                   nodes {
                     timeSpent
