@@ -52,7 +52,7 @@ RSpec.describe API::NpmProjectPackages, feature_category: :package_registry do
           .to change { npm_metadata_cache.reload.last_downloaded_at }.from(nil).to(instance_of(ActiveSupport::TimeWithZone))
       end
 
-      it_behaves_like 'does not enqueue a worker to sync a metadata cache'
+      it_behaves_like 'does not enqueue a worker to sync a npm metadata cache'
 
       context 'when metadata cache file does not exist' do
         before do
@@ -60,7 +60,7 @@ RSpec.describe API::NpmProjectPackages, feature_category: :package_registry do
         end
 
         it_behaves_like 'generates metadata response "on-the-fly"'
-        it_behaves_like 'enqueue a worker to sync a metadata cache'
+        it_behaves_like 'enqueue a worker to sync a npm metadata cache'
       end
     end
 
@@ -84,6 +84,10 @@ RSpec.describe API::NpmProjectPackages, feature_category: :package_registry do
         subject
       end
     end
+
+    it_behaves_like 'updating personal access token last used' do
+      subject { get(url, headers: build_token_auth_header(personal_access_token.token)) }
+    end
   end
 
   describe 'GET /api/v4/projects/:id/packages/npm/-/package/*package_name/dist-tags' do
@@ -91,6 +95,10 @@ RSpec.describe API::NpmProjectPackages, feature_category: :package_registry do
 
     it_behaves_like 'handling get dist tags requests', scope: :project
     it_behaves_like 'accept get request on private project with access to package registry for everyone'
+
+    it_behaves_like 'updating personal access token last used' do
+      subject { get(url, headers: build_token_auth_header(personal_access_token.token)) }
+    end
   end
 
   describe 'PUT /api/v4/projects/:id/packages/npm/-/package/*package_name/dist-tags/:tag' do
@@ -98,7 +106,7 @@ RSpec.describe API::NpmProjectPackages, feature_category: :package_registry do
       let(:url) { api("/projects/#{project.id}/packages/npm/-/package/#{package_name}/dist-tags/#{tag_name}") }
     end
 
-    it_behaves_like 'enqueue a worker to sync a metadata cache' do
+    it_behaves_like 'enqueue a worker to sync a npm metadata cache' do
       let(:tag_name) { 'test' }
       let(:url) { api("/projects/#{project.id}/packages/npm/-/package/#{package_name}/dist-tags/#{tag_name}") }
       let(:env) { { 'api.request.body': package.version } }
@@ -106,6 +114,13 @@ RSpec.describe API::NpmProjectPackages, feature_category: :package_registry do
 
       subject { put(url, env: env, headers: headers) }
     end
+
+    it_behaves_like 'updating personal access token last used' do
+      let(:tag_name) { 'test' }
+      let(:url) { api("/projects/#{project.id}/packages/npm/-/package/#{package_name}/dist-tags/#{tag_name}") }
+
+      subject { put(url, headers: build_token_auth_header(personal_access_token.token)) }
+    end
   end
 
   describe 'DELETE /api/v4/projects/:id/packages/npm/-/package/*package_name/dist-tags/:tag' do
@@ -113,7 +128,7 @@ RSpec.describe API::NpmProjectPackages, feature_category: :package_registry do
       let(:url) { api("/projects/#{project.id}/packages/npm/-/package/#{package_name}/dist-tags/#{tag_name}") }
     end
 
-    it_behaves_like 'enqueue a worker to sync a metadata cache' do
+    it_behaves_like 'enqueue a worker to sync a npm metadata cache' do
       let_it_be(:package_tag) { create(:packages_tag, package: package) }
 
       let(:tag_name) { package_tag.name }
@@ -122,18 +137,37 @@ RSpec.describe API::NpmProjectPackages, feature_category: :package_registry do
 
       subject { delete(url, headers: headers) }
     end
+
+    it_behaves_like 'updating personal access token last used' do
+      let(:tag_name) { 'test' }
+      let(:url) { api("/projects/#{project.id}/packages/npm/-/package/#{package_name}/dist-tags/#{tag_name}") }
+
+      subject { delete(url, headers: build_token_auth_header(personal_access_token.token)) }
+    end
   end
 
   describe 'POST /api/v4/projects/:id/packages/npm/-/npm/v1/security/advisories/bulk' do
     it_behaves_like 'handling audit request', path: 'advisories/bulk', scope: :project do
       let(:url) { api("/projects/#{project.id}/packages/npm/-/npm/v1/security/advisories/bulk") }
     end
+
+    it_behaves_like 'updating personal access token last used' do
+      let(:url) { api("/projects/#{project.id}/packages/npm/-/npm/v1/security/advisories/bulk") }
+
+      subject { post(url, headers: build_token_auth_header(personal_access_token.token)) }
+    end
   end
 
   describe 'POST /api/v4/projects/:id/packages/npm/-/npm/v1/security/audits/quick' do
     it_behaves_like 'handling audit request', path: 'audits/quick', scope: :project do
       let(:url) { api("/projects/#{project.id}/packages/npm/-/npm/v1/security/audits/quick") }
     end
+
+    it_behaves_like 'updating personal access token last used' do
+      let(:url) { api("/projects/#{project.id}/packages/npm/-/npm/v1/security/audits/quick") }
+
+      subject { post(url, headers: build_token_auth_header(personal_access_token.token)) }
+    end
   end
 
   describe 'GET /api/v4/projects/:id/packages/npm/*package_name/-/*file_name' do
@@ -255,6 +289,10 @@ RSpec.describe API::NpmProjectPackages, feature_category: :package_registry do
         it_behaves_like 'successfully downloads the file'
       end
     end
+
+    it_behaves_like 'updating personal access token last used' do
+      let(:headers) { build_token_auth_header(personal_access_token.token) }
+    end
   end
 
   describe 'PUT /api/v4/projects/:id/packages/npm/:package_name' do
@@ -267,7 +305,7 @@ RSpec.describe API::NpmProjectPackages, feature_category: :package_registry do
     shared_examples 'handling invalid record with 400 error' do |error_message|
       it 'handles an ActiveRecord::RecordInvalid exception with 400 error' do
         expect { upload_package_with_token }
-          .not_to change { project.packages.count }
+          .not_to change { ::Packages::Npm::Package.for_projects(project).count }
 
         expect(response).to have_gitlab_http_status(:bad_request)
         expect(json_response['error']).to eq(error_message)
@@ -280,7 +318,7 @@ RSpec.describe API::NpmProjectPackages, feature_category: :package_registry do
           let(:package_name) { "@#{group.path}/my_inv@@lid_package_name" }
           let(:params) { upload_params(package_name: package_name) }
 
-          it_behaves_like 'handling invalid record with 400 error', "Validation failed: Name is invalid, Name #{Gitlab::Regex.npm_package_name_regex_message}"
+          it_behaves_like 'handling invalid record with 400 error', "Validation failed: Name #{Gitlab::Regex.npm_package_name_regex_message}"
           it_behaves_like 'not a package tracking event'
         end
 
@@ -331,7 +369,7 @@ RSpec.describe API::NpmProjectPackages, feature_category: :package_registry do
 
           it 'creates npm package with file with job token' do
             expect { upload_with_job_token(package_name, params) }
-              .to change { project.packages.count }.by(1)
+              .to change { ::Packages::Npm::Package.for_projects(project).count }.by(1)
               .and change { Packages::PackageFile.count }.by(1)
 
             expect(response).to have_gitlab_http_status(:ok)
@@ -362,7 +400,7 @@ RSpec.describe API::NpmProjectPackages, feature_category: :package_registry do
         shared_examples 'uploading the package' do
           it 'uploads the package' do
             expect { upload_package_with_token }
-              .to change { project.packages.count }.by(1)
+              .to change { ::Packages::Npm::Package.for_projects(project).count }.by(1)
 
             expect(response).to have_gitlab_http_status(:ok)
           end
@@ -390,7 +428,7 @@ RSpec.describe API::NpmProjectPackages, feature_category: :package_registry do
           it_behaves_like 'handling upload with different authentications'
         end
 
-        it_behaves_like 'does not enqueue a worker to sync a metadata cache'
+        it_behaves_like 'does not enqueue a worker to sync a npm metadata cache'
 
         context 'with an existing package' do
           let_it_be(:second_project) { create(:project, namespace: namespace) }
@@ -432,13 +470,13 @@ RSpec.describe API::NpmProjectPackages, feature_category: :package_registry do
 
         it 'returns an error if the package already exists' do
           expect { upload_package_with_token }
-            .not_to change { project.packages.count }
+            .not_to change { ::Packages::Npm::Package.for_projects(project).count }
 
           expect(response).to have_gitlab_http_status(:forbidden)
           expect(json_response['error']).to eq('Package already exists.')
         end
 
-        it_behaves_like 'does not enqueue a worker to sync a metadata cache' do
+        it_behaves_like 'does not enqueue a worker to sync a npm metadata cache' do
           subject { upload_package_with_token }
         end
       end
@@ -449,7 +487,7 @@ RSpec.describe API::NpmProjectPackages, feature_category: :package_registry do
 
         it 'creates npm package with file and dependencies' do
           expect { upload_package_with_token }
-            .to change { project.packages.count }.by(1)
+            .to change { ::Packages::Npm::Package.for_projects(project).count }.by(1)
             .and change { Packages::PackageFile.count }.by(1)
             .and change { Packages::Dependency.count }.by(4)
             .and change { Packages::DependencyLink.count }.by(6)
@@ -465,7 +503,7 @@ RSpec.describe API::NpmProjectPackages, feature_category: :package_registry do
 
           it 'reuses them' do
             expect { upload_package_with_token }
-              .to change { project.packages.count }.by(1)
+              .to change { ::Packages::Npm::Package.for_projects(project).count }.by(1)
               .and change { Packages::PackageFile.count }.by(1)
               .and not_change { Packages::Dependency.count }
               .and change { Packages::DependencyLink.count }.by(6)
@@ -486,7 +524,7 @@ RSpec.describe API::NpmProjectPackages, feature_category: :package_registry do
 
         it 'returns an error' do
           expect { upload_package_with_token }
-            .not_to change { project.packages.count }
+            .not_to change { ::Packages::Npm::Package.for_projects(project).count }
 
           expect(response).to have_gitlab_http_status(:bad_request)
           expect(response.body).to include('Could not obtain package lease. Please try again.')
