@@ -803,17 +803,20 @@ RSpec.describe API::Releases, :aggregate_failures, feature_category: :release_or
           expect(response).to have_gitlab_http_status(:redirect)
           expect(uri.path).to eq("/api/v4/projects/#{project.id}/releases/#{release_b.tag}/downloads/bin/example.exe")
         end
+      end
 
-        it 'returns error when there is path traversal in suffix path' do
-          # TODO: remove spec once the feature flag is removed
-          # https://gitlab.com/gitlab-org/gitlab/-/issues/415460
-          stub_feature_flags(check_path_traversal_middleware_reject_requests: false)
+      context 'when a relative URL is configured' do
+        before do
+          stub_config_setting(relative_url_root: '/gitlab-relative-url')
+        end
 
-          get api("/projects/#{project.id}/releases/permalink/latest/downloads/bin/../../../../../../../password.txt", maintainer)
+        it 'includes the relative URL in the redirect' do
+          get api("/projects/#{project.id}/releases/permalink/latest", maintainer)
 
-          expect(response).to have_gitlab_http_status(:bad_request)
+          uri = URI(response.header["Location"])
 
-          expect(json_response['error']).to eq('suffix_path should be a valid file path')
+          expect(response).to have_gitlab_http_status(:redirect)
+          expect(uri.path).to eq("/gitlab-relative-url/api/v4/projects/#{project.id}/releases/#{release_b.tag}")
         end
       end
     end
@@ -875,9 +878,9 @@ RSpec.describe API::Releases, :aggregate_failures, feature_category: :release_or
 
     it 'creates a new release without description' do
       params = {
-          name: 'New release without description',
-          tag_name: 'v0.1',
-          released_at: '2019-03-25 10:00:00'
+        name: 'New release without description',
+        tag_name: 'v0.1',
+        released_at: '2019-03-25 10:00:00'
       }
 
       expect do
