@@ -65,7 +65,7 @@ RSpec.describe 'InternalEventsCli::Flows::MetricDefiner', :aggregate_failures, f
       TEXT
 
       with_cli_thread do
-        expect { plain_last_lines(9) }.to eventually_equal_cli_text(expected_output)
+        expect { plain_last_lines(expected_output.lines.count) }.to eventually_equal_cli_text(expected_output)
       end
     end
 
@@ -93,7 +93,7 @@ RSpec.describe 'InternalEventsCli::Flows::MetricDefiner', :aggregate_failures, f
       TEXT
 
       with_cli_thread do
-        expect { plain_last_lines(5) }.to eventually_equal_cli_text(expected_output)
+        expect { plain_last_lines(expected_output.lines.count) }.to eventually_equal_cli_text(expected_output)
       end
     end
   end
@@ -138,11 +138,11 @@ RSpec.describe 'InternalEventsCli::Flows::MetricDefiner', :aggregate_failures, f
       ‣ Monthly/Weekly count of unique users who triggered internal_events_cli_used
         Monthly/Weekly count of unique projects where internal_events_cli_used occurred
         Monthly/Weekly count of unique namespaces where internal_events_cli_used occurred
-        Monthly/Weekly/Total count of internal_events_cli_used occurrences
+        Total/Monthly/Weekly count of internal_events_cli_used occurrences
       TEXT
 
       with_cli_thread do
-        expect { plain_last_lines(4) }.to eventually_equal_cli_text(expected_output)
+        expect { plain_last_lines(expected_output.lines.count) }.to eventually_equal_cli_text(expected_output)
       end
     end
 
@@ -161,12 +161,12 @@ RSpec.describe 'InternalEventsCli::Flows::MetricDefiner', :aggregate_failures, f
         ‣ Monthly count of unique users who triggered internal_events_cli_used
           Monthly/Weekly count of unique projects where internal_events_cli_used occurred
           Monthly/Weekly count of unique namespaces where internal_events_cli_used occurred
-          Monthly/Weekly/Total count of internal_events_cli_used occurrences
+          Total/Monthly/Weekly count of internal_events_cli_used occurrences
         ✘ Weekly count of unique users who triggered internal_events_cli_used (already defined)
         TEXT
 
         with_cli_thread do
-          expect { plain_last_lines(5) }.to eventually_equal_cli_text(expected_output)
+          expect { plain_last_lines(expected_output.lines.count) }.to eventually_equal_cli_text(expected_output)
         end
       end
     end
@@ -186,11 +186,11 @@ RSpec.describe 'InternalEventsCli::Flows::MetricDefiner', :aggregate_failures, f
         ‣ Monthly/Weekly count of unique users who triggered internal_events_cli_used
           Monthly/Weekly count of unique projects where internal_events_cli_used occurred
           Monthly/Weekly count of unique namespaces where internal_events_cli_used occurred
-        ✘ Monthly/Weekly/Total count of internal_events_cli_used occurrences (already defined)
+        ✘ Total/Monthly/Weekly count of internal_events_cli_used occurrences (already defined)
         TEXT
 
         with_cli_thread do
-          expect { plain_last_lines(4) }.to eventually_equal_cli_text(expected_output)
+          expect { plain_last_lines(expected_output.lines.count) }.to eventually_equal_cli_text(expected_output)
         end
       end
     end
@@ -240,12 +240,12 @@ RSpec.describe 'InternalEventsCli::Flows::MetricDefiner', :aggregate_failures, f
       expected_output = <<~TEXT.chomp
       ‣ Monthly/Weekly count of unique users who triggered any of 2 events
         Monthly/Weekly count of unique namespaces where any of 2 events occurred
-        Monthly/Weekly/Total count of any of 2 events occurrences
+        Total/Monthly/Weekly count of any of 2 events occurrences
       ✘ Monthly/Weekly count of unique projects where any of 2 events occurred (already defined)
       TEXT
 
       with_cli_thread do
-        expect { plain_last_lines(4) }.to eventually_equal_cli_text(expected_output)
+        expect { plain_last_lines(expected_output.lines.count) }.to eventually_equal_cli_text(expected_output)
       end
     end
   end
@@ -264,14 +264,14 @@ RSpec.describe 'InternalEventsCli::Flows::MetricDefiner', :aggregate_failures, f
       ])
 
       expected_output = <<~TEXT.chomp
-      ‣ Monthly/Weekly/Total count of internal_events_cli_opened occurrences
+      ‣ Total/Monthly/Weekly count of internal_events_cli_opened occurrences
       ✘ Monthly/Weekly count of unique users who triggered internal_events_cli_opened (user unavailable)
       ✘ Monthly/Weekly count of unique projects where internal_events_cli_opened occurred (project unavailable)
       ✘ Monthly/Weekly count of unique namespaces where internal_events_cli_opened occurred (namespace unavailable)
       TEXT
 
       with_cli_thread do
-        expect { plain_last_lines(4) }.to eventually_equal_cli_text(expected_output)
+        expect { plain_last_lines(expected_output.lines.count) }.to eventually_equal_cli_text(expected_output)
       end
     end
   end
@@ -334,18 +334,20 @@ RSpec.describe 'InternalEventsCli::Flows::MetricDefiner', :aggregate_failures, f
         Monthly/Weekly count of unique users who triggered internal_events_cli_used where label/property/value is...
         Monthly/Weekly count of unique projects where internal_events_cli_used occurred where label/property/value is...
         Monthly/Weekly count of unique namespaces where internal_events_cli_used occurred where label/property/value is...
-        Monthly/Weekly/Total count of internal_events_cli_used occurrences
-        Monthly/Weekly/Total count of internal_events_cli_used occurrences where label/property/value is...
+        Total/Monthly/Weekly count of internal_events_cli_used occurrences
+        Total/Monthly/Weekly count of internal_events_cli_used occurrences where label/property/value is...
         Monthly/Weekly count of unique values for 'label' from internal_events_cli_used occurrences
         Monthly/Weekly count of unique values for 'property' from internal_events_cli_used occurrences
         Monthly/Weekly count of unique values for 'value' from internal_events_cli_used occurrences
         Monthly/Weekly count of unique values for 'label' from internal_events_cli_used occurrences where property/value is...
         Monthly/Weekly count of unique values for 'property' from internal_events_cli_used occurrences where label/value is...
         Monthly/Weekly count of unique values for 'value' from internal_events_cli_used occurrences where label/property is...
+        Total/Monthly/Weekly sum of all values for 'value' from internal_events_cli_used occurrences
+        Total/Monthly/Weekly sum of all values for 'value' from internal_events_cli_used occurrences where label/property is...
       TEXT
 
       with_cli_thread do
-        expect { plain_last_lines(14) }.to eventually_equal_cli_text(expected_output)
+        expect { plain_last_lines(expected_output.lines.count) }.to eventually_equal_cli_text(expected_output)
       end
     end
 
@@ -376,17 +378,19 @@ RSpec.describe 'InternalEventsCli::Flows::MetricDefiner', :aggregate_failures, f
           Monthly/Weekly count of unique users who triggered any of 2 events where label/value/property is...
           Monthly/Weekly count of unique projects where any of 2 events occurred where label/value/property is...
           Monthly/Weekly count of unique namespaces where any of 2 events occurred where label/value/property is...
-          Monthly/Weekly/Total count of any of 2 events occurrences
-          Monthly/Weekly/Total count of any of 2 events occurrences where label/value/property is...
+          Total/Monthly/Weekly count of any of 2 events occurrences
+          Total/Monthly/Weekly count of any of 2 events occurrences where label/value/property is...
           Monthly/Weekly count of unique values for 'label' from any of 2 events occurrences
           Monthly/Weekly count of unique values for 'value' from any of 2 events occurrences
           Monthly/Weekly count of unique values for 'label' from any of 2 events occurrences where value/property is...
           Monthly/Weekly count of unique values for 'value' from any of 2 events occurrences where label/property is...
+          Total/Monthly/Weekly sum of all values for 'value' from any of 2 events occurrences
+          Total/Monthly/Weekly sum of all values for 'value' from any of 2 events occurrences where label/property is...
         ✘ Monthly/Weekly count of unique values for 'property' from any of 2 events occurrences (property unavailable)
         TEXT
 
         with_cli_thread do
-          expect { plain_last_lines(13) }.to eventually_equal_cli_text(expected_output)
+          expect { plain_last_lines(expected_output.lines.count) }.to eventually_equal_cli_text(expected_output)
         end
       end
 
@@ -398,7 +402,7 @@ RSpec.describe 'InternalEventsCli::Flows::MetricDefiner', :aggregate_failures, f
           " ", # Select: config/events/internal_events_cli_used.yml
           "\e[B ", # Arrow down & Select: config/events/internal_events_cli_opened.yml
           "\n", # Submit Multi-select
-          "\e[A\n", # Arrow up & select Monthly/Weekly unique 'value' from any of 2 events where label/property is...
+          "\e[A\e[A\e[A\n", # Arrow up to: Monthly/Weekly unique 'value' from any of 2 events where label/property is...
           "a label value\n", # Enter a value for 'label' for internal_events_cli_opened
           "\n", # Accept the same 'label' value for internal_events_cli_used
           "a property value\n", # Enter a value for 'property' for internal_events_cli_used
@@ -477,6 +481,35 @@ RSpec.describe 'InternalEventsCli::Flows::MetricDefiner', :aggregate_failures, f
     end
 
     context "when creating a multiple metrics" do
+      it 'displays the metric paths based on the time frames' do
+        queue_cli_inputs([
+          "2\n", # Enum-select: New Metric   -- calculate how often one or more existing events occur over time
+          "2\n", # Enum-select: Multiple events -- count occurrences of several separate events or interactions
+          'internal_events_cli', # Filters to the relevant events
+          ' ', # Multi-select: internal_events_cli_closed
+          "\e[B", # Arrow down to: internal_events_cli_used
+          ' ', # Multi-select: internal_events_cli_used
+          "\n", # Submit selections
+          "\n", # Select: Monthly/Weekly/Total count
+          "where a definition file was created with the CLI\n", # Input description
+          "1\n", # Select: Copy & continue
+          "\e[B \n" # Skip product categories
+          # "y\n" # Create file
+        ])
+
+        expected_output = <<~TEXT.chomp
+          This would create 3 metrics with the following key paths:
+
+          monthly: counts.count_total_internal_events_cli_closed_and_internal_events_cli_used_monthly
+          weekly: counts.count_total_internal_events_cli_closed_and_internal_events_cli_used_weekly
+          total: counts.count_total_internal_events_cli_closed_and_internal_events_cli_used
+        TEXT
+
+        with_cli_thread do
+          expect { plain_last_lines }.to eventually_include_cli_text(expected_output)
+        end
+      end
+
       it 'shows link to the metric dashboard' do
         queue_cli_inputs([
           "2\n", # Enum-select: New Metric   -- calculate how often one or more existing events occur over time
