@@ -122,7 +122,7 @@ RSpec.describe BulkImports::CreateService, :clean_gitlab_redis_shared_state, fea
 
           expect(result).to be_a(ServiceResponse)
           expect(result).to be_error
-          expect(result.message).to eq("Import failed. You don't have permission to export 'full/path/to/group1'.")
+          expect(result.message).to eq("Import failed. You do not have permission to export 'full/path/to/group1'.")
         end
       end
 
@@ -150,8 +150,8 @@ RSpec.describe BulkImports::CreateService, :clean_gitlab_redis_shared_state, fea
           expect(result).to be_error
           expect(result.message)
             .to eq(
-              "Migration by direct transfer disabled on source or destination instance. " \
-              "Ask an administrator to enable it on both instances and try again."
+              "Migration by direct transfer is disabled on the source or destination instance. " \
+              "Ask an administrator to enable this feature on both instances and try again."
             )
         end
       end
@@ -278,6 +278,76 @@ RSpec.describe BulkImports::CreateService, :clean_gitlab_redis_shared_state, fea
           end
         end
 
+        context 'when different destination namespaces belonging to different organizations are provided' do
+          before do
+            second_org_group.add_owner(user)
+          end
+
+          let_it_be(:second_organization) { create(:organization, path: 'second-org') }
+          let_it_be(:second_org_group) { create(:group, organization: second_organization, path: 'second-org') }
+
+          let(:params) do
+            [
+              {
+                source_type: 'group_entity',
+                source_full_path: 'full/path/to/group1',
+                destination_slug: 'destination-group-1',
+                destination_namespace: '',
+                migrate_projects: migrate_projects
+              },
+              {
+                source_type: 'group_entity',
+                source_full_path: 'full/path/to/group1',
+                destination_slug: 'destination-group-1',
+                destination_namespace: second_org_group.path,
+                migrate_projects: migrate_projects
+              }
+            ]
+          end
+
+          it 'returns unsuccessful ServiceResponse' do
+            result = subject.execute
+
+            expect(result).to be_a(ServiceResponse)
+            expect(result).to be_error
+            expect(result.message).to eq("Validation failed: Organization must match the bulk import organization's ID")
+          end
+        end
+
+        context 'when different destination namespaces belonging to the same organization are provided' do
+          before do
+            second_group.add_owner(user)
+          end
+
+          let(:second_group) { create(:group, path: 'second-group', organization: fallback_organization) }
+
+          let(:params) do
+            [
+              {
+                source_type: 'group_entity',
+                source_full_path: 'full/path/to/group1',
+                destination_slug: 'destination-group-1',
+                destination_namespace: '',
+                migrate_projects: migrate_projects
+              },
+              {
+                source_type: 'group_entity',
+                source_full_path: 'full/path/to/group1',
+                destination_slug: 'destination-group-1',
+                destination_namespace: second_group.path,
+                migrate_projects: migrate_projects
+              }
+            ]
+          end
+
+          it 'returns success ServiceResponse' do
+            result = subject.execute
+
+            expect(result).to be_a(ServiceResponse)
+            expect(result).to be_success
+          end
+        end
+
         context 'on the same instance' do
           before do
             allow(Settings.gitlab).to receive(:host).and_return('gitlab.example')
@@ -438,9 +508,9 @@ RSpec.describe BulkImports::CreateService, :clean_gitlab_redis_shared_state, fea
         subject.execute
       end
 
-      context 'when importer_user_mapping feature flag is disable' do
+      context 'when bulk_import_importer_user_mapping feature flag is disable' do
         before do
-          stub_feature_flags(importer_user_mapping: false)
+          stub_feature_flags(bulk_import_importer_user_mapping: false)
         end
 
         it 'does not enable importer_user_mapping' do
@@ -456,18 +526,6 @@ RSpec.describe BulkImports::CreateService, :clean_gitlab_redis_shared_state, fea
         end
       end
 
-      context 'when bulk_import_importer_user_mapping feature flag is disable' do
-        before do
-          stub_feature_flags(bulk_import_importer_user_mapping: false)
-        end
-
-        it 'does not enable importer_user_mapping' do
-          subject.execute
-
-          expect(Import::BulkImports::EphemeralData.new(BulkImport.last.id).importer_user_mapping_enabled?).to eq(false)
-        end
-      end
-
       context 'on the same instance' do
         before do
           allow(Settings.gitlab).to receive(:host).and_return('gitlab.example')
@@ -514,10 +572,10 @@ RSpec.describe BulkImports::CreateService, :clean_gitlab_redis_shared_state, fea
         expect(result).to be_a(ServiceResponse)
         expect(result).to be_error
         expect(result.message).to eq("Validation failed: Source full path can't be blank, " \
-                                     "Source full path must have a relative path structure with " \
-                                     "no HTTP protocol characters, or leading or trailing forward slashes. " \
-                                     "Path segments must not start or end with a special character, and " \
-                                     "must not contain consecutive special characters")
+                                     "Source full path must have a relative path with " \
+                                     "no HTTP protocol characters or leading or trailing forward slashes. " \
+                                     "Path segments must not start or end with a special character or " \
+                                     "contain consecutive special characters.")
       end
 
       describe '#user-role' do
@@ -729,8 +787,8 @@ RSpec.describe BulkImports::CreateService, :clean_gitlab_redis_shared_state, fea
             expect(result).to be_a(ServiceResponse)
             expect(result).to be_error
             expect(result.message)
-              .to eq("Import failed. Destination 'destination-namespace' is invalid, " \
-                     "or you don't have permission.")
+              .to eq("Import failed. 'destination-namespace' is invalid, " \
+                     "or you do not have permission.")
           end
         end
 
@@ -756,8 +814,8 @@ RSpec.describe BulkImports::CreateService, :clean_gitlab_redis_shared_state, fea
             expect(result).to be_a(ServiceResponse)
             expect(result).to be_error
             expect(result.message)
-            .to eq("Import failed. Destination '#{parent_group.path}' is invalid, " \
-                   "or you don't have permission.")
+            .to eq("Import failed. '#{parent_group.path}' is invalid, " \
+                   "or you do not have permission.")
           end
         end
 
@@ -783,8 +841,8 @@ RSpec.describe BulkImports::CreateService, :clean_gitlab_redis_shared_state, fea
             expect(result).to be_a(ServiceResponse)
             expect(result).to be_error
             expect(result.message)
-              .to eq("Import failed. Destination '#{parent_group.path}' is invalid, " \
-                     "or you don't have permission.")
+              .to eq("Import failed. '#{parent_group.path}' is invalid, " \
+                     "or you do not have permission.")
           end
         end
       end
@@ -811,7 +869,7 @@ RSpec.describe BulkImports::CreateService, :clean_gitlab_redis_shared_state, fea
             expect(result).to be_error
             expect(result.message)
               .to eq(
-                "Import failed. Destination URL " \
+                "Import failed. The destination URL " \
                 "can only include non-accented letters, digits, '_', '-' and '.'. " \
                 "It must not start with '-', '_', or '.', nor end with '-', '_', '.', '.git', or '.atom'."
               )
