@@ -196,13 +196,11 @@ RSpec.describe Ci::CreateDownstreamPipelineService, '#execute', feature_category
         let(:trigger) do
           {
             trigger: {
-              include: {
-                project: downstream_project.full_path,
-                file: '.gitlab-ci.yml',
-                inputs: {
-                  stage: 'deploy',
-                  suffix: 'build'
-                }
+              project: downstream_project.full_path,
+              file: '.gitlab-ci.yml',
+              inputs: {
+                stage: 'deploy',
+                suffix: 'build'
               }
             }
           }
@@ -214,6 +212,15 @@ RSpec.describe Ci::CreateDownstreamPipelineService, '#execute', feature_category
         end
 
         it_behaves_like 'creates a downstream pipeline with the inputs provided'
+
+        it 'tracks the usage of inputs' do
+          expect { subject }.to trigger_internal_events('create_pipeline_with_inputs').with(
+            category: 'Gitlab::Ci::Pipeline::Chain::Metrics',
+            additional_properties: { value: 2, label: 'pipeline', property: 'repository_source' },
+            project: downstream_project,
+            user: user
+          )
+        end
       end
 
       context 'when the downstream pipeline is for the same project' do
@@ -238,6 +245,12 @@ RSpec.describe Ci::CreateDownstreamPipelineService, '#execute', feature_category
         end
 
         it_behaves_like 'creates a downstream pipeline with the inputs provided'
+
+        it 'does not track the usage of inputs because the inputs are in the internal include' do
+          expect { subject }.not_to trigger_internal_events('create_pipeline_with_inputs')
+
+          subject
+        end
       end
     end
 
@@ -330,6 +343,14 @@ RSpec.describe Ci::CreateDownstreamPipelineService, '#execute', feature_category
             echo: { script: 'echo' })
         end
 
+        let(:stub_config) { false }
+
+        let(:trigger) do
+          {
+            trigger: { include: 'child-pipeline.yml' }
+          }
+        end
+
         shared_examples 'creates a child pipeline' do
           it 'creates only one new pipeline' do
             expect { subject }
@@ -359,7 +380,7 @@ RSpec.describe Ci::CreateDownstreamPipelineService, '#execute', feature_category
             expect(pipeline.target_sha).to eq(upstream_pipeline.target_sha)
             expect(pipeline.target_sha).to eq(upstream_pipeline.target_sha)
 
-            expect(pipeline.trigger_requests.last).to eq(bridge.trigger_request)
+            expect(pipeline.trigger).to eq(bridge.trigger)
           end
         end
 
@@ -370,14 +391,6 @@ RSpec.describe Ci::CreateDownstreamPipelineService, '#execute', feature_category
           upstream_pipeline.update!(sha: upstream_project.commit.id)
         end
 
-        let(:stub_config) { false }
-
-        let(:trigger) do
-          {
-            trigger: { include: 'child-pipeline.yml' }
-          }
-        end
-
         it_behaves_like 'creates a child pipeline'
 
         it_behaves_like 'logs downstream pipeline creation' do
@@ -392,16 +405,27 @@ RSpec.describe Ci::CreateDownstreamPipelineService, '#execute', feature_category
           expect(subject).to be_success
         end
 
-        context 'when bridge uses "depend" strategy' do
+        context 'when bridge has strategy: depend' do
           let(:trigger) do
             {
               trigger: { include: 'child-pipeline.yml', strategy: 'depend' }
             }
           end
 
-          it 'update the bridge job to running status' do
+          it 'updates the bridge status to `running`' do
+            expect { subject }.to change { bridge.status }.from('pending').to('running')
+          end
+        end
+
+        context 'when bridge has strategy: mirror' do
+          let(:trigger) do
+            {
+              trigger: { include: 'child-pipeline.yml', strategy: 'mirror' }
+            }
+          end
+
+          it 'updates the bridge status to `running`' do
             expect { subject }.to change { bridge.status }.from('pending').to('running')
-            expect(subject).to be_success
           end
         end
 
@@ -510,8 +534,7 @@ RSpec.describe Ci::CreateDownstreamPipelineService, '#execute', feature_category
           before do
             bridge.yaml_variables = [{ key: 'BRIDGE', value: '$PIPELINE_VARIABLE-var', public: true }]
 
-            upstream_pipeline.project.update!(restrict_user_defined_variables: true,
-              ci_pipeline_variables_minimum_override_role: :maintainer)
+            upstream_pipeline.project.update!(ci_pipeline_variables_minimum_override_role: :maintainer)
           end
 
           it 'creates a new pipeline allowing variables to be passed downstream' do
@@ -740,8 +763,7 @@ RSpec.describe Ci::CreateDownstreamPipelineService, '#execute', feature_category
 
         context 'when downstream project does not allow user-defined variables for multi-project pipelines' do
           before do
-            downstream_project.update!(restrict_user_defined_variables: true,
-              ci_pipeline_variables_minimum_override_role: :maintainer)
+            downstream_project.update!(ci_pipeline_variables_minimum_override_role: :maintainer)
           end
 
           it 'does not create a new pipeline' do
@@ -998,6 +1020,100 @@ RSpec.describe Ci::CreateDownstreamPipelineService, '#execute', feature_category
         end
       end
     end
+
+    context 'when trigger:include:artifact is used' do
+      let(:stub_config) { false }
+
+      let!(:build_job) { create(:ci_build, pipeline: upstream_pipeline, name: 'build') }
+
+      let!(:deploy_artifact) do
+        create(:ci_job_artifact, :public, :archive, job: build_job, expire_at: build_job.artifacts_expire_at)
+      end
+
+      let(:trigger) do
+        { trigger: { include: [{ job: 'build', artifact: 'deploy.yml' }] } }
+      end
+
+      before do
+        # We need to create a metadata artifact, otherwise we can't extract the deploy.yml artifact.
+        create(:ci_job_artifact, :metadata, :public, job: build_job, expire_at: build_job.artifacts_expire_at)
+        build_job.reload
+
+        allow_next_instance_of(Gitlab::Ci::ArtifactFileReader) do |reader|
+          allow(reader).to receive(:read).with('deploy.yml', max_size: anything).and_return(artifact_content)
+        end
+      end
+
+      context 'when the artifact is a job definition' do
+        let(:artifact_content) do
+          <<~YAML
+            deploy:
+              script: run deploy
+          YAML
+        end
+
+        it 'creates the downstream pipeline successfully' do
+          expect { subject }.to change(Ci::Pipeline, :count).by(1)
+          expect(subject).to be_success
+
+          pipeline = subject.payload
+
+          expect(pipeline.builds.map(&:name)).to contain_exactly('deploy')
+        end
+      end
+
+      context 'when the artifact is an include definition' do
+        let(:artifact_content) do
+          <<~YAML
+            include: 'test.yml'
+          YAML
+        end
+
+        let(:test_content) do
+          <<~YAML
+            test:
+              script: run tests
+          YAML
+        end
+
+        before do
+          upstream_project.repository.create_file(
+            user, 'test.yml', test_content, message: 'message', branch_name: upstream_project.default_branch
+          )
+          upstream_pipeline.update!(sha: upstream_project.commit.id)
+        end
+
+        it 'creates the downstream pipeline successfully' do
+          expect { subject }.to change(Ci::Pipeline, :count).by(1)
+          expect(subject).to be_success
+
+          pipeline = subject.payload
+
+          expect(pipeline.builds.map(&:name)).to contain_exactly('test')
+        end
+
+        context 'when the include definition contains a variable' do
+          let(:artifact_content) do
+            <<~YAML
+              include: "$FILE_PATH.yml"
+            YAML
+          end
+
+          before do
+            upstream_project.variables.create!(key: 'FILE_PATH', value: 'test')
+          end
+
+          it 'creates the downstream pipeline successfully' do
+            expect { subject }.to change(Ci::Pipeline, :count).by(1)
+            expect(subject).to be_success
+
+            pipeline = subject.payload
+
+            expect(pipeline.builds.map(&:name)).to contain_exactly('test')
+          end
+        end
+      end
+    end
   end
 
   context 'when downstream pipeline creation fails with unexpected errors', :aggregate_failures do
@@ -1011,7 +1127,7 @@ RSpec.describe Ci::CreateDownstreamPipelineService, '#execute', feature_category
     it 'drops the bridge without creating a pipeline' do
       expect { subject }
         .to raise_error(RuntimeError, /undefined failure/)
-        .and change { Ci::Pipeline.count }.by(0)
+        .and not_change { Ci::Pipeline.count }
 
       expect(bridge.reload).to be_failed
       expect(bridge.failure_reason).to eq('data_integrity_failure')
