@@ -6,9 +6,10 @@ RSpec.describe Ci::RetryPipelineService, '#execute', feature_category: :continuo
   include ProjectForksHelper
 
   let_it_be_with_refind(:user) { create(:user) }
-  let_it_be_with_refind(:project) { create(:project) }
+  let_it_be_with_refind(:project) { create(:project, :repository) }
 
-  let(:pipeline) { create(:ci_pipeline, project: project) }
+  let(:sha) { project.repository.commit.sha }
+  let(:pipeline) { create(:ci_pipeline, sha: sha, project: project) }
   let(:build_stage) { create(:ci_stage, name: 'build', position: 0, pipeline: pipeline) }
   let(:test_stage) { create(:ci_stage, name: 'test', position: 1, pipeline: pipeline) }
   let(:deploy_stage) { create(:ci_stage, name: 'deploy', position: 2, pipeline: pipeline) }
@@ -49,6 +50,11 @@ RSpec.describe Ci::RetryPipelineService, '#execute', feature_category: :continuo
         expect(build('rspec 3')).to be_pending
         expect(pipeline.reload).to be_running
       end
+
+      it 'preloads the job definition instances' do
+        expect { service.execute(pipeline) }
+          .to match_query_count(1).for_model(Ci::JobDefinitionInstance)
+      end
     end
 
     context 'when there are failed or canceled builds in the first stage' do
@@ -322,28 +328,21 @@ RSpec.describe Ci::RetryPipelineService, '#execute', feature_category: :continuo
       end
     end
 
-    context 'when the pipeline is a downstream pipeline and the bridge is depended' do
-      let!(:bridge) { create(:ci_bridge, :strategy_depend, status: 'success') }
-
+    shared_examples 'updates the bridge status when authorized' do
       before do
         create(:ci_sources_pipeline, pipeline: pipeline, source_job: bridge)
       end
 
-      context 'without permission' do
-        it 'does nothing to the bridge' do
+      context 'without authorization' do
+        it 'does not change the bridge status' do
           expect { service.execute(pipeline) }.to not_change { bridge.reload.status }
            .and not_change { bridge.reload.user }
         end
       end
 
-      context 'with permission' do
-        let!(:bridge_pipeline) { create(:ci_pipeline, project: create(:project)) }
-        let!(:bridge) do
-          create(:ci_bridge, :strategy_depend, status: 'success', pipeline: bridge_pipeline)
-        end
-
+      context 'with authorization' do
         before do
-          bridge_pipeline.project.add_maintainer(user)
+          downstream_pipeline.project.add_maintainer(user)
         end
 
         it 'marks source bridge as pending' do
@@ -356,6 +355,22 @@ RSpec.describe Ci::RetryPipelineService, '#execute', feature_category: :continuo
       end
     end
 
+    context 'when the pipeline is a downstream pipeline and the bridge status has a strategy' do
+      let!(:downstream_pipeline) { create(:ci_pipeline, project: create(:project)) }
+
+      context 'when the strategy is `depend`' do
+        let!(:bridge) { create(:ci_bridge, :strategy_depend, status: 'success', pipeline: downstream_pipeline) }
+
+        it_behaves_like 'updates the bridge status when authorized'
+      end
+
+      context 'when the strategy is `mirror`' do
+        let!(:bridge) { create(:ci_bridge, :strategy_mirror, status: 'success', pipeline: downstream_pipeline) }
+
+        it_behaves_like 'updates the bridge status when authorized'
+      end
+    end
+
     context 'when there are skipped jobs in later stages' do
       before do
         create_build('build 1', :success, build_stage)
@@ -461,9 +476,10 @@ RSpec.describe Ci::RetryPipelineService, '#execute', feature_category: :continuo
 
   context 'when maintainer is allowed to push to forked project' do
     let(:user) { create(:user) }
-    let(:project) { create(:project, :public) }
-    let(:forked_project) { fork_project(project) }
-    let(:pipeline) { create(:ci_pipeline, project: forked_project, ref: 'fixes') }
+    let(:project) { create(:project, :public, :repository) }
+    let(:forked_project) { fork_project(project, nil, repository: true) }
+    let(:sha) { forked_project.repository.commit.sha }
+    let(:pipeline) { create(:ci_pipeline, sha: sha, project: forked_project, ref: 'fixes') }
 
     before do
       project.add_maintainer(user)
