@@ -307,6 +307,14 @@ RSpec.describe MergeRequests::UpdateService, :mailer, feature_category: :code_re
 
           update_merge_request(reviewer_ids: [user.id])
         end
+
+        it 'sets reviewer state as approved if user has previously approved' do
+          create(:approval, merge_request: merge_request, user: user)
+
+          update_merge_request(reviewer_ids: [user.id])
+
+          expect(merge_request.find_reviewer(user)).to be_approved
+        end
       end
 
       it 'creates a resource label event' do
@@ -322,10 +330,10 @@ RSpec.describe MergeRequests::UpdateService, :mailer, feature_category: :code_re
       it 'creates system note about title change' do
         update_merge_request(opts)
 
-        note = find_note('changed title')
+        note = find_note('<p>changed title')
 
         expect(note).not_to be_nil
-        expect(note.note).to eq 'changed title from **{-Old-} title** to **{+New+} title**'
+        expect(note.note).to eq '<p>changed title from <code class="idiff"><span class="idiff left right deletion">Old</span> title</code> to <code class="idiff"><span class="idiff left right addition">New</span> title</code></p>'
       end
 
       it 'creates system note about description change' do
@@ -732,6 +740,7 @@ RSpec.describe MergeRequests::UpdateService, :mailer, feature_category: :code_re
         end
 
         it 'triggers GraphQL subscription userMergeRequestUpdated' do
+          expect(GraphqlTriggers).to receive(:user_merge_request_updated).with(merge_request.author, merge_request)
           expect(GraphqlTriggers).to receive(:user_merge_request_updated).with(user3, merge_request)
           expect(GraphqlTriggers).to receive(:user_merge_request_updated).with(user2, merge_request)
 
@@ -1109,6 +1118,48 @@ RSpec.describe MergeRequests::UpdateService, :mailer, feature_category: :code_re
       end
     end
 
+    describe 'AutoMerge::TitleDescriptionUpdateEvent' do
+      let(:auto_merge_enabled) { true }
+      let(:title_regex) { 'test' }
+      let(:description) { 'description' }
+
+      before do
+        merge_request.update!(auto_merge_enabled: true, merge_user: user) if auto_merge_enabled
+        project.update!(merge_request_title_regex_description: description, merge_request_title_regex: title_regex)
+      end
+
+      context 'when the title changes' do
+        let(:update_params) { { title: 'New title' } }
+
+        context 'when project has a required regex' do
+          context 'when auto merge is enabled' do
+            it_behaves_like 'it publishes the AutoMerge::TitleDescriptionUpdateEvent once'
+
+            context 'when merge_request_title_regex ff is off' do
+              before do
+                stub_feature_flags(merge_request_title_regex: false)
+              end
+
+              it_behaves_like 'it does not publish the AutoMerge::TitleDescriptionUpdateEvent'
+            end
+          end
+
+          context 'when auto merge is not enabled' do
+            let(:auto_merge_enabled) { false }
+
+            it_behaves_like 'it does not publish the AutoMerge::TitleDescriptionUpdateEvent'
+          end
+        end
+
+        context 'when project has no required regex' do
+          let(:title_regex) { nil }
+          let(:description) { nil }
+
+          it_behaves_like 'it does not publish the AutoMerge::TitleDescriptionUpdateEvent'
+        end
+      end
+    end
+
     context 'while saving references to issues that the updated merge request closes', :aggregate_failures do
       let_it_be(:user) { create(:user) }
       let_it_be(:group) { create(:group, :public) }
@@ -1121,6 +1172,7 @@ RSpec.describe MergeRequests::UpdateService, :mailer, feature_category: :code_re
         it 'triggers a workItemUpdated subscription for all affected records' do
           service = described_class.new(project: project, current_user: user, params: update_params)
           allow(service).to receive(:execute_hooks)
+          allow(GraphqlTriggers).to receive(:work_item_updated).and_call_original
 
           WorkItem.where(id: issues_to_notify).find_each do |work_item|
             expect(GraphqlTriggers).to receive(:work_item_updated).with(work_item).once.and_call_original
