@@ -18,11 +18,11 @@ RSpec.describe Projects::CreateService, '#execute', feature_category: :groups_an
     subject(:project) { create_project(user, opts) }
 
     before_all do
-      Label.create!(title: 'bug', template: true)
+      create(:admin_label, title: 'bug', template: true)
     end
 
     it 'creates labels on project creation' do
-      expect(project.labels).to include have_attributes(
+      expect(project.reload.labels).to include have_attributes(
         type: eq('ProjectLabel'),
         project_id: eq(project.id),
         title: eq('bug')
@@ -31,11 +31,12 @@ RSpec.describe Projects::CreateService, '#execute', feature_category: :groups_an
 
     context 'using gitlab project import' do
       before do
+        stub_application_setting(import_sources: %w[gitlab_project])
         opts[:import_type] = 'gitlab_project'
       end
 
       it 'does not creates labels on project creation' do
-        expect(project.labels.size).to eq(0)
+        expect(project.reload.labels).to be_empty
       end
     end
   end
@@ -235,25 +236,6 @@ RSpec.describe Projects::CreateService, '#execute', feature_category: :groups_an
 
         create_proj
       end
-
-      context 'when project_authorizations_update_in_background feature flag is disabled' do
-        before do
-          stub_feature_flags(project_authorizations_update_in_background: false)
-        end
-
-        it 'calls refresh_members_authorized_projects on the project\'s group with correct params' do
-          expect_next_instances_of(Project, 4) do |instance|
-            allow(group).to receive(:refresh_members_authorized_projects)
-            allow(instance).to receive(:group).and_return(group)
-          end
-
-          create_proj
-
-          expect(group).to have_received(:refresh_members_authorized_projects).with(
-            priority: ::UserProjectAccessChangedService::LOW_PRIORITY
-          )
-        end
-      end
     end
   end
 
@@ -907,6 +889,22 @@ RSpec.describe Projects::CreateService, '#execute', feature_category: :groups_an
     end
   end
 
+  context 'when Secret Detection initialization is requested' do
+    let(:project) { create_project(user, opts) }
+
+    before do
+      opts[:initialize_with_secret_detection] = '1'
+      allow(Gitlab::CurrentSettings).to receive(:default_branch_name).and_return('main')
+    end
+
+    it 'creates a commit for Secret Detection', :aggregate_failures do
+      expect(project.repository.commit_count).to be(1)
+      expect(project.repository.commit.message).to eq(
+        'Configure Secret Detection in `.gitlab-ci.yml`, creating this file if it does not already exist'
+      )
+    end
+  end
+
   context 'when SHA256 format is requested' do
     let(:project) { create_project(user, opts) }
     let(:opts) { super().merge(initialize_with_readme: true, repository_object_format: 'sha256') }
@@ -973,16 +971,16 @@ RSpec.describe Projects::CreateService, '#execute', feature_category: :groups_an
     end
 
     context 'with an active instance-level integration' do
-      let!(:instance_integration) { create(:prometheus_integration, :instance, api_url: 'https://prometheus.instance.com/') }
+      let!(:instance_integration) { create(:confluence_integration, :instance, confluence_url: 'https://instance.atlassian.net/wiki') }
 
       it 'creates an integration from the instance-level integration' do
         expect(project.integrations.count).to eq(1)
-        expect(project.integrations.first.api_url).to eq(instance_integration.api_url)
+        expect(project.integrations.first.confluence_url).to eq(instance_integration.confluence_url)
         expect(project.integrations.first.inherit_from_id).to eq(instance_integration.id)
       end
 
       context 'with an active group-level integration' do
-        let!(:group_integration) { create(:prometheus_integration, :group, group: group, api_url: 'https://prometheus.group.com/') }
+        let!(:group_integration) { create(:confluence_integration, :group, group: group, confluence_url: 'https://group.atlassian.net/wiki') }
         let!(:group) do
           create(:group).tap do |group|
             group.add_owner(user)
@@ -998,12 +996,12 @@ RSpec.describe Projects::CreateService, '#execute', feature_category: :groups_an
 
         it 'creates an integration from the group-level integration' do
           expect(project.integrations.count).to eq(1)
-          expect(project.integrations.first.api_url).to eq(group_integration.api_url)
+          expect(project.integrations.first.confluence_url).to eq(group_integration.confluence_url)
           expect(project.integrations.first.inherit_from_id).to eq(group_integration.id)
         end
 
         context 'with an active subgroup' do
-          let!(:subgroup_integration) { create(:prometheus_integration, :group, group: subgroup, api_url: 'https://prometheus.subgroup.com/') }
+          let!(:subgroup_integration) { create(:confluence_integration, :group, group: subgroup, confluence_url: 'https://subgroup.atlassian.net/wiki') }
           let!(:subgroup) do
             create(:group, parent: group).tap do |subgroup|
               subgroup.add_owner(user)
@@ -1019,7 +1017,7 @@ RSpec.describe Projects::CreateService, '#execute', feature_category: :groups_an
 
           it 'creates an integration from the subgroup-level integration' do
             expect(project.integrations.count).to eq(1)
-            expect(project.integrations.first.api_url).to eq(subgroup_integration.api_url)
+            expect(project.integrations.first.confluence_url).to eq(subgroup_integration.confluence_url)
             expect(project.integrations.first.inherit_from_id).to eq(subgroup_integration.id)
           end
         end
@@ -1366,16 +1364,49 @@ RSpec.describe Projects::CreateService, '#execute', feature_category: :groups_an
     end
   end
 
-  it 'adds pages unique domain', feature_category: :pages do
-    stub_pages_setting(enabled: true)
+  context 'pages unique domain default setting' do
+    before do
+      stub_pages_setting(enabled: true)
+    end
 
-    expect(Gitlab::Pages)
-    .to receive(:add_unique_domain_to)
-    .and_call_original
+    context 'when pages_unique_domain_default_enabled is true' do
+      before do
+        stub_application_setting(pages_unique_domain_default_enabled: true)
+      end
 
-    project = create_project(user, opts)
+      it 'adds pages unique domain', feature_category: :pages do
+        expect(Gitlab::Pages)
+          .to receive(:add_unique_domain_to)
+          .and_call_original
 
-    expect(project.project_setting.pages_unique_domain_enabled).to eq(true)
-    expect(project.project_setting.pages_unique_domain).to be_present
+        project = create_project(user, opts)
+
+        expect(project.project_setting.pages_unique_domain_enabled).to eq(true)
+        expect(project.project_setting.pages_unique_domain).to be_present
+      end
+    end
+
+    context 'when pages_unique_domain_default_enabled is false' do
+      before do
+        stub_application_setting(pages_unique_domain_default_enabled: false)
+      end
+
+      it 'does not add pages unique domain', feature_category: :pages do
+        expect(Gitlab::Pages)
+          .not_to receive(:add_unique_domain_to)
+
+        project = create_project(user, opts)
+
+        expect(project.project_setting.pages_unique_domain_enabled).to eq(false)
+        expect(project.project_setting.pages_unique_domain).to be_nil
+      end
+    end
+  end
+
+  context 'setting protect_merge_request_pipelines settings' do
+    it 'sets the protect_merge_request_pipelines setting as true by default' do
+      project = create_project(user, opts)
+      expect(project.protect_merge_request_pipelines).to be_truthy
+    end
   end
 end
