@@ -70,7 +70,7 @@ RSpec.shared_examples 'work items comments' do |type|
         click_button _('More actions')
 
         expect(page).to have_button _('Copy link')
-        expect(page).to have_button _('Assign to commenting user')
+        expect(page).to have_button _('Assign to comment author')
         expect(page).to have_button _('Delete comment')
         expect(page).to have_button _('Edit comment')
       end
@@ -237,6 +237,27 @@ RSpec.shared_examples 'work items labels' do |namespace_type|
 end
 
 RSpec.shared_examples 'work items description' do
+  it 'shows heading anchor links when headings are hovered' do
+    click_button 'Edit', match: :first
+    fill_in _('Description'), with: '## Heading'
+    click_button 'Save'
+
+    within_testid('work-item-description') do
+      find('h2').hover
+
+      skiplink = find('h2 a[href="#heading"]')
+
+      expect(skiplink).to be_visible
+
+      # The visibility of pseudoelements cannot be checked with have_css, so we need to use evaluate_script
+      after_visibility = skiplink.evaluate_script(
+        "window.getComputedStyle(this, '::after').getPropertyValue('visibility')"
+      )
+
+      expect(after_visibility).to eq('visible')
+    end
+  end
+
   it 'shows GLFM autocomplete' do
     click_button 'Edit', match: :first
     fill_in _('Description'), with: "@#{user.username}"
@@ -389,7 +410,7 @@ RSpec.shared_examples 'authored work item guest user permissions' do
       click_button _('More actions'), match: :first
 
       expect(page).to have_button _('Copy link')
-      expect(page).not_to have_button _('Assign to commenting user')
+      expect(page).not_to have_button _('Assign to comment author')
     end
   end
 end
@@ -418,7 +439,7 @@ RSpec.shared_examples 'non-authored work item guest user permissions' do
       click_button _('More actions'), match: :first
 
       expect(page).to have_button _('Copy link')
-      expect(page).not_to have_button _('Assign to commenting user')
+      expect(page).not_to have_button _('Assign to comment author')
     end
   end
 end
@@ -439,18 +460,17 @@ RSpec.shared_examples 'work items notifications' do
   end
 end
 
-RSpec.shared_examples 'work items lock discussion' do |type|
+RSpec.shared_examples 'work items lock discussion' do
   it 'locks and unlocks discussion', :aggregate_failures do
     click_button _('More actions'), match: :first
     click_button 'Lock discussion'
-    click_button _('More actions'), match: :first # click again to close the dropdown
 
-    expect(page).to have_text "The discussion in this #{type} is locked. Only project members can comment."
+    expect(page).to have_text "Discussion is locked. Only members can comment."
 
     click_button _('More actions'), match: :first
     click_button 'Unlock discussion'
 
-    expect(page).not_to have_text "The discussion in this #{type} is locked. Only project members can comment."
+    expect(page).not_to have_text "Discussion is locked. Only members can comment."
   end
 end
 
@@ -459,12 +479,13 @@ RSpec.shared_examples 'work items confidentiality' do
     click_button _('More actions'), match: :first
     click_button 'Turn on confidentiality'
 
+    expect(page).to have_no_css('[data-testid="confidentiality-toggle-action"]', wait: 5)
     expect(page).to have_css('.gl-badge', text: 'Confidential')
 
     click_button _('More actions'), match: :first
     click_button 'Turn off confidentiality'
 
-    expect(page).not_to have_css('.gl-badge', text: 'Confidential')
+    expect(page).not_to have_css('.gl-badge', text: 'Confidential', wait: 5)
   end
 end
 
@@ -546,6 +567,27 @@ RSpec.shared_examples 'work items parent' do |type|
       expect(page).not_to have_link(work_item_parent.title)
     end
   end
+
+  it 'adds and removes parent from the breadcrumb', :aggregate_failures do
+    within_testid 'work-item-parent' do
+      click_button 'Edit'
+      send_keys(work_item_parent.title)
+      select_listbox_item(work_item_parent.title)
+    end
+
+    within_testid 'ancestors-breadcrumb' do
+      expect(page).to have_link(work_item_parent.title)
+    end
+
+    page.refresh
+
+    within_testid 'work-item-parent' do
+      click_button 'Edit'
+      click_button 'Clear'
+    end
+
+    expect(page).not_to have_selector('[data-testid="ancestors-breadcrumb"]')
+  end
 end
 
 def find_and_click_edit(selector)
@@ -641,6 +683,8 @@ RSpec.shared_examples 'work items iteration' do
 end
 
 RSpec.shared_examples 'work items time tracking' do
+  include WorkItemsHelpers
+
   it 'passes axe automated accessibility testing for estimate and time spent modals', :aggregate_failures do
     click_button 'estimate'
 
@@ -655,11 +699,7 @@ RSpec.shared_examples 'work items time tracking' do
   end
 
   it 'adds and removes an estimate', :aggregate_failures do
-    click_button 'estimate'
-    within_testid 'set-time-estimate-modal' do
-      fill_in 'Estimate', with: '5d'
-      click_button 'Save'
-    end
+    add_estimate('5d')
 
     expect(page).to have_text 'Estimate 5d'
     expect(page).to have_button '5d'
@@ -676,21 +716,9 @@ RSpec.shared_examples 'work items time tracking' do
   end
 
   it 'adds and deletes time entries and view report', :aggregate_failures do
-    click_button 'Add time entry'
+    add_time_entry('1d', 'First summary')
 
-    within_testid 'create-timelog-modal' do
-      fill_in 'Time spent', with: '1d'
-      fill_in 'Summary', with: 'First summary'
-      click_button 'Save'
-    end
-
-    click_button 'Add time entry'
-
-    within_testid 'create-timelog-modal' do
-      fill_in 'Time spent', with: '2d'
-      fill_in 'Summary', with: 'Second summary'
-      click_button 'Save'
-    end
+    add_time_entry('2d', 'Second summary')
 
     expect(page).to have_text 'Spent 3d'
     expect(page).to have_button '3d'
@@ -713,6 +741,52 @@ RSpec.shared_examples 'work items time tracking' do
     expect(page).to have_text 'Spent 1d'
     expect(page).to have_button '1d'
   end
+
+  it 'checks for progess bar with both time entries and estimate', :aggregate_failures do
+    add_estimate('5d')
+
+    expect(page).to have_text 'Estimate 5d'
+    expect(page).to have_button '5d'
+    expect(page).not_to have_button 'estimate'
+
+    add_time_entry('1d')
+
+    expect(page).to have_text 'Spent 1d'
+    expect(page).to have_button '1d'
+
+    within_testid 'time-tracking-body' do
+      expect(page).to have_selector('[role="progressbar"][aria-valuenow="20"]')
+    end
+  end
+
+  it 'using quick actions', :aggregate_failures do
+    add_estimate('5d')
+
+    expect(page).to have_text 'Estimate 5d'
+    expect(page).to have_button '5d'
+    expect(page).not_to have_button 'estimate'
+
+    add_time_entry('1d')
+
+    expect(page).to have_text 'Spent 1d'
+    expect(page).to have_button '1d'
+
+    fill_in _('Add a reply'), with: '/estimate 4d'
+    click_button "Comment"
+
+    fill_in _('Add a reply'), with: '/spend 1d'
+    click_button "Comment"
+
+    expect(page).to have_text 'Estimate 4d'
+    expect(page).to have_button '4d'
+
+    expect(page).to have_text 'Spent 2d'
+    expect(page).to have_button '2d'
+
+    within_testid 'time-tracking-body' do
+      expect(page).to have_selector('[role="progressbar"][aria-valuenow="50"]')
+    end
+  end
 end
 
 RSpec.shared_examples 'work items crm contacts' do
@@ -737,126 +811,190 @@ RSpec.shared_examples 'work items crm contacts' do
       click_button _('Edit')
       wait_for_requests
 
-      expect(page).to be_axe_clean.within('[data-testid="work-item-crm-contacts"]')
+      expect(page).to be_axe_clean.within_testid('work-item-crm-contacts')
     end
   end
 end
 
 RSpec.shared_examples 'work items progress' do
-  let(:progress_wrapper) { '[data-testid="work-item-progress-wrapper"]' }
-  let(:form_selector) { '[data-testid="work-item-progress"]' }
-  let(:input_selector) { '[data-testid="work-item-progress-input"]' }
-
-  it 'successfully sets the progress' do
-    within(progress_wrapper) do
+  it 'successfully sets the progress, and prevents setting invalid values', :aggregate_failures do
+    within_testid('work-item-progress') do
       click_button 'Edit'
+      fill_in('Progress', with: '30')
+      send_keys(:enter)
+
+      expect(page).to have_content '30%'
+
+      click_button 'Edit'
+      fill_in('Progress', with: '101')
+      click_button 'Apply'
+
+      expect(page).to have_content '30%'
+
+      click_button 'Edit'
+      fill_in('Progress', with: 'e')
+      click_button 'Apply'
+
+      expect(page).to have_content '30%'
+    end
+  end
+end
+
+RSpec.shared_examples 'work items status' do
+  context 'when feature is licensed' do
+    context 'when work_item_status_feature_flag feature flag is enabled' do
+      it 'updates and selects system defined work item status' do
+        within_testid 'work-item-status' do
+          click_button 'Edit'
+          select_listbox_item 'In progress'
+
+          expect(page).to have_text 'In progress'
+        end
+      end
+
+      context 'when namespace has custom status' do
+        let(:custom_status) { create(:work_item_custom_status, name: "Ready for development", namespace: root_group) }
+
+        let(:custom_lifecycle) do
+          create(:work_item_custom_lifecycle, default_open_status: custom_status, namespace: root_group)
+        end
+
+        let!(:type_custom_lifecycle) do
+          create(:work_item_type_custom_lifecycle,
+            lifecycle: custom_lifecycle,
+            work_item_type: work_item.work_item_type,
+            namespace: root_group
+          )
+        end
+
+        before do
+          visit work_items_path
+        end
+
+        it 'selects and updates custom status' do
+          within_testid 'work-item-status' do
+            click_button 'Edit'
+            select_listbox_item 'Ready for development'
+
+            expect(page).to have_text 'Ready for development'
+          end
+        end
+      end
     end
 
-    find(input_selector).fill_in(with: '30')
-    send_keys(:tab) # Simulate blur
+    context 'when work_item_status_feature_flag feature flag is disabled' do
+      before do
+        stub_feature_flags(work_item_status_feature_flag: false)
+        page.refresh
+      end
 
-    wait_for_requests
-
-    expect(find(progress_wrapper)).to have_content "30%"
-    expect(work_item.reload.progress.progress).to eq 30
+      it 'does not show the work item status' do
+        expect(page).not_to have_text 'Status'
+      end
+    end
   end
 
-  it 'prevents typing values outside min and max range', :aggregate_failures do
-    page_body = page.find('body')
-
-    within(progress_wrapper) do
-      click_button 'Edit'
+  context 'when feature is not licensed' do
+    before do
+      stub_licensed_features(work_item_status: false)
+      sign_in(user)
+      visit work_items_path
     end
 
-    page.within(form_selector) do
-      progress_input = find(input_selector)
-      progress_input.native.send_keys('101')
+    it 'does not show the work item status' do
+      expect(page).not_to have_text 'Status'
     end
-
-    page_body.click
-    expect(find(progress_wrapper)).to have_content "0%"
-  end
-
-  it 'prevent typing special characters `+`, `-`, and `e`', :aggregate_failures do
-    page_body = page.find('body')
-
-    within(progress_wrapper) do
-      click_button 'Edit'
-    end
-
-    page.within(form_selector) do
-      find(input_selector).native.send_keys('+')
-    end
-
-    page_body.click
-    expect(find(progress_wrapper)).to have_content "0%"
-
-    within(progress_wrapper) do
-      click_button 'Edit'
-    end
-
-    page.within(form_selector) do
-      find(input_selector).native.send_keys('-')
-    end
-
-    page_body.click
-    expect(find(progress_wrapper)).to have_content "0%"
-
-    within(progress_wrapper) do
-      click_button 'Edit'
-    end
-
-    page.within(form_selector) do
-      find(input_selector).native.send_keys('e')
-    end
-
-    page_body.click
-    expect(find(progress_wrapper)).to have_content "0%"
   end
 end
 
 RSpec.shared_examples 'work items health status' do
-  it 'updates and clears a health status', :aggregate_failures do
+  it 'shows default state with no status' do
+    within_testid 'work-item-health-status' do
+      expect(page).to have_text('None')
+    end
+  end
+
+  it 'shows available statuses in the dropdown' do
+    within_testid 'work-item-health-status' do
+      click_button 'Edit'
+      expect(page).to have_text('Needs attention')
+      expect(page).to have_text('On track')
+      expect(page).to have_text('At risk')
+    end
+  end
+
+  it 'selects a health status' do
+    within_testid 'work-item-health-status' do
+      click_button 'Edit'
+      select_listbox_item 'At risk'
+      expect(page).to have_text('At risk')
+      expect(page).not_to have_text('None')
+    end
+  end
+
+  it 'clears the selected health status' do
+    within_testid 'work-item-health-status' do
+      click_button 'Edit'
+      select_listbox_item 'At risk'
+      expect(page).to have_text('At risk')
+      click_button 'Edit'
+      click_button 'Clear'
+      expect(page).to have_text('None')
+    end
+  end
+
+  it 'shows selected status correctly' do
+    within_testid 'work-item-health-status' do
+      click_button 'Edit'
+      select_listbox_item 'Needs attention'
+      expect(page).to have_text('Needs attention')
+    end
+  end
+
+  it 'changes health status' do
     within_testid 'work-item-health-status' do
       click_button 'Edit'
       select_listbox_item 'On track'
-
-      expect(page).to have_text 'On track'
-
-      click_button 'Edit'
-      select_listbox_item 'Needs attention'
-
-      expect(page).to have_text 'Needs attention'
-
+      expect(page).to have_text('On track')
       click_button 'Edit'
       select_listbox_item 'At risk'
-
-      expect(page).to have_text 'At risk'
-
-      click_button 'Edit'
-      click_button 'Clear'
-
-      expect(page).to have_text('None')
+      expect(page).to have_text('At risk')
+      expect(page).not_to have_text('On track')
     end
   end
 end
 
 RSpec.shared_examples 'work items color' do
+  it 'shows default blue color state' do
+    within_testid 'work-item-color' do
+      expect(page).to have_text('Blue')
+    end
+  end
+
+  it 'shows color selection dropdown when clicked' do
+    within_testid 'work-item-color' do
+      click_button 'Edit'
+      expect(page).to have_css('[data-testid="color-header-title"]')
+      expect(page).to have_text('Select a color')
+      expect(page).to have_css('[data-testid="reset-color"]')
+    end
+  end
+
+  it 'allows color selection and shows selected color' do
+    within_testid 'work-item-color' do
+      click_button 'Edit'
+      expect(page).to have_css('.suggested-colors')
+      within('.suggested-colors') do
+        find('.gl-link', match: :first).click
+      end
+      expect(page).to have_css('[data-testid="color-header-title"]')
+    end
+  end
+
   it 'updates and clears color', :aggregate_failures do
     within_testid 'work-item-color' do
-      click_button 'Edit'
-      click_link 'Purple'
-
-      expect(page).to have_text 'Purple'
-
-      click_button 'Edit'
-      send_keys(:backspace, :backspace, :backspace, :backspace, :backspace, :backspace, 112233, :escape)
-
-      expect(page).to have_text 'Custom'
-
       click_button 'Edit'
       click_button 'Reset'
-
       expect(page).to have_text('Blue')
     end
   end
