@@ -10,14 +10,12 @@ RSpec.describe Ci::Runners::UpdateProjectRunnersOwnerWorker, '#handle_event', fe
     { project_id: project.id, namespace_id: project.namespace_id, root_namespace_id: project.root_namespace.id }
   end
 
-  it_behaves_like 'subscribes to event' do
+  it_behaves_like 'ignores the published event' do
     let(:event) { project_deleted_event }
   end
 
-  it 'calls Ci::Runners::UpdateProjectRunnersOwnerService' do
-    expect_next_instance_of(Ci::Runners::UpdateProjectRunnersOwnerService, project.id) do |service|
-      expect(service).to receive(:execute)
-    end
+  it 'does not call Ci::Runners::UpdateProjectRunnersOwnerService' do
+    expect(Ci::Runners::UpdateProjectRunnersOwnerService).not_to receive(:new)
 
     described_class.new.handle_event(project_deleted_event)
   end
