@@ -150,6 +150,7 @@ RSpec.describe 'Every Sidekiq worker', feature_category: :shared do
         'BulkImports::FinishProjectImportWorker' => 3,
         'BulkImports::TransformReferencesWorker' => 3,
         'Chaos::CpuSpinWorker' => 3,
+        'Chaos::DbSleepWorker' => false,
         'Chaos::DbSpinWorker' => 3,
         'Chaos::KillWorker' => false,
         'Chaos::LeakMemWorker' => 3,
@@ -168,6 +169,7 @@ RSpec.describe 'Every Sidekiq worker', feature_category: :shared do
         'Ci::UpdateBuildNamesWorker' => 3,
         'Ci::MergeRequests::AddTodoWhenBuildFailsWorker' => 3,
         'Ci::Minutes::UpdateProjectAndNamespaceUsageWorker' => 3,
+        'Ci::Minutes::UpdateGitlabHostedRunnerMonthlyUsageWorker' => 3,
         'Ci::PipelineArtifacts::CoverageReportWorker' => 3,
         'Ci::PipelineArtifacts::CreateQualityReportWorker' => 3,
         'Ci::PipelineCleanupRefWorker' => 3,
@@ -207,6 +209,9 @@ RSpec.describe 'Every Sidekiq worker', feature_category: :shared do
         'Database::LockTablesWorker' => false,
         'Database::BatchedBackgroundMigration::CiExecutionWorker' => 0,
         'Database::BatchedBackgroundMigration::MainExecutionWorker' => 0,
+        'Database::BatchedBackgroundMigration::SecExecutionWorker' => 0,
+        'Database::CollationCheckerWorker' => false,
+        'Database::SchemaCheckerWorker' => false,
         'DeleteDiffFilesWorker' => 3,
         'DeleteMergedBranchesWorker' => 3,
         'DeleteStoredFilesWorker' => 3,
@@ -225,10 +230,8 @@ RSpec.describe 'Every Sidekiq worker', feature_category: :shared do
         'DisallowTwoFactorForSubgroupsWorker' => 3,
         'Dora::DailyMetrics::RefreshWorker' => 3,
         'ElasticAssociationIndexerWorker' => 3,
-        'ElasticCommitIndexerWorker' => 2,
         'ElasticDeleteProjectWorker' => 2,
         'ElasticFullIndexWorker' => 2,
-        'ElasticIndexingControlWorker' => 3,
         'ElasticNamespaceIndexerWorker' => 2,
         'ElasticNamespaceRolloutWorker' => 2,
         'EmailReceiverWorker' => 3,
@@ -252,7 +255,6 @@ RSpec.describe 'Every Sidekiq worker', feature_category: :shared do
         'Geo::VerificationBatchWorker' => 0,
         'Geo::VerificationStateBackfillWorker' => false,
         'Geo::VerificationTimeoutWorker' => false,
-        'Geo::VerificationWorker' => 3,
         'Gitlab::BitbucketImport::AdvanceStageWorker' => 6,
         'Gitlab::BitbucketImport::Stage::FinishImportWorker' => 6,
         'Gitlab::BitbucketImport::Stage::ImportIssuesWorker' => 6,
@@ -377,7 +379,6 @@ RSpec.describe 'Every Sidekiq worker', feature_category: :shared do
         'Namespaces::RootStatisticsWorker' => 3,
         'Namespaces::ScheduleAggregationWorker' => 3,
         'Namespaces::RemoveDormantMembersWorker' => 0,
-        'NewEpicWorker' => 3,
         'NewIssueWorker' => 3,
         'NewMergeRequestWorker' => 3,
         'NewNoteWorker' => 3,
@@ -392,6 +393,7 @@ RSpec.describe 'Every Sidekiq worker', feature_category: :shared do
         'Packages::MarkPackageFilesForDestructionWorker' => 3,
         'Packages::Maven::Metadata::SyncWorker' => 3,
         'Packages::Npm::CleanupStaleMetadataCacheWorker' => 0,
+        'Packages::Helm::CleanupStaleMetadataCacheWorker' => 0,
         'Packages::Nuget::CleanupStaleSymbolsWorker' => 0,
         'Packages::Nuget::ExtractionWorker' => 3,
         'Packages::Rubygems::ExtractionWorker' => 3,
@@ -403,7 +405,6 @@ RSpec.describe 'Every Sidekiq worker', feature_category: :shared do
         'PipelineHooksWorker' => 3,
         'PipelineMetricsWorker' => 3,
         'PipelineNotificationWorker' => 3,
-        'PipelineProcessWorker' => 3,
         'PostReceive' => 3,
         'ProcessCommitWorker' => 3,
         'ProductAnalytics::InitializeSnowplowProductAnalyticsWorker' => 1,
@@ -445,17 +446,17 @@ RSpec.describe 'Every Sidekiq worker', feature_category: :shared do
         'RequirementsManagement::ImportRequirementsCsvWorker' => 3,
         'RequirementsManagement::ProcessRequirementsReportsWorker' => 3,
         'RunPipelineScheduleWorker' => 3,
+        'Sbom::BuildDependencyGraphWorker' => 2,
         'ScanSecurityReportSecretsWorker' => 17,
         'Search::ElasticGroupAssociationDeletionWorker' => 3,
         'Search::Elastic::CommitIndexerWorker' => 2,
         'Search::Elastic::DeleteWorker' => 3,
-        'Search::Zoekt::AdjustIndicesReservedStorageBytesEventWorker' => 1,
+        'Search::Zoekt::ForceUpdateOverprovisionedIndexEventWorker' => 1,
         'Search::Zoekt::DeleteProjectEventWorker' => 1,
         'Search::Zoekt::IndexMarkedAsReadyEventWorker' => 1,
         'Search::Zoekt::IndexMarkAsPendingEvictionEventWorker' => 1,
         'Search::Zoekt::IndexMarkedAsToDeleteEventWorker' => 1,
         'Search::Zoekt::IndexToEvictEventWorker' => 1,
-        'Search::Zoekt::IndexWatermarkChangedEventWorker' => 1,
         'Search::Zoekt::InitialIndexingEventWorker' => 1,
         'Search::Zoekt::LostNodeEventWorker' => 1,
         'Search::Zoekt::NodeWithNegativeUnclaimedStorageEventWorker' => 1,
@@ -463,6 +464,7 @@ RSpec.describe 'Every Sidekiq worker', feature_category: :shared do
         'Search::Zoekt::OrphanedRepoEventWorker' => 1,
         'Search::Zoekt::RepoMarkedAsToDeleteEventWorker' => 1,
         'Search::Zoekt::RepoToIndexEventWorker' => 1,
+        'Search::Zoekt::RepoToReindexEventWorker' => 1,
         'Search::Zoekt::TaskFailedEventWorker' => 1,
         'Search::Zoekt::UpdateIndexUsedStorageBytesEventWorker' => 1,
         'Search::Zoekt::SaasRolloutEventWorker' => 1,
@@ -497,7 +499,6 @@ RSpec.describe 'Every Sidekiq worker', feature_category: :shared do
         'Vulnerabilities::Statistics::AdjustmentWorker' => 3,
         'VulnerabilityExports::ExportDeletionWorker' => 3,
         'VulnerabilityExports::ExportWorker' => 3,
-        'VirtualRegistries::Packages::DestroyOrphanCachedResponsesWorker' => 0,
         'VirtualRegistries::Packages::Cache::DestroyOrphanEntriesWorker' => 0,
         'WaitForClusterCreationWorker' => 3,
         'WebHookWorker' => 4,
@@ -511,7 +512,8 @@ RSpec.describe 'Every Sidekiq worker', feature_category: :shared do
         'BulkImports::RelationExportWorker' => 6,
         'Ci::Runners::ExportUsageCsvWorker' => 3,
         'AppSec::ContainerScanning::ScanImageWorker' => 3,
-        'Ci::DestroyOldPipelinesWorker' => 0
+        'Ci::DestroyOldPipelinesWorker' => 0,
+        'AuditEvents::AuditEventStreamingWorker' => 3
       }.merge(extra_retry_exceptions)
     end
 
